CREATE TABLE IF NOT EXISTS `academic_calendars` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `date` date NOT NULL,
  `title` varchar(512) NOT NULL,
  `description` varchar(1024) DEFAULT NULL,
  `session_year_id` bigint(20) unsigned NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `academic_calendars_school_id_foreign` (`school_id`),
  KEY `academic_calendars_session_year_id_foreign` (`session_year_id`),
  CONSTRAINT `academic_calendars_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `academic_calendars_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `addon_subscriptions` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `subscription_id` bigint(20) unsigned DEFAULT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `feature_id` bigint(20) unsigned NOT NULL,
  `price` double(64,4) NOT NULL,
  `start_date` date NOT NULL,
  `end_date` date NOT NULL,
  `status` tinyint(4) NOT NULL DEFAULT 1 COMMENT '0 => Discontinue next billing, 1 => Continue',
  `payment_transaction_id` bigint(20) unsigned DEFAULT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `addon_subscriptions_school_id_foreign` (`school_id`),
  KEY `addon_subscriptions_feature_id_foreign` (`feature_id`),
  KEY `addon_subscriptions_subscription_id_foreign` (`subscription_id`),
  KEY `addon_subscriptions_payment_transaction_id_foreign` (`payment_transaction_id`),
  CONSTRAINT `addon_subscriptions_feature_id_foreign` FOREIGN KEY (`feature_id`) REFERENCES `features` (`id`) ON DELETE CASCADE,
  CONSTRAINT `addon_subscriptions_payment_transaction_id_foreign` FOREIGN KEY (`payment_transaction_id`) REFERENCES `payment_transactions` (`id`) ON DELETE CASCADE,
  CONSTRAINT `addon_subscriptions_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `addon_subscriptions_subscription_id_foreign` FOREIGN KEY (`subscription_id`) REFERENCES `subscriptions` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `announcement_classes` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `announcement_id` bigint(20) unsigned DEFAULT NULL,
  `class_section_id` bigint(20) unsigned DEFAULT NULL,
  `class_subject_id` bigint(20) unsigned DEFAULT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `unique_columns` (`announcement_id`,`class_section_id`,`school_id`),
  KEY `announcement_classes_school_id_foreign` (`school_id`),
  KEY `announcement_classes_announcement_id_index` (`announcement_id`),
  KEY `announcement_classes_class_section_id_index` (`class_section_id`),
  KEY `announcement_classes_class_subject_id_foreign` (`class_subject_id`),
  CONSTRAINT `announcement_classes_announcement_id_foreign` FOREIGN KEY (`announcement_id`) REFERENCES `announcements` (`id`) ON DELETE CASCADE,
  CONSTRAINT `announcement_classes_class_section_id_foreign` FOREIGN KEY (`class_section_id`) REFERENCES `class_sections` (`id`) ON DELETE CASCADE,
  CONSTRAINT `announcement_classes_class_subject_id_foreign` FOREIGN KEY (`class_subject_id`) REFERENCES `class_subjects` (`id`) ON DELETE CASCADE,
  CONSTRAINT `announcement_classes_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=73 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `announcement_classes` VALUES ('7', '7', '21', NULL, '12', '2023-11-20 05:53:09', '2023-11-20 05:53:09');
INSERT INTO `announcement_classes` VALUES ('8', '8', '22', NULL, '12', '2023-11-20 05:54:57', '2023-11-20 05:54:57');
INSERT INTO `announcement_classes` VALUES ('9', '9', '23', NULL, '12', '2023-11-20 05:56:32', '2023-11-20 05:56:32');
INSERT INTO `announcement_classes` VALUES ('10', '10', '24', NULL, '12', '2023-11-20 05:57:00', '2023-11-20 05:57:00');
INSERT INTO `announcement_classes` VALUES ('11', '11', '25', NULL, '12', '2023-11-20 05:57:26', '2024-07-02 17:32:52');
INSERT INTO `announcement_classes` VALUES ('12', '12', '26', NULL, '12', '2023-11-20 05:57:47', '2024-07-02 17:32:33');
INSERT INTO `announcement_classes` VALUES ('13', '13', '27', NULL, '12', '2023-11-20 05:58:11', '2023-11-20 05:58:11');
INSERT INTO `announcement_classes` VALUES ('14', '14', '28', NULL, '12', '2023-11-20 05:58:34', '2023-11-20 05:58:34');
INSERT INTO `announcement_classes` VALUES ('15', '15', '29', NULL, '12', '2023-11-20 05:59:03', '2023-11-20 05:59:03');
INSERT INTO `announcement_classes` VALUES ('16', '16', '31', NULL, '12', '2023-11-20 05:59:29', '2023-11-20 05:59:29');
INSERT INTO `announcement_classes` VALUES ('23', '19', '21', NULL, '12', '2023-11-23 06:21:38', '2024-07-02 17:33:21');
INSERT INTO `announcement_classes` VALUES ('24', '20', '21', NULL, '12', '2023-11-23 06:22:37', '2023-11-23 06:22:37');
INSERT INTO `announcement_classes` VALUES ('26', '21', '29', '127', '12', '2024-05-17 17:17:33', '2024-05-17 17:17:33');
INSERT INTO `announcement_classes` VALUES ('27', '22', '29', '127', '12', '2024-05-17 17:20:13', '2024-05-17 17:20:13');
INSERT INTO `announcement_classes` VALUES ('34', '25', '21', NULL, '12', '2024-07-16 11:01:17', '2024-07-16 11:01:17');
INSERT INTO `announcement_classes` VALUES ('35', '25', '22', NULL, '12', '2024-07-16 11:01:17', '2024-07-16 11:01:17');
INSERT INTO `announcement_classes` VALUES ('36', '25', '55', NULL, '12', '2024-07-16 11:01:17', '2024-07-16 11:01:17');
INSERT INTO `announcement_classes` VALUES ('37', '25', '56', NULL, '12', '2024-07-16 11:01:17', '2024-07-16 11:01:17');
INSERT INTO `announcement_classes` VALUES ('38', '25', '57', NULL, '12', '2024-07-16 11:01:17', '2024-07-16 11:01:17');
INSERT INTO `announcement_classes` VALUES ('39', '25', '58', NULL, '12', '2024-07-16 11:01:17', '2024-07-16 11:01:17');
INSERT INTO `announcement_classes` VALUES ('40', '26', '26', NULL, '12', '2024-07-17 15:01:34', '2024-07-17 15:01:34');
INSERT INTO `announcement_classes` VALUES ('41', '26', '27', NULL, '12', '2024-07-17 15:01:34', '2024-07-17 15:01:34');
INSERT INTO `announcement_classes` VALUES ('42', '27', '26', NULL, '12', '2024-07-17 15:02:38', '2024-07-17 15:02:38');
INSERT INTO `announcement_classes` VALUES ('43', '27', '27', NULL, '12', '2024-07-17 15:02:38', '2024-07-17 15:02:38');
INSERT INTO `announcement_classes` VALUES ('44', '28', '26', NULL, '12', '2024-07-17 15:03:10', '2024-07-17 15:03:10');
INSERT INTO `announcement_classes` VALUES ('45', '28', '27', NULL, '12', '2024-07-17 15:03:10', '2024-07-17 15:03:10');
INSERT INTO `announcement_classes` VALUES ('46', '29', '22', '62', '12', '2024-10-02 21:47:52', '2024-10-02 21:47:52');
INSERT INTO `announcement_classes` VALUES ('47', '30', '21', '46', '12', '2024-10-05 16:43:05', '2024-10-05 16:43:05');
INSERT INTO `announcement_classes` VALUES ('48', '31', '22', '62', '12', '2024-10-09 05:24:13', '2024-10-09 05:24:13');
INSERT INTO `announcement_classes` VALUES ('49', '32', '55', '48', '12', '2024-10-10 02:19:23', '2024-10-10 02:19:23');
INSERT INTO `announcement_classes` VALUES ('50', '33', '57', '56', '12', '2024-10-16 13:00:34', '2024-10-16 13:00:34');
INSERT INTO `announcement_classes` VALUES ('51', '34', '21', '54', '12', '2024-10-23 01:22:06', '2024-10-23 01:22:06');
INSERT INTO `announcement_classes` VALUES ('53', '36', '22', '62', '12', '2024-11-04 20:58:54', '2024-11-04 20:58:54');
INSERT INTO `announcement_classes` VALUES ('54', '37', '22', '61', '12', '2024-11-07 05:55:54', '2024-11-07 05:55:54');
INSERT INTO `announcement_classes` VALUES ('55', '38', '23', '72', '12', '2024-11-17 00:13:14', '2024-11-17 00:13:14');
INSERT INTO `announcement_classes` VALUES ('56', '39', '21', '54', '12', '2024-11-25 12:14:16', '2024-11-25 12:14:16');
INSERT INTO `announcement_classes` VALUES ('57', '40', '22', '61', '12', '2024-11-25 19:47:57', '2024-11-25 19:47:57');
INSERT INTO `announcement_classes` VALUES ('58', '41', '21', '54', '12', '2024-11-30 00:07:32', '2024-11-30 00:07:32');
INSERT INTO `announcement_classes` VALUES ('59', '42', '21', '54', '12', '2024-11-30 00:07:55', '2024-11-30 00:07:55');
INSERT INTO `announcement_classes` VALUES ('60', '43', '21', '54', '12', '2024-11-30 00:08:53', '2024-11-30 00:08:53');
INSERT INTO `announcement_classes` VALUES ('61', '44', '21', '54', '12', '2024-11-30 00:23:46', '2024-11-30 00:23:46');
INSERT INTO `announcement_classes` VALUES ('63', '46', '21', '54', '12', '2024-12-01 10:41:29', '2024-12-01 10:41:29');
INSERT INTO `announcement_classes` VALUES ('64', '47', '22', '63', '12', '2024-12-01 10:41:50', '2024-12-01 10:41:50');
INSERT INTO `announcement_classes` VALUES ('65', '48', '21', '54', '12', '2024-12-07 18:16:41', '2024-12-07 18:16:41');
INSERT INTO `announcement_classes` VALUES ('67', '49', '55', '46', '12', '2024-12-19 06:30:41', '2024-12-19 06:30:41');
INSERT INTO `announcement_classes` VALUES ('69', '50', '55', '46', '12', '2024-12-19 21:15:36', '2024-12-19 21:15:36');
INSERT INTO `announcement_classes` VALUES ('70', '51', '55', '46', '12', '2024-12-23 12:43:52', '2024-12-23 12:43:52');
INSERT INTO `announcement_classes` VALUES ('71', '52', '22', '55', '12', '2024-12-24 05:14:34', '2024-12-24 05:14:34');
INSERT INTO `announcement_classes` VALUES ('72', '24', '55', '46', '12', '2024-12-26 21:12:16', '2024-12-26 21:12:16');

CREATE TABLE IF NOT EXISTS `announcements` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `title` varchar(128) NOT NULL,
  `description` varchar(1024) DEFAULT NULL,
  `session_year_id` bigint(20) unsigned NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `announcements_school_id_foreign` (`school_id`),
  KEY `announcements_session_year_id_foreign` (`session_year_id`),
  CONSTRAINT `announcements_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `announcements_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=53 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `announcements` VALUES ('7', 'Colors Day Celebration', '🌟 Attention Class 1! 🌈

Get ready for \"Colors Day\" next Monday! 🎨 Wear your favorite color and bring a small item to share during show-and-tell. Let\'s make our classroom a rainbow of joy! See you in your colorful best!

Best,
Class Teacher', '17', '12', '2023-11-20 05:53:09', '2023-11-20 05:53:09');
INSERT INTO `announcements` VALUES ('8', 'Book Buddies Day', '🌟 Attention Class 2! 📚

Exciting news! This Friday is \"Book Buddies Day.\" Bring your favorite storybook, and let\'s share tales with a friend. Get ready for a day of reading fun!

See you there!

Best,
Class Teacher', '17', '12', '2023-11-20 05:54:57', '2023-11-20 05:54:57');
INSERT INTO `announcements` VALUES ('9', 'Science Explorers Day', '🌟 Attention Class 3! 🎉
Join us for \"Science Explorers Day\" this Wednesday. Bring your curious minds, and let\'s have fun with exciting experiments!', '17', '12', '2023-11-20 05:56:32', '2023-11-20 05:56:32');
INSERT INTO `announcements` VALUES ('10', 'Math Marvels Challenge', '🌟 Hey Class 4 Superstars! 🚀
Get ready for \"Math Marvels Challenge\" on Friday. Bring your math skills, and let\'s solve some fun puzzles together!

Cheers,
Class Teacher', '17', '12', '2023-11-20 05:57:00', '2023-11-20 05:57:00');
INSERT INTO `announcements` VALUES ('11', 'Geography Quest Day.', '🌟 Calling Class 5 Adventurers! 🌍
This Monday is \"Geography Quest Day.\" Bring your maps and explore the wonders of our world. Let the adventure begin!', '17', '12', '2023-11-20 05:57:26', '2024-07-02 17:32:52');
INSERT INTO `announcements` VALUES ('12', 'History Hunt', '🌟 Greetings Class 6 Explorers! 🚀
Exciting news! We\'re having a \"History Hunt\" this Thursday. Bring your curiosity, and let\'s discover the past together!', '17', '12', '2023-11-20 05:57:47', '2024-07-02 17:32:33');
INSERT INTO `announcements` VALUES ('13', 'Creative Arts Showcase', '🌟 Attention Class 7 Mavericks! 📸
It\'s \"Creative Arts Showcase\" on Wednesday. Bring your artistic creations, and let\'s celebrate the magic of creativity!

Best,
Class teacher', '17', '12', '2023-11-20 05:58:11', '2023-11-20 05:58:11');
INSERT INTO `announcements` VALUES ('14', 'Literary Feast', '🌟 Hey Class 8 Stars! 🌟
Don\'t miss \"Literary Feast\" this Friday. Bring your favorite book or poem, and let\'s share the joy of reading!

Cheers,
Class Teacher', '17', '12', '2023-11-20 05:58:34', '2023-11-20 05:58:34');
INSERT INTO `announcements` VALUES ('15', 'Science Symposium', '🌟 Attention Class 9 Scholars! 🧪
Exciting news! \"Science Symposium\" on Tuesday. Bring your scientific spirit, and let\'s dive into fascinating discussions!

Best,
Class teacher', '17', '12', '2023-11-20 05:59:03', '2023-11-20 05:59:03');
INSERT INTO `announcements` VALUES ('16', 'Career Day', '🌟 Calling Class 10 Achievers! 🌐
Gear up for \"Career Day\" this Thursday. Bring your questions, and let\'s explore exciting career possibilities together!

Cheers,
Class Teacher', '17', '12', '2023-11-20 05:59:29', '2023-11-20 05:59:29');
INSERT INTO `announcements` VALUES ('19', '🎉 Attention Class 1 Students! 🎉', 'Exciting news! Get ready for fun-filled lessons and cool activities coming your way this month. Stay tuned for more updates! 🚀📚', '17', '12', '2023-11-23 06:21:38', '2024-07-02 17:33:21');
INSERT INTO `announcements` VALUES ('20', 'Attention Students!', 'Get ready to showcase your knowledge! The upcoming exams are just around the corner. Remember to review your notes and prepare well. You\'ve got this! 💪✨', '17', '12', '2023-11-23 06:22:37', '2023-11-23 06:22:37');
INSERT INTO `announcements` VALUES ('21', 'Attention English enthusiasts!', 'This is an announcement for all students who love to play with language, explore stories, and hone their writing skills.🏫', '17', '12', '2024-05-17 17:14:20', '2024-05-17 17:17:33');
INSERT INTO `announcements` VALUES ('22', 'Heads Up, Book worms!!', 'This announcement is for all of you who love diving into a good story, exploring the powers words, and mastering the English language', '17', '12', '2024-05-17 17:20:13', '2024-05-17 17:20:13');
INSERT INTO `announcements` VALUES ('24', 'Essay writing competition', 'COMPLETE', '17', '12', '2024-07-16 10:03:42', '2024-12-26 21:12:16');
INSERT INTO `announcements` VALUES ('25', 'Sports day', NULL, '17', '12', '2024-07-16 11:01:17', '2024-07-16 11:01:17');
INSERT INTO `announcements` VALUES ('26', 'Book Fair', 'Book fairs often occur during school hours, but this isn\'t always the case. A book fair can also draw students and parents back into the school building after hours.', '17', '12', '2024-07-17 15:01:34', '2024-07-17 15:01:34');
INSERT INTO `announcements` VALUES ('27', 'Sports Days', 'Speaking of outdoor activities, here\'s one event for schools that\'s always popular and a hit fundraising event. Momentarily bring down the barrier between the teachers and students and get them on the court together at a teacher-student sports day.', '17', '12', '2024-07-17 15:02:38', '2024-07-17 15:02:38');
INSERT INTO `announcements` VALUES ('28', 'Mascot Music Festival', 'Have a bunch of talented musicians at your school? You probably do, whether you know it or not. Get everyone excited by launching your own school-based music festival, named after the mascot of your high school.', '17', '12', '2024-07-17 15:03:10', '2024-07-17 15:03:10');
INSERT INTO `announcements` VALUES ('29', 'yyy', 'hyy', '17', '12', '2024-10-02 21:47:52', '2024-10-02 21:47:52');
INSERT INTO `announcements` VALUES ('30', 'test', 'test', '17', '12', '2024-10-05 16:43:05', '2024-10-05 16:43:05');
INSERT INTO `announcements` VALUES ('31', 'GREETings', 'now please', '17', '12', '2024-10-09 05:24:13', '2024-10-09 05:24:13');
INSERT INTO `announcements` VALUES ('32', 'class assignment updates', 'class assignment will be handing in today. Those who hand in late will loss 15% of their final mark', '17', '12', '2024-10-10 02:19:23', '2024-10-10 02:19:23');
INSERT INTO `announcements` VALUES ('33', 'ok', 'hi', '17', '12', '2024-10-16 13:00:34', '2024-10-16 13:00:34');
INSERT INTO `announcements` VALUES ('34', 'tester', 'hi it works', '17', '12', '2024-10-23 01:22:06', '2024-10-23 01:22:06');
INSERT INTO `announcements` VALUES ('36', 'للب', 'للل', '17', '12', '2024-11-04 20:58:54', '2024-11-04 20:58:54');
INSERT INTO `announcements` VALUES ('37', 'test', 'test', '17', '12', '2024-11-07 05:55:54', '2024-11-07 05:55:54');
INSERT INTO `announcements` VALUES ('38', 'Helo', 'Hello', '17', '12', '2024-11-17 00:13:14', '2024-11-17 00:13:14');
INSERT INTO `announcements` VALUES ('39', 'jejjeje', 'uejejej', '17', '12', '2024-11-25 12:14:16', '2024-11-25 12:14:16');
INSERT INTO `announcements` VALUES ('40', 'music', 'music', '17', '12', '2024-11-25 19:47:57', '2024-11-25 19:47:57');
INSERT INTO `announcements` VALUES ('41', 'some announcement', 'the announcement', '17', '12', '2024-11-30 00:07:32', '2024-11-30 00:07:32');
INSERT INTO `announcements` VALUES ('42', 'some announcement', 'the announcement', '17', '12', '2024-11-30 00:07:55', '2024-11-30 00:07:55');
INSERT INTO `announcements` VALUES ('43', 'just announced', 'doc', '17', '12', '2024-11-30 00:08:53', '2024-11-30 00:08:53');
INSERT INTO `announcements` VALUES ('44', 'announced', 'what annoys', '17', '12', '2024-11-30 00:23:46', '2024-11-30 00:23:46');
INSERT INTO `announcements` VALUES ('46', 'hHH', 'gwsg', '17', '12', '2024-12-01 10:41:29', '2024-12-01 10:41:29');
INSERT INTO `announcements` VALUES ('47', 'test', 'twst', '17', '12', '2024-12-01 10:41:50', '2024-12-01 10:41:50');
INSERT INTO `announcements` VALUES ('48', 'test announcement', 'test', '17', '12', '2024-12-07 18:16:41', '2024-12-07 18:16:41');
INSERT INTO `announcements` VALUES ('49', 'Holiday', 'Tomorrow will be holiday', '17', '12', '2024-12-18 20:49:29', '2024-12-18 20:49:29');
INSERT INTO `announcements` VALUES ('50', 'NO LECTURE', 'THERE WILL BE NO LECTURE CONDUCTED TODAY. YOU ARE REQUESTED TO COMPLETE YOUR HOMEWORK THAT IS UPLOADED ON THE APP. SUBMISSION WILL IN ONLINE MODE. SUBMIT BEFORE DEADLINE.', '17', '12', '2024-12-19 06:33:12', '2024-12-19 21:15:36');
INSERT INTO `announcements` VALUES ('51', 'HOLIDAY', 'DIWALI HOLIDAYS FOR STD 2 AND 12 WILL BE FROM 27TH OCTOBER 2024 TO 3RD OCTOBER  2024. SCHOOL REOPENS ON 4TH NOVEMBER 2024.', '17', '12', '2024-12-23 12:43:52', '2024-12-23 12:43:52');
INSERT INTO `announcements` VALUES ('52', 'test', 'tesr', '17', '12', '2024-12-24 05:14:34', '2024-12-24 05:14:34');

CREATE TABLE IF NOT EXISTS `assignment_commons` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `assignment_id` bigint(20) unsigned NOT NULL,
  `class_section_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `assignment_commons_assignment_id_foreign` (`assignment_id`),
  KEY `assignment_commons_class_section_id_foreign` (`class_section_id`),
  CONSTRAINT `assignment_commons_assignment_id_foreign` FOREIGN KEY (`assignment_id`) REFERENCES `assignments` (`id`) ON DELETE CASCADE,
  CONSTRAINT `assignment_commons_class_section_id_foreign` FOREIGN KEY (`class_section_id`) REFERENCES `class_sections` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=34 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `assignment_commons` VALUES ('1', '6', '21', '2025-01-03 10:51:01', '2025-01-03 10:51:01');
INSERT INTO `assignment_commons` VALUES ('2', '7', '21', '2025-01-03 10:51:01', '2025-01-03 10:51:01');
INSERT INTO `assignment_commons` VALUES ('3', '8', '21', '2025-01-03 10:51:01', '2025-01-03 10:51:01');
INSERT INTO `assignment_commons` VALUES ('4', '9', '21', '2025-01-03 10:51:01', '2025-01-03 10:51:01');
INSERT INTO `assignment_commons` VALUES ('5', '10', '21', '2025-01-03 10:51:01', '2025-01-03 10:51:01');
INSERT INTO `assignment_commons` VALUES ('6', '14', '55', '2025-01-03 10:51:01', '2025-01-03 10:51:01');
INSERT INTO `assignment_commons` VALUES ('7', '15', '55', '2025-01-03 10:51:01', '2025-01-03 10:51:01');
INSERT INTO `assignment_commons` VALUES ('8', '16', '26', '2025-01-03 10:51:01', '2025-01-03 10:51:01');
INSERT INTO `assignment_commons` VALUES ('9', '17', '26', '2025-01-03 10:51:01', '2025-01-03 10:51:01');
INSERT INTO `assignment_commons` VALUES ('10', '18', '26', '2025-01-03 10:51:01', '2025-01-03 10:51:01');
INSERT INTO `assignment_commons` VALUES ('11', '19', '22', '2025-01-03 10:51:01', '2025-01-03 10:51:01');
INSERT INTO `assignment_commons` VALUES ('12', '20', '22', '2025-01-03 10:51:01', '2025-01-03 10:51:01');
INSERT INTO `assignment_commons` VALUES ('13', '21', '57', '2025-01-03 10:51:01', '2025-01-03 10:51:01');
INSERT INTO `assignment_commons` VALUES ('14', '22', '55', '2025-01-03 10:51:01', '2025-01-03 10:51:01');
INSERT INTO `assignment_commons` VALUES ('15', '24', '57', '2025-01-03 10:51:01', '2025-01-03 10:51:01');
INSERT INTO `assignment_commons` VALUES ('16', '26', '22', '2025-01-03 10:51:01', '2025-01-03 10:51:01');
INSERT INTO `assignment_commons` VALUES ('17', '27', '55', '2025-01-03 10:51:01', '2025-01-03 10:51:01');
INSERT INTO `assignment_commons` VALUES ('18', '28', '22', '2025-01-03 10:51:01', '2025-01-03 10:51:01');
INSERT INTO `assignment_commons` VALUES ('19', '29', '55', '2025-01-03 10:51:01', '2025-01-03 10:51:01');
INSERT INTO `assignment_commons` VALUES ('20', '30', '55', '2025-01-03 10:51:01', '2025-01-03 10:51:01');
INSERT INTO `assignment_commons` VALUES ('21', '31', '55', '2025-01-03 10:51:01', '2025-01-03 10:51:01');
INSERT INTO `assignment_commons` VALUES ('23', '33', '55', '2025-01-03 10:51:01', '2025-01-03 10:51:01');

CREATE TABLE IF NOT EXISTS `assignment_submissions` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `assignment_id` bigint(20) unsigned NOT NULL,
  `student_id` bigint(20) unsigned NOT NULL,
  `session_year_id` bigint(20) unsigned NOT NULL,
  `feedback` text DEFAULT NULL,
  `points` int(11) DEFAULT NULL,
  `status` tinyint(4) NOT NULL DEFAULT 0 COMMENT '0 = Pending/In Review , 1 = Accepted , 2 = Rejected , 3 = Resubmitted',
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `assignment_submissions_assignment_id_foreign` (`assignment_id`),
  KEY `assignment_submissions_school_id_foreign` (`school_id`),
  KEY `assignment_submissions_student_id_foreign` (`student_id`),
  KEY `assignment_submissions_session_year_id_foreign` (`session_year_id`),
  CONSTRAINT `assignment_submissions_assignment_id_foreign` FOREIGN KEY (`assignment_id`) REFERENCES `assignments` (`id`) ON DELETE CASCADE,
  CONSTRAINT `assignment_submissions_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `assignment_submissions_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE,
  CONSTRAINT `assignment_submissions_student_id_foreign` FOREIGN KEY (`student_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=12 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `assignment_submissions` VALUES ('4', '7', '331', '17', 'Great work, Excellent', '50', '1', '12', '2023-11-21 09:17:36', '2023-11-21 09:19:44');
INSERT INTO `assignment_submissions` VALUES ('6', '17', '744', '17', NULL, '18', '1', '12', '2024-07-17 15:24:36', '2024-07-17 15:26:16');
INSERT INTO `assignment_submissions` VALUES ('7', '16', '744', '17', NULL, '16', '1', '12', '2024-07-17 15:24:56', '2024-07-17 15:26:27');
INSERT INTO `assignment_submissions` VALUES ('8', '18', '744', '17', 'Great work, Excellent', '25', '1', '12', '2024-07-17 15:25:37', '2024-07-17 15:27:32');
INSERT INTO `assignment_submissions` VALUES ('9', '22', '331', '17', 'Complete again', NULL, '2', '12', '2024-10-16 04:29:54', '2024-12-19 10:57:25');
INSERT INTO `assignment_submissions` VALUES ('10', '27', '331', '17', 'good', NULL, '1', '12', '2024-12-18 03:01:34', '2024-12-19 10:59:58');
INSERT INTO `assignment_submissions` VALUES ('11', '33', '331', '17', NULL, NULL, '0', '12', '2024-12-30 20:40:15', '2024-12-30 20:40:15');

CREATE TABLE IF NOT EXISTS `assignments` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `class_section_id` bigint(20) unsigned NOT NULL,
  `class_subject_id` bigint(20) unsigned NOT NULL,
  `name` varchar(128) NOT NULL,
  `instructions` varchar(1024) DEFAULT NULL,
  `due_date` datetime NOT NULL,
  `points` int(11) DEFAULT NULL,
  `resubmission` tinyint(1) NOT NULL DEFAULT 0,
  `extra_days_for_resubmission` int(11) DEFAULT NULL,
  `session_year_id` bigint(20) unsigned NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_by` bigint(20) unsigned NOT NULL COMMENT 'teacher_user_id',
  `edited_by` bigint(20) unsigned DEFAULT NULL COMMENT 'teacher_user_id',
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `assignments_school_id_foreign` (`school_id`),
  KEY `assignments_class_section_id_foreign` (`class_section_id`),
  KEY `assignments_class_subject_id_foreign` (`class_subject_id`),
  KEY `assignments_session_year_id_foreign` (`session_year_id`),
  KEY `assignments_created_by_foreign` (`created_by`),
  KEY `assignments_edited_by_foreign` (`edited_by`),
  CONSTRAINT `assignments_class_section_id_foreign` FOREIGN KEY (`class_section_id`) REFERENCES `class_sections` (`id`) ON DELETE CASCADE,
  CONSTRAINT `assignments_class_subject_id_foreign` FOREIGN KEY (`class_subject_id`) REFERENCES `class_subjects` (`id`) ON DELETE CASCADE,
  CONSTRAINT `assignments_created_by_foreign` FOREIGN KEY (`created_by`) REFERENCES `users` (`id`) ON DELETE CASCADE,
  CONSTRAINT `assignments_edited_by_foreign` FOREIGN KEY (`edited_by`) REFERENCES `users` (`id`) ON DELETE CASCADE,
  CONSTRAINT `assignments_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `assignments_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=34 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `assignments` VALUES ('6', '21', '47', 'My Family Tree', 'To introduce students to the concept of family and encourage simple drawing skills.

Instructions:

Draw a picture of your family.
Label family members (mom, dad, siblings, etc.).
Share your drawing with the class.', '2024-02-25 11:59:00', '20', '1', '5', '17', '12', '49', '45', '2023-11-21 05:02:14', '2023-11-21 07:49:31');
INSERT INTO `assignments` VALUES ('7', '21', '46', 'Shapes Hunt', 'To identify and recognize basic shapes.

Instructions:

Look around your home or classroom.
Find and draw three different shapes.
Write the names of the shapes (circle, square, triangle).', '2024-02-25 11:59:00', '50', '0', NULL, '17', '12', '49', NULL, '2023-11-21 05:04:11', '2023-11-21 05:04:11');
INSERT INTO `assignments` VALUES ('8', '21', '56', 'Count and Match', 'To reinforce counting skills and matching objects with numbers.

Instructions:

Draw a line to match each number with the correct number of objects.
Count the objects and write the matching number.
Color the pictures for fun!
Example:
Draw a line to match:

3 apples 🍎🍎🍎
2 stars ⭐⭐
1 sun ☀️', '2023-12-31 00:00:00', '20', '1', '3', '17', '12', '43', '49', '2023-11-21 06:47:58', '2024-03-12 12:56:53');
INSERT INTO `assignments` VALUES ('9', '21', '47', 'Word Matching', 'To reinforce basic Hindi vocabulary and improve word-picture association.

Instructions:

Match the Hindi words with the correct pictures.
Draw lines connecting the words to the corresponding images.
Practice saying the words aloud.
Example:
Match \"गुलाब\" with the picture of a rose 🌹.', '2023-12-31 00:00:00', '20', '1', '1', '17', '12', '45', '49', '2023-11-21 06:51:03', '2024-03-12 12:56:27');
INSERT INTO `assignments` VALUES ('10', '21', '91', 'Create a Beat', 'To develop a sense of rhythm and musical expression.

Instructions:

Choose simple household items as instruments (spoons, containers).
Create a rhythmic beat using the items.
Record a short video or perform for the class.
Example:
Create a beat inspired by raindrops.', '2023-12-31 00:00:00', '50', '1', '2', '17', '12', '45', '49', '2023-11-21 06:53:30', '2024-03-12 12:56:16');
INSERT INTO `assignments` VALUES ('14', '55', '46', 'My Dream Vacation', NULL, '2024-07-31 17:00:00', '50', '1', '0', '17', '12', '42', NULL, '2024-07-16 10:10:45', '2024-12-16 22:07:18');
INSERT INTO `assignments` VALUES ('15', '55', '48', 'Basic Maths operations', 'Basic maths operations', '2024-07-31 17:00:00', '25', '0', NULL, '17', '12', '49', NULL, '2024-07-16 10:59:13', '2024-07-16 10:59:13');
INSERT INTO `assignments` VALUES ('16', '26', '91', 'Descriptive Writing', 'My Favorite Place', '2024-07-31 17:00:00', '20', '0', NULL, '17', '12', '49', NULL, '2024-07-17 15:23:25', '2024-07-17 15:23:25');
INSERT INTO `assignments` VALUES ('17', '26', '91', 'Grammar Exercise', 'Identifying Parts of Speech in Sentences', '2024-07-31 17:00:00', '20', '0', NULL, '17', '12', '49', NULL, '2024-07-17 15:24:01', '2024-07-17 15:24:01');
INSERT INTO `assignments` VALUES ('18', '26', '92', 'Algebra', 'Introduction to Simple Equations', '2024-07-17 17:00:00', '25', '0', NULL, '17', '12', '49', NULL, '2024-07-17 15:25:06', '2024-07-17 15:25:06');
INSERT INTO `assignments` VALUES ('19', '22', '62', 'Interrogation ecrite y', NULL, '2024-10-10 10:30:00', '20', '0', NULL, '17', '12', '49', NULL, '2024-10-10 16:01:39', '2024-10-13 13:59:43');
INSERT INTO `assignments` VALUES ('20', '22', '62', 'test', 'test', '2024-10-16 14:52:00', '10', '1', '2', '17', '12', '49', NULL, '2024-10-16 04:23:31', '2024-10-16 04:23:31');
INSERT INTO `assignments` VALUES ('21', '57', '56', 'test', 'test', '2024-10-16 14:54:00', '10', '1', '1', '17', '12', '49', NULL, '2024-10-16 04:24:46', '2024-10-16 04:24:46');
INSERT INTO `assignments` VALUES ('22', '55', '46', 'test', 'test', '2024-10-17 02:56:00', '20', '1', '1', '17', '12', '49', NULL, '2024-10-16 04:26:56', '2024-10-16 04:26:56');
INSERT INTO `assignments` VALUES ('24', '57', '60', 'homework', 'homework txt', '2024-11-22 09:45:00', '10', '0', NULL, '17', '12', '48', NULL, '2024-11-21 13:35:46', '2024-11-21 13:35:46');
INSERT INTO `assignments` VALUES ('26', '22', '55', 'test', 'hsjs', '2024-12-12 10:55:00', '100', '0', NULL, '17', '12', '42', NULL, '2024-12-11 10:55:46', '2024-12-11 10:55:46');
INSERT INTO `assignments` VALUES ('27', '55', '46', 'Sonu', 'afgghk', '2024-12-20 22:08:00', NULL, '0', NULL, '17', '12', '42', NULL, '2024-12-16 22:08:28', '2024-12-16 22:08:28');
INSERT INTO `assignments` VALUES ('28', '22', '55', 'English', 'Write your notes', '2024-12-19 12:40:00', NULL, '1', '10', '17', '12', '42', NULL, '2024-12-18 20:40:56', '2024-12-18 20:40:56');
INSERT INTO `assignments` VALUES ('29', '55', '46', 'English', 'complete the homework', '2024-12-19 20:41:00', NULL, '1', '10', '17', '12', '42', NULL, '2024-12-18 20:41:57', '2024-12-18 20:41:57');
INSERT INTO `assignments` VALUES ('30', '55', '46', 'Assignment 1', 'complete your work', '2024-12-19 01:01:00', '10', '1', '10', '17', '12', '42', NULL, '2024-12-19 11:01:41', '2024-12-19 11:01:41');
INSERT INTO `assignments` VALUES ('31', '55', '46', 'Homework', NULL, '2024-12-22 21:17:00', '5', '1', '5', '17', '12', '42', NULL, '2024-12-21 21:17:06', '2024-12-21 21:17:06');
INSERT INTO `assignments` VALUES ('33', '55', '46', 'test', 'tttt', '2024-12-31 20:07:00', '10', '1', '5', '17', '12', '42', NULL, '2024-12-30 20:38:05', '2024-12-30 20:38:05');

CREATE TABLE IF NOT EXISTS `attendances` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `class_section_id` bigint(20) unsigned NOT NULL,
  `student_id` bigint(20) unsigned NOT NULL COMMENT 'user_id',
  `session_year_id` bigint(20) unsigned NOT NULL,
  `type` tinyint(4) NOT NULL COMMENT '0=Absent, 1=Present',
  `date` date NOT NULL,
  `remark` varchar(512) NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `attendances_school_id_foreign` (`school_id`),
  KEY `attendances_class_section_id_foreign` (`class_section_id`),
  KEY `attendances_student_id_foreign` (`student_id`),
  KEY `attendances_session_year_id_foreign` (`session_year_id`),
  CONSTRAINT `attendances_class_section_id_foreign` FOREIGN KEY (`class_section_id`) REFERENCES `class_sections` (`id`) ON DELETE CASCADE,
  CONSTRAINT `attendances_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `attendances_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE,
  CONSTRAINT `attendances_student_id_foreign` FOREIGN KEY (`student_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=4210 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `attendances` VALUES ('11', '21', '467', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('12', '21', '465', '17', '0', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('13', '21', '463', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('14', '21', '461', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('15', '21', '459', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('16', '21', '457', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('17', '21', '455', '17', '0', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('18', '21', '453', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('19', '21', '451', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('20', '21', '449', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('21', '21', '447', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('22', '21', '445', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('23', '21', '443', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('24', '21', '441', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('25', '21', '439', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('26', '21', '437', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('27', '21', '435', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('28', '21', '433', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('29', '21', '431', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('30', '21', '429', '17', '0', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('31', '21', '427', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('32', '21', '425', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('33', '21', '423', '17', '0', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('34', '21', '421', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('35', '21', '419', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('36', '21', '417', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('37', '21', '415', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('38', '21', '413', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('39', '21', '411', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('40', '21', '409', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('41', '21', '407', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('42', '21', '405', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('43', '21', '403', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('44', '21', '401', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('45', '21', '399', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('46', '21', '397', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('47', '21', '395', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('48', '21', '393', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('49', '21', '391', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('50', '21', '389', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('51', '21', '387', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('52', '21', '385', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('53', '21', '383', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('54', '21', '381', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('55', '21', '379', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('56', '21', '377', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('57', '21', '375', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('58', '21', '373', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('59', '21', '371', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('60', '21', '369', '17', '0', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('61', '55', '367', '17', '0', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('62', '55', '365', '17', '0', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('63', '55', '363', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('64', '55', '361', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('65', '55', '359', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('66', '55', '357', '17', '0', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('67', '55', '355', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('68', '55', '353', '17', '0', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('69', '55', '351', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('70', '55', '349', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('71', '55', '331', '17', '1', '2023-11-22', '', '12', '2023-11-22 11:05:03', '2023-11-22 11:05:03');
INSERT INTO `attendances` VALUES ('72', '21', '467', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('73', '21', '465', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('74', '21', '463', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('75', '21', '461', '17', '0', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('76', '21', '459', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('77', '21', '457', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('78', '21', '455', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('79', '21', '453', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('80', '21', '451', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('81', '21', '449', '17', '0', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('82', '21', '447', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('83', '21', '445', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('84', '21', '443', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('85', '21', '441', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('86', '21', '439', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('87', '21', '437', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('88', '21', '435', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('89', '21', '433', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('90', '21', '431', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('91', '21', '429', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('92', '21', '427', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('93', '21', '425', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('94', '21', '423', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('95', '21', '421', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('96', '21', '419', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('97', '21', '417', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('98', '21', '415', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('99', '21', '413', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('100', '21', '411', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('101', '21', '409', '17', '0', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('102', '21', '407', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('103', '21', '405', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('104', '21', '403', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('105', '21', '401', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('106', '21', '399', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('107', '21', '397', '17', '0', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('108', '21', '395', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('109', '21', '393', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('110', '21', '391', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('111', '21', '389', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('112', '21', '387', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('113', '21', '385', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('114', '21', '383', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('115', '21', '381', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('116', '21', '379', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('117', '21', '377', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('118', '21', '375', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('119', '21', '373', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('120', '21', '371', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('121', '21', '369', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('122', '55', '367', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('123', '55', '365', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('124', '55', '363', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('125', '55', '361', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('126', '55', '359', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('127', '55', '357', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('128', '55', '355', '17', '0', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('129', '55', '353', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('130', '55', '351', '17', '0', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('131', '55', '349', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('132', '55', '331', '17', '1', '2023-11-21', '', '12', '2023-11-22 11:05:28', '2023-11-22 11:05:28');
INSERT INTO `attendances` VALUES ('133', '21', '467', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('134', '21', '465', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('135', '21', '463', '17', '0', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('136', '21', '461', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('137', '21', '459', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('138', '21', '457', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('139', '21', '455', '17', '0', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('140', '21', '453', '17', '0', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('141', '21', '451', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('142', '21', '449', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('143', '21', '447', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('144', '21', '445', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('145', '21', '443', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('146', '21', '441', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('147', '21', '439', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('148', '21', '437', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('149', '21', '435', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('150', '21', '433', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('151', '21', '431', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('152', '21', '429', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('153', '21', '427', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('154', '21', '425', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('155', '21', '423', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('156', '21', '421', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('157', '21', '419', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('158', '21', '417', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('159', '21', '415', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('160', '21', '413', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('161', '21', '411', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('162', '21', '409', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('163', '21', '407', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('164', '21', '405', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('165', '21', '403', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('166', '21', '401', '17', '0', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('167', '21', '399', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('168', '21', '397', '17', '0', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('169', '21', '395', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('170', '21', '393', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('171', '21', '391', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('172', '21', '389', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('173', '21', '387', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('174', '21', '385', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('175', '21', '383', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('176', '21', '381', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('177', '21', '379', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('178', '21', '377', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('179', '21', '375', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('180', '21', '373', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('181', '21', '371', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('182', '21', '369', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('183', '55', '367', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('184', '55', '365', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('185', '55', '363', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('186', '55', '361', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('187', '55', '359', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('188', '55', '357', '17', '0', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('189', '55', '355', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('190', '55', '353', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('191', '55', '351', '17', '0', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('192', '55', '349', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('193', '55', '331', '17', '1', '2023-11-20', '', '12', '2023-11-22 11:05:48', '2023-11-22 11:05:48');
INSERT INTO `attendances` VALUES ('194', '21', '467', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('195', '21', '465', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('196', '21', '463', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('197', '21', '461', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('198', '21', '459', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('199', '21', '457', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('200', '21', '455', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('201', '21', '453', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('202', '21', '451', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('203', '21', '449', '17', '0', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('204', '21', '447', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('205', '21', '445', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('206', '21', '443', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('207', '21', '441', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('208', '21', '439', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('209', '21', '437', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('210', '21', '435', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('211', '21', '433', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('212', '21', '431', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('213', '21', '429', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('214', '21', '427', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('215', '21', '425', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('216', '21', '423', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('217', '21', '421', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('218', '21', '419', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('219', '21', '417', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('220', '21', '415', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('221', '21', '413', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('222', '21', '411', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('223', '21', '409', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('224', '21', '407', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('225', '21', '405', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('226', '21', '403', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('227', '21', '401', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('228', '21', '399', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('229', '21', '397', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('230', '21', '395', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('231', '21', '393', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('232', '21', '391', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('233', '21', '389', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('234', '21', '387', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('235', '21', '385', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('236', '21', '383', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('237', '21', '381', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('238', '21', '379', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('239', '21', '377', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('240', '21', '375', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('241', '21', '373', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('242', '21', '371', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('243', '21', '369', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('244', '55', '367', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('245', '55', '365', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('246', '55', '363', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('247', '55', '361', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('248', '55', '359', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('249', '55', '357', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('250', '55', '355', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('251', '55', '353', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('252', '55', '351', '17', '0', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('253', '55', '349', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('254', '55', '331', '17', '1', '2023-11-19', '', '12', '2023-11-22 11:06:02', '2023-11-22 11:06:02');
INSERT INTO `attendances` VALUES ('255', '21', '467', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('256', '21', '465', '17', '0', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('257', '21', '463', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('258', '21', '461', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('259', '21', '459', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('260', '21', '457', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('261', '21', '455', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('262', '21', '453', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('263', '21', '451', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('264', '21', '449', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('265', '21', '447', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('266', '21', '445', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('267', '21', '443', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('268', '21', '441', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('269', '21', '439', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('270', '21', '437', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('271', '21', '435', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('272', '21', '433', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('273', '21', '431', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('274', '21', '429', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('275', '21', '427', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('276', '21', '425', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('277', '21', '423', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('278', '21', '421', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('279', '21', '419', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('280', '21', '417', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('281', '21', '415', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('282', '21', '413', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('283', '21', '411', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('284', '21', '409', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('285', '21', '407', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('286', '21', '405', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('287', '21', '403', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('288', '21', '401', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('289', '21', '399', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('290', '21', '397', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('291', '21', '395', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('292', '21', '393', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('293', '21', '391', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('294', '21', '389', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('295', '21', '387', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('296', '21', '385', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('297', '21', '383', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('298', '21', '381', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('299', '21', '379', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('300', '21', '377', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('301', '21', '375', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('302', '21', '373', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('303', '21', '371', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('304', '21', '369', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('305', '55', '367', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('306', '55', '365', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('307', '55', '363', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('308', '55', '361', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('309', '55', '359', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('310', '55', '357', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('311', '55', '355', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('312', '55', '353', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('313', '55', '351', '17', '0', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('314', '55', '349', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('315', '55', '331', '17', '1', '2023-11-18', '', '12', '2023-11-22 11:08:00', '2023-11-22 11:08:00');
INSERT INTO `attendances` VALUES ('316', '21', '467', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('317', '21', '465', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('318', '21', '463', '17', '0', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('319', '21', '461', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('320', '21', '459', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('321', '21', '457', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('322', '21', '455', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('323', '21', '453', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('324', '21', '451', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('325', '21', '449', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('326', '21', '447', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('327', '21', '445', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('328', '21', '443', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('329', '21', '441', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('330', '21', '439', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('331', '21', '437', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('332', '21', '435', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('333', '21', '433', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('334', '21', '431', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('335', '21', '429', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('336', '21', '427', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('337', '21', '425', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('338', '21', '423', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('339', '21', '421', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('340', '21', '419', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('341', '21', '417', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('342', '21', '415', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('343', '21', '413', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('344', '21', '411', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('345', '21', '409', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('346', '21', '407', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('347', '21', '405', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('348', '21', '403', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('349', '21', '401', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('350', '21', '399', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('351', '21', '397', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('352', '21', '395', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('353', '21', '393', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('354', '21', '391', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('355', '21', '389', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('356', '21', '387', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('357', '21', '385', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('358', '21', '383', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('359', '21', '381', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('360', '21', '379', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('361', '21', '377', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('362', '21', '375', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('363', '21', '373', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('364', '21', '371', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('365', '21', '369', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('366', '55', '367', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('367', '55', '365', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('368', '55', '363', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('369', '55', '361', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('370', '55', '359', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('371', '55', '357', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('372', '55', '355', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('373', '55', '353', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('374', '55', '351', '17', '0', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('375', '55', '349', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('376', '55', '331', '17', '1', '2023-11-17', '', '12', '2023-11-22 11:08:13', '2023-11-22 11:08:13');
INSERT INTO `attendances` VALUES ('377', '21', '467', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('378', '21', '465', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('379', '21', '463', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('380', '21', '461', '17', '0', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('381', '21', '459', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('382', '21', '457', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('383', '21', '455', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('384', '21', '453', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('385', '21', '451', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('386', '21', '449', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('387', '21', '447', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('388', '21', '445', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('389', '21', '443', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('390', '21', '441', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('391', '21', '439', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('392', '21', '437', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('393', '21', '435', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('394', '21', '433', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('395', '21', '431', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('396', '21', '429', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('397', '21', '427', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('398', '21', '425', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('399', '21', '423', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('400', '21', '421', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('401', '21', '419', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('402', '21', '417', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('403', '21', '415', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('404', '21', '413', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('405', '21', '411', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('406', '21', '409', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('407', '21', '407', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('408', '21', '405', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('409', '21', '403', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('410', '21', '401', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('411', '21', '399', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('412', '21', '397', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('413', '21', '395', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('414', '21', '393', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('415', '21', '391', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('416', '21', '389', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('417', '21', '387', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('418', '21', '385', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('419', '21', '383', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('420', '21', '381', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('421', '21', '379', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('422', '21', '377', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('423', '21', '375', '17', '0', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('424', '21', '373', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('425', '21', '371', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('426', '21', '369', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('427', '55', '367', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('428', '55', '365', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('429', '55', '363', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('430', '55', '361', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('431', '55', '359', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('432', '55', '357', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('433', '55', '355', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('434', '55', '353', '17', '0', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('435', '55', '351', '17', '0', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('436', '55', '349', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('437', '55', '331', '17', '1', '2023-11-16', '', '12', '2023-11-22 11:08:27', '2023-11-22 11:08:27');
INSERT INTO `attendances` VALUES ('438', '21', '467', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('439', '21', '465', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('440', '21', '463', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('441', '21', '461', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('442', '21', '459', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('443', '21', '457', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('444', '21', '455', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('445', '21', '453', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('446', '21', '451', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('447', '21', '449', '17', '0', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('448', '21', '447', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('449', '21', '445', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('450', '21', '443', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('451', '21', '441', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('452', '21', '439', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('453', '21', '437', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('454', '21', '435', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('455', '21', '433', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('456', '21', '431', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('457', '21', '429', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('458', '21', '427', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('459', '21', '425', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('460', '21', '423', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('461', '21', '421', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('462', '21', '419', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('463', '21', '417', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('464', '21', '415', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('465', '21', '413', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('466', '21', '411', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('467', '21', '409', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('468', '21', '407', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('469', '21', '405', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('470', '21', '403', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('471', '21', '401', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('472', '21', '399', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('473', '21', '397', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('474', '21', '395', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('475', '21', '393', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('476', '21', '391', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('477', '21', '389', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('478', '21', '387', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('479', '21', '385', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('480', '21', '383', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('481', '21', '381', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('482', '21', '379', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('483', '21', '377', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('484', '21', '375', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('485', '21', '373', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('486', '21', '371', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('487', '21', '369', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('488', '55', '367', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('489', '55', '365', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('490', '55', '363', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('491', '55', '361', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('492', '55', '359', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('493', '55', '357', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('494', '55', '355', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('495', '55', '353', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('496', '55', '351', '17', '0', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('497', '55', '349', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('498', '55', '331', '17', '1', '2023-11-15', '', '12', '2023-11-22 11:08:40', '2023-11-22 11:08:40');
INSERT INTO `attendances` VALUES ('499', '21', '467', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('500', '21', '465', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('501', '21', '463', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('502', '21', '461', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('503', '21', '459', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('504', '21', '457', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('505', '21', '455', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('506', '21', '453', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('507', '21', '451', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('508', '21', '449', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('509', '21', '447', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('510', '21', '445', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('511', '21', '443', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('512', '21', '441', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('513', '21', '439', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('514', '21', '437', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('515', '21', '435', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('516', '21', '433', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('517', '21', '431', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('518', '21', '429', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('519', '21', '427', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('520', '21', '425', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('521', '21', '423', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('522', '21', '421', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('523', '21', '419', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('524', '21', '417', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('525', '21', '415', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('526', '21', '413', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('527', '21', '411', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('528', '21', '409', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('529', '21', '407', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('530', '21', '405', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('531', '21', '403', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('532', '21', '401', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('533', '21', '399', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('534', '21', '397', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('535', '21', '395', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('536', '21', '393', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('537', '21', '391', '17', '0', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('538', '21', '389', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('539', '21', '387', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('540', '21', '385', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('541', '21', '383', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('542', '21', '381', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('543', '21', '379', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('544', '21', '377', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('545', '21', '375', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('546', '21', '373', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('547', '21', '371', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('548', '21', '369', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('549', '55', '367', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('550', '55', '365', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('551', '55', '363', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('552', '55', '361', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('553', '55', '359', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('554', '55', '357', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('555', '55', '355', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('556', '55', '353', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('557', '55', '351', '17', '0', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('558', '55', '349', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('559', '55', '331', '17', '1', '2023-11-14', '', '12', '2023-11-22 11:08:50', '2023-11-22 11:08:50');
INSERT INTO `attendances` VALUES ('560', '21', '467', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('561', '21', '465', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('562', '21', '463', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('563', '21', '461', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('564', '21', '459', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('565', '21', '457', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('566', '21', '455', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('567', '21', '453', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('568', '21', '451', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('569', '21', '449', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('570', '21', '447', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('571', '21', '445', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('572', '21', '443', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('573', '21', '441', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('574', '21', '439', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('575', '21', '437', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('576', '21', '435', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('577', '21', '433', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('578', '21', '431', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('579', '21', '429', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('580', '21', '427', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('581', '21', '425', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('582', '21', '423', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('583', '21', '421', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('584', '21', '419', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('585', '21', '417', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('586', '21', '415', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('587', '21', '413', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('588', '21', '411', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('589', '21', '409', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('590', '21', '407', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('591', '21', '405', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('592', '21', '403', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('593', '21', '401', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('594', '21', '399', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('595', '21', '397', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('596', '21', '395', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('597', '21', '393', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('598', '21', '391', '17', '0', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('599', '21', '389', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('600', '21', '387', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('601', '21', '385', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('602', '21', '383', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('603', '21', '381', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('604', '21', '379', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('605', '21', '377', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('606', '21', '375', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('607', '21', '373', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('608', '21', '371', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('609', '21', '369', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('610', '55', '367', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('611', '55', '365', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('612', '55', '363', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('613', '55', '361', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('614', '55', '359', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('615', '55', '357', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('616', '55', '355', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('617', '55', '353', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('618', '55', '351', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('619', '55', '349', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('620', '55', '331', '17', '1', '2023-11-13', '', '12', '2023-11-22 11:09:00', '2023-11-22 11:09:00');
INSERT INTO `attendances` VALUES ('621', '21', '467', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('622', '21', '465', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('623', '21', '463', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('624', '21', '461', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('625', '21', '459', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('626', '21', '457', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('627', '21', '455', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('628', '21', '453', '17', '0', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('629', '21', '451', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('630', '21', '449', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('631', '21', '447', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('632', '21', '445', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('633', '21', '443', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('634', '21', '441', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('635', '21', '439', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('636', '21', '437', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('637', '21', '435', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('638', '21', '433', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('639', '21', '431', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('640', '21', '429', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('641', '21', '427', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('642', '21', '425', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('643', '21', '423', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('644', '21', '421', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('645', '21', '419', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('646', '21', '417', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('647', '21', '415', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('648', '21', '413', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('649', '21', '411', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('650', '21', '409', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('651', '21', '407', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('652', '21', '405', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('653', '21', '403', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('654', '21', '401', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('655', '21', '399', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('656', '21', '397', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('657', '21', '395', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('658', '21', '393', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('659', '21', '391', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('660', '21', '389', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('661', '21', '387', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('662', '21', '385', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('663', '21', '383', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('664', '21', '381', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('665', '21', '379', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('666', '21', '377', '17', '0', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('667', '21', '375', '17', '0', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('668', '21', '373', '17', '0', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('669', '21', '371', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('670', '21', '369', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('671', '55', '367', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('672', '55', '365', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('673', '55', '363', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('674', '55', '361', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('675', '55', '359', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('676', '55', '357', '17', '0', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('677', '55', '355', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('678', '55', '353', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('679', '55', '351', '17', '0', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('680', '55', '349', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('681', '55', '331', '17', '1', '2023-11-11', '', '12', '2023-11-22 11:09:17', '2023-11-22 11:09:17');
INSERT INTO `attendances` VALUES ('682', '21', '467', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('683', '21', '465', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('684', '21', '463', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('685', '21', '461', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('686', '21', '459', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('687', '21', '457', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('688', '21', '455', '17', '0', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('689', '21', '453', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('690', '21', '451', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('691', '21', '449', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('692', '21', '447', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('693', '21', '445', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('694', '21', '443', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('695', '21', '441', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('696', '21', '439', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('697', '21', '437', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('698', '21', '435', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('699', '21', '433', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('700', '21', '431', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('701', '21', '429', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('702', '21', '427', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('703', '21', '425', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('704', '21', '423', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('705', '21', '421', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('706', '21', '419', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('707', '21', '417', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('708', '21', '415', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('709', '21', '413', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('710', '21', '411', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('711', '21', '409', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('712', '21', '407', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('713', '21', '405', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('714', '21', '403', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('715', '21', '401', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('716', '21', '399', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('717', '21', '397', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('718', '21', '395', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('719', '21', '393', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('720', '21', '391', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('721', '21', '389', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('722', '21', '387', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('723', '21', '385', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('724', '21', '383', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('725', '21', '381', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('726', '21', '379', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('727', '21', '377', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('728', '21', '375', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('729', '21', '373', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('730', '21', '371', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('731', '21', '369', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('732', '55', '367', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('733', '55', '365', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('734', '55', '363', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('735', '55', '361', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('736', '55', '359', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('737', '55', '357', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('738', '55', '355', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('739', '55', '353', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('740', '55', '351', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('741', '55', '349', '17', '1', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('742', '55', '331', '17', '0', '2023-11-10', '', '12', '2023-11-22 11:09:41', '2023-11-22 11:09:41');
INSERT INTO `attendances` VALUES ('743', '21', '467', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('744', '21', '465', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('745', '21', '463', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('746', '21', '461', '17', '0', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('747', '21', '459', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('748', '21', '457', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('749', '21', '455', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('750', '21', '453', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('751', '21', '451', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('752', '21', '449', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('753', '21', '447', '17', '0', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('754', '21', '445', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('755', '21', '443', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('756', '21', '441', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('757', '21', '439', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('758', '21', '437', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('759', '21', '435', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('760', '21', '433', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('761', '21', '431', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('762', '21', '429', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('763', '21', '427', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('764', '21', '425', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('765', '21', '423', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('766', '21', '421', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('767', '21', '419', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('768', '21', '417', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('769', '21', '415', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('770', '21', '413', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('771', '21', '411', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('772', '21', '409', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('773', '21', '407', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('774', '21', '405', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('775', '21', '403', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('776', '21', '401', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('777', '21', '399', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('778', '21', '397', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('779', '21', '395', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('780', '21', '393', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('781', '21', '391', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('782', '21', '389', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('783', '21', '387', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('784', '21', '385', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('785', '21', '383', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('786', '21', '381', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('787', '21', '379', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('788', '21', '377', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('789', '21', '375', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('790', '21', '373', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('791', '21', '371', '17', '0', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('792', '21', '369', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('793', '55', '367', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('794', '55', '365', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('795', '55', '363', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('796', '55', '361', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('797', '55', '359', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('798', '55', '357', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('799', '55', '355', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('800', '55', '353', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('801', '55', '351', '17', '0', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('802', '55', '349', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('803', '55', '331', '17', '1', '2023-11-09', '', '12', '2023-11-22 11:10:01', '2023-11-22 11:10:01');
INSERT INTO `attendances` VALUES ('804', '21', '467', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('805', '21', '465', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('806', '21', '463', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('807', '21', '461', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('808', '21', '459', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('809', '21', '457', '17', '0', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('810', '21', '455', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('811', '21', '453', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('812', '21', '451', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('813', '21', '449', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('814', '21', '447', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('815', '21', '445', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('816', '21', '443', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('817', '21', '441', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('818', '21', '439', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('819', '21', '437', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('820', '21', '435', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('821', '21', '433', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('822', '21', '431', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('823', '21', '429', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('824', '21', '427', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('825', '21', '425', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('826', '21', '423', '17', '0', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('827', '21', '421', '17', '0', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('828', '21', '419', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('829', '21', '417', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('830', '21', '415', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('831', '21', '413', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('832', '21', '411', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('833', '21', '409', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('834', '21', '407', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('835', '21', '405', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('836', '21', '403', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('837', '21', '401', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('838', '21', '399', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('839', '21', '397', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('840', '21', '395', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('841', '21', '393', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('842', '21', '391', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('843', '21', '389', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('844', '21', '387', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('845', '21', '385', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('846', '21', '383', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('847', '21', '381', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('848', '21', '379', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('849', '21', '377', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('850', '21', '375', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('851', '21', '373', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('852', '21', '371', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('853', '21', '369', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('854', '55', '367', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('855', '55', '365', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('856', '55', '363', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('857', '55', '361', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('858', '55', '359', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('859', '55', '357', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('860', '55', '355', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('861', '55', '353', '17', '0', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('862', '55', '351', '17', '0', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('863', '55', '349', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('864', '55', '331', '17', '1', '2023-11-08', '', '12', '2023-11-22 11:10:19', '2023-11-22 11:10:19');
INSERT INTO `attendances` VALUES ('865', '21', '467', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('866', '21', '465', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('867', '21', '463', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('868', '21', '461', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('869', '21', '459', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('870', '21', '457', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('871', '21', '455', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('872', '21', '453', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('873', '21', '451', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('874', '21', '449', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('875', '21', '447', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('876', '21', '445', '17', '0', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('877', '21', '443', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('878', '21', '441', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('879', '21', '439', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('880', '21', '437', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('881', '21', '435', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('882', '21', '433', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('883', '21', '431', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('884', '21', '429', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('885', '21', '427', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('886', '21', '425', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('887', '21', '423', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('888', '21', '421', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('889', '21', '419', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('890', '21', '417', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('891', '21', '415', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('892', '21', '413', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('893', '21', '411', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('894', '21', '409', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('895', '21', '407', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('896', '21', '405', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('897', '21', '403', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('898', '21', '401', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('899', '21', '399', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('900', '21', '397', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('901', '21', '395', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('902', '21', '393', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('903', '21', '391', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('904', '21', '389', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('905', '21', '387', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('906', '21', '385', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('907', '21', '383', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('908', '21', '381', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('909', '21', '379', '17', '0', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('910', '21', '377', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('911', '21', '375', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('912', '21', '373', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('913', '21', '371', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('914', '21', '369', '17', '0', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('915', '55', '367', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('916', '55', '365', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('917', '55', '363', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('918', '55', '361', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('919', '55', '359', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('920', '55', '357', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('921', '55', '355', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('922', '55', '353', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('923', '55', '351', '17', '0', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('924', '55', '349', '17', '1', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('925', '55', '331', '17', '0', '2023-11-07', '', '12', '2023-11-22 11:10:35', '2023-11-22 11:10:35');
INSERT INTO `attendances` VALUES ('926', '21', '467', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('927', '21', '465', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('928', '21', '463', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('929', '21', '461', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('930', '21', '459', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('931', '21', '457', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('932', '21', '455', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('933', '21', '453', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('934', '21', '451', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('935', '21', '449', '17', '0', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('936', '21', '447', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('937', '21', '445', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('938', '21', '443', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('939', '21', '441', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('940', '21', '439', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('941', '21', '437', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('942', '21', '435', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('943', '21', '433', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('944', '21', '431', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('945', '21', '429', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('946', '21', '427', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('947', '21', '425', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('948', '21', '423', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('949', '21', '421', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('950', '21', '419', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('951', '21', '417', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('952', '21', '415', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('953', '21', '413', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('954', '21', '411', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('955', '21', '409', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('956', '21', '407', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('957', '21', '405', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('958', '21', '403', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('959', '21', '401', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('960', '21', '399', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('961', '21', '397', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('962', '21', '395', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('963', '21', '393', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('964', '21', '391', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('965', '21', '389', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('966', '21', '387', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('967', '21', '385', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('968', '21', '383', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('969', '21', '381', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('970', '21', '379', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('971', '21', '377', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('972', '21', '375', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('973', '21', '373', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('974', '21', '371', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('975', '21', '369', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('976', '55', '367', '17', '0', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('977', '55', '365', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('978', '55', '363', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('979', '55', '361', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('980', '55', '359', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('981', '55', '357', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('982', '55', '355', '17', '0', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('983', '55', '353', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('984', '55', '351', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('985', '55', '349', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('986', '55', '331', '17', '1', '2023-11-06', '', '12', '2023-11-22 11:10:47', '2023-11-22 11:10:47');
INSERT INTO `attendances` VALUES ('987', '21', '467', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('988', '21', '465', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('989', '21', '463', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('990', '21', '461', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('991', '21', '459', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('992', '21', '457', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('993', '21', '455', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('994', '21', '453', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('995', '21', '451', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('996', '21', '449', '17', '0', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('997', '21', '447', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('998', '21', '445', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('999', '21', '443', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1000', '21', '441', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1001', '21', '439', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1002', '21', '437', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1003', '21', '435', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1004', '21', '433', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1005', '21', '431', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1006', '21', '429', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1007', '21', '427', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1008', '21', '425', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1009', '21', '423', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1010', '21', '421', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1011', '21', '419', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1012', '21', '417', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1013', '21', '415', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1014', '21', '413', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1015', '21', '411', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1016', '21', '409', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1017', '21', '407', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1018', '21', '405', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1019', '21', '403', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1020', '21', '401', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1021', '21', '399', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1022', '21', '397', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1023', '21', '395', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1024', '21', '393', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1025', '21', '391', '17', '0', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1026', '21', '389', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1027', '21', '387', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1028', '21', '385', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1029', '21', '383', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1030', '21', '381', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1031', '21', '379', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1032', '21', '377', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1033', '21', '375', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1034', '21', '373', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1035', '21', '371', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1036', '21', '369', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1037', '55', '367', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1038', '55', '365', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1039', '55', '363', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1040', '55', '361', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1041', '55', '359', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1042', '55', '357', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1043', '55', '355', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1044', '55', '353', '17', '0', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1045', '55', '351', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1046', '55', '349', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1047', '55', '331', '17', '1', '2023-11-04', '', '12', '2023-11-22 11:10:59', '2023-11-22 11:10:59');
INSERT INTO `attendances` VALUES ('1048', '21', '467', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1049', '21', '465', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1050', '21', '463', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1051', '21', '461', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1052', '21', '459', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1053', '21', '457', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1054', '21', '455', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1055', '21', '453', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1056', '21', '451', '17', '0', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1057', '21', '449', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1058', '21', '447', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1059', '21', '445', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1060', '21', '443', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1061', '21', '441', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1062', '21', '439', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1063', '21', '437', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1064', '21', '435', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1065', '21', '433', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1066', '21', '431', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1067', '21', '429', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1068', '21', '427', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1069', '21', '425', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1070', '21', '423', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1071', '21', '421', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1072', '21', '419', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1073', '21', '417', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1074', '21', '415', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1075', '21', '413', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1076', '21', '411', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1077', '21', '409', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1078', '21', '407', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1079', '21', '405', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1080', '21', '403', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1081', '21', '401', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1082', '21', '399', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1083', '21', '397', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1084', '21', '395', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1085', '21', '393', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1086', '21', '391', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1087', '21', '389', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1088', '21', '387', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1089', '21', '385', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1090', '21', '383', '17', '0', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1091', '21', '381', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1092', '21', '379', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1093', '21', '377', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1094', '21', '375', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1095', '21', '373', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1096', '21', '371', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1097', '21', '369', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1098', '55', '367', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1099', '55', '365', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1100', '55', '363', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1101', '55', '361', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1102', '55', '359', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1103', '55', '357', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1104', '55', '355', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1105', '55', '353', '17', '0', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1106', '55', '351', '17', '0', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1107', '55', '349', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1108', '55', '331', '17', '1', '2023-11-03', '', '12', '2023-11-22 11:11:13', '2023-11-22 11:11:13');
INSERT INTO `attendances` VALUES ('1109', '21', '467', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1110', '21', '465', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1111', '21', '463', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1112', '21', '461', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1113', '21', '459', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1114', '21', '457', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1115', '21', '455', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1116', '21', '453', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1117', '21', '451', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1118', '21', '449', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1119', '21', '447', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1120', '21', '445', '17', '0', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1121', '21', '443', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1122', '21', '441', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1123', '21', '439', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1124', '21', '437', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1125', '21', '435', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1126', '21', '433', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1127', '21', '431', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1128', '21', '429', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1129', '21', '427', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1130', '21', '425', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1131', '21', '423', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1132', '21', '421', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1133', '21', '419', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1134', '21', '417', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1135', '21', '415', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1136', '21', '413', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1137', '21', '411', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1138', '21', '409', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1139', '21', '407', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1140', '21', '405', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1141', '21', '403', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1142', '21', '401', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1143', '21', '399', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1144', '21', '397', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1145', '21', '395', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1146', '21', '393', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1147', '21', '391', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1148', '21', '389', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1149', '21', '387', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1150', '21', '385', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1151', '21', '383', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1152', '21', '381', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1153', '21', '379', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1154', '21', '377', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1155', '21', '375', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1156', '21', '373', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1157', '21', '371', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1158', '21', '369', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1159', '55', '367', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1160', '55', '365', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1161', '55', '363', '17', '0', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1162', '55', '361', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1163', '55', '359', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1164', '55', '357', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1165', '55', '355', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1166', '55', '353', '17', '0', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1167', '55', '351', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1168', '55', '349', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1169', '55', '331', '17', '1', '2023-11-02', '', '12', '2023-11-22 11:11:27', '2023-11-22 11:11:27');
INSERT INTO `attendances` VALUES ('1170', '21', '467', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1171', '21', '465', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1172', '21', '463', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1173', '21', '461', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1174', '21', '459', '17', '0', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1175', '21', '457', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1176', '21', '455', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1177', '21', '453', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1178', '21', '451', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1179', '21', '449', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1180', '21', '447', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1181', '21', '445', '17', '0', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1182', '21', '443', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1183', '21', '441', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1184', '21', '439', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1185', '21', '437', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1186', '21', '435', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1187', '21', '433', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1188', '21', '431', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1189', '21', '429', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1190', '21', '427', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1191', '21', '425', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1192', '21', '423', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1193', '21', '421', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1194', '21', '419', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1195', '21', '417', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1196', '21', '415', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1197', '21', '413', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1198', '21', '411', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1199', '21', '409', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1200', '21', '407', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1201', '21', '405', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1202', '21', '403', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1203', '21', '401', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1204', '21', '399', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1205', '21', '397', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1206', '21', '395', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1207', '21', '393', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1208', '21', '391', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1209', '21', '389', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1210', '21', '387', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1211', '21', '385', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1212', '21', '383', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1213', '21', '381', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1214', '21', '379', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1215', '21', '377', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1216', '21', '375', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1217', '21', '373', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1218', '21', '371', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1219', '21', '369', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1220', '55', '367', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1221', '55', '365', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1222', '55', '363', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1223', '55', '361', '17', '0', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1224', '55', '359', '17', '0', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1225', '55', '357', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1226', '55', '355', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1227', '55', '353', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1228', '55', '351', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1229', '55', '349', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1230', '55', '331', '17', '1', '2023-11-01', '', '12', '2023-11-22 11:11:44', '2023-11-22 11:11:44');
INSERT INTO `attendances` VALUES ('1231', '57', '333', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:47:19', '2024-01-23 04:47:19');
INSERT INTO `attendances` VALUES ('1232', '57', '470', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:47:19', '2024-01-23 04:47:19');
INSERT INTO `attendances` VALUES ('1233', '57', '472', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:47:19', '2024-01-23 04:47:19');
INSERT INTO `attendances` VALUES ('1234', '57', '474', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:47:19', '2024-01-23 04:47:19');
INSERT INTO `attendances` VALUES ('1235', '57', '476', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:47:19', '2024-01-23 04:47:19');
INSERT INTO `attendances` VALUES ('1236', '57', '478', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:47:19', '2024-01-23 04:47:19');
INSERT INTO `attendances` VALUES ('1237', '57', '480', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:47:19', '2024-01-23 04:47:19');
INSERT INTO `attendances` VALUES ('1238', '57', '482', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:47:19', '2024-01-23 04:47:19');
INSERT INTO `attendances` VALUES ('1239', '57', '484', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:47:19', '2024-01-23 04:47:19');
INSERT INTO `attendances` VALUES ('1240', '57', '486', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:47:19', '2024-01-23 04:47:19');
INSERT INTO `attendances` VALUES ('1241', '22', '488', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:47:19', '2024-01-23 04:47:19');
INSERT INTO `attendances` VALUES ('1242', '22', '490', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:47:19', '2024-01-23 04:47:19');
INSERT INTO `attendances` VALUES ('1243', '22', '492', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:47:19', '2024-01-23 04:47:19');
INSERT INTO `attendances` VALUES ('1244', '22', '494', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:47:19', '2024-01-23 04:47:19');
INSERT INTO `attendances` VALUES ('1245', '22', '496', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:47:19', '2024-01-23 04:47:19');
INSERT INTO `attendances` VALUES ('1246', '22', '498', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:47:19', '2024-01-23 04:47:19');
INSERT INTO `attendances` VALUES ('1247', '22', '500', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:47:19', '2024-01-23 04:47:19');
INSERT INTO `attendances` VALUES ('1248', '22', '502', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:47:19', '2024-01-23 04:47:19');
INSERT INTO `attendances` VALUES ('1249', '22', '504', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:47:19', '2024-01-23 04:47:19');
INSERT INTO `attendances` VALUES ('1250', '22', '506', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:47:19', '2024-01-23 04:47:19');
INSERT INTO `attendances` VALUES ('1251', '22', '508', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:47:19', '2024-01-23 04:47:19');
INSERT INTO `attendances` VALUES ('1252', '22', '510', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:47:19', '2024-01-23 04:47:19');
INSERT INTO `attendances` VALUES ('1253', '22', '512', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:47:19', '2024-01-23 04:47:19');
INSERT INTO `attendances` VALUES ('1254', '22', '514', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:47:19', '2024-01-23 04:47:19');
INSERT INTO `attendances` VALUES ('1255', '22', '516', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:47:19', '2024-01-23 04:47:19');
INSERT INTO `attendances` VALUES ('1256', '22', '518', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:47:19', '2024-01-23 04:47:19');
INSERT INTO `attendances` VALUES ('1257', '22', '520', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:47:19', '2024-01-23 04:47:19');
INSERT INTO `attendances` VALUES ('1258', '22', '522', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:47:19', '2024-01-23 04:47:19');
INSERT INTO `attendances` VALUES ('1259', '22', '524', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:47:19', '2024-01-23 04:47:19');
INSERT INTO `attendances` VALUES ('1260', '22', '526', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:47:19', '2024-01-23 04:47:19');
INSERT INTO `attendances` VALUES ('1261', '57', '333', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:47:30', '2024-01-23 04:47:30');
INSERT INTO `attendances` VALUES ('1262', '57', '470', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:47:30', '2024-01-23 04:47:30');
INSERT INTO `attendances` VALUES ('1263', '57', '472', '17', '0', '2023-11-23', '', '12', '2024-01-23 04:47:30', '2024-01-23 04:47:30');
INSERT INTO `attendances` VALUES ('1264', '57', '474', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:47:30', '2024-01-23 04:47:30');
INSERT INTO `attendances` VALUES ('1265', '57', '476', '17', '0', '2023-11-23', '', '12', '2024-01-23 04:47:30', '2024-01-23 04:47:30');
INSERT INTO `attendances` VALUES ('1266', '57', '478', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:47:30', '2024-01-23 04:47:30');
INSERT INTO `attendances` VALUES ('1267', '57', '480', '17', '0', '2023-11-23', '', '12', '2024-01-23 04:47:30', '2024-01-23 04:47:30');
INSERT INTO `attendances` VALUES ('1268', '57', '482', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:47:30', '2024-01-23 04:47:30');
INSERT INTO `attendances` VALUES ('1269', '57', '484', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:47:30', '2024-01-23 04:47:30');
INSERT INTO `attendances` VALUES ('1270', '57', '486', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:47:30', '2024-01-23 04:47:30');
INSERT INTO `attendances` VALUES ('1271', '22', '488', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:47:30', '2024-01-23 04:47:30');
INSERT INTO `attendances` VALUES ('1272', '22', '490', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:47:30', '2024-01-23 04:47:30');
INSERT INTO `attendances` VALUES ('1273', '22', '492', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:47:30', '2024-01-23 04:47:30');
INSERT INTO `attendances` VALUES ('1274', '22', '494', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:47:30', '2024-01-23 04:47:30');
INSERT INTO `attendances` VALUES ('1275', '22', '496', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:47:30', '2024-01-23 04:47:30');
INSERT INTO `attendances` VALUES ('1276', '22', '498', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:47:30', '2024-01-23 04:47:30');
INSERT INTO `attendances` VALUES ('1277', '22', '500', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:47:30', '2024-01-23 04:47:30');
INSERT INTO `attendances` VALUES ('1278', '22', '502', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:47:30', '2024-01-23 04:47:30');
INSERT INTO `attendances` VALUES ('1279', '22', '504', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:47:30', '2024-01-23 04:47:30');
INSERT INTO `attendances` VALUES ('1280', '22', '506', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:47:30', '2024-01-23 04:47:30');
INSERT INTO `attendances` VALUES ('1281', '22', '508', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:47:30', '2024-01-23 04:47:30');
INSERT INTO `attendances` VALUES ('1282', '22', '510', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:47:30', '2024-01-23 04:47:30');
INSERT INTO `attendances` VALUES ('1283', '22', '512', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:47:30', '2024-01-23 04:47:30');
INSERT INTO `attendances` VALUES ('1284', '22', '514', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:47:30', '2024-01-23 04:47:30');
INSERT INTO `attendances` VALUES ('1285', '22', '516', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:47:30', '2024-01-23 04:47:30');
INSERT INTO `attendances` VALUES ('1286', '22', '518', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:47:30', '2024-01-23 04:47:30');
INSERT INTO `attendances` VALUES ('1287', '22', '520', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:47:30', '2024-01-23 04:47:30');
INSERT INTO `attendances` VALUES ('1288', '22', '522', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:47:30', '2024-01-23 04:47:30');
INSERT INTO `attendances` VALUES ('1289', '22', '524', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:47:30', '2024-01-23 04:47:30');
INSERT INTO `attendances` VALUES ('1290', '22', '526', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:47:30', '2024-01-23 04:47:30');
INSERT INTO `attendances` VALUES ('1291', '57', '333', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:47:41', '2024-01-23 04:47:41');
INSERT INTO `attendances` VALUES ('1292', '57', '470', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:47:41', '2024-01-23 04:47:41');
INSERT INTO `attendances` VALUES ('1293', '57', '472', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:47:41', '2024-01-23 04:47:41');
INSERT INTO `attendances` VALUES ('1294', '57', '474', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:47:41', '2024-01-23 04:47:41');
INSERT INTO `attendances` VALUES ('1295', '57', '476', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:47:41', '2024-01-23 04:47:41');
INSERT INTO `attendances` VALUES ('1296', '57', '478', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:47:41', '2024-01-23 04:47:41');
INSERT INTO `attendances` VALUES ('1297', '57', '480', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:47:41', '2024-01-23 04:47:41');
INSERT INTO `attendances` VALUES ('1298', '57', '482', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:47:41', '2024-01-23 04:47:41');
INSERT INTO `attendances` VALUES ('1299', '57', '484', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:47:41', '2024-01-23 04:47:41');
INSERT INTO `attendances` VALUES ('1300', '57', '486', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:47:41', '2024-01-23 04:47:41');
INSERT INTO `attendances` VALUES ('1301', '22', '488', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:47:41', '2024-01-23 04:47:41');
INSERT INTO `attendances` VALUES ('1302', '22', '490', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:47:41', '2024-01-23 04:47:41');
INSERT INTO `attendances` VALUES ('1303', '22', '492', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:47:41', '2024-01-23 04:47:41');
INSERT INTO `attendances` VALUES ('1304', '22', '494', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:47:41', '2024-01-23 04:47:41');
INSERT INTO `attendances` VALUES ('1305', '22', '496', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:47:41', '2024-01-23 04:47:41');
INSERT INTO `attendances` VALUES ('1306', '22', '498', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:47:41', '2024-01-23 04:47:41');
INSERT INTO `attendances` VALUES ('1307', '22', '500', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:47:41', '2024-01-23 04:47:41');
INSERT INTO `attendances` VALUES ('1308', '22', '502', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:47:41', '2024-01-23 04:47:41');
INSERT INTO `attendances` VALUES ('1309', '22', '504', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:47:41', '2024-01-23 04:47:41');
INSERT INTO `attendances` VALUES ('1310', '22', '506', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:47:41', '2024-01-23 04:47:41');
INSERT INTO `attendances` VALUES ('1311', '22', '508', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:47:41', '2024-01-23 04:47:41');
INSERT INTO `attendances` VALUES ('1312', '22', '510', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:47:41', '2024-01-23 04:47:41');
INSERT INTO `attendances` VALUES ('1313', '22', '512', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:47:41', '2024-01-23 04:47:41');
INSERT INTO `attendances` VALUES ('1314', '22', '514', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:47:41', '2024-01-23 04:47:41');
INSERT INTO `attendances` VALUES ('1315', '22', '516', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:47:41', '2024-01-23 04:47:41');
INSERT INTO `attendances` VALUES ('1316', '22', '518', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:47:41', '2024-01-23 04:47:41');
INSERT INTO `attendances` VALUES ('1317', '22', '520', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:47:41', '2024-01-23 04:47:41');
INSERT INTO `attendances` VALUES ('1318', '22', '522', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:47:41', '2024-01-23 04:47:41');
INSERT INTO `attendances` VALUES ('1319', '22', '524', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:47:41', '2024-01-23 04:47:41');
INSERT INTO `attendances` VALUES ('1320', '22', '526', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:47:41', '2024-01-23 04:47:41');
INSERT INTO `attendances` VALUES ('1321', '59', '334', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:49:20', '2024-01-23 04:49:20');
INSERT INTO `attendances` VALUES ('1322', '59', '528', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:49:20', '2024-01-23 04:49:20');
INSERT INTO `attendances` VALUES ('1323', '23', '530', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:49:20', '2024-01-23 04:49:20');
INSERT INTO `attendances` VALUES ('1324', '59', '532', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:49:20', '2024-01-23 04:49:20');
INSERT INTO `attendances` VALUES ('1325', '59', '534', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:49:20', '2024-01-23 04:49:20');
INSERT INTO `attendances` VALUES ('1326', '59', '536', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:49:20', '2024-01-23 04:49:20');
INSERT INTO `attendances` VALUES ('1327', '59', '538', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:49:20', '2024-01-23 04:49:20');
INSERT INTO `attendances` VALUES ('1328', '59', '540', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:49:20', '2024-01-23 04:49:20');
INSERT INTO `attendances` VALUES ('1329', '59', '542', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:49:20', '2024-01-23 04:49:20');
INSERT INTO `attendances` VALUES ('1330', '59', '544', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:49:20', '2024-01-23 04:49:20');
INSERT INTO `attendances` VALUES ('1331', '59', '546', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:49:20', '2024-01-23 04:49:20');
INSERT INTO `attendances` VALUES ('1332', '23', '548', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:49:20', '2024-01-23 04:49:20');
INSERT INTO `attendances` VALUES ('1333', '23', '550', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:49:20', '2024-01-23 04:49:20');
INSERT INTO `attendances` VALUES ('1334', '23', '552', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:49:20', '2024-01-23 04:49:20');
INSERT INTO `attendances` VALUES ('1335', '23', '554', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:49:20', '2024-01-23 04:49:20');
INSERT INTO `attendances` VALUES ('1336', '23', '556', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:49:20', '2024-01-23 04:49:20');
INSERT INTO `attendances` VALUES ('1337', '23', '558', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:49:20', '2024-01-23 04:49:20');
INSERT INTO `attendances` VALUES ('1338', '23', '560', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:49:20', '2024-01-23 04:49:20');
INSERT INTO `attendances` VALUES ('1339', '23', '562', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:49:20', '2024-01-23 04:49:20');
INSERT INTO `attendances` VALUES ('1340', '23', '564', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:49:20', '2024-01-23 04:49:20');
INSERT INTO `attendances` VALUES ('1341', '23', '566', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:49:20', '2024-01-23 04:49:20');
INSERT INTO `attendances` VALUES ('1342', '23', '568', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:49:20', '2024-01-23 04:49:20');
INSERT INTO `attendances` VALUES ('1343', '23', '570', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:49:20', '2024-01-23 04:49:20');
INSERT INTO `attendances` VALUES ('1344', '23', '572', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:49:20', '2024-01-23 04:49:20');
INSERT INTO `attendances` VALUES ('1345', '23', '574', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:49:20', '2024-01-23 04:49:20');
INSERT INTO `attendances` VALUES ('1346', '23', '576', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:49:20', '2024-01-23 04:49:20');
INSERT INTO `attendances` VALUES ('1347', '23', '578', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:49:20', '2024-01-23 04:49:20');
INSERT INTO `attendances` VALUES ('1348', '23', '580', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:49:20', '2024-01-23 04:49:20');
INSERT INTO `attendances` VALUES ('1349', '23', '582', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:49:20', '2024-01-23 04:49:20');
INSERT INTO `attendances` VALUES ('1350', '23', '584', '17', '0', '2023-11-22', '', '12', '2024-01-23 04:49:20', '2024-01-23 04:49:20');
INSERT INTO `attendances` VALUES ('1351', '23', '586', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:49:20', '2024-01-23 04:49:20');
INSERT INTO `attendances` VALUES ('1352', '23', '588', '17', '0', '2023-11-22', '', '12', '2024-01-23 04:49:20', '2024-01-23 04:49:20');
INSERT INTO `attendances` VALUES ('1353', '59', '334', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:49:31', '2024-01-23 04:49:31');
INSERT INTO `attendances` VALUES ('1354', '59', '528', '17', '0', '2023-11-23', '', '12', '2024-01-23 04:49:31', '2024-01-23 04:49:31');
INSERT INTO `attendances` VALUES ('1355', '23', '530', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:49:31', '2024-01-23 04:49:31');
INSERT INTO `attendances` VALUES ('1356', '59', '532', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:49:31', '2024-01-23 04:49:31');
INSERT INTO `attendances` VALUES ('1357', '59', '534', '17', '0', '2023-11-23', '', '12', '2024-01-23 04:49:31', '2024-01-23 04:49:31');
INSERT INTO `attendances` VALUES ('1358', '59', '536', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:49:31', '2024-01-23 04:49:31');
INSERT INTO `attendances` VALUES ('1359', '59', '538', '17', '0', '2023-11-23', '', '12', '2024-01-23 04:49:31', '2024-01-23 04:49:31');
INSERT INTO `attendances` VALUES ('1360', '59', '540', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:49:31', '2024-01-23 04:49:31');
INSERT INTO `attendances` VALUES ('1361', '59', '542', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:49:31', '2024-01-23 04:49:31');
INSERT INTO `attendances` VALUES ('1362', '59', '544', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:49:31', '2024-01-23 04:49:31');
INSERT INTO `attendances` VALUES ('1363', '59', '546', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:49:31', '2024-01-23 04:49:31');
INSERT INTO `attendances` VALUES ('1364', '23', '548', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:49:31', '2024-01-23 04:49:31');
INSERT INTO `attendances` VALUES ('1365', '23', '550', '17', '0', '2023-11-23', '', '12', '2024-01-23 04:49:31', '2024-01-23 04:49:31');
INSERT INTO `attendances` VALUES ('1366', '23', '552', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:49:31', '2024-01-23 04:49:31');
INSERT INTO `attendances` VALUES ('1367', '23', '554', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:49:31', '2024-01-23 04:49:31');
INSERT INTO `attendances` VALUES ('1368', '23', '556', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:49:31', '2024-01-23 04:49:31');
INSERT INTO `attendances` VALUES ('1369', '23', '558', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:49:31', '2024-01-23 04:49:31');
INSERT INTO `attendances` VALUES ('1370', '23', '560', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:49:31', '2024-01-23 04:49:31');
INSERT INTO `attendances` VALUES ('1371', '23', '562', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:49:31', '2024-01-23 04:49:31');
INSERT INTO `attendances` VALUES ('1372', '23', '564', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:49:31', '2024-01-23 04:49:31');
INSERT INTO `attendances` VALUES ('1373', '23', '566', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:49:31', '2024-01-23 04:49:31');
INSERT INTO `attendances` VALUES ('1374', '23', '568', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:49:31', '2024-01-23 04:49:31');
INSERT INTO `attendances` VALUES ('1375', '23', '570', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:49:31', '2024-01-23 04:49:31');
INSERT INTO `attendances` VALUES ('1376', '23', '572', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:49:31', '2024-01-23 04:49:31');
INSERT INTO `attendances` VALUES ('1377', '23', '574', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:49:31', '2024-01-23 04:49:31');
INSERT INTO `attendances` VALUES ('1378', '23', '576', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:49:31', '2024-01-23 04:49:31');
INSERT INTO `attendances` VALUES ('1379', '23', '578', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:49:31', '2024-01-23 04:49:31');
INSERT INTO `attendances` VALUES ('1380', '23', '580', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:49:31', '2024-01-23 04:49:31');
INSERT INTO `attendances` VALUES ('1381', '23', '582', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:49:31', '2024-01-23 04:49:31');
INSERT INTO `attendances` VALUES ('1382', '23', '584', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:49:31', '2024-01-23 04:49:31');
INSERT INTO `attendances` VALUES ('1383', '23', '586', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:49:31', '2024-01-23 04:49:31');
INSERT INTO `attendances` VALUES ('1384', '23', '588', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:49:31', '2024-01-23 04:49:31');
INSERT INTO `attendances` VALUES ('1385', '59', '334', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:49:44', '2024-01-23 04:49:44');
INSERT INTO `attendances` VALUES ('1386', '59', '528', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:49:44', '2024-01-23 04:49:44');
INSERT INTO `attendances` VALUES ('1387', '23', '530', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:49:44', '2024-01-23 04:49:44');
INSERT INTO `attendances` VALUES ('1388', '59', '532', '17', '0', '2023-11-24', '', '12', '2024-01-23 04:49:44', '2024-01-23 04:49:44');
INSERT INTO `attendances` VALUES ('1389', '59', '534', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:49:44', '2024-01-23 04:49:44');
INSERT INTO `attendances` VALUES ('1390', '59', '536', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:49:44', '2024-01-23 04:49:44');
INSERT INTO `attendances` VALUES ('1391', '59', '538', '17', '0', '2023-11-24', '', '12', '2024-01-23 04:49:44', '2024-01-23 04:49:44');
INSERT INTO `attendances` VALUES ('1392', '59', '540', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:49:44', '2024-01-23 04:49:44');
INSERT INTO `attendances` VALUES ('1393', '59', '542', '17', '0', '2023-11-24', '', '12', '2024-01-23 04:49:44', '2024-01-23 04:49:44');
INSERT INTO `attendances` VALUES ('1394', '59', '544', '17', '0', '2023-11-24', '', '12', '2024-01-23 04:49:44', '2024-01-23 04:49:44');
INSERT INTO `attendances` VALUES ('1395', '59', '546', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:49:44', '2024-01-23 04:49:44');
INSERT INTO `attendances` VALUES ('1396', '23', '548', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:49:44', '2024-01-23 04:49:44');
INSERT INTO `attendances` VALUES ('1397', '23', '550', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:49:44', '2024-01-23 04:49:44');
INSERT INTO `attendances` VALUES ('1398', '23', '552', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:49:44', '2024-01-23 04:49:44');
INSERT INTO `attendances` VALUES ('1399', '23', '554', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:49:44', '2024-01-23 04:49:44');
INSERT INTO `attendances` VALUES ('1400', '23', '556', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:49:44', '2024-01-23 04:49:44');
INSERT INTO `attendances` VALUES ('1401', '23', '558', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:49:44', '2024-01-23 04:49:44');
INSERT INTO `attendances` VALUES ('1402', '23', '560', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:49:44', '2024-01-23 04:49:44');
INSERT INTO `attendances` VALUES ('1403', '23', '562', '17', '0', '2023-11-24', '', '12', '2024-01-23 04:49:44', '2024-01-23 04:49:44');
INSERT INTO `attendances` VALUES ('1404', '23', '564', '17', '0', '2023-11-24', '', '12', '2024-01-23 04:49:44', '2024-01-23 04:49:44');
INSERT INTO `attendances` VALUES ('1405', '23', '566', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:49:44', '2024-01-23 04:49:44');
INSERT INTO `attendances` VALUES ('1406', '23', '568', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:49:44', '2024-01-23 04:49:44');
INSERT INTO `attendances` VALUES ('1407', '23', '570', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:49:44', '2024-01-23 04:49:44');
INSERT INTO `attendances` VALUES ('1408', '23', '572', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:49:44', '2024-01-23 04:49:44');
INSERT INTO `attendances` VALUES ('1409', '23', '574', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:49:44', '2024-01-23 04:49:44');
INSERT INTO `attendances` VALUES ('1410', '23', '576', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:49:44', '2024-01-23 04:49:44');
INSERT INTO `attendances` VALUES ('1411', '23', '578', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:49:44', '2024-01-23 04:49:44');
INSERT INTO `attendances` VALUES ('1412', '23', '580', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:49:44', '2024-01-23 04:49:44');
INSERT INTO `attendances` VALUES ('1413', '23', '582', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:49:44', '2024-01-23 04:49:44');
INSERT INTO `attendances` VALUES ('1414', '23', '584', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:49:44', '2024-01-23 04:49:44');
INSERT INTO `attendances` VALUES ('1415', '23', '586', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:49:44', '2024-01-23 04:49:44');
INSERT INTO `attendances` VALUES ('1416', '23', '588', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:49:44', '2024-01-23 04:49:44');
INSERT INTO `attendances` VALUES ('1417', '59', '334', '17', '1', '2023-11-25', '', '12', '2024-01-23 04:49:56', '2024-01-23 04:49:56');
INSERT INTO `attendances` VALUES ('1418', '59', '528', '17', '1', '2023-11-25', '', '12', '2024-01-23 04:49:56', '2024-01-23 04:49:56');
INSERT INTO `attendances` VALUES ('1419', '23', '530', '17', '1', '2023-11-25', '', '12', '2024-01-23 04:49:56', '2024-01-23 04:49:56');
INSERT INTO `attendances` VALUES ('1420', '59', '532', '17', '0', '2023-11-25', '', '12', '2024-01-23 04:49:56', '2024-01-23 04:49:56');
INSERT INTO `attendances` VALUES ('1421', '59', '534', '17', '1', '2023-11-25', '', '12', '2024-01-23 04:49:56', '2024-01-23 04:49:56');
INSERT INTO `attendances` VALUES ('1422', '59', '536', '17', '1', '2023-11-25', '', '12', '2024-01-23 04:49:56', '2024-01-23 04:49:56');
INSERT INTO `attendances` VALUES ('1423', '59', '538', '17', '1', '2023-11-25', '', '12', '2024-01-23 04:49:56', '2024-01-23 04:49:56');
INSERT INTO `attendances` VALUES ('1424', '59', '540', '17', '1', '2023-11-25', '', '12', '2024-01-23 04:49:56', '2024-01-23 04:49:56');
INSERT INTO `attendances` VALUES ('1425', '59', '542', '17', '1', '2023-11-25', '', '12', '2024-01-23 04:49:56', '2024-01-23 04:49:56');
INSERT INTO `attendances` VALUES ('1426', '59', '544', '17', '0', '2023-11-25', '', '12', '2024-01-23 04:49:56', '2024-01-23 04:49:56');
INSERT INTO `attendances` VALUES ('1427', '59', '546', '17', '0', '2023-11-25', '', '12', '2024-01-23 04:49:56', '2024-01-23 04:49:56');
INSERT INTO `attendances` VALUES ('1428', '23', '548', '17', '0', '2023-11-25', '', '12', '2024-01-23 04:49:56', '2024-01-23 04:49:56');
INSERT INTO `attendances` VALUES ('1429', '23', '550', '17', '1', '2023-11-25', '', '12', '2024-01-23 04:49:56', '2024-01-23 04:49:56');
INSERT INTO `attendances` VALUES ('1430', '23', '552', '17', '0', '2023-11-25', '', '12', '2024-01-23 04:49:56', '2024-01-23 04:49:56');
INSERT INTO `attendances` VALUES ('1431', '23', '554', '17', '1', '2023-11-25', '', '12', '2024-01-23 04:49:56', '2024-01-23 04:49:56');
INSERT INTO `attendances` VALUES ('1432', '23', '556', '17', '1', '2023-11-25', '', '12', '2024-01-23 04:49:56', '2024-01-23 04:49:56');
INSERT INTO `attendances` VALUES ('1433', '23', '558', '17', '1', '2023-11-25', '', '12', '2024-01-23 04:49:56', '2024-01-23 04:49:56');
INSERT INTO `attendances` VALUES ('1434', '23', '560', '17', '1', '2023-11-25', '', '12', '2024-01-23 04:49:56', '2024-01-23 04:49:56');
INSERT INTO `attendances` VALUES ('1435', '23', '562', '17', '1', '2023-11-25', '', '12', '2024-01-23 04:49:56', '2024-01-23 04:49:56');
INSERT INTO `attendances` VALUES ('1436', '23', '564', '17', '1', '2023-11-25', '', '12', '2024-01-23 04:49:56', '2024-01-23 04:49:56');
INSERT INTO `attendances` VALUES ('1437', '23', '566', '17', '0', '2023-11-25', '', '12', '2024-01-23 04:49:56', '2024-01-23 04:49:56');
INSERT INTO `attendances` VALUES ('1438', '23', '568', '17', '0', '2023-11-25', '', '12', '2024-01-23 04:49:56', '2024-01-23 04:49:56');
INSERT INTO `attendances` VALUES ('1439', '23', '570', '17', '1', '2023-11-25', '', '12', '2024-01-23 04:49:56', '2024-01-23 04:49:56');
INSERT INTO `attendances` VALUES ('1440', '23', '572', '17', '1', '2023-11-25', '', '12', '2024-01-23 04:49:56', '2024-01-23 04:49:56');
INSERT INTO `attendances` VALUES ('1441', '23', '574', '17', '1', '2023-11-25', '', '12', '2024-01-23 04:49:56', '2024-01-23 04:49:56');
INSERT INTO `attendances` VALUES ('1442', '23', '576', '17', '1', '2023-11-25', '', '12', '2024-01-23 04:49:56', '2024-01-23 04:49:56');
INSERT INTO `attendances` VALUES ('1443', '23', '578', '17', '1', '2023-11-25', '', '12', '2024-01-23 04:49:56', '2024-01-23 04:49:56');
INSERT INTO `attendances` VALUES ('1444', '23', '580', '17', '1', '2023-11-25', '', '12', '2024-01-23 04:49:56', '2024-01-23 04:49:56');
INSERT INTO `attendances` VALUES ('1445', '23', '582', '17', '1', '2023-11-25', '', '12', '2024-01-23 04:49:56', '2024-01-23 04:49:56');
INSERT INTO `attendances` VALUES ('1446', '23', '584', '17', '1', '2023-11-25', '', '12', '2024-01-23 04:49:56', '2024-01-23 04:49:56');
INSERT INTO `attendances` VALUES ('1447', '23', '586', '17', '1', '2023-11-25', '', '12', '2024-01-23 04:49:56', '2024-01-23 04:49:56');
INSERT INTO `attendances` VALUES ('1448', '23', '588', '17', '1', '2023-11-25', '', '12', '2024-01-23 04:49:56', '2024-01-23 04:49:56');
INSERT INTO `attendances` VALUES ('1449', '24', '335', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1450', '24', '590', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1451', '24', '592', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1452', '24', '594', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1453', '24', '596', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1454', '24', '598', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1455', '24', '600', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1456', '24', '602', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1457', '24', '604', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1458', '24', '606', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1459', '24', '608', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1460', '24', '610', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1461', '24', '612', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1462', '24', '614', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1463', '24', '616', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1464', '24', '618', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1465', '24', '620', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1466', '24', '622', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1467', '24', '624', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1468', '24', '626', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1469', '24', '628', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1470', '24', '630', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1471', '24', '632', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1472', '24', '634', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1473', '24', '636', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1474', '24', '638', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1475', '24', '640', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1476', '24', '642', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1477', '24', '644', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1478', '24', '646', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1479', '24', '648', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1480', '24', '650', '17', '0', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1481', '24', '652', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1482', '24', '654', '17', '0', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1483', '24', '656', '17', '0', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1484', '24', '658', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1485', '24', '660', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1486', '24', '662', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:51:25', '2024-01-23 04:51:25');
INSERT INTO `attendances` VALUES ('1487', '24', '335', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1488', '24', '590', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1489', '24', '592', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1490', '24', '594', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1491', '24', '596', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1492', '24', '598', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1493', '24', '600', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1494', '24', '602', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1495', '24', '604', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1496', '24', '606', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1497', '24', '608', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1498', '24', '610', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1499', '24', '612', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1500', '24', '614', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1501', '24', '616', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1502', '24', '618', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1503', '24', '620', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1504', '24', '622', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1505', '24', '624', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1506', '24', '626', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1507', '24', '628', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1508', '24', '630', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1509', '24', '632', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1510', '24', '634', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1511', '24', '636', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1512', '24', '638', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1513', '24', '640', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1514', '24', '642', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1515', '24', '644', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1516', '24', '646', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1517', '24', '648', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1518', '24', '650', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1519', '24', '652', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1520', '24', '654', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1521', '24', '656', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1522', '24', '658', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1523', '24', '660', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1524', '24', '662', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:51:32', '2024-01-23 04:51:32');
INSERT INTO `attendances` VALUES ('1525', '24', '335', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1526', '24', '590', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1527', '24', '592', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1528', '24', '594', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1529', '24', '596', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1530', '24', '598', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1531', '24', '600', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1532', '24', '602', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1533', '24', '604', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1534', '24', '606', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1535', '24', '608', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1536', '24', '610', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1537', '24', '612', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1538', '24', '614', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1539', '24', '616', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1540', '24', '618', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1541', '24', '620', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1542', '24', '622', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1543', '24', '624', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1544', '24', '626', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1545', '24', '628', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1546', '24', '630', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1547', '24', '632', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1548', '24', '634', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1549', '24', '636', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1550', '24', '638', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1551', '24', '640', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1552', '24', '642', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1553', '24', '644', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1554', '24', '646', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1555', '24', '648', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1556', '24', '650', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1557', '24', '652', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1558', '24', '654', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1559', '24', '656', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1560', '24', '658', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1561', '24', '660', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1562', '24', '662', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:51:40', '2024-01-23 04:51:40');
INSERT INTO `attendances` VALUES ('1563', '25', '336', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1564', '25', '664', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1565', '25', '666', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1566', '25', '668', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1567', '25', '670', '17', '0', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1568', '25', '672', '17', '0', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1569', '25', '674', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1570', '25', '676', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1571', '25', '678', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1572', '25', '680', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1573', '25', '682', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1574', '25', '684', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1575', '25', '686', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1576', '25', '688', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1577', '25', '690', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1578', '25', '692', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1579', '25', '694', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1580', '25', '696', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1581', '25', '698', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1582', '25', '700', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1583', '25', '702', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1584', '25', '704', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1585', '25', '706', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1586', '25', '708', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1587', '25', '710', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1588', '25', '712', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1589', '25', '714', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1590', '25', '716', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1591', '25', '718', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1592', '25', '720', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1593', '25', '722', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1594', '25', '724', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1595', '25', '726', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1596', '25', '728', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1597', '25', '730', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1598', '25', '732', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1599', '25', '734', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1600', '25', '736', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1601', '25', '738', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1602', '25', '740', '17', '0', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1603', '25', '742', '17', '0', '2023-11-22', '', '12', '2024-01-23 04:53:32', '2024-01-23 04:53:32');
INSERT INTO `attendances` VALUES ('1604', '25', '336', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1605', '25', '664', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1606', '25', '666', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1607', '25', '668', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1608', '25', '670', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1609', '25', '672', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1610', '25', '674', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1611', '25', '676', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1612', '25', '678', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1613', '25', '680', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1614', '25', '682', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1615', '25', '684', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1616', '25', '686', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1617', '25', '688', '17', '0', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1618', '25', '690', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1619', '25', '692', '17', '0', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1620', '25', '694', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1621', '25', '696', '17', '0', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1622', '25', '698', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1623', '25', '700', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1624', '25', '702', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1625', '25', '704', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1626', '25', '706', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1627', '25', '708', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1628', '25', '710', '17', '0', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1629', '25', '712', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1630', '25', '714', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1631', '25', '716', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1632', '25', '718', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1633', '25', '720', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1634', '25', '722', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1635', '25', '724', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1636', '25', '726', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1637', '25', '728', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1638', '25', '730', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1639', '25', '732', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1640', '25', '734', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1641', '25', '736', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1642', '25', '738', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1643', '25', '740', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1644', '25', '742', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:53:41', '2024-01-23 04:53:41');
INSERT INTO `attendances` VALUES ('1645', '25', '336', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1646', '25', '664', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1647', '25', '666', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1648', '25', '668', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1649', '25', '670', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1650', '25', '672', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1651', '25', '674', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1652', '25', '676', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1653', '25', '678', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1654', '25', '680', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1655', '25', '682', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1656', '25', '684', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1657', '25', '686', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1658', '25', '688', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1659', '25', '690', '17', '0', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1660', '25', '692', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1661', '25', '694', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1662', '25', '696', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1663', '25', '698', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1664', '25', '700', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1665', '25', '702', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1666', '25', '704', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1667', '25', '706', '17', '0', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1668', '25', '708', '17', '0', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1669', '25', '710', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1670', '25', '712', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1671', '25', '714', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1672', '25', '716', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1673', '25', '718', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1674', '25', '720', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1675', '25', '722', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1676', '25', '724', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1677', '25', '726', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1678', '25', '728', '17', '0', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1679', '25', '730', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1680', '25', '732', '17', '0', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1681', '25', '734', '17', '0', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1682', '25', '736', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1683', '25', '738', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1684', '25', '740', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1685', '25', '742', '17', '0', '2023-11-24', '', '12', '2024-01-23 04:53:53', '2024-01-23 04:53:53');
INSERT INTO `attendances` VALUES ('1686', '26', '337', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:54:49', '2024-01-23 04:54:49');
INSERT INTO `attendances` VALUES ('1687', '26', '744', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:54:49', '2024-01-23 04:54:49');
INSERT INTO `attendances` VALUES ('1688', '26', '746', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:54:49', '2024-01-23 04:54:49');
INSERT INTO `attendances` VALUES ('1689', '26', '748', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:54:49', '2024-01-23 04:54:49');
INSERT INTO `attendances` VALUES ('1690', '26', '750', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:54:49', '2024-01-23 04:54:49');
INSERT INTO `attendances` VALUES ('1691', '26', '752', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:54:49', '2024-01-23 04:54:49');
INSERT INTO `attendances` VALUES ('1692', '26', '754', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:54:49', '2024-01-23 04:54:49');
INSERT INTO `attendances` VALUES ('1693', '26', '756', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:54:49', '2024-01-23 04:54:49');
INSERT INTO `attendances` VALUES ('1694', '26', '758', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:54:49', '2024-01-23 04:54:49');
INSERT INTO `attendances` VALUES ('1695', '26', '760', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:54:49', '2024-01-23 04:54:49');
INSERT INTO `attendances` VALUES ('1696', '26', '762', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:54:49', '2024-01-23 04:54:49');
INSERT INTO `attendances` VALUES ('1697', '26', '764', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:54:49', '2024-01-23 04:54:49');
INSERT INTO `attendances` VALUES ('1698', '26', '766', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:54:49', '2024-01-23 04:54:49');
INSERT INTO `attendances` VALUES ('1699', '26', '768', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:54:49', '2024-01-23 04:54:49');
INSERT INTO `attendances` VALUES ('1700', '26', '770', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:54:49', '2024-01-23 04:54:49');
INSERT INTO `attendances` VALUES ('1701', '26', '772', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:54:49', '2024-01-23 04:54:49');
INSERT INTO `attendances` VALUES ('1702', '26', '774', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:54:49', '2024-01-23 04:54:49');
INSERT INTO `attendances` VALUES ('1703', '26', '776', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:54:49', '2024-01-23 04:54:49');
INSERT INTO `attendances` VALUES ('1704', '26', '778', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:54:49', '2024-01-23 04:54:49');
INSERT INTO `attendances` VALUES ('1705', '26', '780', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:54:49', '2024-01-23 04:54:49');
INSERT INTO `attendances` VALUES ('1706', '26', '782', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:54:49', '2024-01-23 04:54:49');
INSERT INTO `attendances` VALUES ('1707', '26', '784', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:54:49', '2024-01-23 04:54:49');
INSERT INTO `attendances` VALUES ('1708', '26', '786', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:54:49', '2024-01-23 04:54:49');
INSERT INTO `attendances` VALUES ('1709', '26', '788', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:54:49', '2024-01-23 04:54:49');
INSERT INTO `attendances` VALUES ('1710', '26', '790', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:54:49', '2024-01-23 04:54:49');
INSERT INTO `attendances` VALUES ('1711', '26', '792', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:54:49', '2024-01-23 04:54:49');
INSERT INTO `attendances` VALUES ('1712', '26', '794', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:54:49', '2024-01-23 04:54:49');
INSERT INTO `attendances` VALUES ('1713', '26', '796', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:54:49', '2024-01-23 04:54:49');
INSERT INTO `attendances` VALUES ('1714', '26', '798', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:54:49', '2024-01-23 04:54:49');
INSERT INTO `attendances` VALUES ('1715', '26', '800', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:54:49', '2024-01-23 04:54:49');
INSERT INTO `attendances` VALUES ('1716', '26', '802', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:54:49', '2024-01-23 04:54:49');
INSERT INTO `attendances` VALUES ('1717', '31', '341', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:55:40', '2024-01-23 04:55:40');
INSERT INTO `attendances` VALUES ('1718', '31', '1004', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:55:40', '2024-01-23 04:55:40');
INSERT INTO `attendances` VALUES ('1719', '31', '1006', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:55:40', '2024-01-23 04:55:40');
INSERT INTO `attendances` VALUES ('1720', '31', '1008', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:55:40', '2024-01-23 04:55:40');
INSERT INTO `attendances` VALUES ('1721', '31', '1010', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:55:40', '2024-01-23 04:55:40');
INSERT INTO `attendances` VALUES ('1722', '31', '1012', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:55:40', '2024-01-23 04:55:40');
INSERT INTO `attendances` VALUES ('1723', '31', '1014', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:55:40', '2024-01-23 04:55:40');
INSERT INTO `attendances` VALUES ('1724', '31', '1016', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:55:40', '2024-01-23 04:55:40');
INSERT INTO `attendances` VALUES ('1725', '31', '1018', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:55:40', '2024-01-23 04:55:40');
INSERT INTO `attendances` VALUES ('1726', '31', '1020', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:55:40', '2024-01-23 04:55:40');
INSERT INTO `attendances` VALUES ('1727', '31', '1022', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:55:40', '2024-01-23 04:55:40');
INSERT INTO `attendances` VALUES ('1728', '31', '1024', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:55:40', '2024-01-23 04:55:40');
INSERT INTO `attendances` VALUES ('1729', '31', '1026', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:55:40', '2024-01-23 04:55:40');
INSERT INTO `attendances` VALUES ('1730', '31', '1028', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:55:40', '2024-01-23 04:55:40');
INSERT INTO `attendances` VALUES ('1731', '31', '1030', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:55:40', '2024-01-23 04:55:40');
INSERT INTO `attendances` VALUES ('1732', '31', '1032', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:55:40', '2024-01-23 04:55:40');
INSERT INTO `attendances` VALUES ('1733', '31', '1034', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:55:40', '2024-01-23 04:55:40');
INSERT INTO `attendances` VALUES ('1734', '31', '1036', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:55:40', '2024-01-23 04:55:40');
INSERT INTO `attendances` VALUES ('1735', '31', '1038', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:55:40', '2024-01-23 04:55:40');
INSERT INTO `attendances` VALUES ('1736', '31', '1040', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:55:40', '2024-01-23 04:55:40');
INSERT INTO `attendances` VALUES ('1737', '31', '1042', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:55:40', '2024-01-23 04:55:40');
INSERT INTO `attendances` VALUES ('1738', '31', '1044', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:55:40', '2024-01-23 04:55:40');
INSERT INTO `attendances` VALUES ('1739', '31', '1046', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:55:40', '2024-01-23 04:55:40');
INSERT INTO `attendances` VALUES ('1740', '31', '1048', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:55:40', '2024-01-23 04:55:40');
INSERT INTO `attendances` VALUES ('1741', '31', '1050', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:55:40', '2024-01-23 04:55:40');
INSERT INTO `attendances` VALUES ('1742', '31', '1052', '17', '0', '2023-11-22', '', '12', '2024-01-23 04:55:40', '2024-01-23 04:55:40');
INSERT INTO `attendances` VALUES ('1743', '31', '1054', '17', '1', '2023-11-22', '', '12', '2024-01-23 04:55:40', '2024-01-23 04:55:40');
INSERT INTO `attendances` VALUES ('1744', '31', '1056', '17', '0', '2023-11-22', '', '12', '2024-01-23 04:55:40', '2024-01-23 04:55:40');
INSERT INTO `attendances` VALUES ('1745', '31', '1058', '17', '0', '2023-11-22', '', '12', '2024-01-23 04:55:40', '2024-01-23 04:55:40');
INSERT INTO `attendances` VALUES ('1746', '31', '1060', '17', '0', '2023-11-22', '', '12', '2024-01-23 04:55:40', '2024-01-23 04:55:40');
INSERT INTO `attendances` VALUES ('1747', '31', '1062', '17', '0', '2023-11-22', '', '12', '2024-01-23 04:55:40', '2024-01-23 04:55:40');
INSERT INTO `attendances` VALUES ('1748', '31', '341', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:55:55', '2024-01-23 04:55:55');
INSERT INTO `attendances` VALUES ('1749', '31', '1004', '17', '0', '2023-11-23', '', '12', '2024-01-23 04:55:55', '2024-01-23 04:55:55');
INSERT INTO `attendances` VALUES ('1750', '31', '1006', '17', '0', '2023-11-23', '', '12', '2024-01-23 04:55:55', '2024-01-23 04:55:55');
INSERT INTO `attendances` VALUES ('1751', '31', '1008', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:55:55', '2024-01-23 04:55:55');
INSERT INTO `attendances` VALUES ('1752', '31', '1010', '17', '0', '2023-11-23', '', '12', '2024-01-23 04:55:55', '2024-01-23 04:55:55');
INSERT INTO `attendances` VALUES ('1753', '31', '1012', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:55:55', '2024-01-23 04:55:55');
INSERT INTO `attendances` VALUES ('1754', '31', '1014', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:55:55', '2024-01-23 04:55:55');
INSERT INTO `attendances` VALUES ('1755', '31', '1016', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:55:55', '2024-01-23 04:55:55');
INSERT INTO `attendances` VALUES ('1756', '31', '1018', '17', '0', '2023-11-23', '', '12', '2024-01-23 04:55:55', '2024-01-23 04:55:55');
INSERT INTO `attendances` VALUES ('1757', '31', '1020', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:55:55', '2024-01-23 04:55:55');
INSERT INTO `attendances` VALUES ('1758', '31', '1022', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:55:55', '2024-01-23 04:55:55');
INSERT INTO `attendances` VALUES ('1759', '31', '1024', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:55:55', '2024-01-23 04:55:55');
INSERT INTO `attendances` VALUES ('1760', '31', '1026', '17', '0', '2023-11-23', '', '12', '2024-01-23 04:55:55', '2024-01-23 04:55:55');
INSERT INTO `attendances` VALUES ('1761', '31', '1028', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:55:55', '2024-01-23 04:55:55');
INSERT INTO `attendances` VALUES ('1762', '31', '1030', '17', '0', '2023-11-23', '', '12', '2024-01-23 04:55:55', '2024-01-23 04:55:55');
INSERT INTO `attendances` VALUES ('1763', '31', '1032', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:55:55', '2024-01-23 04:55:55');
INSERT INTO `attendances` VALUES ('1764', '31', '1034', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:55:55', '2024-01-23 04:55:55');
INSERT INTO `attendances` VALUES ('1765', '31', '1036', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:55:55', '2024-01-23 04:55:55');
INSERT INTO `attendances` VALUES ('1766', '31', '1038', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:55:55', '2024-01-23 04:55:55');
INSERT INTO `attendances` VALUES ('1767', '31', '1040', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:55:55', '2024-01-23 04:55:55');
INSERT INTO `attendances` VALUES ('1768', '31', '1042', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:55:55', '2024-01-23 04:55:55');
INSERT INTO `attendances` VALUES ('1769', '31', '1044', '17', '0', '2023-11-23', '', '12', '2024-01-23 04:55:55', '2024-01-23 04:55:55');
INSERT INTO `attendances` VALUES ('1770', '31', '1046', '17', '0', '2023-11-23', '', '12', '2024-01-23 04:55:55', '2024-01-23 04:55:55');
INSERT INTO `attendances` VALUES ('1771', '31', '1048', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:55:55', '2024-01-23 04:55:55');
INSERT INTO `attendances` VALUES ('1772', '31', '1050', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:55:55', '2024-01-23 04:55:55');
INSERT INTO `attendances` VALUES ('1773', '31', '1052', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:55:55', '2024-01-23 04:55:55');
INSERT INTO `attendances` VALUES ('1774', '31', '1054', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:55:55', '2024-01-23 04:55:55');
INSERT INTO `attendances` VALUES ('1775', '31', '1056', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:55:55', '2024-01-23 04:55:55');
INSERT INTO `attendances` VALUES ('1776', '31', '1058', '17', '1', '2023-11-23', '', '12', '2024-01-23 04:55:55', '2024-01-23 04:55:55');
INSERT INTO `attendances` VALUES ('1777', '31', '1060', '17', '0', '2023-11-23', '', '12', '2024-01-23 04:55:55', '2024-01-23 04:55:55');
INSERT INTO `attendances` VALUES ('1778', '31', '1062', '17', '0', '2023-11-23', '', '12', '2024-01-23 04:55:55', '2024-01-23 04:55:55');
INSERT INTO `attendances` VALUES ('1779', '31', '341', '17', '0', '2023-11-24', '', '12', '2024-01-23 04:56:10', '2024-01-23 04:56:10');
INSERT INTO `attendances` VALUES ('1780', '31', '1004', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:56:10', '2024-01-23 04:56:10');
INSERT INTO `attendances` VALUES ('1781', '31', '1006', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:56:10', '2024-01-23 04:56:10');
INSERT INTO `attendances` VALUES ('1782', '31', '1008', '17', '0', '2023-11-24', '', '12', '2024-01-23 04:56:10', '2024-01-23 04:56:10');
INSERT INTO `attendances` VALUES ('1783', '31', '1010', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:56:10', '2024-01-23 04:56:10');
INSERT INTO `attendances` VALUES ('1784', '31', '1012', '17', '0', '2023-11-24', '', '12', '2024-01-23 04:56:10', '2024-01-23 04:56:10');
INSERT INTO `attendances` VALUES ('1785', '31', '1014', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:56:10', '2024-01-23 04:56:10');
INSERT INTO `attendances` VALUES ('1786', '31', '1016', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:56:10', '2024-01-23 04:56:10');
INSERT INTO `attendances` VALUES ('1787', '31', '1018', '17', '0', '2023-11-24', '', '12', '2024-01-23 04:56:10', '2024-01-23 04:56:10');
INSERT INTO `attendances` VALUES ('1788', '31', '1020', '17', '0', '2023-11-24', '', '12', '2024-01-23 04:56:10', '2024-01-23 04:56:10');
INSERT INTO `attendances` VALUES ('1789', '31', '1022', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:56:10', '2024-01-23 04:56:10');
INSERT INTO `attendances` VALUES ('1790', '31', '1024', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:56:10', '2024-01-23 04:56:10');
INSERT INTO `attendances` VALUES ('1791', '31', '1026', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:56:10', '2024-01-23 04:56:10');
INSERT INTO `attendances` VALUES ('1792', '31', '1028', '17', '0', '2023-11-24', '', '12', '2024-01-23 04:56:10', '2024-01-23 04:56:10');
INSERT INTO `attendances` VALUES ('1793', '31', '1030', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:56:10', '2024-01-23 04:56:10');
INSERT INTO `attendances` VALUES ('1794', '31', '1032', '17', '0', '2023-11-24', '', '12', '2024-01-23 04:56:10', '2024-01-23 04:56:10');
INSERT INTO `attendances` VALUES ('1795', '31', '1034', '17', '0', '2023-11-24', '', '12', '2024-01-23 04:56:10', '2024-01-23 04:56:10');
INSERT INTO `attendances` VALUES ('1796', '31', '1036', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:56:10', '2024-01-23 04:56:10');
INSERT INTO `attendances` VALUES ('1797', '31', '1038', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:56:10', '2024-01-23 04:56:10');
INSERT INTO `attendances` VALUES ('1798', '31', '1040', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:56:10', '2024-01-23 04:56:10');
INSERT INTO `attendances` VALUES ('1799', '31', '1042', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:56:10', '2024-01-23 04:56:10');
INSERT INTO `attendances` VALUES ('1800', '31', '1044', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:56:10', '2024-01-23 04:56:10');
INSERT INTO `attendances` VALUES ('1801', '31', '1046', '17', '0', '2023-11-24', '', '12', '2024-01-23 04:56:10', '2024-01-23 04:56:10');
INSERT INTO `attendances` VALUES ('1802', '31', '1048', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:56:10', '2024-01-23 04:56:10');
INSERT INTO `attendances` VALUES ('1803', '31', '1050', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:56:10', '2024-01-23 04:56:10');
INSERT INTO `attendances` VALUES ('1804', '31', '1052', '17', '0', '2023-11-24', '', '12', '2024-01-23 04:56:10', '2024-01-23 04:56:10');
INSERT INTO `attendances` VALUES ('1805', '31', '1054', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:56:10', '2024-01-23 04:56:10');
INSERT INTO `attendances` VALUES ('1806', '31', '1056', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:56:10', '2024-01-23 04:56:10');
INSERT INTO `attendances` VALUES ('1807', '31', '1058', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:56:10', '2024-01-23 04:56:10');
INSERT INTO `attendances` VALUES ('1808', '31', '1060', '17', '0', '2023-11-24', '', '12', '2024-01-23 04:56:10', '2024-01-23 04:56:10');
INSERT INTO `attendances` VALUES ('1809', '31', '1062', '17', '1', '2023-11-24', '', '12', '2024-01-23 04:56:10', '2024-01-23 04:56:10');
INSERT INTO `attendances` VALUES ('1810', '21', '369', '17', '0', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1811', '21', '371', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1812', '21', '373', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1813', '21', '375', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1814', '21', '377', '17', '0', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1815', '21', '379', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1816', '21', '381', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1817', '21', '383', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1818', '21', '385', '17', '0', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1819', '21', '387', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1820', '21', '389', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1821', '21', '391', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1822', '21', '393', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1823', '21', '395', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1824', '21', '397', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1825', '21', '399', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1826', '21', '401', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1827', '21', '403', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1828', '21', '405', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1829', '21', '407', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1830', '21', '409', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1831', '21', '411', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1832', '21', '413', '17', '0', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1833', '21', '415', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1834', '21', '417', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1835', '21', '419', '17', '0', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1836', '21', '421', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1837', '21', '423', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1838', '21', '425', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1839', '21', '427', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1840', '21', '429', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1841', '21', '431', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1842', '21', '433', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1843', '21', '435', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1844', '21', '437', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1845', '21', '439', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1846', '21', '441', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1847', '21', '443', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1848', '21', '445', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1849', '21', '447', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1850', '21', '449', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1851', '21', '451', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1852', '21', '453', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1853', '21', '455', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1854', '21', '457', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1855', '21', '459', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1856', '21', '461', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1857', '21', '463', '17', '0', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1858', '21', '465', '17', '0', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1859', '21', '467', '17', '1', '2024-03-12', '', '12', '2024-03-12 13:08:43', '2024-03-12 13:08:43');
INSERT INTO `attendances` VALUES ('1860', '26', '337', '17', '1', '2024-05-17', '', '12', '2024-05-17 17:08:04', '2024-05-17 17:08:04');
INSERT INTO `attendances` VALUES ('1861', '26', '744', '17', '0', '2024-05-17', '', '12', '2024-05-17 17:08:04', '2024-05-17 17:08:04');
INSERT INTO `attendances` VALUES ('1862', '26', '746', '17', '1', '2024-05-17', '', '12', '2024-05-17 17:08:04', '2024-05-17 17:08:04');
INSERT INTO `attendances` VALUES ('1863', '26', '748', '17', '1', '2024-05-17', '', '12', '2024-05-17 17:08:04', '2024-05-17 17:08:04');
INSERT INTO `attendances` VALUES ('1864', '26', '750', '17', '0', '2024-05-17', '', '12', '2024-05-17 17:08:04', '2024-05-17 17:08:04');
INSERT INTO `attendances` VALUES ('1865', '26', '752', '17', '1', '2024-05-17', '', '12', '2024-05-17 17:08:04', '2024-05-17 17:08:04');
INSERT INTO `attendances` VALUES ('1866', '26', '754', '17', '1', '2024-05-17', '', '12', '2024-05-17 17:08:04', '2024-05-17 17:08:04');
INSERT INTO `attendances` VALUES ('1867', '26', '756', '17', '1', '2024-05-17', '', '12', '2024-05-17 17:08:04', '2024-05-17 17:08:04');
INSERT INTO `attendances` VALUES ('1868', '26', '758', '17', '1', '2024-05-17', '', '12', '2024-05-17 17:08:04', '2024-05-17 17:08:04');
INSERT INTO `attendances` VALUES ('1869', '26', '760', '17', '1', '2024-05-17', '', '12', '2024-05-17 17:08:04', '2024-05-17 17:08:04');
INSERT INTO `attendances` VALUES ('1870', '26', '762', '17', '1', '2024-05-17', '', '12', '2024-05-17 17:08:04', '2024-05-17 17:08:04');
INSERT INTO `attendances` VALUES ('1871', '26', '764', '17', '1', '2024-05-17', '', '12', '2024-05-17 17:08:04', '2024-05-17 17:08:04');
INSERT INTO `attendances` VALUES ('1872', '26', '766', '17', '1', '2024-05-17', '', '12', '2024-05-17 17:08:04', '2024-05-17 17:08:04');
INSERT INTO `attendances` VALUES ('1873', '26', '768', '17', '1', '2024-05-17', '', '12', '2024-05-17 17:08:04', '2024-05-17 17:08:04');
INSERT INTO `attendances` VALUES ('1874', '26', '770', '17', '1', '2024-05-17', '', '12', '2024-05-17 17:08:04', '2024-05-17 17:08:04');
INSERT INTO `attendances` VALUES ('1875', '26', '772', '17', '1', '2024-05-17', '', '12', '2024-05-17 17:08:04', '2024-05-17 17:08:04');
INSERT INTO `attendances` VALUES ('1876', '26', '774', '17', '1', '2024-05-17', '', '12', '2024-05-17 17:08:04', '2024-05-17 17:08:04');
INSERT INTO `attendances` VALUES ('1877', '26', '776', '17', '1', '2024-05-17', '', '12', '2024-05-17 17:08:04', '2024-05-17 17:08:04');
INSERT INTO `attendances` VALUES ('1878', '26', '778', '17', '1', '2024-05-17', '', '12', '2024-05-17 17:08:04', '2024-05-17 17:08:04');
INSERT INTO `attendances` VALUES ('1879', '26', '780', '17', '1', '2024-05-17', '', '12', '2024-05-17 17:08:04', '2024-05-17 17:08:04');
INSERT INTO `attendances` VALUES ('1880', '26', '782', '17', '1', '2024-05-17', '', '12', '2024-05-17 17:08:04', '2024-05-17 17:08:04');
INSERT INTO `attendances` VALUES ('1881', '26', '784', '17', '1', '2024-05-17', '', '12', '2024-05-17 17:08:04', '2024-05-17 17:08:04');
INSERT INTO `attendances` VALUES ('1882', '26', '786', '17', '1', '2024-05-17', '', '12', '2024-05-17 17:08:04', '2024-05-17 17:08:04');
INSERT INTO `attendances` VALUES ('1883', '26', '788', '17', '1', '2024-05-17', '', '12', '2024-05-17 17:08:04', '2024-05-17 17:08:04');
INSERT INTO `attendances` VALUES ('1884', '26', '790', '17', '1', '2024-05-17', '', '12', '2024-05-17 17:08:04', '2024-05-17 17:08:04');
INSERT INTO `attendances` VALUES ('1885', '26', '792', '17', '1', '2024-05-17', '', '12', '2024-05-17 17:08:04', '2024-05-17 17:08:04');
INSERT INTO `attendances` VALUES ('1886', '26', '794', '17', '1', '2024-05-17', '', '12', '2024-05-17 17:08:04', '2024-05-17 17:08:04');
INSERT INTO `attendances` VALUES ('1887', '26', '796', '17', '1', '2024-05-17', '', '12', '2024-05-17 17:08:04', '2024-05-17 17:08:04');
INSERT INTO `attendances` VALUES ('1888', '26', '798', '17', '1', '2024-05-17', '', '12', '2024-05-17 17:08:04', '2024-05-17 17:08:04');
INSERT INTO `attendances` VALUES ('1889', '26', '800', '17', '1', '2024-05-17', '', '12', '2024-05-17 17:08:04', '2024-05-17 17:08:04');
INSERT INTO `attendances` VALUES ('1890', '26', '802', '17', '0', '2024-05-17', '', '12', '2024-05-17 17:08:04', '2024-05-17 17:08:04');
INSERT INTO `attendances` VALUES ('1892', '26', '337', '17', '1', '2024-07-17', '', '12', '2024-07-17 14:12:19', '2024-07-17 14:12:19');
INSERT INTO `attendances` VALUES ('1893', '26', '744', '17', '1', '2024-07-17', '', '12', '2024-07-17 14:12:19', '2024-07-17 14:12:19');
INSERT INTO `attendances` VALUES ('1894', '26', '746', '17', '0', '2024-07-17', '', '12', '2024-07-17 14:12:19', '2024-07-17 14:12:19');
INSERT INTO `attendances` VALUES ('1895', '26', '748', '17', '1', '2024-07-17', '', '12', '2024-07-17 14:12:19', '2024-07-17 14:12:19');
INSERT INTO `attendances` VALUES ('1896', '26', '750', '17', '1', '2024-07-17', '', '12', '2024-07-17 14:12:19', '2024-07-17 14:12:19');
INSERT INTO `attendances` VALUES ('1897', '26', '752', '17', '1', '2024-07-17', '', '12', '2024-07-17 14:12:19', '2024-07-17 14:12:19');
INSERT INTO `attendances` VALUES ('1898', '26', '754', '17', '1', '2024-07-17', '', '12', '2024-07-17 14:12:19', '2024-07-17 14:12:19');
INSERT INTO `attendances` VALUES ('1899', '26', '756', '17', '1', '2024-07-17', '', '12', '2024-07-17 14:12:19', '2024-07-17 14:12:19');
INSERT INTO `attendances` VALUES ('1900', '26', '758', '17', '1', '2024-07-17', '', '12', '2024-07-17 14:12:19', '2024-07-17 14:12:19');
INSERT INTO `attendances` VALUES ('1901', '26', '760', '17', '1', '2024-07-17', '', '12', '2024-07-17 14:12:19', '2024-07-17 14:12:19');
INSERT INTO `attendances` VALUES ('1902', '26', '762', '17', '1', '2024-07-17', '', '12', '2024-07-17 14:12:19', '2024-07-17 14:12:19');
INSERT INTO `attendances` VALUES ('1903', '26', '764', '17', '0', '2024-07-17', '', '12', '2024-07-17 14:12:19', '2024-07-17 14:12:19');
INSERT INTO `attendances` VALUES ('1904', '26', '766', '17', '1', '2024-07-17', '', '12', '2024-07-17 14:12:19', '2024-07-17 14:12:19');
INSERT INTO `attendances` VALUES ('1905', '26', '768', '17', '1', '2024-07-17', '', '12', '2024-07-17 14:12:19', '2024-07-17 14:12:19');
INSERT INTO `attendances` VALUES ('1906', '26', '770', '17', '1', '2024-07-17', '', '12', '2024-07-17 14:12:19', '2024-07-17 14:12:19');
INSERT INTO `attendances` VALUES ('1907', '26', '772', '17', '1', '2024-07-17', '', '12', '2024-07-17 14:12:19', '2024-07-17 14:12:19');
INSERT INTO `attendances` VALUES ('1908', '26', '774', '17', '1', '2024-07-17', '', '12', '2024-07-17 14:12:19', '2024-07-17 14:12:19');
INSERT INTO `attendances` VALUES ('1909', '26', '776', '17', '1', '2024-07-17', '', '12', '2024-07-17 14:12:19', '2024-07-17 14:12:19');
INSERT INTO `attendances` VALUES ('1910', '26', '778', '17', '1', '2024-07-17', '', '12', '2024-07-17 14:12:19', '2024-07-17 14:12:19');
INSERT INTO `attendances` VALUES ('1911', '26', '780', '17', '1', '2024-07-17', '', '12', '2024-07-17 14:12:19', '2024-07-17 14:12:19');
INSERT INTO `attendances` VALUES ('1912', '26', '782', '17', '1', '2024-07-17', '', '12', '2024-07-17 14:12:19', '2024-07-17 14:12:19');
INSERT INTO `attendances` VALUES ('1913', '26', '784', '17', '1', '2024-07-17', '', '12', '2024-07-17 14:12:19', '2024-07-17 14:12:19');
INSERT INTO `attendances` VALUES ('1914', '26', '786', '17', '1', '2024-07-17', '', '12', '2024-07-17 14:12:19', '2024-07-17 14:12:19');
INSERT INTO `attendances` VALUES ('1915', '26', '788', '17', '1', '2024-07-17', '', '12', '2024-07-17 14:12:19', '2024-07-17 14:12:19');
INSERT INTO `attendances` VALUES ('1916', '26', '790', '17', '1', '2024-07-17', '', '12', '2024-07-17 14:12:19', '2024-07-17 14:12:19');
INSERT INTO `attendances` VALUES ('1917', '26', '792', '17', '1', '2024-07-17', '', '12', '2024-07-17 14:12:19', '2024-07-17 14:12:19');
INSERT INTO `attendances` VALUES ('1918', '26', '794', '17', '1', '2024-07-17', '', '12', '2024-07-17 14:12:19', '2024-07-17 14:12:19');
INSERT INTO `attendances` VALUES ('1919', '26', '796', '17', '1', '2024-07-17', '', '12', '2024-07-17 14:12:19', '2024-07-17 14:12:19');
INSERT INTO `attendances` VALUES ('1920', '26', '798', '17', '1', '2024-07-17', '', '12', '2024-07-17 14:12:19', '2024-07-17 14:12:19');
INSERT INTO `attendances` VALUES ('1921', '26', '800', '17', '1', '2024-07-17', '', '12', '2024-07-17 14:12:19', '2024-07-17 14:12:19');
INSERT INTO `attendances` VALUES ('1922', '26', '802', '17', '1', '2024-07-17', '', '12', '2024-07-17 14:12:19', '2024-07-17 14:12:19');
INSERT INTO `attendances` VALUES ('1923', '26', '337', '17', '1', '2024-07-01', '', '12', '2024-07-17 15:21:36', '2024-07-17 15:22:10');
INSERT INTO `attendances` VALUES ('1924', '26', '744', '17', '1', '2024-07-01', '', '12', '2024-07-17 15:21:36', '2024-07-17 15:22:10');
INSERT INTO `attendances` VALUES ('1925', '26', '746', '17', '1', '2024-07-01', '', '12', '2024-07-17 15:21:36', '2024-07-17 15:22:10');
INSERT INTO `attendances` VALUES ('1926', '26', '748', '17', '1', '2024-07-01', '', '12', '2024-07-17 15:21:36', '2024-07-17 15:22:10');
INSERT INTO `attendances` VALUES ('1927', '26', '750', '17', '1', '2024-07-01', '', '12', '2024-07-17 15:21:36', '2024-07-17 15:22:10');
INSERT INTO `attendances` VALUES ('1928', '26', '752', '17', '1', '2024-07-01', '', '12', '2024-07-17 15:21:36', '2024-07-17 15:22:10');
INSERT INTO `attendances` VALUES ('1929', '26', '754', '17', '1', '2024-07-01', '', '12', '2024-07-17 15:21:36', '2024-07-17 15:22:10');
INSERT INTO `attendances` VALUES ('1930', '26', '756', '17', '1', '2024-07-01', '', '12', '2024-07-17 15:21:36', '2024-07-17 15:22:10');
INSERT INTO `attendances` VALUES ('1931', '26', '758', '17', '1', '2024-07-01', '', '12', '2024-07-17 15:21:36', '2024-07-17 15:22:10');
INSERT INTO `attendances` VALUES ('1932', '26', '760', '17', '1', '2024-07-01', '', '12', '2024-07-17 15:21:36', '2024-07-17 15:22:10');
INSERT INTO `attendances` VALUES ('1933', '26', '762', '17', '1', '2024-07-01', '', '12', '2024-07-17 15:21:36', '2024-07-17 15:22:10');
INSERT INTO `attendances` VALUES ('1934', '26', '764', '17', '1', '2024-07-01', '', '12', '2024-07-17 15:21:36', '2024-07-17 15:22:10');
INSERT INTO `attendances` VALUES ('1935', '26', '766', '17', '1', '2024-07-01', '', '12', '2024-07-17 15:21:36', '2024-07-17 15:22:10');
INSERT INTO `attendances` VALUES ('1936', '26', '768', '17', '1', '2024-07-01', '', '12', '2024-07-17 15:21:36', '2024-07-17 15:22:10');
INSERT INTO `attendances` VALUES ('1937', '26', '770', '17', '1', '2024-07-01', '', '12', '2024-07-17 15:21:36', '2024-07-17 15:22:10');
INSERT INTO `attendances` VALUES ('1938', '26', '772', '17', '1', '2024-07-01', '', '12', '2024-07-17 15:21:36', '2024-07-17 15:22:10');
INSERT INTO `attendances` VALUES ('1939', '26', '774', '17', '1', '2024-07-01', '', '12', '2024-07-17 15:21:36', '2024-07-17 15:22:10');
INSERT INTO `attendances` VALUES ('1940', '26', '776', '17', '1', '2024-07-01', '', '12', '2024-07-17 15:21:36', '2024-07-17 15:22:10');
INSERT INTO `attendances` VALUES ('1941', '26', '778', '17', '1', '2024-07-01', '', '12', '2024-07-17 15:21:36', '2024-07-17 15:22:10');
INSERT INTO `attendances` VALUES ('1942', '26', '780', '17', '1', '2024-07-01', '', '12', '2024-07-17 15:21:36', '2024-07-17 15:22:10');
INSERT INTO `attendances` VALUES ('1943', '26', '782', '17', '1', '2024-07-01', '', '12', '2024-07-17 15:21:36', '2024-07-17 15:22:10');
INSERT INTO `attendances` VALUES ('1944', '26', '784', '17', '1', '2024-07-01', '', '12', '2024-07-17 15:21:36', '2024-07-17 15:22:10');
INSERT INTO `attendances` VALUES ('1945', '26', '786', '17', '1', '2024-07-01', '', '12', '2024-07-17 15:21:36', '2024-07-17 15:22:10');
INSERT INTO `attendances` VALUES ('1946', '26', '788', '17', '1', '2024-07-01', '', '12', '2024-07-17 15:21:36', '2024-07-17 15:22:10');
INSERT INTO `attendances` VALUES ('1947', '26', '790', '17', '1', '2024-07-01', '', '12', '2024-07-17 15:21:36', '2024-07-17 15:22:10');
INSERT INTO `attendances` VALUES ('1948', '26', '792', '17', '1', '2024-07-01', '', '12', '2024-07-17 15:21:36', '2024-07-17 15:22:10');
INSERT INTO `attendances` VALUES ('1949', '26', '794', '17', '1', '2024-07-01', '', '12', '2024-07-17 15:21:36', '2024-07-17 15:22:10');
INSERT INTO `attendances` VALUES ('1950', '26', '796', '17', '1', '2024-07-01', '', '12', '2024-07-17 15:21:36', '2024-07-17 15:22:10');
INSERT INTO `attendances` VALUES ('1951', '26', '798', '17', '1', '2024-07-01', '', '12', '2024-07-17 15:21:36', '2024-07-17 15:22:10');
INSERT INTO `attendances` VALUES ('1952', '26', '800', '17', '1', '2024-07-01', '', '12', '2024-07-17 15:21:36', '2024-07-17 15:22:10');
INSERT INTO `attendances` VALUES ('1953', '26', '802', '17', '1', '2024-07-01', '', '12', '2024-07-17 15:21:36', '2024-07-17 15:22:10');
INSERT INTO `attendances` VALUES ('1954', '26', '337', '17', '1', '2024-07-02', '', '12', '2024-07-17 15:21:46', '2024-07-17 15:21:46');
INSERT INTO `attendances` VALUES ('1955', '26', '744', '17', '1', '2024-07-02', '', '12', '2024-07-17 15:21:46', '2024-07-17 15:21:46');
INSERT INTO `attendances` VALUES ('1956', '26', '746', '17', '1', '2024-07-02', '', '12', '2024-07-17 15:21:46', '2024-07-17 15:21:46');
INSERT INTO `attendances` VALUES ('1957', '26', '748', '17', '1', '2024-07-02', '', '12', '2024-07-17 15:21:46', '2024-07-17 15:21:46');
INSERT INTO `attendances` VALUES ('1958', '26', '750', '17', '1', '2024-07-02', '', '12', '2024-07-17 15:21:46', '2024-07-17 15:21:46');
INSERT INTO `attendances` VALUES ('1959', '26', '752', '17', '1', '2024-07-02', '', '12', '2024-07-17 15:21:46', '2024-07-17 15:21:46');
INSERT INTO `attendances` VALUES ('1960', '26', '754', '17', '1', '2024-07-02', '', '12', '2024-07-17 15:21:46', '2024-07-17 15:21:46');
INSERT INTO `attendances` VALUES ('1961', '26', '756', '17', '1', '2024-07-02', '', '12', '2024-07-17 15:21:46', '2024-07-17 15:21:46');
INSERT INTO `attendances` VALUES ('1962', '26', '758', '17', '1', '2024-07-02', '', '12', '2024-07-17 15:21:46', '2024-07-17 15:21:46');
INSERT INTO `attendances` VALUES ('1963', '26', '760', '17', '1', '2024-07-02', '', '12', '2024-07-17 15:21:46', '2024-07-17 15:21:46');
INSERT INTO `attendances` VALUES ('1964', '26', '762', '17', '1', '2024-07-02', '', '12', '2024-07-17 15:21:46', '2024-07-17 15:21:46');
INSERT INTO `attendances` VALUES ('1965', '26', '764', '17', '1', '2024-07-02', '', '12', '2024-07-17 15:21:46', '2024-07-17 15:21:46');
INSERT INTO `attendances` VALUES ('1966', '26', '766', '17', '1', '2024-07-02', '', '12', '2024-07-17 15:21:46', '2024-07-17 15:21:46');
INSERT INTO `attendances` VALUES ('1967', '26', '768', '17', '0', '2024-07-02', '', '12', '2024-07-17 15:21:46', '2024-07-17 15:21:46');
INSERT INTO `attendances` VALUES ('1968', '26', '770', '17', '1', '2024-07-02', '', '12', '2024-07-17 15:21:46', '2024-07-17 15:21:46');
INSERT INTO `attendances` VALUES ('1969', '26', '772', '17', '1', '2024-07-02', '', '12', '2024-07-17 15:21:46', '2024-07-17 15:21:46');
INSERT INTO `attendances` VALUES ('1970', '26', '774', '17', '1', '2024-07-02', '', '12', '2024-07-17 15:21:46', '2024-07-17 15:21:46');
INSERT INTO `attendances` VALUES ('1971', '26', '776', '17', '1', '2024-07-02', '', '12', '2024-07-17 15:21:46', '2024-07-17 15:21:46');
INSERT INTO `attendances` VALUES ('1972', '26', '778', '17', '1', '2024-07-02', '', '12', '2024-07-17 15:21:46', '2024-07-17 15:21:46');
INSERT INTO `attendances` VALUES ('1973', '26', '780', '17', '1', '2024-07-02', '', '12', '2024-07-17 15:21:46', '2024-07-17 15:21:46');
INSERT INTO `attendances` VALUES ('1974', '26', '782', '17', '1', '2024-07-02', '', '12', '2024-07-17 15:21:46', '2024-07-17 15:21:46');
INSERT INTO `attendances` VALUES ('1975', '26', '784', '17', '1', '2024-07-02', '', '12', '2024-07-17 15:21:46', '2024-07-17 15:21:46');
INSERT INTO `attendances` VALUES ('1976', '26', '786', '17', '1', '2024-07-02', '', '12', '2024-07-17 15:21:46', '2024-07-17 15:21:46');
INSERT INTO `attendances` VALUES ('1977', '26', '788', '17', '1', '2024-07-02', '', '12', '2024-07-17 15:21:46', '2024-07-17 15:21:46');
INSERT INTO `attendances` VALUES ('1978', '26', '790', '17', '1', '2024-07-02', '', '12', '2024-07-17 15:21:46', '2024-07-17 15:21:46');
INSERT INTO `attendances` VALUES ('1979', '26', '792', '17', '1', '2024-07-02', '', '12', '2024-07-17 15:21:46', '2024-07-17 15:21:46');
INSERT INTO `attendances` VALUES ('1980', '26', '794', '17', '1', '2024-07-02', '', '12', '2024-07-17 15:21:46', '2024-07-17 15:21:46');
INSERT INTO `attendances` VALUES ('1981', '26', '796', '17', '0', '2024-07-02', '', '12', '2024-07-17 15:21:46', '2024-07-17 15:21:46');
INSERT INTO `attendances` VALUES ('1982', '26', '798', '17', '1', '2024-07-02', '', '12', '2024-07-17 15:21:46', '2024-07-17 15:21:46');
INSERT INTO `attendances` VALUES ('1983', '26', '800', '17', '1', '2024-07-02', '', '12', '2024-07-17 15:21:46', '2024-07-17 15:21:46');
INSERT INTO `attendances` VALUES ('1984', '26', '802', '17', '1', '2024-07-02', '', '12', '2024-07-17 15:21:46', '2024-07-17 15:21:46');
INSERT INTO `attendances` VALUES ('1985', '26', '337', '17', '1', '2024-07-03', '', '12', '2024-07-17 15:21:52', '2024-07-17 15:21:52');
INSERT INTO `attendances` VALUES ('1986', '26', '744', '17', '1', '2024-07-03', '', '12', '2024-07-17 15:21:52', '2024-07-17 15:21:52');
INSERT INTO `attendances` VALUES ('1987', '26', '746', '17', '1', '2024-07-03', '', '12', '2024-07-17 15:21:52', '2024-07-17 15:21:52');
INSERT INTO `attendances` VALUES ('1988', '26', '748', '17', '1', '2024-07-03', '', '12', '2024-07-17 15:21:52', '2024-07-17 15:21:52');
INSERT INTO `attendances` VALUES ('1989', '26', '750', '17', '1', '2024-07-03', '', '12', '2024-07-17 15:21:52', '2024-07-17 15:21:52');
INSERT INTO `attendances` VALUES ('1990', '26', '752', '17', '1', '2024-07-03', '', '12', '2024-07-17 15:21:52', '2024-07-17 15:21:52');
INSERT INTO `attendances` VALUES ('1991', '26', '754', '17', '1', '2024-07-03', '', '12', '2024-07-17 15:21:52', '2024-07-17 15:21:52');
INSERT INTO `attendances` VALUES ('1992', '26', '756', '17', '1', '2024-07-03', '', '12', '2024-07-17 15:21:52', '2024-07-17 15:21:52');
INSERT INTO `attendances` VALUES ('1993', '26', '758', '17', '1', '2024-07-03', '', '12', '2024-07-17 15:21:52', '2024-07-17 15:21:52');
INSERT INTO `attendances` VALUES ('1994', '26', '760', '17', '1', '2024-07-03', '', '12', '2024-07-17 15:21:52', '2024-07-17 15:21:52');
INSERT INTO `attendances` VALUES ('1995', '26', '762', '17', '1', '2024-07-03', '', '12', '2024-07-17 15:21:52', '2024-07-17 15:21:52');
INSERT INTO `attendances` VALUES ('1996', '26', '764', '17', '1', '2024-07-03', '', '12', '2024-07-17 15:21:52', '2024-07-17 15:21:52');
INSERT INTO `attendances` VALUES ('1997', '26', '766', '17', '1', '2024-07-03', '', '12', '2024-07-17 15:21:52', '2024-07-17 15:21:52');
INSERT INTO `attendances` VALUES ('1998', '26', '768', '17', '1', '2024-07-03', '', '12', '2024-07-17 15:21:52', '2024-07-17 15:21:52');
INSERT INTO `attendances` VALUES ('1999', '26', '770', '17', '1', '2024-07-03', '', '12', '2024-07-17 15:21:52', '2024-07-17 15:21:52');
INSERT INTO `attendances` VALUES ('2000', '26', '772', '17', '1', '2024-07-03', '', '12', '2024-07-17 15:21:52', '2024-07-17 15:21:52');
INSERT INTO `attendances` VALUES ('2001', '26', '774', '17', '1', '2024-07-03', '', '12', '2024-07-17 15:21:52', '2024-07-17 15:21:52');
INSERT INTO `attendances` VALUES ('2002', '26', '776', '17', '1', '2024-07-03', '', '12', '2024-07-17 15:21:52', '2024-07-17 15:21:52');
INSERT INTO `attendances` VALUES ('2003', '26', '778', '17', '1', '2024-07-03', '', '12', '2024-07-17 15:21:52', '2024-07-17 15:21:52');
INSERT INTO `attendances` VALUES ('2004', '26', '780', '17', '1', '2024-07-03', '', '12', '2024-07-17 15:21:52', '2024-07-17 15:21:52');
INSERT INTO `attendances` VALUES ('2005', '26', '782', '17', '1', '2024-07-03', '', '12', '2024-07-17 15:21:52', '2024-07-17 15:21:52');
INSERT INTO `attendances` VALUES ('2006', '26', '784', '17', '1', '2024-07-03', '', '12', '2024-07-17 15:21:52', '2024-07-17 15:21:52');
INSERT INTO `attendances` VALUES ('2007', '26', '786', '17', '1', '2024-07-03', '', '12', '2024-07-17 15:21:52', '2024-07-17 15:21:52');
INSERT INTO `attendances` VALUES ('2008', '26', '788', '17', '1', '2024-07-03', '', '12', '2024-07-17 15:21:52', '2024-07-17 15:21:52');
INSERT INTO `attendances` VALUES ('2009', '26', '790', '17', '1', '2024-07-03', '', '12', '2024-07-17 15:21:52', '2024-07-17 15:21:52');
INSERT INTO `attendances` VALUES ('2010', '26', '792', '17', '1', '2024-07-03', '', '12', '2024-07-17 15:21:52', '2024-07-17 15:21:52');
INSERT INTO `attendances` VALUES ('2011', '26', '794', '17', '1', '2024-07-03', '', '12', '2024-07-17 15:21:52', '2024-07-17 15:21:52');
INSERT INTO `attendances` VALUES ('2012', '26', '796', '17', '1', '2024-07-03', '', '12', '2024-07-17 15:21:52', '2024-07-17 15:21:52');
INSERT INTO `attendances` VALUES ('2013', '26', '798', '17', '1', '2024-07-03', '', '12', '2024-07-17 15:21:52', '2024-07-17 15:21:52');
INSERT INTO `attendances` VALUES ('2014', '26', '800', '17', '1', '2024-07-03', '', '12', '2024-07-17 15:21:52', '2024-07-17 15:21:52');
INSERT INTO `attendances` VALUES ('2015', '26', '802', '17', '1', '2024-07-03', '', '12', '2024-07-17 15:21:52', '2024-07-17 15:21:52');
INSERT INTO `attendances` VALUES ('2016', '26', '337', '17', '1', '2024-07-04', '', '12', '2024-07-17 15:21:58', '2024-07-17 15:21:58');
INSERT INTO `attendances` VALUES ('2017', '26', '744', '17', '1', '2024-07-04', '', '12', '2024-07-17 15:21:58', '2024-07-17 15:21:58');
INSERT INTO `attendances` VALUES ('2018', '26', '746', '17', '1', '2024-07-04', '', '12', '2024-07-17 15:21:58', '2024-07-17 15:21:58');
INSERT INTO `attendances` VALUES ('2019', '26', '748', '17', '1', '2024-07-04', '', '12', '2024-07-17 15:21:58', '2024-07-17 15:21:58');
INSERT INTO `attendances` VALUES ('2020', '26', '750', '17', '1', '2024-07-04', '', '12', '2024-07-17 15:21:58', '2024-07-17 15:21:58');
INSERT INTO `attendances` VALUES ('2021', '26', '752', '17', '1', '2024-07-04', '', '12', '2024-07-17 15:21:58', '2024-07-17 15:21:58');
INSERT INTO `attendances` VALUES ('2022', '26', '754', '17', '1', '2024-07-04', '', '12', '2024-07-17 15:21:58', '2024-07-17 15:21:58');
INSERT INTO `attendances` VALUES ('2023', '26', '756', '17', '1', '2024-07-04', '', '12', '2024-07-17 15:21:58', '2024-07-17 15:21:58');
INSERT INTO `attendances` VALUES ('2024', '26', '758', '17', '1', '2024-07-04', '', '12', '2024-07-17 15:21:58', '2024-07-17 15:21:58');
INSERT INTO `attendances` VALUES ('2025', '26', '760', '17', '1', '2024-07-04', '', '12', '2024-07-17 15:21:58', '2024-07-17 15:21:58');
INSERT INTO `attendances` VALUES ('2026', '26', '762', '17', '1', '2024-07-04', '', '12', '2024-07-17 15:21:58', '2024-07-17 15:21:58');
INSERT INTO `attendances` VALUES ('2027', '26', '764', '17', '1', '2024-07-04', '', '12', '2024-07-17 15:21:58', '2024-07-17 15:21:58');
INSERT INTO `attendances` VALUES ('2028', '26', '766', '17', '1', '2024-07-04', '', '12', '2024-07-17 15:21:58', '2024-07-17 15:21:58');
INSERT INTO `attendances` VALUES ('2029', '26', '768', '17', '1', '2024-07-04', '', '12', '2024-07-17 15:21:58', '2024-07-17 15:21:58');
INSERT INTO `attendances` VALUES ('2030', '26', '770', '17', '1', '2024-07-04', '', '12', '2024-07-17 15:21:58', '2024-07-17 15:21:58');
INSERT INTO `attendances` VALUES ('2031', '26', '772', '17', '1', '2024-07-04', '', '12', '2024-07-17 15:21:58', '2024-07-17 15:21:58');
INSERT INTO `attendances` VALUES ('2032', '26', '774', '17', '1', '2024-07-04', '', '12', '2024-07-17 15:21:58', '2024-07-17 15:21:58');
INSERT INTO `attendances` VALUES ('2033', '26', '776', '17', '1', '2024-07-04', '', '12', '2024-07-17 15:21:58', '2024-07-17 15:21:58');
INSERT INTO `attendances` VALUES ('2034', '26', '778', '17', '1', '2024-07-04', '', '12', '2024-07-17 15:21:58', '2024-07-17 15:21:58');
INSERT INTO `attendances` VALUES ('2035', '26', '780', '17', '1', '2024-07-04', '', '12', '2024-07-17 15:21:58', '2024-07-17 15:21:58');
INSERT INTO `attendances` VALUES ('2036', '26', '782', '17', '1', '2024-07-04', '', '12', '2024-07-17 15:21:58', '2024-07-17 15:21:58');
INSERT INTO `attendances` VALUES ('2037', '26', '784', '17', '1', '2024-07-04', '', '12', '2024-07-17 15:21:58', '2024-07-17 15:21:58');
INSERT INTO `attendances` VALUES ('2038', '26', '786', '17', '1', '2024-07-04', '', '12', '2024-07-17 15:21:58', '2024-07-17 15:21:58');
INSERT INTO `attendances` VALUES ('2039', '26', '788', '17', '1', '2024-07-04', '', '12', '2024-07-17 15:21:58', '2024-07-17 15:21:58');
INSERT INTO `attendances` VALUES ('2040', '26', '790', '17', '1', '2024-07-04', '', '12', '2024-07-17 15:21:58', '2024-07-17 15:21:58');
INSERT INTO `attendances` VALUES ('2041', '26', '792', '17', '1', '2024-07-04', '', '12', '2024-07-17 15:21:58', '2024-07-17 15:21:58');
INSERT INTO `attendances` VALUES ('2042', '26', '794', '17', '1', '2024-07-04', '', '12', '2024-07-17 15:21:58', '2024-07-17 15:21:58');
INSERT INTO `attendances` VALUES ('2043', '26', '796', '17', '1', '2024-07-04', '', '12', '2024-07-17 15:21:58', '2024-07-17 15:21:58');
INSERT INTO `attendances` VALUES ('2044', '26', '798', '17', '1', '2024-07-04', '', '12', '2024-07-17 15:21:58', '2024-07-17 15:21:58');
INSERT INTO `attendances` VALUES ('2045', '26', '800', '17', '1', '2024-07-04', '', '12', '2024-07-17 15:21:58', '2024-07-17 15:21:58');
INSERT INTO `attendances` VALUES ('2046', '26', '802', '17', '1', '2024-07-04', '', '12', '2024-07-17 15:21:58', '2024-07-17 15:21:58');
INSERT INTO `attendances` VALUES ('2047', '26', '337', '17', '1', '2024-07-05', '', '12', '2024-07-17 15:22:18', '2024-07-17 15:22:18');
INSERT INTO `attendances` VALUES ('2048', '26', '744', '17', '0', '2024-07-05', '', '12', '2024-07-17 15:22:18', '2024-07-17 15:22:18');
INSERT INTO `attendances` VALUES ('2049', '26', '746', '17', '1', '2024-07-05', '', '12', '2024-07-17 15:22:18', '2024-07-17 15:22:18');
INSERT INTO `attendances` VALUES ('2050', '26', '748', '17', '1', '2024-07-05', '', '12', '2024-07-17 15:22:18', '2024-07-17 15:22:18');
INSERT INTO `attendances` VALUES ('2051', '26', '750', '17', '1', '2024-07-05', '', '12', '2024-07-17 15:22:18', '2024-07-17 15:22:18');
INSERT INTO `attendances` VALUES ('2052', '26', '752', '17', '1', '2024-07-05', '', '12', '2024-07-17 15:22:18', '2024-07-17 15:22:18');
INSERT INTO `attendances` VALUES ('2053', '26', '754', '17', '1', '2024-07-05', '', '12', '2024-07-17 15:22:18', '2024-07-17 15:22:18');
INSERT INTO `attendances` VALUES ('2054', '26', '756', '17', '1', '2024-07-05', '', '12', '2024-07-17 15:22:18', '2024-07-17 15:22:18');
INSERT INTO `attendances` VALUES ('2055', '26', '758', '17', '1', '2024-07-05', '', '12', '2024-07-17 15:22:18', '2024-07-17 15:22:18');
INSERT INTO `attendances` VALUES ('2056', '26', '760', '17', '1', '2024-07-05', '', '12', '2024-07-17 15:22:18', '2024-07-17 15:22:18');
INSERT INTO `attendances` VALUES ('2057', '26', '762', '17', '1', '2024-07-05', '', '12', '2024-07-17 15:22:18', '2024-07-17 15:22:18');
INSERT INTO `attendances` VALUES ('2058', '26', '764', '17', '1', '2024-07-05', '', '12', '2024-07-17 15:22:18', '2024-07-17 15:22:18');
INSERT INTO `attendances` VALUES ('2059', '26', '766', '17', '0', '2024-07-05', '', '12', '2024-07-17 15:22:18', '2024-07-17 15:22:18');
INSERT INTO `attendances` VALUES ('2060', '26', '768', '17', '1', '2024-07-05', '', '12', '2024-07-17 15:22:18', '2024-07-17 15:22:18');
INSERT INTO `attendances` VALUES ('2061', '26', '770', '17', '1', '2024-07-05', '', '12', '2024-07-17 15:22:18', '2024-07-17 15:22:18');
INSERT INTO `attendances` VALUES ('2062', '26', '772', '17', '1', '2024-07-05', '', '12', '2024-07-17 15:22:18', '2024-07-17 15:22:18');
INSERT INTO `attendances` VALUES ('2063', '26', '774', '17', '1', '2024-07-05', '', '12', '2024-07-17 15:22:18', '2024-07-17 15:22:18');
INSERT INTO `attendances` VALUES ('2064', '26', '776', '17', '1', '2024-07-05', '', '12', '2024-07-17 15:22:18', '2024-07-17 15:22:18');
INSERT INTO `attendances` VALUES ('2065', '26', '778', '17', '1', '2024-07-05', '', '12', '2024-07-17 15:22:18', '2024-07-17 15:22:18');
INSERT INTO `attendances` VALUES ('2066', '26', '780', '17', '1', '2024-07-05', '', '12', '2024-07-17 15:22:18', '2024-07-17 15:22:18');
INSERT INTO `attendances` VALUES ('2067', '26', '782', '17', '1', '2024-07-05', '', '12', '2024-07-17 15:22:18', '2024-07-17 15:22:18');
INSERT INTO `attendances` VALUES ('2068', '26', '784', '17', '1', '2024-07-05', '', '12', '2024-07-17 15:22:18', '2024-07-17 15:22:18');
INSERT INTO `attendances` VALUES ('2069', '26', '786', '17', '1', '2024-07-05', '', '12', '2024-07-17 15:22:18', '2024-07-17 15:22:18');
INSERT INTO `attendances` VALUES ('2070', '26', '788', '17', '1', '2024-07-05', '', '12', '2024-07-17 15:22:18', '2024-07-17 15:22:18');
INSERT INTO `attendances` VALUES ('2071', '26', '790', '17', '1', '2024-07-05', '', '12', '2024-07-17 15:22:18', '2024-07-17 15:22:18');
INSERT INTO `attendances` VALUES ('2072', '26', '792', '17', '1', '2024-07-05', '', '12', '2024-07-17 15:22:18', '2024-07-17 15:22:18');
INSERT INTO `attendances` VALUES ('2073', '26', '794', '17', '1', '2024-07-05', '', '12', '2024-07-17 15:22:18', '2024-07-17 15:22:18');
INSERT INTO `attendances` VALUES ('2074', '26', '796', '17', '1', '2024-07-05', '', '12', '2024-07-17 15:22:18', '2024-07-17 15:22:18');
INSERT INTO `attendances` VALUES ('2075', '26', '798', '17', '0', '2024-07-05', '', '12', '2024-07-17 15:22:18', '2024-07-17 15:22:18');
INSERT INTO `attendances` VALUES ('2076', '26', '800', '17', '1', '2024-07-05', '', '12', '2024-07-17 15:22:18', '2024-07-17 15:22:18');
INSERT INTO `attendances` VALUES ('2077', '26', '802', '17', '1', '2024-07-05', '', '12', '2024-07-17 15:22:18', '2024-07-17 15:22:18');
INSERT INTO `attendances` VALUES ('2078', '26', '337', '17', '1', '2024-07-06', '', '12', '2024-07-17 15:22:24', '2024-07-17 15:22:24');
INSERT INTO `attendances` VALUES ('2079', '26', '744', '17', '1', '2024-07-06', '', '12', '2024-07-17 15:22:24', '2024-07-17 15:22:24');
INSERT INTO `attendances` VALUES ('2080', '26', '746', '17', '1', '2024-07-06', '', '12', '2024-07-17 15:22:24', '2024-07-17 15:22:24');
INSERT INTO `attendances` VALUES ('2081', '26', '748', '17', '1', '2024-07-06', '', '12', '2024-07-17 15:22:24', '2024-07-17 15:22:24');
INSERT INTO `attendances` VALUES ('2082', '26', '750', '17', '1', '2024-07-06', '', '12', '2024-07-17 15:22:24', '2024-07-17 15:22:24');
INSERT INTO `attendances` VALUES ('2083', '26', '752', '17', '1', '2024-07-06', '', '12', '2024-07-17 15:22:24', '2024-07-17 15:22:24');
INSERT INTO `attendances` VALUES ('2084', '26', '754', '17', '1', '2024-07-06', '', '12', '2024-07-17 15:22:24', '2024-07-17 15:22:24');
INSERT INTO `attendances` VALUES ('2085', '26', '756', '17', '1', '2024-07-06', '', '12', '2024-07-17 15:22:24', '2024-07-17 15:22:24');
INSERT INTO `attendances` VALUES ('2086', '26', '758', '17', '1', '2024-07-06', '', '12', '2024-07-17 15:22:24', '2024-07-17 15:22:24');
INSERT INTO `attendances` VALUES ('2087', '26', '760', '17', '1', '2024-07-06', '', '12', '2024-07-17 15:22:24', '2024-07-17 15:22:24');
INSERT INTO `attendances` VALUES ('2088', '26', '762', '17', '1', '2024-07-06', '', '12', '2024-07-17 15:22:24', '2024-07-17 15:22:24');
INSERT INTO `attendances` VALUES ('2089', '26', '764', '17', '1', '2024-07-06', '', '12', '2024-07-17 15:22:24', '2024-07-17 15:22:24');
INSERT INTO `attendances` VALUES ('2090', '26', '766', '17', '1', '2024-07-06', '', '12', '2024-07-17 15:22:24', '2024-07-17 15:22:24');
INSERT INTO `attendances` VALUES ('2091', '26', '768', '17', '1', '2024-07-06', '', '12', '2024-07-17 15:22:24', '2024-07-17 15:22:24');
INSERT INTO `attendances` VALUES ('2092', '26', '770', '17', '1', '2024-07-06', '', '12', '2024-07-17 15:22:24', '2024-07-17 15:22:24');
INSERT INTO `attendances` VALUES ('2093', '26', '772', '17', '1', '2024-07-06', '', '12', '2024-07-17 15:22:24', '2024-07-17 15:22:24');
INSERT INTO `attendances` VALUES ('2094', '26', '774', '17', '1', '2024-07-06', '', '12', '2024-07-17 15:22:24', '2024-07-17 15:22:24');
INSERT INTO `attendances` VALUES ('2095', '26', '776', '17', '1', '2024-07-06', '', '12', '2024-07-17 15:22:24', '2024-07-17 15:22:24');
INSERT INTO `attendances` VALUES ('2096', '26', '778', '17', '1', '2024-07-06', '', '12', '2024-07-17 15:22:24', '2024-07-17 15:22:24');
INSERT INTO `attendances` VALUES ('2097', '26', '780', '17', '1', '2024-07-06', '', '12', '2024-07-17 15:22:24', '2024-07-17 15:22:24');
INSERT INTO `attendances` VALUES ('2098', '26', '782', '17', '1', '2024-07-06', '', '12', '2024-07-17 15:22:24', '2024-07-17 15:22:24');
INSERT INTO `attendances` VALUES ('2099', '26', '784', '17', '1', '2024-07-06', '', '12', '2024-07-17 15:22:24', '2024-07-17 15:22:24');
INSERT INTO `attendances` VALUES ('2100', '26', '786', '17', '1', '2024-07-06', '', '12', '2024-07-17 15:22:24', '2024-07-17 15:22:24');
INSERT INTO `attendances` VALUES ('2101', '26', '788', '17', '1', '2024-07-06', '', '12', '2024-07-17 15:22:24', '2024-07-17 15:22:24');
INSERT INTO `attendances` VALUES ('2102', '26', '790', '17', '1', '2024-07-06', '', '12', '2024-07-17 15:22:24', '2024-07-17 15:22:24');
INSERT INTO `attendances` VALUES ('2103', '26', '792', '17', '1', '2024-07-06', '', '12', '2024-07-17 15:22:24', '2024-07-17 15:22:24');
INSERT INTO `attendances` VALUES ('2104', '26', '794', '17', '1', '2024-07-06', '', '12', '2024-07-17 15:22:24', '2024-07-17 15:22:24');
INSERT INTO `attendances` VALUES ('2105', '26', '796', '17', '1', '2024-07-06', '', '12', '2024-07-17 15:22:24', '2024-07-17 15:22:24');
INSERT INTO `attendances` VALUES ('2106', '26', '798', '17', '1', '2024-07-06', '', '12', '2024-07-17 15:22:24', '2024-07-17 15:22:24');
INSERT INTO `attendances` VALUES ('2107', '26', '800', '17', '1', '2024-07-06', '', '12', '2024-07-17 15:22:24', '2024-07-17 15:22:24');
INSERT INTO `attendances` VALUES ('2108', '26', '802', '17', '1', '2024-07-06', '', '12', '2024-07-17 15:22:24', '2024-07-17 15:22:24');
INSERT INTO `attendances` VALUES ('2109', '26', '337', '17', '1', '2024-07-08', '', '12', '2024-07-17 15:22:34', '2024-07-17 15:22:34');
INSERT INTO `attendances` VALUES ('2110', '26', '744', '17', '1', '2024-07-08', '', '12', '2024-07-17 15:22:34', '2024-07-17 15:22:34');
INSERT INTO `attendances` VALUES ('2111', '26', '746', '17', '1', '2024-07-08', '', '12', '2024-07-17 15:22:34', '2024-07-17 15:22:34');
INSERT INTO `attendances` VALUES ('2112', '26', '748', '17', '1', '2024-07-08', '', '12', '2024-07-17 15:22:34', '2024-07-17 15:22:34');
INSERT INTO `attendances` VALUES ('2113', '26', '750', '17', '1', '2024-07-08', '', '12', '2024-07-17 15:22:34', '2024-07-17 15:22:34');
INSERT INTO `attendances` VALUES ('2114', '26', '752', '17', '1', '2024-07-08', '', '12', '2024-07-17 15:22:34', '2024-07-17 15:22:34');
INSERT INTO `attendances` VALUES ('2115', '26', '754', '17', '1', '2024-07-08', '', '12', '2024-07-17 15:22:34', '2024-07-17 15:22:34');
INSERT INTO `attendances` VALUES ('2116', '26', '756', '17', '1', '2024-07-08', '', '12', '2024-07-17 15:22:34', '2024-07-17 15:22:34');
INSERT INTO `attendances` VALUES ('2117', '26', '758', '17', '0', '2024-07-08', '', '12', '2024-07-17 15:22:34', '2024-07-17 15:22:34');
INSERT INTO `attendances` VALUES ('2118', '26', '760', '17', '1', '2024-07-08', '', '12', '2024-07-17 15:22:34', '2024-07-17 15:22:34');
INSERT INTO `attendances` VALUES ('2119', '26', '762', '17', '0', '2024-07-08', '', '12', '2024-07-17 15:22:34', '2024-07-17 15:22:34');
INSERT INTO `attendances` VALUES ('2120', '26', '764', '17', '1', '2024-07-08', '', '12', '2024-07-17 15:22:34', '2024-07-17 15:22:34');
INSERT INTO `attendances` VALUES ('2121', '26', '766', '17', '1', '2024-07-08', '', '12', '2024-07-17 15:22:34', '2024-07-17 15:22:34');
INSERT INTO `attendances` VALUES ('2122', '26', '768', '17', '1', '2024-07-08', '', '12', '2024-07-17 15:22:34', '2024-07-17 15:22:34');
INSERT INTO `attendances` VALUES ('2123', '26', '770', '17', '1', '2024-07-08', '', '12', '2024-07-17 15:22:34', '2024-07-17 15:22:34');
INSERT INTO `attendances` VALUES ('2124', '26', '772', '17', '1', '2024-07-08', '', '12', '2024-07-17 15:22:34', '2024-07-17 15:22:34');
INSERT INTO `attendances` VALUES ('2125', '26', '774', '17', '1', '2024-07-08', '', '12', '2024-07-17 15:22:34', '2024-07-17 15:22:34');
INSERT INTO `attendances` VALUES ('2126', '26', '776', '17', '1', '2024-07-08', '', '12', '2024-07-17 15:22:34', '2024-07-17 15:22:34');
INSERT INTO `attendances` VALUES ('2127', '26', '778', '17', '0', '2024-07-08', '', '12', '2024-07-17 15:22:34', '2024-07-17 15:22:34');
INSERT INTO `attendances` VALUES ('2128', '26', '780', '17', '1', '2024-07-08', '', '12', '2024-07-17 15:22:34', '2024-07-17 15:22:34');
INSERT INTO `attendances` VALUES ('2129', '26', '782', '17', '1', '2024-07-08', '', '12', '2024-07-17 15:22:34', '2024-07-17 15:22:34');
INSERT INTO `attendances` VALUES ('2130', '26', '784', '17', '1', '2024-07-08', '', '12', '2024-07-17 15:22:34', '2024-07-17 15:22:34');
INSERT INTO `attendances` VALUES ('2131', '26', '786', '17', '1', '2024-07-08', '', '12', '2024-07-17 15:22:34', '2024-07-17 15:22:34');
INSERT INTO `attendances` VALUES ('2132', '26', '788', '17', '1', '2024-07-08', '', '12', '2024-07-17 15:22:34', '2024-07-17 15:22:34');
INSERT INTO `attendances` VALUES ('2133', '26', '790', '17', '1', '2024-07-08', '', '12', '2024-07-17 15:22:34', '2024-07-17 15:22:34');
INSERT INTO `attendances` VALUES ('2134', '26', '792', '17', '1', '2024-07-08', '', '12', '2024-07-17 15:22:34', '2024-07-17 15:22:34');
INSERT INTO `attendances` VALUES ('2135', '26', '794', '17', '1', '2024-07-08', '', '12', '2024-07-17 15:22:34', '2024-07-17 15:22:34');
INSERT INTO `attendances` VALUES ('2136', '26', '796', '17', '1', '2024-07-08', '', '12', '2024-07-17 15:22:34', '2024-07-17 15:22:34');
INSERT INTO `attendances` VALUES ('2137', '26', '798', '17', '1', '2024-07-08', '', '12', '2024-07-17 15:22:34', '2024-07-17 15:22:34');
INSERT INTO `attendances` VALUES ('2138', '26', '800', '17', '1', '2024-07-08', '', '12', '2024-07-17 15:22:34', '2024-07-17 15:22:34');
INSERT INTO `attendances` VALUES ('2139', '26', '802', '17', '1', '2024-07-08', '', '12', '2024-07-17 15:22:34', '2024-07-17 15:22:34');
INSERT INTO `attendances` VALUES ('2140', '21', '371', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:09', '2024-08-23 15:15:09');
INSERT INTO `attendances` VALUES ('2141', '21', '377', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:09', '2024-08-23 15:15:09');
INSERT INTO `attendances` VALUES ('2142', '21', '381', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:09', '2024-08-23 15:15:09');
INSERT INTO `attendances` VALUES ('2143', '21', '387', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:09', '2024-08-23 15:15:09');
INSERT INTO `attendances` VALUES ('2144', '21', '403', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:09', '2024-08-23 15:15:09');
INSERT INTO `attendances` VALUES ('2145', '21', '407', '17', '0', '2024-08-23', '', '12', '2024-08-23 15:15:09', '2024-08-23 15:15:09');
INSERT INTO `attendances` VALUES ('2146', '21', '409', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:09', '2024-08-23 15:15:09');
INSERT INTO `attendances` VALUES ('2147', '21', '417', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:09', '2024-08-23 15:15:09');
INSERT INTO `attendances` VALUES ('2148', '21', '419', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:09', '2024-08-23 15:15:09');
INSERT INTO `attendances` VALUES ('2149', '21', '421', '17', '0', '2024-08-23', '', '12', '2024-08-23 15:15:09', '2024-08-23 15:15:09');
INSERT INTO `attendances` VALUES ('2150', '21', '423', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:09', '2024-08-23 15:15:09');
INSERT INTO `attendances` VALUES ('2151', '21', '425', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:09', '2024-08-23 15:15:09');
INSERT INTO `attendances` VALUES ('2152', '21', '427', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:09', '2024-08-23 15:15:09');
INSERT INTO `attendances` VALUES ('2153', '21', '429', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:09', '2024-08-23 15:15:09');
INSERT INTO `attendances` VALUES ('2154', '21', '431', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:09', '2024-08-23 15:15:09');
INSERT INTO `attendances` VALUES ('2155', '21', '433', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:09', '2024-08-23 15:15:09');
INSERT INTO `attendances` VALUES ('2156', '21', '435', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:09', '2024-08-23 15:15:09');
INSERT INTO `attendances` VALUES ('2157', '21', '437', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:09', '2024-08-23 15:15:09');
INSERT INTO `attendances` VALUES ('2158', '21', '439', '17', '0', '2024-08-23', '', '12', '2024-08-23 15:15:09', '2024-08-23 15:15:09');
INSERT INTO `attendances` VALUES ('2159', '21', '441', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:09', '2024-08-23 15:15:09');
INSERT INTO `attendances` VALUES ('2160', '21', '443', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:09', '2024-08-23 15:15:09');
INSERT INTO `attendances` VALUES ('2161', '21', '445', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:09', '2024-08-23 15:15:09');
INSERT INTO `attendances` VALUES ('2162', '21', '447', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:09', '2024-08-23 15:15:09');
INSERT INTO `attendances` VALUES ('2163', '21', '449', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:09', '2024-08-23 15:15:09');
INSERT INTO `attendances` VALUES ('2164', '21', '451', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:09', '2024-08-23 15:15:09');
INSERT INTO `attendances` VALUES ('2165', '21', '453', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:09', '2024-08-23 15:15:09');
INSERT INTO `attendances` VALUES ('2166', '21', '455', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:09', '2024-08-23 15:15:09');
INSERT INTO `attendances` VALUES ('2167', '21', '457', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:09', '2024-08-23 15:15:09');
INSERT INTO `attendances` VALUES ('2168', '21', '459', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:09', '2024-08-23 15:15:09');
INSERT INTO `attendances` VALUES ('2169', '21', '461', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:09', '2024-08-23 15:15:09');
INSERT INTO `attendances` VALUES ('2170', '21', '463', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:09', '2024-08-23 15:15:09');
INSERT INTO `attendances` VALUES ('2171', '21', '465', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:09', '2024-08-23 15:15:09');
INSERT INTO `attendances` VALUES ('2172', '21', '467', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:09', '2024-08-23 15:15:09');
INSERT INTO `attendances` VALUES ('2173', '26', '337', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:59', '2024-08-23 15:15:59');
INSERT INTO `attendances` VALUES ('2174', '26', '744', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:59', '2024-08-23 15:15:59');
INSERT INTO `attendances` VALUES ('2175', '26', '746', '17', '0', '2024-08-23', '', '12', '2024-08-23 15:15:59', '2024-08-23 15:15:59');
INSERT INTO `attendances` VALUES ('2176', '26', '748', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:59', '2024-08-23 15:15:59');
INSERT INTO `attendances` VALUES ('2177', '26', '750', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:59', '2024-08-23 15:15:59');
INSERT INTO `attendances` VALUES ('2178', '26', '752', '17', '0', '2024-08-23', '', '12', '2024-08-23 15:15:59', '2024-08-23 15:15:59');
INSERT INTO `attendances` VALUES ('2179', '26', '754', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:59', '2024-08-23 15:15:59');
INSERT INTO `attendances` VALUES ('2180', '26', '756', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:59', '2024-08-23 15:15:59');
INSERT INTO `attendances` VALUES ('2181', '26', '758', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:59', '2024-08-23 15:15:59');
INSERT INTO `attendances` VALUES ('2182', '26', '760', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:59', '2024-08-23 15:15:59');
INSERT INTO `attendances` VALUES ('2183', '26', '762', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:59', '2024-08-23 15:15:59');
INSERT INTO `attendances` VALUES ('2184', '26', '764', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:59', '2024-08-23 15:15:59');
INSERT INTO `attendances` VALUES ('2185', '26', '766', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:59', '2024-08-23 15:15:59');
INSERT INTO `attendances` VALUES ('2186', '26', '768', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:59', '2024-08-23 15:15:59');
INSERT INTO `attendances` VALUES ('2187', '26', '770', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:59', '2024-08-23 15:15:59');
INSERT INTO `attendances` VALUES ('2188', '26', '772', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:59', '2024-08-23 15:15:59');
INSERT INTO `attendances` VALUES ('2189', '26', '774', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:59', '2024-08-23 15:15:59');
INSERT INTO `attendances` VALUES ('2190', '26', '776', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:59', '2024-08-23 15:15:59');
INSERT INTO `attendances` VALUES ('2191', '26', '778', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:59', '2024-08-23 15:15:59');
INSERT INTO `attendances` VALUES ('2192', '26', '780', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:59', '2024-08-23 15:15:59');
INSERT INTO `attendances` VALUES ('2193', '26', '782', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:59', '2024-08-23 15:15:59');
INSERT INTO `attendances` VALUES ('2194', '26', '784', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:59', '2024-08-23 15:15:59');
INSERT INTO `attendances` VALUES ('2195', '26', '786', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:59', '2024-08-23 15:15:59');
INSERT INTO `attendances` VALUES ('2196', '26', '788', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:59', '2024-08-23 15:15:59');
INSERT INTO `attendances` VALUES ('2197', '26', '790', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:59', '2024-08-23 15:15:59');
INSERT INTO `attendances` VALUES ('2198', '26', '792', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:59', '2024-08-23 15:15:59');
INSERT INTO `attendances` VALUES ('2199', '26', '794', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:59', '2024-08-23 15:15:59');
INSERT INTO `attendances` VALUES ('2200', '26', '796', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:59', '2024-08-23 15:15:59');
INSERT INTO `attendances` VALUES ('2201', '26', '798', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:59', '2024-08-23 15:15:59');
INSERT INTO `attendances` VALUES ('2202', '26', '800', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:59', '2024-08-23 15:15:59');
INSERT INTO `attendances` VALUES ('2203', '26', '802', '17', '1', '2024-08-23', '', '12', '2024-08-23 15:15:59', '2024-08-23 15:15:59');
INSERT INTO `attendances` VALUES ('2204', '21', '371', '17', '1', '2024-09-02', '', '12', '2024-09-06 12:07:11', '2024-09-06 12:07:11');
INSERT INTO `attendances` VALUES ('2205', '21', '377', '17', '1', '2024-09-02', '', '12', '2024-09-06 12:07:11', '2024-09-06 12:07:11');
INSERT INTO `attendances` VALUES ('2206', '21', '381', '17', '1', '2024-09-02', '', '12', '2024-09-06 12:07:11', '2024-09-06 12:07:11');
INSERT INTO `attendances` VALUES ('2207', '21', '387', '17', '1', '2024-09-02', '', '12', '2024-09-06 12:07:11', '2024-09-06 12:07:11');
INSERT INTO `attendances` VALUES ('2208', '21', '403', '17', '1', '2024-09-02', '', '12', '2024-09-06 12:07:11', '2024-09-06 12:07:11');
INSERT INTO `attendances` VALUES ('2209', '21', '407', '17', '1', '2024-09-02', '', '12', '2024-09-06 12:07:11', '2024-09-06 12:07:11');
INSERT INTO `attendances` VALUES ('2210', '21', '409', '17', '1', '2024-09-02', '', '12', '2024-09-06 12:07:11', '2024-09-06 12:07:11');
INSERT INTO `attendances` VALUES ('2211', '21', '417', '17', '1', '2024-09-02', '', '12', '2024-09-06 12:07:11', '2024-09-06 12:07:11');
INSERT INTO `attendances` VALUES ('2212', '21', '419', '17', '1', '2024-09-02', '', '12', '2024-09-06 12:07:11', '2024-09-06 12:07:11');
INSERT INTO `attendances` VALUES ('2213', '21', '421', '17', '1', '2024-09-02', '', '12', '2024-09-06 12:07:11', '2024-09-06 12:07:11');
INSERT INTO `attendances` VALUES ('2214', '21', '423', '17', '1', '2024-09-02', '', '12', '2024-09-06 12:07:11', '2024-09-06 12:07:11');
INSERT INTO `attendances` VALUES ('2215', '21', '425', '17', '1', '2024-09-02', '', '12', '2024-09-06 12:07:11', '2024-09-06 12:07:11');
INSERT INTO `attendances` VALUES ('2216', '21', '427', '17', '1', '2024-09-02', '', '12', '2024-09-06 12:07:11', '2024-09-06 12:07:11');
INSERT INTO `attendances` VALUES ('2217', '21', '429', '17', '1', '2024-09-02', '', '12', '2024-09-06 12:07:11', '2024-09-06 12:07:11');
INSERT INTO `attendances` VALUES ('2218', '21', '431', '17', '1', '2024-09-02', '', '12', '2024-09-06 12:07:11', '2024-09-06 12:07:11');
INSERT INTO `attendances` VALUES ('2219', '21', '433', '17', '1', '2024-09-02', '', '12', '2024-09-06 12:07:11', '2024-09-06 12:07:11');
INSERT INTO `attendances` VALUES ('2220', '21', '435', '17', '1', '2024-09-02', '', '12', '2024-09-06 12:07:11', '2024-09-06 12:07:11');
INSERT INTO `attendances` VALUES ('2221', '21', '437', '17', '1', '2024-09-02', '', '12', '2024-09-06 12:07:11', '2024-09-06 12:07:11');
INSERT INTO `attendances` VALUES ('2222', '21', '439', '17', '1', '2024-09-02', '', '12', '2024-09-06 12:07:11', '2024-09-06 12:07:11');
INSERT INTO `attendances` VALUES ('2223', '21', '441', '17', '1', '2024-09-02', '', '12', '2024-09-06 12:07:11', '2024-09-06 12:07:11');
INSERT INTO `attendances` VALUES ('2224', '21', '443', '17', '1', '2024-09-02', '', '12', '2024-09-06 12:07:11', '2024-09-06 12:07:11');
INSERT INTO `attendances` VALUES ('2225', '21', '445', '17', '1', '2024-09-02', '', '12', '2024-09-06 12:07:11', '2024-09-06 12:07:11');
INSERT INTO `attendances` VALUES ('2226', '21', '447', '17', '1', '2024-09-02', '', '12', '2024-09-06 12:07:11', '2024-09-06 12:07:11');
INSERT INTO `attendances` VALUES ('2227', '21', '449', '17', '1', '2024-09-02', '', '12', '2024-09-06 12:07:11', '2024-09-06 12:07:11');
INSERT INTO `attendances` VALUES ('2228', '21', '451', '17', '1', '2024-09-02', '', '12', '2024-09-06 12:07:11', '2024-09-06 12:07:11');
INSERT INTO `attendances` VALUES ('2229', '21', '453', '17', '1', '2024-09-02', '', '12', '2024-09-06 12:07:11', '2024-09-06 12:07:11');
INSERT INTO `attendances` VALUES ('2230', '21', '455', '17', '1', '2024-09-02', '', '12', '2024-09-06 12:07:11', '2024-09-06 12:07:11');
INSERT INTO `attendances` VALUES ('2231', '21', '457', '17', '1', '2024-09-02', '', '12', '2024-09-06 12:07:11', '2024-09-06 12:07:11');
INSERT INTO `attendances` VALUES ('2232', '21', '459', '17', '1', '2024-09-02', '', '12', '2024-09-06 12:07:11', '2024-09-06 12:07:11');
INSERT INTO `attendances` VALUES ('2233', '21', '461', '17', '1', '2024-09-02', '', '12', '2024-09-06 12:07:11', '2024-09-06 12:07:11');
INSERT INTO `attendances` VALUES ('2234', '21', '463', '17', '1', '2024-09-02', '', '12', '2024-09-06 12:07:11', '2024-09-06 12:07:11');
INSERT INTO `attendances` VALUES ('2235', '21', '465', '17', '1', '2024-09-02', '', '12', '2024-09-06 12:07:11', '2024-09-06 12:07:11');
INSERT INTO `attendances` VALUES ('2236', '21', '467', '17', '1', '2024-09-02', '', '12', '2024-09-06 12:07:11', '2024-09-06 12:07:11');
INSERT INTO `attendances` VALUES ('2237', '21', '371', '17', '1', '2024-09-03', '', '12', '2024-09-06 12:07:25', '2024-09-06 12:07:25');
INSERT INTO `attendances` VALUES ('2238', '21', '377', '17', '1', '2024-09-03', '', '12', '2024-09-06 12:07:25', '2024-09-06 12:07:25');
INSERT INTO `attendances` VALUES ('2239', '21', '381', '17', '1', '2024-09-03', '', '12', '2024-09-06 12:07:25', '2024-09-06 12:07:25');
INSERT INTO `attendances` VALUES ('2240', '21', '387', '17', '1', '2024-09-03', '', '12', '2024-09-06 12:07:25', '2024-09-06 12:07:25');
INSERT INTO `attendances` VALUES ('2241', '21', '403', '17', '1', '2024-09-03', '', '12', '2024-09-06 12:07:25', '2024-09-06 12:07:25');
INSERT INTO `attendances` VALUES ('2242', '21', '407', '17', '1', '2024-09-03', '', '12', '2024-09-06 12:07:25', '2024-09-06 12:07:25');
INSERT INTO `attendances` VALUES ('2243', '21', '409', '17', '1', '2024-09-03', '', '12', '2024-09-06 12:07:25', '2024-09-06 12:07:25');
INSERT INTO `attendances` VALUES ('2244', '21', '417', '17', '1', '2024-09-03', '', '12', '2024-09-06 12:07:25', '2024-09-06 12:07:25');
INSERT INTO `attendances` VALUES ('2245', '21', '419', '17', '1', '2024-09-03', '', '12', '2024-09-06 12:07:25', '2024-09-06 12:07:25');
INSERT INTO `attendances` VALUES ('2246', '21', '421', '17', '1', '2024-09-03', '', '12', '2024-09-06 12:07:25', '2024-09-06 12:07:25');
INSERT INTO `attendances` VALUES ('2247', '21', '423', '17', '0', '2024-09-03', '', '12', '2024-09-06 12:07:25', '2024-09-06 12:07:25');
INSERT INTO `attendances` VALUES ('2248', '21', '425', '17', '1', '2024-09-03', '', '12', '2024-09-06 12:07:25', '2024-09-06 12:07:25');
INSERT INTO `attendances` VALUES ('2249', '21', '427', '17', '1', '2024-09-03', '', '12', '2024-09-06 12:07:25', '2024-09-06 12:07:25');
INSERT INTO `attendances` VALUES ('2250', '21', '429', '17', '1', '2024-09-03', '', '12', '2024-09-06 12:07:25', '2024-09-06 12:07:25');
INSERT INTO `attendances` VALUES ('2251', '21', '431', '17', '1', '2024-09-03', '', '12', '2024-09-06 12:07:25', '2024-09-06 12:07:25');
INSERT INTO `attendances` VALUES ('2252', '21', '433', '17', '1', '2024-09-03', '', '12', '2024-09-06 12:07:25', '2024-09-06 12:07:25');
INSERT INTO `attendances` VALUES ('2253', '21', '435', '17', '1', '2024-09-03', '', '12', '2024-09-06 12:07:25', '2024-09-06 12:07:25');
INSERT INTO `attendances` VALUES ('2254', '21', '437', '17', '1', '2024-09-03', '', '12', '2024-09-06 12:07:25', '2024-09-06 12:07:25');
INSERT INTO `attendances` VALUES ('2255', '21', '439', '17', '1', '2024-09-03', '', '12', '2024-09-06 12:07:25', '2024-09-06 12:07:25');
INSERT INTO `attendances` VALUES ('2256', '21', '441', '17', '1', '2024-09-03', '', '12', '2024-09-06 12:07:25', '2024-09-06 12:07:25');
INSERT INTO `attendances` VALUES ('2257', '21', '443', '17', '1', '2024-09-03', '', '12', '2024-09-06 12:07:25', '2024-09-06 12:07:25');
INSERT INTO `attendances` VALUES ('2258', '21', '445', '17', '1', '2024-09-03', '', '12', '2024-09-06 12:07:25', '2024-09-06 12:07:25');
INSERT INTO `attendances` VALUES ('2259', '21', '447', '17', '0', '2024-09-03', '', '12', '2024-09-06 12:07:25', '2024-09-06 12:07:25');
INSERT INTO `attendances` VALUES ('2260', '21', '449', '17', '1', '2024-09-03', '', '12', '2024-09-06 12:07:25', '2024-09-06 12:07:25');
INSERT INTO `attendances` VALUES ('2261', '21', '451', '17', '1', '2024-09-03', '', '12', '2024-09-06 12:07:25', '2024-09-06 12:07:25');
INSERT INTO `attendances` VALUES ('2262', '21', '453', '17', '1', '2024-09-03', '', '12', '2024-09-06 12:07:25', '2024-09-06 12:07:25');
INSERT INTO `attendances` VALUES ('2263', '21', '455', '17', '1', '2024-09-03', '', '12', '2024-09-06 12:07:25', '2024-09-06 12:07:25');
INSERT INTO `attendances` VALUES ('2264', '21', '457', '17', '1', '2024-09-03', '', '12', '2024-09-06 12:07:25', '2024-09-06 12:07:25');
INSERT INTO `attendances` VALUES ('2265', '21', '459', '17', '1', '2024-09-03', '', '12', '2024-09-06 12:07:25', '2024-09-06 12:07:25');
INSERT INTO `attendances` VALUES ('2266', '21', '461', '17', '1', '2024-09-03', '', '12', '2024-09-06 12:07:25', '2024-09-06 12:07:25');
INSERT INTO `attendances` VALUES ('2267', '21', '463', '17', '0', '2024-09-03', '', '12', '2024-09-06 12:07:25', '2024-09-06 12:07:25');
INSERT INTO `attendances` VALUES ('2268', '21', '465', '17', '1', '2024-09-03', '', '12', '2024-09-06 12:07:25', '2024-09-06 12:07:25');
INSERT INTO `attendances` VALUES ('2269', '21', '467', '17', '1', '2024-09-03', '', '12', '2024-09-06 12:07:25', '2024-09-06 12:07:25');
INSERT INTO `attendances` VALUES ('2270', '21', '371', '17', '1', '2024-09-04', '', '12', '2024-09-06 12:08:03', '2024-09-06 12:08:03');
INSERT INTO `attendances` VALUES ('2271', '21', '377', '17', '1', '2024-09-04', '', '12', '2024-09-06 12:08:03', '2024-09-06 12:08:03');
INSERT INTO `attendances` VALUES ('2272', '21', '381', '17', '1', '2024-09-04', '', '12', '2024-09-06 12:08:03', '2024-09-06 12:08:03');
INSERT INTO `attendances` VALUES ('2273', '21', '387', '17', '1', '2024-09-04', '', '12', '2024-09-06 12:08:03', '2024-09-06 12:08:03');
INSERT INTO `attendances` VALUES ('2274', '21', '403', '17', '1', '2024-09-04', '', '12', '2024-09-06 12:08:03', '2024-09-06 12:08:03');
INSERT INTO `attendances` VALUES ('2275', '21', '407', '17', '1', '2024-09-04', '', '12', '2024-09-06 12:08:03', '2024-09-06 12:08:03');
INSERT INTO `attendances` VALUES ('2276', '21', '409', '17', '1', '2024-09-04', '', '12', '2024-09-06 12:08:03', '2024-09-06 12:08:03');
INSERT INTO `attendances` VALUES ('2277', '21', '417', '17', '0', '2024-09-04', '', '12', '2024-09-06 12:08:03', '2024-09-06 12:08:03');
INSERT INTO `attendances` VALUES ('2278', '21', '419', '17', '1', '2024-09-04', '', '12', '2024-09-06 12:08:03', '2024-09-06 12:08:03');
INSERT INTO `attendances` VALUES ('2279', '21', '421', '17', '1', '2024-09-04', '', '12', '2024-09-06 12:08:03', '2024-09-06 12:08:03');
INSERT INTO `attendances` VALUES ('2280', '21', '423', '17', '1', '2024-09-04', '', '12', '2024-09-06 12:08:03', '2024-09-06 12:08:03');
INSERT INTO `attendances` VALUES ('2281', '21', '425', '17', '1', '2024-09-04', '', '12', '2024-09-06 12:08:03', '2024-09-06 12:08:03');
INSERT INTO `attendances` VALUES ('2282', '21', '427', '17', '1', '2024-09-04', '', '12', '2024-09-06 12:08:03', '2024-09-06 12:08:03');
INSERT INTO `attendances` VALUES ('2283', '21', '429', '17', '1', '2024-09-04', '', '12', '2024-09-06 12:08:03', '2024-09-06 12:08:03');
INSERT INTO `attendances` VALUES ('2284', '21', '431', '17', '1', '2024-09-04', '', '12', '2024-09-06 12:08:03', '2024-09-06 12:08:03');
INSERT INTO `attendances` VALUES ('2285', '21', '433', '17', '1', '2024-09-04', '', '12', '2024-09-06 12:08:03', '2024-09-06 12:08:03');
INSERT INTO `attendances` VALUES ('2286', '21', '435', '17', '1', '2024-09-04', '', '12', '2024-09-06 12:08:03', '2024-09-06 12:08:03');
INSERT INTO `attendances` VALUES ('2287', '21', '437', '17', '1', '2024-09-04', '', '12', '2024-09-06 12:08:03', '2024-09-06 12:08:03');
INSERT INTO `attendances` VALUES ('2288', '21', '439', '17', '0', '2024-09-04', '', '12', '2024-09-06 12:08:03', '2024-09-06 12:08:03');
INSERT INTO `attendances` VALUES ('2289', '21', '441', '17', '1', '2024-09-04', '', '12', '2024-09-06 12:08:03', '2024-09-06 12:08:03');
INSERT INTO `attendances` VALUES ('2290', '21', '443', '17', '1', '2024-09-04', '', '12', '2024-09-06 12:08:03', '2024-09-06 12:08:03');
INSERT INTO `attendances` VALUES ('2291', '21', '445', '17', '1', '2024-09-04', '', '12', '2024-09-06 12:08:03', '2024-09-06 12:08:03');
INSERT INTO `attendances` VALUES ('2292', '21', '447', '17', '1', '2024-09-04', '', '12', '2024-09-06 12:08:03', '2024-09-06 12:08:03');
INSERT INTO `attendances` VALUES ('2293', '21', '449', '17', '1', '2024-09-04', '', '12', '2024-09-06 12:08:03', '2024-09-06 12:08:03');
INSERT INTO `attendances` VALUES ('2294', '21', '451', '17', '1', '2024-09-04', '', '12', '2024-09-06 12:08:03', '2024-09-06 12:08:03');
INSERT INTO `attendances` VALUES ('2295', '21', '453', '17', '1', '2024-09-04', '', '12', '2024-09-06 12:08:03', '2024-09-06 12:08:03');
INSERT INTO `attendances` VALUES ('2296', '21', '455', '17', '1', '2024-09-04', '', '12', '2024-09-06 12:08:03', '2024-09-06 12:08:03');
INSERT INTO `attendances` VALUES ('2297', '21', '457', '17', '1', '2024-09-04', '', '12', '2024-09-06 12:08:03', '2024-09-06 12:08:03');
INSERT INTO `attendances` VALUES ('2298', '21', '459', '17', '1', '2024-09-04', '', '12', '2024-09-06 12:08:03', '2024-09-06 12:08:03');
INSERT INTO `attendances` VALUES ('2299', '21', '461', '17', '1', '2024-09-04', '', '12', '2024-09-06 12:08:03', '2024-09-06 12:08:03');
INSERT INTO `attendances` VALUES ('2300', '21', '463', '17', '1', '2024-09-04', '', '12', '2024-09-06 12:08:03', '2024-09-06 12:08:03');
INSERT INTO `attendances` VALUES ('2301', '21', '465', '17', '1', '2024-09-04', '', '12', '2024-09-06 12:08:03', '2024-09-06 12:08:03');
INSERT INTO `attendances` VALUES ('2302', '21', '467', '17', '1', '2024-09-04', '', '12', '2024-09-06 12:08:03', '2024-09-06 12:08:03');
INSERT INTO `attendances` VALUES ('2303', '21', '371', '17', '1', '2024-09-05', '', '12', '2024-09-06 12:08:11', '2024-09-06 12:08:11');
INSERT INTO `attendances` VALUES ('2304', '21', '377', '17', '1', '2024-09-05', '', '12', '2024-09-06 12:08:11', '2024-09-06 12:08:11');
INSERT INTO `attendances` VALUES ('2305', '21', '381', '17', '1', '2024-09-05', '', '12', '2024-09-06 12:08:11', '2024-09-06 12:08:11');
INSERT INTO `attendances` VALUES ('2306', '21', '387', '17', '1', '2024-09-05', '', '12', '2024-09-06 12:08:11', '2024-09-06 12:08:11');
INSERT INTO `attendances` VALUES ('2307', '21', '403', '17', '1', '2024-09-05', '', '12', '2024-09-06 12:08:11', '2024-09-06 12:08:11');
INSERT INTO `attendances` VALUES ('2308', '21', '407', '17', '1', '2024-09-05', '', '12', '2024-09-06 12:08:11', '2024-09-06 12:08:11');
INSERT INTO `attendances` VALUES ('2309', '21', '409', '17', '1', '2024-09-05', '', '12', '2024-09-06 12:08:11', '2024-09-06 12:08:11');
INSERT INTO `attendances` VALUES ('2310', '21', '417', '17', '0', '2024-09-05', '', '12', '2024-09-06 12:08:11', '2024-09-06 12:08:11');
INSERT INTO `attendances` VALUES ('2311', '21', '419', '17', '1', '2024-09-05', '', '12', '2024-09-06 12:08:11', '2024-09-06 12:08:11');
INSERT INTO `attendances` VALUES ('2312', '21', '421', '17', '1', '2024-09-05', '', '12', '2024-09-06 12:08:11', '2024-09-06 12:08:11');
INSERT INTO `attendances` VALUES ('2313', '21', '423', '17', '1', '2024-09-05', '', '12', '2024-09-06 12:08:11', '2024-09-06 12:08:11');
INSERT INTO `attendances` VALUES ('2314', '21', '425', '17', '1', '2024-09-05', '', '12', '2024-09-06 12:08:11', '2024-09-06 12:08:11');
INSERT INTO `attendances` VALUES ('2315', '21', '427', '17', '1', '2024-09-05', '', '12', '2024-09-06 12:08:11', '2024-09-06 12:08:11');
INSERT INTO `attendances` VALUES ('2316', '21', '429', '17', '1', '2024-09-05', '', '12', '2024-09-06 12:08:11', '2024-09-06 12:08:11');
INSERT INTO `attendances` VALUES ('2317', '21', '431', '17', '1', '2024-09-05', '', '12', '2024-09-06 12:08:11', '2024-09-06 12:08:11');
INSERT INTO `attendances` VALUES ('2318', '21', '433', '17', '1', '2024-09-05', '', '12', '2024-09-06 12:08:11', '2024-09-06 12:08:11');
INSERT INTO `attendances` VALUES ('2319', '21', '435', '17', '1', '2024-09-05', '', '12', '2024-09-06 12:08:11', '2024-09-06 12:08:11');
INSERT INTO `attendances` VALUES ('2320', '21', '437', '17', '1', '2024-09-05', '', '12', '2024-09-06 12:08:11', '2024-09-06 12:08:11');
INSERT INTO `attendances` VALUES ('2321', '21', '439', '17', '0', '2024-09-05', '', '12', '2024-09-06 12:08:11', '2024-09-06 12:08:11');
INSERT INTO `attendances` VALUES ('2322', '21', '441', '17', '1', '2024-09-05', '', '12', '2024-09-06 12:08:11', '2024-09-06 12:08:11');
INSERT INTO `attendances` VALUES ('2323', '21', '443', '17', '1', '2024-09-05', '', '12', '2024-09-06 12:08:11', '2024-09-06 12:08:11');
INSERT INTO `attendances` VALUES ('2324', '21', '445', '17', '1', '2024-09-05', '', '12', '2024-09-06 12:08:11', '2024-09-06 12:08:11');
INSERT INTO `attendances` VALUES ('2325', '21', '447', '17', '1', '2024-09-05', '', '12', '2024-09-06 12:08:11', '2024-09-06 12:08:11');
INSERT INTO `attendances` VALUES ('2326', '21', '449', '17', '1', '2024-09-05', '', '12', '2024-09-06 12:08:11', '2024-09-06 12:08:11');
INSERT INTO `attendances` VALUES ('2327', '21', '451', '17', '1', '2024-09-05', '', '12', '2024-09-06 12:08:11', '2024-09-06 12:08:11');
INSERT INTO `attendances` VALUES ('2328', '21', '453', '17', '1', '2024-09-05', '', '12', '2024-09-06 12:08:11', '2024-09-06 12:08:11');
INSERT INTO `attendances` VALUES ('2329', '21', '455', '17', '1', '2024-09-05', '', '12', '2024-09-06 12:08:11', '2024-09-06 12:08:11');
INSERT INTO `attendances` VALUES ('2330', '21', '457', '17', '1', '2024-09-05', '', '12', '2024-09-06 12:08:11', '2024-09-06 12:08:11');
INSERT INTO `attendances` VALUES ('2331', '21', '459', '17', '1', '2024-09-05', '', '12', '2024-09-06 12:08:11', '2024-09-06 12:08:11');
INSERT INTO `attendances` VALUES ('2332', '21', '461', '17', '1', '2024-09-05', '', '12', '2024-09-06 12:08:11', '2024-09-06 12:08:11');
INSERT INTO `attendances` VALUES ('2333', '21', '463', '17', '1', '2024-09-05', '', '12', '2024-09-06 12:08:11', '2024-09-06 12:08:11');
INSERT INTO `attendances` VALUES ('2334', '21', '465', '17', '1', '2024-09-05', '', '12', '2024-09-06 12:08:11', '2024-09-06 12:08:11');
INSERT INTO `attendances` VALUES ('2335', '21', '467', '17', '1', '2024-09-05', '', '12', '2024-09-06 12:08:11', '2024-09-06 12:08:11');
INSERT INTO `attendances` VALUES ('2336', '26', '337', '17', '1', '2024-09-30', '', '12', '2024-09-30 16:09:45', '2024-09-30 16:45:48');
INSERT INTO `attendances` VALUES ('2337', '26', '744', '17', '0', '2024-09-30', '', '12', '2024-09-30 16:09:45', '2024-09-30 16:45:48');
INSERT INTO `attendances` VALUES ('2338', '26', '746', '17', '0', '2024-09-30', '', '12', '2024-09-30 16:09:45', '2024-09-30 16:45:48');
INSERT INTO `attendances` VALUES ('2339', '26', '748', '17', '0', '2024-09-30', '', '12', '2024-09-30 16:09:45', '2024-09-30 16:45:48');
INSERT INTO `attendances` VALUES ('2340', '26', '750', '17', '0', '2024-09-30', '', '12', '2024-09-30 16:09:45', '2024-09-30 16:45:48');
INSERT INTO `attendances` VALUES ('2341', '26', '752', '17', '0', '2024-09-30', '', '12', '2024-09-30 16:09:45', '2024-09-30 16:45:48');
INSERT INTO `attendances` VALUES ('2342', '26', '754', '17', '0', '2024-09-30', '', '12', '2024-09-30 16:09:45', '2024-09-30 16:45:48');
INSERT INTO `attendances` VALUES ('2343', '26', '756', '17', '0', '2024-09-30', '', '12', '2024-09-30 16:09:45', '2024-09-30 16:45:48');
INSERT INTO `attendances` VALUES ('2344', '26', '758', '17', '0', '2024-09-30', '', '12', '2024-09-30 16:09:45', '2024-09-30 16:45:48');
INSERT INTO `attendances` VALUES ('2345', '26', '760', '17', '0', '2024-09-30', '', '12', '2024-09-30 16:09:45', '2024-09-30 16:45:48');
INSERT INTO `attendances` VALUES ('2346', '26', '762', '17', '0', '2024-09-30', '', '12', '2024-09-30 16:09:45', '2024-09-30 16:45:48');
INSERT INTO `attendances` VALUES ('2347', '26', '764', '17', '1', '2024-09-30', '', '12', '2024-09-30 16:09:45', '2024-09-30 16:46:06');
INSERT INTO `attendances` VALUES ('2348', '26', '766', '17', '0', '2024-09-30', '', '12', '2024-09-30 16:09:45', '2024-09-30 16:45:48');
INSERT INTO `attendances` VALUES ('2349', '26', '768', '17', '0', '2024-09-30', '', '12', '2024-09-30 16:09:45', '2024-09-30 16:45:48');
INSERT INTO `attendances` VALUES ('2350', '26', '770', '17', '0', '2024-09-30', '', '12', '2024-09-30 16:09:45', '2024-09-30 16:45:48');
INSERT INTO `attendances` VALUES ('2351', '26', '772', '17', '0', '2024-09-30', '', '12', '2024-09-30 16:09:45', '2024-09-30 16:45:48');
INSERT INTO `attendances` VALUES ('2352', '26', '774', '17', '0', '2024-09-30', '', '12', '2024-09-30 16:09:45', '2024-09-30 16:45:48');
INSERT INTO `attendances` VALUES ('2353', '26', '776', '17', '0', '2024-09-30', '', '12', '2024-09-30 16:09:45', '2024-09-30 16:45:48');
INSERT INTO `attendances` VALUES ('2354', '26', '778', '17', '0', '2024-09-30', '', '12', '2024-09-30 16:09:45', '2024-09-30 16:45:48');
INSERT INTO `attendances` VALUES ('2355', '26', '780', '17', '0', '2024-09-30', '', '12', '2024-09-30 16:09:45', '2024-09-30 16:45:48');
INSERT INTO `attendances` VALUES ('2356', '26', '782', '17', '0', '2024-09-30', '', '12', '2024-09-30 16:09:45', '2024-09-30 16:45:48');
INSERT INTO `attendances` VALUES ('2357', '26', '784', '17', '0', '2024-09-30', '', '12', '2024-09-30 16:09:45', '2024-09-30 16:45:48');
INSERT INTO `attendances` VALUES ('2358', '26', '786', '17', '0', '2024-09-30', '', '12', '2024-09-30 16:09:45', '2024-09-30 16:45:48');
INSERT INTO `attendances` VALUES ('2359', '26', '788', '17', '0', '2024-09-30', '', '12', '2024-09-30 16:09:45', '2024-09-30 16:45:48');
INSERT INTO `attendances` VALUES ('2360', '26', '790', '17', '0', '2024-09-30', '', '12', '2024-09-30 16:09:45', '2024-09-30 16:45:48');
INSERT INTO `attendances` VALUES ('2361', '26', '792', '17', '0', '2024-09-30', '', '12', '2024-09-30 16:09:45', '2024-09-30 16:45:48');
INSERT INTO `attendances` VALUES ('2362', '26', '794', '17', '0', '2024-09-30', '', '12', '2024-09-30 16:09:45', '2024-09-30 16:45:48');
INSERT INTO `attendances` VALUES ('2363', '26', '796', '17', '0', '2024-09-30', '', '12', '2024-09-30 16:09:45', '2024-09-30 16:45:48');
INSERT INTO `attendances` VALUES ('2364', '26', '798', '17', '0', '2024-09-30', '', '12', '2024-09-30 16:09:45', '2024-09-30 16:45:48');
INSERT INTO `attendances` VALUES ('2365', '26', '800', '17', '0', '2024-09-30', '', '12', '2024-09-30 16:09:45', '2024-09-30 16:45:48');
INSERT INTO `attendances` VALUES ('2366', '26', '802', '17', '0', '2024-09-30', '', '12', '2024-09-30 16:09:45', '2024-09-30 16:45:48');
INSERT INTO `attendances` VALUES ('2367', '21', '371', '17', '1', '2024-09-30', '', '12', '2024-09-30 16:10:16', '2024-09-30 16:10:16');
INSERT INTO `attendances` VALUES ('2368', '21', '377', '17', '1', '2024-09-30', '', '12', '2024-09-30 16:10:16', '2024-09-30 16:10:16');
INSERT INTO `attendances` VALUES ('2369', '21', '381', '17', '1', '2024-09-30', '', '12', '2024-09-30 16:10:16', '2024-09-30 16:10:16');
INSERT INTO `attendances` VALUES ('2370', '21', '387', '17', '1', '2024-09-30', '', '12', '2024-09-30 16:10:16', '2024-09-30 16:10:16');
INSERT INTO `attendances` VALUES ('2371', '21', '403', '17', '1', '2024-09-30', '', '12', '2024-09-30 16:10:16', '2024-09-30 16:10:16');
INSERT INTO `attendances` VALUES ('2372', '21', '407', '17', '1', '2024-09-30', '', '12', '2024-09-30 16:10:16', '2024-09-30 16:10:16');
INSERT INTO `attendances` VALUES ('2373', '21', '409', '17', '1', '2024-09-30', '', '12', '2024-09-30 16:10:16', '2024-09-30 16:10:16');
INSERT INTO `attendances` VALUES ('2374', '21', '417', '17', '1', '2024-09-30', '', '12', '2024-09-30 16:10:16', '2024-09-30 16:10:16');
INSERT INTO `attendances` VALUES ('2375', '21', '419', '17', '1', '2024-09-30', '', '12', '2024-09-30 16:10:16', '2024-09-30 16:10:16');
INSERT INTO `attendances` VALUES ('2376', '21', '421', '17', '1', '2024-09-30', '', '12', '2024-09-30 16:10:16', '2024-09-30 16:10:16');
INSERT INTO `attendances` VALUES ('2377', '21', '423', '17', '1', '2024-09-30', '', '12', '2024-09-30 16:10:16', '2024-09-30 16:10:16');
INSERT INTO `attendances` VALUES ('2378', '21', '425', '17', '1', '2024-09-30', '', '12', '2024-09-30 16:10:16', '2024-09-30 16:10:16');
INSERT INTO `attendances` VALUES ('2379', '21', '427', '17', '1', '2024-09-30', '', '12', '2024-09-30 16:10:16', '2024-09-30 16:10:16');
INSERT INTO `attendances` VALUES ('2380', '21', '429', '17', '1', '2024-09-30', '', '12', '2024-09-30 16:10:16', '2024-09-30 16:10:16');
INSERT INTO `attendances` VALUES ('2381', '21', '431', '17', '1', '2024-09-30', '', '12', '2024-09-30 16:10:16', '2024-09-30 16:10:16');
INSERT INTO `attendances` VALUES ('2382', '21', '433', '17', '1', '2024-09-30', '', '12', '2024-09-30 16:10:16', '2024-09-30 16:10:16');
INSERT INTO `attendances` VALUES ('2383', '21', '435', '17', '1', '2024-09-30', '', '12', '2024-09-30 16:10:16', '2024-09-30 16:10:16');
INSERT INTO `attendances` VALUES ('2384', '21', '437', '17', '1', '2024-09-30', '', '12', '2024-09-30 16:10:16', '2024-09-30 16:10:16');
INSERT INTO `attendances` VALUES ('2385', '21', '439', '17', '1', '2024-09-30', '', '12', '2024-09-30 16:10:16', '2024-09-30 16:10:16');
INSERT INTO `attendances` VALUES ('2386', '21', '441', '17', '1', '2024-09-30', '', '12', '2024-09-30 16:10:16', '2024-09-30 16:10:16');
INSERT INTO `attendances` VALUES ('2387', '21', '443', '17', '1', '2024-09-30', '', '12', '2024-09-30 16:10:16', '2024-09-30 16:10:16');
INSERT INTO `attendances` VALUES ('2388', '21', '445', '17', '1', '2024-09-30', '', '12', '2024-09-30 16:10:16', '2024-09-30 16:10:16');
INSERT INTO `attendances` VALUES ('2389', '21', '447', '17', '1', '2024-09-30', '', '12', '2024-09-30 16:10:16', '2024-09-30 16:10:16');
INSERT INTO `attendances` VALUES ('2390', '21', '449', '17', '1', '2024-09-30', '', '12', '2024-09-30 16:10:16', '2024-09-30 16:10:16');
INSERT INTO `attendances` VALUES ('2391', '21', '451', '17', '1', '2024-09-30', '', '12', '2024-09-30 16:10:16', '2024-09-30 16:10:16');
INSERT INTO `attendances` VALUES ('2392', '21', '453', '17', '1', '2024-09-30', '', '12', '2024-09-30 16:10:16', '2024-09-30 16:10:16');
INSERT INTO `attendances` VALUES ('2393', '21', '455', '17', '1', '2024-09-30', '', '12', '2024-09-30 16:10:16', '2024-09-30 16:10:16');
INSERT INTO `attendances` VALUES ('2394', '21', '457', '17', '1', '2024-09-30', '', '12', '2024-09-30 16:10:16', '2024-09-30 16:10:16');
INSERT INTO `attendances` VALUES ('2395', '21', '459', '17', '1', '2024-09-30', '', '12', '2024-09-30 16:10:16', '2024-09-30 16:10:16');
INSERT INTO `attendances` VALUES ('2396', '21', '461', '17', '1', '2024-09-30', '', '12', '2024-09-30 16:10:16', '2024-09-30 16:10:16');
INSERT INTO `attendances` VALUES ('2397', '21', '463', '17', '1', '2024-09-30', '', '12', '2024-09-30 16:10:16', '2024-09-30 16:10:16');
INSERT INTO `attendances` VALUES ('2398', '21', '465', '17', '1', '2024-09-30', '', '12', '2024-09-30 16:10:16', '2024-09-30 16:10:16');
INSERT INTO `attendances` VALUES ('2399', '21', '467', '17', '1', '2024-09-30', '', '12', '2024-09-30 16:10:16', '2024-09-30 16:10:16');
INSERT INTO `attendances` VALUES ('2400', '26', '337', '17', '0', '2024-10-01', '', '12', '2024-10-01 08:17:47', '2024-10-01 08:17:47');
INSERT INTO `attendances` VALUES ('2401', '26', '744', '17', '1', '2024-10-01', '', '12', '2024-10-01 08:17:47', '2024-10-01 08:17:47');
INSERT INTO `attendances` VALUES ('2402', '26', '746', '17', '1', '2024-10-01', '', '12', '2024-10-01 08:17:47', '2024-10-01 08:17:47');
INSERT INTO `attendances` VALUES ('2403', '26', '748', '17', '1', '2024-10-01', '', '12', '2024-10-01 08:17:47', '2024-10-01 08:17:47');
INSERT INTO `attendances` VALUES ('2404', '26', '750', '17', '1', '2024-10-01', '', '12', '2024-10-01 08:17:47', '2024-10-01 08:17:47');
INSERT INTO `attendances` VALUES ('2405', '26', '752', '17', '1', '2024-10-01', '', '12', '2024-10-01 08:17:47', '2024-10-01 08:17:47');
INSERT INTO `attendances` VALUES ('2406', '26', '754', '17', '1', '2024-10-01', '', '12', '2024-10-01 08:17:47', '2024-10-01 08:17:47');
INSERT INTO `attendances` VALUES ('2407', '26', '756', '17', '1', '2024-10-01', '', '12', '2024-10-01 08:17:47', '2024-10-01 08:17:47');
INSERT INTO `attendances` VALUES ('2408', '26', '758', '17', '1', '2024-10-01', '', '12', '2024-10-01 08:17:47', '2024-10-01 08:17:47');
INSERT INTO `attendances` VALUES ('2409', '26', '760', '17', '1', '2024-10-01', '', '12', '2024-10-01 08:17:47', '2024-10-01 08:17:47');
INSERT INTO `attendances` VALUES ('2410', '26', '762', '17', '1', '2024-10-01', '', '12', '2024-10-01 08:17:47', '2024-10-01 08:17:47');
INSERT INTO `attendances` VALUES ('2411', '26', '764', '17', '1', '2024-10-01', '', '12', '2024-10-01 08:17:47', '2024-10-01 08:17:47');
INSERT INTO `attendances` VALUES ('2412', '26', '766', '17', '1', '2024-10-01', '', '12', '2024-10-01 08:17:47', '2024-10-01 08:17:47');
INSERT INTO `attendances` VALUES ('2413', '26', '768', '17', '1', '2024-10-01', '', '12', '2024-10-01 08:17:47', '2024-10-01 08:17:47');
INSERT INTO `attendances` VALUES ('2414', '26', '770', '17', '1', '2024-10-01', '', '12', '2024-10-01 08:17:47', '2024-10-01 08:17:47');
INSERT INTO `attendances` VALUES ('2415', '26', '772', '17', '1', '2024-10-01', '', '12', '2024-10-01 08:17:47', '2024-10-01 08:17:47');
INSERT INTO `attendances` VALUES ('2416', '26', '774', '17', '1', '2024-10-01', '', '12', '2024-10-01 08:17:47', '2024-10-01 08:17:47');
INSERT INTO `attendances` VALUES ('2417', '26', '776', '17', '1', '2024-10-01', '', '12', '2024-10-01 08:17:47', '2024-10-01 08:17:47');
INSERT INTO `attendances` VALUES ('2418', '26', '778', '17', '1', '2024-10-01', '', '12', '2024-10-01 08:17:47', '2024-10-01 08:17:47');
INSERT INTO `attendances` VALUES ('2419', '26', '780', '17', '1', '2024-10-01', '', '12', '2024-10-01 08:17:47', '2024-10-01 08:17:47');
INSERT INTO `attendances` VALUES ('2420', '26', '782', '17', '1', '2024-10-01', '', '12', '2024-10-01 08:17:47', '2024-10-01 08:17:47');
INSERT INTO `attendances` VALUES ('2421', '26', '784', '17', '1', '2024-10-01', '', '12', '2024-10-01 08:17:47', '2024-10-01 08:17:47');
INSERT INTO `attendances` VALUES ('2422', '26', '786', '17', '1', '2024-10-01', '', '12', '2024-10-01 08:17:47', '2024-10-01 08:17:47');
INSERT INTO `attendances` VALUES ('2423', '26', '788', '17', '1', '2024-10-01', '', '12', '2024-10-01 08:17:47', '2024-10-01 08:17:47');
INSERT INTO `attendances` VALUES ('2424', '26', '790', '17', '1', '2024-10-01', '', '12', '2024-10-01 08:17:47', '2024-10-01 08:17:47');
INSERT INTO `attendances` VALUES ('2425', '26', '792', '17', '1', '2024-10-01', '', '12', '2024-10-01 08:17:47', '2024-10-01 08:17:47');
INSERT INTO `attendances` VALUES ('2426', '26', '794', '17', '1', '2024-10-01', '', '12', '2024-10-01 08:17:47', '2024-10-01 08:17:47');
INSERT INTO `attendances` VALUES ('2427', '26', '796', '17', '1', '2024-10-01', '', '12', '2024-10-01 08:17:47', '2024-10-01 08:17:47');
INSERT INTO `attendances` VALUES ('2428', '26', '798', '17', '1', '2024-10-01', '', '12', '2024-10-01 08:17:47', '2024-10-01 08:17:47');
INSERT INTO `attendances` VALUES ('2429', '26', '800', '17', '1', '2024-10-01', '', '12', '2024-10-01 08:17:47', '2024-10-01 08:17:47');
INSERT INTO `attendances` VALUES ('2430', '26', '802', '17', '1', '2024-10-01', '', '12', '2024-10-01 08:17:47', '2024-10-01 08:17:47');
INSERT INTO `attendances` VALUES ('2431', '26', '337', '17', '1', '2024-10-02', '', '12', '2024-10-02 07:48:04', '2024-10-02 07:48:04');
INSERT INTO `attendances` VALUES ('2432', '26', '744', '17', '1', '2024-10-02', '', '12', '2024-10-02 07:48:05', '2024-10-02 21:47:21');
INSERT INTO `attendances` VALUES ('2433', '26', '746', '17', '1', '2024-10-02', '', '12', '2024-10-02 07:48:05', '2024-10-02 07:48:05');
INSERT INTO `attendances` VALUES ('2434', '26', '748', '17', '0', '2024-10-02', '', '12', '2024-10-02 07:48:05', '2024-10-02 17:36:47');
INSERT INTO `attendances` VALUES ('2435', '26', '750', '17', '1', '2024-10-02', '', '12', '2024-10-02 07:48:05', '2024-10-02 07:48:05');
INSERT INTO `attendances` VALUES ('2436', '26', '752', '17', '1', '2024-10-02', '', '12', '2024-10-02 07:48:05', '2024-10-02 07:48:05');
INSERT INTO `attendances` VALUES ('2437', '26', '754', '17', '1', '2024-10-02', '', '12', '2024-10-02 07:48:05', '2024-10-02 07:48:05');
INSERT INTO `attendances` VALUES ('2438', '26', '756', '17', '1', '2024-10-02', '', '12', '2024-10-02 07:48:05', '2024-10-02 07:48:05');
INSERT INTO `attendances` VALUES ('2439', '26', '758', '17', '1', '2024-10-02', '', '12', '2024-10-02 07:48:05', '2024-10-02 07:48:05');
INSERT INTO `attendances` VALUES ('2440', '26', '760', '17', '1', '2024-10-02', '', '12', '2024-10-02 07:48:05', '2024-10-02 07:48:05');
INSERT INTO `attendances` VALUES ('2441', '26', '762', '17', '1', '2024-10-02', '', '12', '2024-10-02 07:48:05', '2024-10-02 07:48:05');
INSERT INTO `attendances` VALUES ('2442', '26', '764', '17', '1', '2024-10-02', '', '12', '2024-10-02 07:48:05', '2024-10-02 07:48:05');
INSERT INTO `attendances` VALUES ('2443', '26', '766', '17', '1', '2024-10-02', '', '12', '2024-10-02 07:48:05', '2024-10-02 07:48:05');
INSERT INTO `attendances` VALUES ('2444', '26', '768', '17', '1', '2024-10-02', '', '12', '2024-10-02 07:48:05', '2024-10-02 07:48:05');
INSERT INTO `attendances` VALUES ('2445', '26', '770', '17', '1', '2024-10-02', '', '12', '2024-10-02 07:48:05', '2024-10-02 07:48:05');
INSERT INTO `attendances` VALUES ('2446', '26', '772', '17', '1', '2024-10-02', '', '12', '2024-10-02 07:48:05', '2024-10-02 07:48:05');
INSERT INTO `attendances` VALUES ('2447', '26', '774', '17', '1', '2024-10-02', '', '12', '2024-10-02 07:48:05', '2024-10-02 07:48:05');
INSERT INTO `attendances` VALUES ('2448', '26', '776', '17', '1', '2024-10-02', '', '12', '2024-10-02 07:48:05', '2024-10-02 07:48:05');
INSERT INTO `attendances` VALUES ('2449', '26', '778', '17', '1', '2024-10-02', '', '12', '2024-10-02 07:48:05', '2024-10-02 07:48:05');
INSERT INTO `attendances` VALUES ('2450', '26', '780', '17', '1', '2024-10-02', '', '12', '2024-10-02 07:48:05', '2024-10-02 07:48:05');
INSERT INTO `attendances` VALUES ('2451', '26', '782', '17', '1', '2024-10-02', '', '12', '2024-10-02 07:48:05', '2024-10-02 07:48:05');
INSERT INTO `attendances` VALUES ('2452', '26', '784', '17', '1', '2024-10-02', '', '12', '2024-10-02 07:48:05', '2024-10-02 07:48:05');
INSERT INTO `attendances` VALUES ('2453', '26', '786', '17', '1', '2024-10-02', '', '12', '2024-10-02 07:48:05', '2024-10-02 07:48:05');
INSERT INTO `attendances` VALUES ('2454', '26', '788', '17', '1', '2024-10-02', '', '12', '2024-10-02 07:48:05', '2024-10-02 07:48:05');
INSERT INTO `attendances` VALUES ('2455', '26', '790', '17', '1', '2024-10-02', '', '12', '2024-10-02 07:48:05', '2024-10-02 07:48:05');
INSERT INTO `attendances` VALUES ('2456', '26', '792', '17', '1', '2024-10-02', '', '12', '2024-10-02 07:48:05', '2024-10-02 07:48:05');
INSERT INTO `attendances` VALUES ('2457', '26', '794', '17', '1', '2024-10-02', '', '12', '2024-10-02 07:48:05', '2024-10-02 07:48:05');
INSERT INTO `attendances` VALUES ('2458', '26', '796', '17', '1', '2024-10-02', '', '12', '2024-10-02 07:48:05', '2024-10-02 21:47:21');
INSERT INTO `attendances` VALUES ('2459', '26', '798', '17', '1', '2024-10-02', '', '12', '2024-10-02 07:48:05', '2024-10-02 21:47:21');
INSERT INTO `attendances` VALUES ('2460', '26', '800', '17', '1', '2024-10-02', '', '12', '2024-10-02 07:48:05', '2024-10-02 07:48:05');
INSERT INTO `attendances` VALUES ('2461', '26', '802', '17', '1', '2024-10-02', '', '12', '2024-10-02 07:48:05', '2024-10-02 07:48:05');
INSERT INTO `attendances` VALUES ('2462', '26', '337', '17', '0', '2024-10-03', '', '12', '2024-10-03 00:17:39', '2024-10-03 00:17:39');
INSERT INTO `attendances` VALUES ('2463', '26', '744', '17', '1', '2024-10-03', '', '12', '2024-10-03 00:17:39', '2024-10-03 00:17:39');
INSERT INTO `attendances` VALUES ('2464', '26', '746', '17', '1', '2024-10-03', '', '12', '2024-10-03 00:17:39', '2024-10-03 00:17:39');
INSERT INTO `attendances` VALUES ('2465', '26', '748', '17', '1', '2024-10-03', '', '12', '2024-10-03 00:17:39', '2024-10-03 00:17:39');
INSERT INTO `attendances` VALUES ('2466', '26', '750', '17', '1', '2024-10-03', '', '12', '2024-10-03 00:17:39', '2024-10-03 00:17:39');
INSERT INTO `attendances` VALUES ('2467', '26', '752', '17', '1', '2024-10-03', '', '12', '2024-10-03 00:17:39', '2024-10-03 00:17:39');
INSERT INTO `attendances` VALUES ('2468', '26', '754', '17', '1', '2024-10-03', '', '12', '2024-10-03 00:17:39', '2024-10-03 00:17:39');
INSERT INTO `attendances` VALUES ('2469', '26', '756', '17', '1', '2024-10-03', '', '12', '2024-10-03 00:17:39', '2024-10-03 00:17:39');
INSERT INTO `attendances` VALUES ('2470', '26', '758', '17', '1', '2024-10-03', '', '12', '2024-10-03 00:17:39', '2024-10-03 00:17:39');
INSERT INTO `attendances` VALUES ('2471', '26', '760', '17', '1', '2024-10-03', '', '12', '2024-10-03 00:17:39', '2024-10-03 00:17:39');
INSERT INTO `attendances` VALUES ('2472', '26', '762', '17', '1', '2024-10-03', '', '12', '2024-10-03 00:17:39', '2024-10-03 00:17:39');
INSERT INTO `attendances` VALUES ('2473', '26', '764', '17', '1', '2024-10-03', '', '12', '2024-10-03 00:17:39', '2024-10-03 00:17:39');
INSERT INTO `attendances` VALUES ('2474', '26', '766', '17', '1', '2024-10-03', '', '12', '2024-10-03 00:17:39', '2024-10-03 00:17:39');
INSERT INTO `attendances` VALUES ('2475', '26', '768', '17', '1', '2024-10-03', '', '12', '2024-10-03 00:17:39', '2024-10-03 00:17:39');
INSERT INTO `attendances` VALUES ('2476', '26', '770', '17', '1', '2024-10-03', '', '12', '2024-10-03 00:17:39', '2024-10-03 00:17:39');
INSERT INTO `attendances` VALUES ('2477', '26', '772', '17', '1', '2024-10-03', '', '12', '2024-10-03 00:17:39', '2024-10-03 00:17:39');
INSERT INTO `attendances` VALUES ('2478', '26', '774', '17', '1', '2024-10-03', '', '12', '2024-10-03 00:17:39', '2024-10-03 00:17:39');
INSERT INTO `attendances` VALUES ('2479', '26', '776', '17', '1', '2024-10-03', '', '12', '2024-10-03 00:17:39', '2024-10-03 00:17:39');
INSERT INTO `attendances` VALUES ('2480', '26', '778', '17', '1', '2024-10-03', '', '12', '2024-10-03 00:17:39', '2024-10-03 00:17:39');
INSERT INTO `attendances` VALUES ('2481', '26', '780', '17', '1', '2024-10-03', '', '12', '2024-10-03 00:17:39', '2024-10-03 00:17:39');
INSERT INTO `attendances` VALUES ('2482', '26', '782', '17', '1', '2024-10-03', '', '12', '2024-10-03 00:17:39', '2024-10-03 00:17:39');
INSERT INTO `attendances` VALUES ('2483', '26', '784', '17', '1', '2024-10-03', '', '12', '2024-10-03 00:17:39', '2024-10-03 00:17:39');
INSERT INTO `attendances` VALUES ('2484', '26', '786', '17', '1', '2024-10-03', '', '12', '2024-10-03 00:17:39', '2024-10-03 00:17:39');
INSERT INTO `attendances` VALUES ('2485', '26', '788', '17', '1', '2024-10-03', '', '12', '2024-10-03 00:17:39', '2024-10-03 00:17:39');
INSERT INTO `attendances` VALUES ('2486', '26', '790', '17', '1', '2024-10-03', '', '12', '2024-10-03 00:17:39', '2024-10-03 00:17:39');
INSERT INTO `attendances` VALUES ('2487', '26', '792', '17', '1', '2024-10-03', '', '12', '2024-10-03 00:17:39', '2024-10-03 00:17:39');
INSERT INTO `attendances` VALUES ('2488', '26', '794', '17', '1', '2024-10-03', '', '12', '2024-10-03 00:17:39', '2024-10-03 00:17:39');
INSERT INTO `attendances` VALUES ('2489', '26', '796', '17', '1', '2024-10-03', '', '12', '2024-10-03 00:17:39', '2024-10-03 00:17:39');
INSERT INTO `attendances` VALUES ('2490', '26', '798', '17', '1', '2024-10-03', '', '12', '2024-10-03 00:17:39', '2024-10-03 00:17:39');
INSERT INTO `attendances` VALUES ('2491', '26', '800', '17', '1', '2024-10-03', '', '12', '2024-10-03 00:17:39', '2024-10-03 00:17:39');
INSERT INTO `attendances` VALUES ('2492', '26', '802', '17', '1', '2024-10-03', '', '12', '2024-10-03 00:17:39', '2024-10-03 00:17:39');
INSERT INTO `attendances` VALUES ('2493', '26', '337', '17', '0', '2024-10-04', '', '12', '2024-10-04 10:25:38', '2024-10-04 22:45:24');
INSERT INTO `attendances` VALUES ('2494', '26', '744', '17', '0', '2024-10-04', '', '12', '2024-10-04 10:25:38', '2024-10-04 22:45:24');
INSERT INTO `attendances` VALUES ('2495', '26', '746', '17', '0', '2024-10-04', '', '12', '2024-10-04 10:25:38', '2024-10-04 22:45:24');
INSERT INTO `attendances` VALUES ('2496', '26', '748', '17', '1', '2024-10-04', '', '12', '2024-10-04 10:25:38', '2024-10-04 10:25:38');
INSERT INTO `attendances` VALUES ('2497', '26', '750', '17', '0', '2024-10-04', '', '12', '2024-10-04 10:25:38', '2024-10-04 22:45:24');
INSERT INTO `attendances` VALUES ('2498', '26', '752', '17', '0', '2024-10-04', '', '12', '2024-10-04 10:25:38', '2024-10-04 22:45:24');
INSERT INTO `attendances` VALUES ('2499', '26', '754', '17', '0', '2024-10-04', '', '12', '2024-10-04 10:25:38', '2024-10-04 22:45:24');
INSERT INTO `attendances` VALUES ('2500', '26', '756', '17', '0', '2024-10-04', '', '12', '2024-10-04 10:25:38', '2024-10-04 22:45:24');
INSERT INTO `attendances` VALUES ('2501', '26', '758', '17', '1', '2024-10-04', '', '12', '2024-10-04 10:25:38', '2024-10-04 10:25:38');
INSERT INTO `attendances` VALUES ('2502', '26', '760', '17', '1', '2024-10-04', '', '12', '2024-10-04 10:25:38', '2024-10-04 10:25:38');
INSERT INTO `attendances` VALUES ('2503', '26', '762', '17', '1', '2024-10-04', '', '12', '2024-10-04 10:25:38', '2024-10-04 10:25:38');
INSERT INTO `attendances` VALUES ('2504', '26', '764', '17', '1', '2024-10-04', '', '12', '2024-10-04 10:25:38', '2024-10-04 10:25:38');
INSERT INTO `attendances` VALUES ('2505', '26', '766', '17', '1', '2024-10-04', '', '12', '2024-10-04 10:25:38', '2024-10-04 10:25:38');
INSERT INTO `attendances` VALUES ('2506', '26', '768', '17', '1', '2024-10-04', '', '12', '2024-10-04 10:25:38', '2024-10-04 10:25:38');
INSERT INTO `attendances` VALUES ('2507', '26', '770', '17', '1', '2024-10-04', '', '12', '2024-10-04 10:25:38', '2024-10-04 10:25:38');
INSERT INTO `attendances` VALUES ('2508', '26', '772', '17', '1', '2024-10-04', '', '12', '2024-10-04 10:25:38', '2024-10-04 10:25:38');
INSERT INTO `attendances` VALUES ('2509', '26', '774', '17', '1', '2024-10-04', '', '12', '2024-10-04 10:25:38', '2024-10-04 10:25:38');
INSERT INTO `attendances` VALUES ('2510', '26', '776', '17', '1', '2024-10-04', '', '12', '2024-10-04 10:25:38', '2024-10-04 10:25:38');
INSERT INTO `attendances` VALUES ('2511', '26', '778', '17', '1', '2024-10-04', '', '12', '2024-10-04 10:25:38', '2024-10-04 10:25:38');
INSERT INTO `attendances` VALUES ('2512', '26', '780', '17', '1', '2024-10-04', '', '12', '2024-10-04 10:25:38', '2024-10-04 10:25:38');
INSERT INTO `attendances` VALUES ('2513', '26', '782', '17', '1', '2024-10-04', '', '12', '2024-10-04 10:25:38', '2024-10-04 10:25:38');
INSERT INTO `attendances` VALUES ('2514', '26', '784', '17', '1', '2024-10-04', '', '12', '2024-10-04 10:25:38', '2024-10-04 10:25:38');
INSERT INTO `attendances` VALUES ('2515', '26', '786', '17', '1', '2024-10-04', '', '12', '2024-10-04 10:25:38', '2024-10-04 10:25:38');
INSERT INTO `attendances` VALUES ('2516', '26', '788', '17', '1', '2024-10-04', '', '12', '2024-10-04 10:25:38', '2024-10-04 10:25:38');
INSERT INTO `attendances` VALUES ('2517', '26', '790', '17', '1', '2024-10-04', '', '12', '2024-10-04 10:25:38', '2024-10-04 10:25:38');
INSERT INTO `attendances` VALUES ('2518', '26', '792', '17', '1', '2024-10-04', '', '12', '2024-10-04 10:25:38', '2024-10-04 10:25:38');
INSERT INTO `attendances` VALUES ('2519', '26', '794', '17', '1', '2024-10-04', '', '12', '2024-10-04 10:25:38', '2024-10-04 10:25:38');
INSERT INTO `attendances` VALUES ('2520', '26', '796', '17', '1', '2024-10-04', '', '12', '2024-10-04 10:25:38', '2024-10-04 10:25:38');
INSERT INTO `attendances` VALUES ('2521', '26', '798', '17', '1', '2024-10-04', '', '12', '2024-10-04 10:25:38', '2024-10-04 10:25:38');
INSERT INTO `attendances` VALUES ('2522', '26', '800', '17', '1', '2024-10-04', '', '12', '2024-10-04 10:25:38', '2024-10-04 10:25:38');
INSERT INTO `attendances` VALUES ('2523', '26', '802', '17', '1', '2024-10-04', '', '12', '2024-10-04 10:25:38', '2024-10-04 10:25:38');
INSERT INTO `attendances` VALUES ('2524', '26', '337', '17', '1', '2024-10-05', '', '12', '2024-10-05 08:38:26', '2024-10-05 16:41:13');
INSERT INTO `attendances` VALUES ('2525', '26', '744', '17', '1', '2024-10-05', '', '12', '2024-10-05 08:38:27', '2024-10-05 16:41:13');
INSERT INTO `attendances` VALUES ('2526', '26', '746', '17', '1', '2024-10-05', '', '12', '2024-10-05 08:38:27', '2024-10-05 08:38:27');
INSERT INTO `attendances` VALUES ('2527', '26', '748', '17', '1', '2024-10-05', '', '12', '2024-10-05 08:38:27', '2024-10-05 08:38:27');
INSERT INTO `attendances` VALUES ('2528', '26', '750', '17', '1', '2024-10-05', '', '12', '2024-10-05 08:38:27', '2024-10-05 08:38:27');
INSERT INTO `attendances` VALUES ('2529', '26', '752', '17', '1', '2024-10-05', '', '12', '2024-10-05 08:38:27', '2024-10-05 08:38:27');
INSERT INTO `attendances` VALUES ('2530', '26', '754', '17', '1', '2024-10-05', '', '12', '2024-10-05 08:38:27', '2024-10-05 08:38:27');
INSERT INTO `attendances` VALUES ('2531', '26', '756', '17', '1', '2024-10-05', '', '12', '2024-10-05 08:38:27', '2024-10-05 08:38:27');
INSERT INTO `attendances` VALUES ('2532', '26', '758', '17', '1', '2024-10-05', '', '12', '2024-10-05 08:38:27', '2024-10-05 08:38:27');
INSERT INTO `attendances` VALUES ('2533', '26', '760', '17', '1', '2024-10-05', '', '12', '2024-10-05 08:38:27', '2024-10-05 08:38:27');
INSERT INTO `attendances` VALUES ('2534', '26', '762', '17', '1', '2024-10-05', '', '12', '2024-10-05 08:38:27', '2024-10-05 08:38:27');
INSERT INTO `attendances` VALUES ('2535', '26', '764', '17', '1', '2024-10-05', '', '12', '2024-10-05 08:38:27', '2024-10-05 08:38:27');
INSERT INTO `attendances` VALUES ('2536', '26', '766', '17', '1', '2024-10-05', '', '12', '2024-10-05 08:38:27', '2024-10-05 08:38:27');
INSERT INTO `attendances` VALUES ('2537', '26', '768', '17', '1', '2024-10-05', '', '12', '2024-10-05 08:38:27', '2024-10-05 08:38:27');
INSERT INTO `attendances` VALUES ('2538', '26', '770', '17', '1', '2024-10-05', '', '12', '2024-10-05 08:38:27', '2024-10-05 08:38:27');
INSERT INTO `attendances` VALUES ('2539', '26', '772', '17', '1', '2024-10-05', '', '12', '2024-10-05 08:38:27', '2024-10-05 08:38:27');
INSERT INTO `attendances` VALUES ('2540', '26', '774', '17', '1', '2024-10-05', '', '12', '2024-10-05 08:38:27', '2024-10-05 08:38:27');
INSERT INTO `attendances` VALUES ('2541', '26', '776', '17', '1', '2024-10-05', '', '12', '2024-10-05 08:38:27', '2024-10-05 08:38:27');
INSERT INTO `attendances` VALUES ('2542', '26', '778', '17', '1', '2024-10-05', '', '12', '2024-10-05 08:38:27', '2024-10-05 08:38:27');
INSERT INTO `attendances` VALUES ('2543', '26', '780', '17', '1', '2024-10-05', '', '12', '2024-10-05 08:38:27', '2024-10-05 08:38:27');
INSERT INTO `attendances` VALUES ('2544', '26', '782', '17', '1', '2024-10-05', '', '12', '2024-10-05 08:38:27', '2024-10-05 08:38:27');
INSERT INTO `attendances` VALUES ('2545', '26', '784', '17', '1', '2024-10-05', '', '12', '2024-10-05 08:38:27', '2024-10-05 08:38:27');
INSERT INTO `attendances` VALUES ('2546', '26', '786', '17', '1', '2024-10-05', '', '12', '2024-10-05 08:38:27', '2024-10-05 08:38:27');
INSERT INTO `attendances` VALUES ('2547', '26', '788', '17', '1', '2024-10-05', '', '12', '2024-10-05 08:38:27', '2024-10-05 08:38:27');
INSERT INTO `attendances` VALUES ('2548', '26', '790', '17', '1', '2024-10-05', '', '12', '2024-10-05 08:38:27', '2024-10-05 08:38:27');
INSERT INTO `attendances` VALUES ('2549', '26', '792', '17', '1', '2024-10-05', '', '12', '2024-10-05 08:38:27', '2024-10-05 08:38:27');
INSERT INTO `attendances` VALUES ('2550', '26', '794', '17', '1', '2024-10-05', '', '12', '2024-10-05 08:38:27', '2024-10-05 08:38:27');
INSERT INTO `attendances` VALUES ('2551', '26', '796', '17', '1', '2024-10-05', '', '12', '2024-10-05 08:38:27', '2024-10-05 08:38:27');
INSERT INTO `attendances` VALUES ('2552', '26', '798', '17', '1', '2024-10-05', '', '12', '2024-10-05 08:38:27', '2024-10-05 08:38:27');
INSERT INTO `attendances` VALUES ('2553', '26', '800', '17', '1', '2024-10-05', '', '12', '2024-10-05 08:38:27', '2024-10-05 08:38:27');
INSERT INTO `attendances` VALUES ('2554', '26', '802', '17', '1', '2024-10-05', '', '12', '2024-10-05 08:38:27', '2024-10-05 08:38:27');
INSERT INTO `attendances` VALUES ('2555', '26', '337', '17', '0', '2024-10-06', '', '12', '2024-10-06 04:40:14', '2024-10-06 22:53:52');
INSERT INTO `attendances` VALUES ('2556', '26', '744', '17', '0', '2024-10-06', '', '12', '2024-10-06 04:40:14', '2024-10-06 04:40:14');
INSERT INTO `attendances` VALUES ('2557', '26', '746', '17', '1', '2024-10-06', '', '12', '2024-10-06 04:40:14', '2024-10-06 04:40:14');
INSERT INTO `attendances` VALUES ('2558', '26', '748', '17', '0', '2024-10-06', '', '12', '2024-10-06 04:40:14', '2024-10-06 22:53:52');
INSERT INTO `attendances` VALUES ('2559', '26', '750', '17', '1', '2024-10-06', '', '12', '2024-10-06 04:40:14', '2024-10-06 04:40:14');
INSERT INTO `attendances` VALUES ('2560', '26', '752', '17', '1', '2024-10-06', '', '12', '2024-10-06 04:40:14', '2024-10-06 04:40:14');
INSERT INTO `attendances` VALUES ('2561', '26', '754', '17', '1', '2024-10-06', '', '12', '2024-10-06 04:40:14', '2024-10-06 04:40:14');
INSERT INTO `attendances` VALUES ('2562', '26', '756', '17', '1', '2024-10-06', '', '12', '2024-10-06 04:40:14', '2024-10-06 04:40:14');
INSERT INTO `attendances` VALUES ('2563', '26', '758', '17', '1', '2024-10-06', '', '12', '2024-10-06 04:40:14', '2024-10-06 04:40:14');
INSERT INTO `attendances` VALUES ('2564', '26', '760', '17', '1', '2024-10-06', '', '12', '2024-10-06 04:40:14', '2024-10-06 04:40:14');
INSERT INTO `attendances` VALUES ('2565', '26', '762', '17', '1', '2024-10-06', '', '12', '2024-10-06 04:40:14', '2024-10-06 04:40:14');
INSERT INTO `attendances` VALUES ('2566', '26', '764', '17', '1', '2024-10-06', '', '12', '2024-10-06 04:40:14', '2024-10-06 04:40:14');
INSERT INTO `attendances` VALUES ('2567', '26', '766', '17', '1', '2024-10-06', '', '12', '2024-10-06 04:40:14', '2024-10-06 04:40:14');
INSERT INTO `attendances` VALUES ('2568', '26', '768', '17', '1', '2024-10-06', '', '12', '2024-10-06 04:40:14', '2024-10-06 04:40:14');
INSERT INTO `attendances` VALUES ('2569', '26', '770', '17', '1', '2024-10-06', '', '12', '2024-10-06 04:40:14', '2024-10-06 04:40:14');
INSERT INTO `attendances` VALUES ('2570', '26', '772', '17', '1', '2024-10-06', '', '12', '2024-10-06 04:40:14', '2024-10-06 04:40:14');
INSERT INTO `attendances` VALUES ('2571', '26', '774', '17', '1', '2024-10-06', '', '12', '2024-10-06 04:40:14', '2024-10-06 04:40:14');
INSERT INTO `attendances` VALUES ('2572', '26', '776', '17', '1', '2024-10-06', '', '12', '2024-10-06 04:40:14', '2024-10-06 04:40:14');
INSERT INTO `attendances` VALUES ('2573', '26', '778', '17', '1', '2024-10-06', '', '12', '2024-10-06 04:40:14', '2024-10-06 04:40:14');
INSERT INTO `attendances` VALUES ('2574', '26', '780', '17', '1', '2024-10-06', '', '12', '2024-10-06 04:40:14', '2024-10-06 04:40:14');
INSERT INTO `attendances` VALUES ('2575', '26', '782', '17', '1', '2024-10-06', '', '12', '2024-10-06 04:40:14', '2024-10-06 04:40:14');
INSERT INTO `attendances` VALUES ('2576', '26', '784', '17', '1', '2024-10-06', '', '12', '2024-10-06 04:40:14', '2024-10-06 04:40:14');
INSERT INTO `attendances` VALUES ('2577', '26', '786', '17', '1', '2024-10-06', '', '12', '2024-10-06 04:40:14', '2024-10-06 04:40:14');
INSERT INTO `attendances` VALUES ('2578', '26', '788', '17', '1', '2024-10-06', '', '12', '2024-10-06 04:40:14', '2024-10-06 04:40:14');
INSERT INTO `attendances` VALUES ('2579', '26', '790', '17', '1', '2024-10-06', '', '12', '2024-10-06 04:40:14', '2024-10-06 04:40:14');
INSERT INTO `attendances` VALUES ('2580', '26', '792', '17', '1', '2024-10-06', '', '12', '2024-10-06 04:40:14', '2024-10-06 04:40:14');
INSERT INTO `attendances` VALUES ('2581', '26', '794', '17', '1', '2024-10-06', '', '12', '2024-10-06 04:40:14', '2024-10-06 04:40:14');
INSERT INTO `attendances` VALUES ('2582', '26', '796', '17', '1', '2024-10-06', '', '12', '2024-10-06 04:40:14', '2024-10-06 04:40:14');
INSERT INTO `attendances` VALUES ('2583', '26', '798', '17', '1', '2024-10-06', '', '12', '2024-10-06 04:40:14', '2024-10-06 04:40:14');
INSERT INTO `attendances` VALUES ('2584', '26', '800', '17', '1', '2024-10-06', '', '12', '2024-10-06 04:40:14', '2024-10-06 04:40:14');
INSERT INTO `attendances` VALUES ('2585', '26', '802', '17', '1', '2024-10-06', '', '12', '2024-10-06 04:40:14', '2024-10-06 04:40:14');
INSERT INTO `attendances` VALUES ('2586', '21', '371', '17', '1', '2024-10-06', '', '12', '2024-10-06 09:08:51', '2024-10-06 09:08:51');
INSERT INTO `attendances` VALUES ('2587', '21', '377', '17', '1', '2024-10-06', '', '12', '2024-10-06 09:08:51', '2024-10-06 09:08:51');
INSERT INTO `attendances` VALUES ('2588', '21', '381', '17', '1', '2024-10-06', '', '12', '2024-10-06 09:08:51', '2024-10-06 09:08:51');
INSERT INTO `attendances` VALUES ('2589', '21', '387', '17', '1', '2024-10-06', '', '12', '2024-10-06 09:08:51', '2024-10-06 09:08:51');
INSERT INTO `attendances` VALUES ('2590', '21', '403', '17', '1', '2024-10-06', '', '12', '2024-10-06 09:08:51', '2024-10-06 09:08:51');
INSERT INTO `attendances` VALUES ('2591', '21', '407', '17', '1', '2024-10-06', '', '12', '2024-10-06 09:08:51', '2024-10-06 09:08:51');
INSERT INTO `attendances` VALUES ('2592', '21', '409', '17', '1', '2024-10-06', '', '12', '2024-10-06 09:08:51', '2024-10-06 09:08:51');
INSERT INTO `attendances` VALUES ('2593', '21', '417', '17', '1', '2024-10-06', '', '12', '2024-10-06 09:08:51', '2024-10-06 09:08:51');
INSERT INTO `attendances` VALUES ('2594', '21', '419', '17', '1', '2024-10-06', '', '12', '2024-10-06 09:08:51', '2024-10-06 09:08:51');
INSERT INTO `attendances` VALUES ('2595', '21', '421', '17', '1', '2024-10-06', '', '12', '2024-10-06 09:08:51', '2024-10-06 09:08:51');
INSERT INTO `attendances` VALUES ('2596', '21', '423', '17', '1', '2024-10-06', '', '12', '2024-10-06 09:08:51', '2024-10-06 09:08:51');
INSERT INTO `attendances` VALUES ('2597', '21', '425', '17', '1', '2024-10-06', '', '12', '2024-10-06 09:08:51', '2024-10-06 09:08:51');
INSERT INTO `attendances` VALUES ('2598', '21', '427', '17', '1', '2024-10-06', '', '12', '2024-10-06 09:08:51', '2024-10-06 09:08:51');
INSERT INTO `attendances` VALUES ('2599', '21', '429', '17', '1', '2024-10-06', '', '12', '2024-10-06 09:08:51', '2024-10-06 09:08:51');
INSERT INTO `attendances` VALUES ('2600', '21', '431', '17', '1', '2024-10-06', '', '12', '2024-10-06 09:08:51', '2024-10-06 09:08:51');
INSERT INTO `attendances` VALUES ('2601', '21', '433', '17', '1', '2024-10-06', '', '12', '2024-10-06 09:08:51', '2024-10-06 09:08:51');
INSERT INTO `attendances` VALUES ('2602', '21', '435', '17', '1', '2024-10-06', '', '12', '2024-10-06 09:08:51', '2024-10-06 09:08:51');
INSERT INTO `attendances` VALUES ('2603', '21', '437', '17', '1', '2024-10-06', '', '12', '2024-10-06 09:08:51', '2024-10-06 09:08:51');
INSERT INTO `attendances` VALUES ('2604', '21', '439', '17', '1', '2024-10-06', '', '12', '2024-10-06 09:08:51', '2024-10-06 09:08:51');
INSERT INTO `attendances` VALUES ('2605', '21', '441', '17', '1', '2024-10-06', '', '12', '2024-10-06 09:08:51', '2024-10-06 09:08:51');
INSERT INTO `attendances` VALUES ('2606', '21', '443', '17', '1', '2024-10-06', '', '12', '2024-10-06 09:08:51', '2024-10-06 09:08:51');
INSERT INTO `attendances` VALUES ('2607', '21', '445', '17', '1', '2024-10-06', '', '12', '2024-10-06 09:08:51', '2024-10-06 09:08:51');
INSERT INTO `attendances` VALUES ('2608', '21', '447', '17', '1', '2024-10-06', '', '12', '2024-10-06 09:08:51', '2024-10-06 09:08:51');
INSERT INTO `attendances` VALUES ('2609', '21', '449', '17', '1', '2024-10-06', '', '12', '2024-10-06 09:08:51', '2024-10-06 09:08:51');
INSERT INTO `attendances` VALUES ('2610', '21', '451', '17', '1', '2024-10-06', '', '12', '2024-10-06 09:08:51', '2024-10-06 09:08:51');
INSERT INTO `attendances` VALUES ('2611', '21', '453', '17', '1', '2024-10-06', '', '12', '2024-10-06 09:08:51', '2024-10-06 09:08:51');
INSERT INTO `attendances` VALUES ('2612', '21', '455', '17', '1', '2024-10-06', '', '12', '2024-10-06 09:08:51', '2024-10-06 09:08:51');
INSERT INTO `attendances` VALUES ('2613', '21', '457', '17', '1', '2024-10-06', '', '12', '2024-10-06 09:08:51', '2024-10-06 09:08:51');
INSERT INTO `attendances` VALUES ('2614', '21', '459', '17', '1', '2024-10-06', '', '12', '2024-10-06 09:08:51', '2024-10-06 09:08:51');
INSERT INTO `attendances` VALUES ('2615', '21', '461', '17', '1', '2024-10-06', '', '12', '2024-10-06 09:08:51', '2024-10-06 09:08:51');
INSERT INTO `attendances` VALUES ('2616', '21', '463', '17', '1', '2024-10-06', '', '12', '2024-10-06 09:08:51', '2024-10-06 09:08:51');
INSERT INTO `attendances` VALUES ('2617', '21', '465', '17', '1', '2024-10-06', '', '12', '2024-10-06 09:08:51', '2024-10-06 09:08:51');
INSERT INTO `attendances` VALUES ('2618', '21', '467', '17', '1', '2024-10-06', '', '12', '2024-10-06 09:08:51', '2024-10-06 09:08:51');
INSERT INTO `attendances` VALUES ('2619', '26', '337', '17', '0', '2024-10-07', '', '12', '2024-10-07 04:12:11', '2024-10-07 10:25:57');
INSERT INTO `attendances` VALUES ('2620', '26', '744', '17', '0', '2024-10-07', '', '12', '2024-10-07 04:12:11', '2024-10-07 17:02:41');
INSERT INTO `attendances` VALUES ('2621', '26', '746', '17', '1', '2024-10-07', '', '12', '2024-10-07 04:12:11', '2024-10-07 04:12:11');
INSERT INTO `attendances` VALUES ('2622', '26', '748', '17', '0', '2024-10-07', '', '12', '2024-10-07 04:12:11', '2024-10-07 17:02:41');
INSERT INTO `attendances` VALUES ('2623', '26', '750', '17', '1', '2024-10-07', '', '12', '2024-10-07 04:12:11', '2024-10-07 04:12:11');
INSERT INTO `attendances` VALUES ('2624', '26', '752', '17', '1', '2024-10-07', '', '12', '2024-10-07 04:12:11', '2024-10-07 04:12:11');
INSERT INTO `attendances` VALUES ('2625', '26', '754', '17', '1', '2024-10-07', '', '12', '2024-10-07 04:12:11', '2024-10-07 04:12:11');
INSERT INTO `attendances` VALUES ('2626', '26', '756', '17', '1', '2024-10-07', '', '12', '2024-10-07 04:12:11', '2024-10-07 04:12:11');
INSERT INTO `attendances` VALUES ('2627', '26', '758', '17', '1', '2024-10-07', '', '12', '2024-10-07 04:12:11', '2024-10-07 04:12:11');
INSERT INTO `attendances` VALUES ('2628', '26', '760', '17', '1', '2024-10-07', '', '12', '2024-10-07 04:12:11', '2024-10-07 04:12:11');
INSERT INTO `attendances` VALUES ('2629', '26', '762', '17', '1', '2024-10-07', '', '12', '2024-10-07 04:12:11', '2024-10-07 04:12:11');
INSERT INTO `attendances` VALUES ('2630', '26', '764', '17', '1', '2024-10-07', '', '12', '2024-10-07 04:12:11', '2024-10-07 04:12:11');
INSERT INTO `attendances` VALUES ('2631', '26', '766', '17', '1', '2024-10-07', '', '12', '2024-10-07 04:12:11', '2024-10-07 04:12:11');
INSERT INTO `attendances` VALUES ('2632', '26', '768', '17', '1', '2024-10-07', '', '12', '2024-10-07 04:12:11', '2024-10-07 04:12:11');
INSERT INTO `attendances` VALUES ('2633', '26', '770', '17', '1', '2024-10-07', '', '12', '2024-10-07 04:12:11', '2024-10-07 04:12:11');
INSERT INTO `attendances` VALUES ('2634', '26', '772', '17', '1', '2024-10-07', '', '12', '2024-10-07 04:12:11', '2024-10-07 04:12:11');
INSERT INTO `attendances` VALUES ('2635', '26', '774', '17', '1', '2024-10-07', '', '12', '2024-10-07 04:12:11', '2024-10-07 04:12:11');
INSERT INTO `attendances` VALUES ('2636', '26', '776', '17', '1', '2024-10-07', '', '12', '2024-10-07 04:12:11', '2024-10-07 04:12:11');
INSERT INTO `attendances` VALUES ('2637', '26', '778', '17', '1', '2024-10-07', '', '12', '2024-10-07 04:12:11', '2024-10-07 04:12:11');
INSERT INTO `attendances` VALUES ('2638', '26', '780', '17', '1', '2024-10-07', '', '12', '2024-10-07 04:12:11', '2024-10-07 04:12:11');
INSERT INTO `attendances` VALUES ('2639', '26', '782', '17', '1', '2024-10-07', '', '12', '2024-10-07 04:12:11', '2024-10-07 04:12:11');
INSERT INTO `attendances` VALUES ('2640', '26', '784', '17', '1', '2024-10-07', '', '12', '2024-10-07 04:12:11', '2024-10-07 04:12:11');
INSERT INTO `attendances` VALUES ('2641', '26', '786', '17', '1', '2024-10-07', '', '12', '2024-10-07 04:12:11', '2024-10-07 04:12:11');
INSERT INTO `attendances` VALUES ('2642', '26', '788', '17', '1', '2024-10-07', '', '12', '2024-10-07 04:12:11', '2024-10-07 04:12:11');
INSERT INTO `attendances` VALUES ('2643', '26', '790', '17', '1', '2024-10-07', '', '12', '2024-10-07 04:12:11', '2024-10-07 04:12:11');
INSERT INTO `attendances` VALUES ('2644', '26', '792', '17', '1', '2024-10-07', '', '12', '2024-10-07 04:12:11', '2024-10-07 04:12:11');
INSERT INTO `attendances` VALUES ('2645', '26', '794', '17', '1', '2024-10-07', '', '12', '2024-10-07 04:12:11', '2024-10-07 04:12:11');
INSERT INTO `attendances` VALUES ('2646', '26', '796', '17', '1', '2024-10-07', '', '12', '2024-10-07 04:12:11', '2024-10-07 04:12:11');
INSERT INTO `attendances` VALUES ('2647', '26', '798', '17', '1', '2024-10-07', '', '12', '2024-10-07 04:12:11', '2024-10-07 04:12:11');
INSERT INTO `attendances` VALUES ('2648', '26', '800', '17', '1', '2024-10-07', '', '12', '2024-10-07 04:12:11', '2024-10-07 04:12:11');
INSERT INTO `attendances` VALUES ('2649', '26', '802', '17', '1', '2024-10-07', '', '12', '2024-10-07 04:12:11', '2024-10-07 04:12:11');
INSERT INTO `attendances` VALUES ('2650', '26', '337', '17', '0', '2024-10-09', '', '12', '2024-10-09 05:31:15', '2024-10-09 05:31:15');
INSERT INTO `attendances` VALUES ('2651', '26', '744', '17', '0', '2024-10-09', '', '12', '2024-10-09 05:31:15', '2024-10-09 05:31:15');
INSERT INTO `attendances` VALUES ('2652', '26', '746', '17', '1', '2024-10-09', '', '12', '2024-10-09 05:31:15', '2024-10-09 05:31:15');
INSERT INTO `attendances` VALUES ('2653', '26', '748', '17', '1', '2024-10-09', '', '12', '2024-10-09 05:31:15', '2024-10-09 05:31:15');
INSERT INTO `attendances` VALUES ('2654', '26', '750', '17', '1', '2024-10-09', '', '12', '2024-10-09 05:31:15', '2024-10-09 05:31:15');
INSERT INTO `attendances` VALUES ('2655', '26', '752', '17', '1', '2024-10-09', '', '12', '2024-10-09 05:31:15', '2024-10-09 05:31:15');
INSERT INTO `attendances` VALUES ('2656', '26', '754', '17', '1', '2024-10-09', '', '12', '2024-10-09 05:31:15', '2024-10-09 05:31:15');
INSERT INTO `attendances` VALUES ('2657', '26', '756', '17', '1', '2024-10-09', '', '12', '2024-10-09 05:31:15', '2024-10-09 05:31:15');
INSERT INTO `attendances` VALUES ('2658', '26', '758', '17', '1', '2024-10-09', '', '12', '2024-10-09 05:31:15', '2024-10-09 05:31:15');
INSERT INTO `attendances` VALUES ('2659', '26', '760', '17', '1', '2024-10-09', '', '12', '2024-10-09 05:31:15', '2024-10-09 05:31:15');
INSERT INTO `attendances` VALUES ('2660', '26', '762', '17', '1', '2024-10-09', '', '12', '2024-10-09 05:31:15', '2024-10-09 05:31:15');
INSERT INTO `attendances` VALUES ('2661', '26', '764', '17', '1', '2024-10-09', '', '12', '2024-10-09 05:31:15', '2024-10-09 05:31:15');
INSERT INTO `attendances` VALUES ('2662', '26', '766', '17', '1', '2024-10-09', '', '12', '2024-10-09 05:31:15', '2024-10-09 05:31:15');
INSERT INTO `attendances` VALUES ('2663', '26', '768', '17', '1', '2024-10-09', '', '12', '2024-10-09 05:31:15', '2024-10-09 05:31:15');
INSERT INTO `attendances` VALUES ('2664', '26', '770', '17', '1', '2024-10-09', '', '12', '2024-10-09 05:31:15', '2024-10-09 05:31:15');
INSERT INTO `attendances` VALUES ('2665', '26', '772', '17', '1', '2024-10-09', '', '12', '2024-10-09 05:31:15', '2024-10-09 05:31:15');
INSERT INTO `attendances` VALUES ('2666', '26', '774', '17', '1', '2024-10-09', '', '12', '2024-10-09 05:31:15', '2024-10-09 05:31:15');
INSERT INTO `attendances` VALUES ('2667', '26', '776', '17', '1', '2024-10-09', '', '12', '2024-10-09 05:31:15', '2024-10-09 05:31:15');
INSERT INTO `attendances` VALUES ('2668', '26', '778', '17', '1', '2024-10-09', '', '12', '2024-10-09 05:31:15', '2024-10-09 05:31:15');
INSERT INTO `attendances` VALUES ('2669', '26', '780', '17', '1', '2024-10-09', '', '12', '2024-10-09 05:31:15', '2024-10-09 05:31:15');
INSERT INTO `attendances` VALUES ('2670', '26', '782', '17', '1', '2024-10-09', '', '12', '2024-10-09 05:31:15', '2024-10-09 05:31:15');
INSERT INTO `attendances` VALUES ('2671', '26', '784', '17', '1', '2024-10-09', '', '12', '2024-10-09 05:31:15', '2024-10-09 05:31:15');
INSERT INTO `attendances` VALUES ('2672', '26', '786', '17', '1', '2024-10-09', '', '12', '2024-10-09 05:31:15', '2024-10-09 05:31:15');
INSERT INTO `attendances` VALUES ('2673', '26', '788', '17', '1', '2024-10-09', '', '12', '2024-10-09 05:31:15', '2024-10-09 05:31:15');
INSERT INTO `attendances` VALUES ('2674', '26', '790', '17', '1', '2024-10-09', '', '12', '2024-10-09 05:31:15', '2024-10-09 05:31:15');
INSERT INTO `attendances` VALUES ('2675', '26', '792', '17', '1', '2024-10-09', '', '12', '2024-10-09 05:31:15', '2024-10-09 05:31:15');
INSERT INTO `attendances` VALUES ('2676', '26', '794', '17', '1', '2024-10-09', '', '12', '2024-10-09 05:31:15', '2024-10-09 05:31:15');
INSERT INTO `attendances` VALUES ('2677', '26', '796', '17', '1', '2024-10-09', '', '12', '2024-10-09 05:31:15', '2024-10-09 05:31:15');
INSERT INTO `attendances` VALUES ('2678', '26', '798', '17', '1', '2024-10-09', '', '12', '2024-10-09 05:31:15', '2024-10-09 05:31:15');
INSERT INTO `attendances` VALUES ('2679', '26', '800', '17', '1', '2024-10-09', '', '12', '2024-10-09 05:31:15', '2024-10-09 05:31:15');
INSERT INTO `attendances` VALUES ('2680', '26', '802', '17', '1', '2024-10-09', '', '12', '2024-10-09 05:31:15', '2024-10-09 05:31:15');
INSERT INTO `attendances` VALUES ('2681', '21', '371', '17', '1', '2024-10-09', '', '12', '2024-10-09 13:27:04', '2024-10-09 13:27:04');
INSERT INTO `attendances` VALUES ('2682', '21', '377', '17', '1', '2024-10-09', '', '12', '2024-10-09 13:27:04', '2024-10-09 13:27:04');
INSERT INTO `attendances` VALUES ('2683', '21', '381', '17', '1', '2024-10-09', '', '12', '2024-10-09 13:27:04', '2024-10-09 13:27:04');
INSERT INTO `attendances` VALUES ('2684', '21', '387', '17', '1', '2024-10-09', '', '12', '2024-10-09 13:27:04', '2024-10-09 13:27:04');
INSERT INTO `attendances` VALUES ('2685', '21', '403', '17', '1', '2024-10-09', '', '12', '2024-10-09 13:27:04', '2024-10-09 13:27:04');
INSERT INTO `attendances` VALUES ('2686', '21', '407', '17', '1', '2024-10-09', '', '12', '2024-10-09 13:27:04', '2024-10-09 13:27:04');
INSERT INTO `attendances` VALUES ('2687', '21', '409', '17', '1', '2024-10-09', '', '12', '2024-10-09 13:27:04', '2024-10-09 13:27:04');
INSERT INTO `attendances` VALUES ('2688', '21', '417', '17', '1', '2024-10-09', '', '12', '2024-10-09 13:27:04', '2024-10-09 13:27:04');
INSERT INTO `attendances` VALUES ('2689', '21', '419', '17', '1', '2024-10-09', '', '12', '2024-10-09 13:27:04', '2024-10-09 13:27:04');
INSERT INTO `attendances` VALUES ('2690', '21', '421', '17', '1', '2024-10-09', '', '12', '2024-10-09 13:27:04', '2024-10-09 13:27:04');
INSERT INTO `attendances` VALUES ('2691', '21', '423', '17', '1', '2024-10-09', '', '12', '2024-10-09 13:27:04', '2024-10-09 13:27:04');
INSERT INTO `attendances` VALUES ('2692', '21', '425', '17', '1', '2024-10-09', '', '12', '2024-10-09 13:27:04', '2024-10-09 13:27:04');
INSERT INTO `attendances` VALUES ('2693', '21', '427', '17', '1', '2024-10-09', '', '12', '2024-10-09 13:27:04', '2024-10-09 13:27:04');
INSERT INTO `attendances` VALUES ('2694', '21', '429', '17', '1', '2024-10-09', '', '12', '2024-10-09 13:27:04', '2024-10-09 13:27:04');
INSERT INTO `attendances` VALUES ('2695', '21', '431', '17', '1', '2024-10-09', '', '12', '2024-10-09 13:27:04', '2024-10-09 13:27:04');
INSERT INTO `attendances` VALUES ('2696', '21', '433', '17', '1', '2024-10-09', '', '12', '2024-10-09 13:27:04', '2024-10-09 13:27:04');
INSERT INTO `attendances` VALUES ('2697', '21', '435', '17', '1', '2024-10-09', '', '12', '2024-10-09 13:27:04', '2024-10-09 13:27:04');
INSERT INTO `attendances` VALUES ('2698', '21', '437', '17', '1', '2024-10-09', '', '12', '2024-10-09 13:27:04', '2024-10-09 13:27:04');
INSERT INTO `attendances` VALUES ('2699', '21', '439', '17', '1', '2024-10-09', '', '12', '2024-10-09 13:27:04', '2024-10-09 13:27:04');
INSERT INTO `attendances` VALUES ('2700', '21', '441', '17', '1', '2024-10-09', '', '12', '2024-10-09 13:27:04', '2024-10-09 13:27:04');
INSERT INTO `attendances` VALUES ('2701', '21', '443', '17', '1', '2024-10-09', '', '12', '2024-10-09 13:27:04', '2024-10-09 13:27:04');
INSERT INTO `attendances` VALUES ('2702', '21', '445', '17', '1', '2024-10-09', '', '12', '2024-10-09 13:27:04', '2024-10-09 13:27:04');
INSERT INTO `attendances` VALUES ('2703', '21', '447', '17', '1', '2024-10-09', '', '12', '2024-10-09 13:27:04', '2024-10-09 13:27:04');
INSERT INTO `attendances` VALUES ('2704', '21', '449', '17', '1', '2024-10-09', '', '12', '2024-10-09 13:27:04', '2024-10-09 13:27:04');
INSERT INTO `attendances` VALUES ('2705', '21', '451', '17', '1', '2024-10-09', '', '12', '2024-10-09 13:27:04', '2024-10-09 13:27:04');
INSERT INTO `attendances` VALUES ('2706', '21', '453', '17', '1', '2024-10-09', '', '12', '2024-10-09 13:27:04', '2024-10-09 13:27:04');
INSERT INTO `attendances` VALUES ('2707', '21', '455', '17', '1', '2024-10-09', '', '12', '2024-10-09 13:27:04', '2024-10-09 13:27:04');
INSERT INTO `attendances` VALUES ('2708', '21', '457', '17', '1', '2024-10-09', '', '12', '2024-10-09 13:27:04', '2024-10-09 13:27:04');
INSERT INTO `attendances` VALUES ('2709', '21', '459', '17', '1', '2024-10-09', '', '12', '2024-10-09 13:27:04', '2024-10-09 13:27:04');
INSERT INTO `attendances` VALUES ('2710', '21', '461', '17', '1', '2024-10-09', '', '12', '2024-10-09 13:27:04', '2024-10-09 13:27:04');
INSERT INTO `attendances` VALUES ('2711', '21', '463', '17', '1', '2024-10-09', '', '12', '2024-10-09 13:27:04', '2024-10-09 13:27:04');
INSERT INTO `attendances` VALUES ('2712', '21', '465', '17', '1', '2024-10-09', '', '12', '2024-10-09 13:27:04', '2024-10-09 13:27:04');
INSERT INTO `attendances` VALUES ('2713', '21', '467', '17', '1', '2024-10-09', '', '12', '2024-10-09 13:27:04', '2024-10-09 13:27:04');
INSERT INTO `attendances` VALUES ('2714', '21', '371', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:41:12', '2024-10-10 15:41:12');
INSERT INTO `attendances` VALUES ('2715', '21', '377', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:41:12', '2024-10-10 15:41:12');
INSERT INTO `attendances` VALUES ('2716', '21', '381', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:41:12', '2024-10-10 15:41:12');
INSERT INTO `attendances` VALUES ('2717', '21', '387', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:41:12', '2024-10-10 15:41:12');
INSERT INTO `attendances` VALUES ('2718', '21', '403', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:41:12', '2024-10-10 15:41:12');
INSERT INTO `attendances` VALUES ('2719', '21', '407', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:41:12', '2024-10-10 15:41:12');
INSERT INTO `attendances` VALUES ('2720', '21', '409', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:41:12', '2024-10-10 15:41:12');
INSERT INTO `attendances` VALUES ('2721', '21', '417', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:41:12', '2024-10-10 15:41:12');
INSERT INTO `attendances` VALUES ('2722', '21', '419', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:41:12', '2024-10-10 15:41:12');
INSERT INTO `attendances` VALUES ('2723', '21', '421', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:41:12', '2024-10-10 15:41:12');
INSERT INTO `attendances` VALUES ('2724', '21', '423', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:41:12', '2024-10-10 15:41:12');
INSERT INTO `attendances` VALUES ('2725', '21', '425', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:41:12', '2024-10-10 15:41:12');
INSERT INTO `attendances` VALUES ('2726', '21', '427', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:41:12', '2024-10-10 15:41:12');
INSERT INTO `attendances` VALUES ('2727', '21', '429', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:41:12', '2024-10-10 15:41:12');
INSERT INTO `attendances` VALUES ('2728', '21', '431', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:41:12', '2024-10-10 15:41:12');
INSERT INTO `attendances` VALUES ('2729', '21', '433', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:41:12', '2024-10-10 15:41:12');
INSERT INTO `attendances` VALUES ('2730', '21', '435', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:41:12', '2024-10-10 15:41:12');
INSERT INTO `attendances` VALUES ('2731', '21', '437', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:41:12', '2024-10-10 15:41:12');
INSERT INTO `attendances` VALUES ('2732', '21', '439', '17', '0', '2024-10-10', '', '12', '2024-10-10 15:41:12', '2024-10-10 15:41:29');
INSERT INTO `attendances` VALUES ('2733', '21', '441', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:41:12', '2024-10-10 15:41:12');
INSERT INTO `attendances` VALUES ('2734', '21', '443', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:41:12', '2024-10-10 15:41:12');
INSERT INTO `attendances` VALUES ('2735', '21', '445', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:41:12', '2024-10-10 15:41:12');
INSERT INTO `attendances` VALUES ('2736', '21', '447', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:41:12', '2024-10-10 15:41:12');
INSERT INTO `attendances` VALUES ('2737', '21', '449', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:41:12', '2024-10-10 15:41:12');
INSERT INTO `attendances` VALUES ('2738', '21', '451', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:41:12', '2024-10-10 15:41:12');
INSERT INTO `attendances` VALUES ('2739', '21', '453', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:41:12', '2024-10-10 15:41:12');
INSERT INTO `attendances` VALUES ('2740', '21', '455', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:41:12', '2024-10-10 15:41:12');
INSERT INTO `attendances` VALUES ('2741', '21', '457', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:41:12', '2024-10-10 15:41:12');
INSERT INTO `attendances` VALUES ('2742', '21', '459', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:41:12', '2024-10-10 15:41:12');
INSERT INTO `attendances` VALUES ('2743', '21', '461', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:41:12', '2024-10-10 15:41:12');
INSERT INTO `attendances` VALUES ('2744', '21', '463', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:41:12', '2024-10-10 15:41:12');
INSERT INTO `attendances` VALUES ('2745', '21', '465', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:41:12', '2024-10-10 15:41:12');
INSERT INTO `attendances` VALUES ('2746', '21', '467', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:41:12', '2024-10-10 15:41:12');
INSERT INTO `attendances` VALUES ('2747', '26', '337', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:44:05', '2024-10-10 15:44:05');
INSERT INTO `attendances` VALUES ('2748', '26', '744', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:44:05', '2024-10-11 22:22:13');
INSERT INTO `attendances` VALUES ('2749', '26', '746', '17', '0', '2024-10-10', '', '12', '2024-10-10 15:44:05', '2024-10-11 22:22:26');
INSERT INTO `attendances` VALUES ('2750', '26', '748', '17', '0', '2024-10-10', '', '12', '2024-10-10 15:44:05', '2024-10-10 15:44:05');
INSERT INTO `attendances` VALUES ('2751', '26', '750', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:44:05', '2024-10-10 15:44:05');
INSERT INTO `attendances` VALUES ('2752', '26', '752', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:44:05', '2024-10-10 15:44:05');
INSERT INTO `attendances` VALUES ('2753', '26', '754', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:44:05', '2024-10-10 15:44:05');
INSERT INTO `attendances` VALUES ('2754', '26', '756', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:44:05', '2024-10-10 15:44:05');
INSERT INTO `attendances` VALUES ('2755', '26', '758', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:44:05', '2024-10-10 15:44:05');
INSERT INTO `attendances` VALUES ('2756', '26', '760', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:44:05', '2024-10-10 15:44:05');
INSERT INTO `attendances` VALUES ('2757', '26', '762', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:44:05', '2024-10-10 15:44:05');
INSERT INTO `attendances` VALUES ('2758', '26', '764', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:44:06', '2024-10-10 15:44:06');
INSERT INTO `attendances` VALUES ('2759', '26', '766', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:44:06', '2024-10-10 15:44:06');
INSERT INTO `attendances` VALUES ('2760', '26', '768', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:44:06', '2024-10-10 15:44:06');
INSERT INTO `attendances` VALUES ('2761', '26', '770', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:44:06', '2024-10-10 15:44:06');
INSERT INTO `attendances` VALUES ('2762', '26', '772', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:44:06', '2024-10-10 15:44:06');
INSERT INTO `attendances` VALUES ('2763', '26', '774', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:44:06', '2024-10-10 15:44:06');
INSERT INTO `attendances` VALUES ('2764', '26', '776', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:44:06', '2024-10-10 15:44:06');
INSERT INTO `attendances` VALUES ('2765', '26', '778', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:44:06', '2024-10-10 15:44:06');
INSERT INTO `attendances` VALUES ('2766', '26', '780', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:44:06', '2024-10-10 15:44:06');
INSERT INTO `attendances` VALUES ('2767', '26', '782', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:44:06', '2024-10-10 15:44:06');
INSERT INTO `attendances` VALUES ('2768', '26', '784', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:44:06', '2024-10-10 15:44:06');
INSERT INTO `attendances` VALUES ('2769', '26', '786', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:44:06', '2024-10-10 15:44:06');
INSERT INTO `attendances` VALUES ('2770', '26', '788', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:44:06', '2024-10-10 15:44:06');
INSERT INTO `attendances` VALUES ('2771', '26', '790', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:44:06', '2024-10-10 15:44:06');
INSERT INTO `attendances` VALUES ('2772', '26', '792', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:44:06', '2024-10-10 15:44:06');
INSERT INTO `attendances` VALUES ('2773', '26', '794', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:44:06', '2024-10-10 15:44:06');
INSERT INTO `attendances` VALUES ('2774', '26', '796', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:44:06', '2024-10-10 15:44:06');
INSERT INTO `attendances` VALUES ('2775', '26', '798', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:44:06', '2024-10-10 15:44:06');
INSERT INTO `attendances` VALUES ('2776', '26', '800', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:44:06', '2024-10-10 15:44:06');
INSERT INTO `attendances` VALUES ('2777', '26', '802', '17', '1', '2024-10-10', '', '12', '2024-10-10 15:44:06', '2024-10-10 15:44:06');
INSERT INTO `attendances` VALUES ('2778', '26', '337', '17', '0', '2024-10-14', '', '12', '2024-10-14 08:37:04', '2024-10-15 01:29:48');
INSERT INTO `attendances` VALUES ('2779', '26', '744', '17', '1', '2024-10-14', '', '12', '2024-10-14 08:37:04', '2024-10-14 08:37:04');
INSERT INTO `attendances` VALUES ('2780', '26', '746', '17', '1', '2024-10-14', '', '12', '2024-10-14 08:37:04', '2024-10-14 08:37:04');
INSERT INTO `attendances` VALUES ('2781', '26', '748', '17', '1', '2024-10-14', '', '12', '2024-10-14 08:37:04', '2024-10-14 08:37:04');
INSERT INTO `attendances` VALUES ('2782', '26', '750', '17', '1', '2024-10-14', '', '12', '2024-10-14 08:37:04', '2024-10-14 08:37:04');
INSERT INTO `attendances` VALUES ('2783', '26', '752', '17', '1', '2024-10-14', '', '12', '2024-10-14 08:37:04', '2024-10-14 08:37:04');
INSERT INTO `attendances` VALUES ('2784', '26', '754', '17', '1', '2024-10-14', '', '12', '2024-10-14 08:37:04', '2024-10-14 08:37:04');
INSERT INTO `attendances` VALUES ('2785', '26', '756', '17', '1', '2024-10-14', '', '12', '2024-10-14 08:37:04', '2024-10-14 08:37:04');
INSERT INTO `attendances` VALUES ('2786', '26', '758', '17', '1', '2024-10-14', '', '12', '2024-10-14 08:37:04', '2024-10-14 08:37:04');
INSERT INTO `attendances` VALUES ('2787', '26', '760', '17', '1', '2024-10-14', '', '12', '2024-10-14 08:37:04', '2024-10-14 08:37:04');
INSERT INTO `attendances` VALUES ('2788', '26', '762', '17', '1', '2024-10-14', '', '12', '2024-10-14 08:37:04', '2024-10-14 08:37:04');
INSERT INTO `attendances` VALUES ('2789', '26', '764', '17', '1', '2024-10-14', '', '12', '2024-10-14 08:37:04', '2024-10-14 08:37:04');
INSERT INTO `attendances` VALUES ('2790', '26', '766', '17', '1', '2024-10-14', '', '12', '2024-10-14 08:37:04', '2024-10-14 08:37:04');
INSERT INTO `attendances` VALUES ('2791', '26', '768', '17', '1', '2024-10-14', '', '12', '2024-10-14 08:37:04', '2024-10-14 08:37:04');
INSERT INTO `attendances` VALUES ('2792', '26', '770', '17', '1', '2024-10-14', '', '12', '2024-10-14 08:37:04', '2024-10-14 08:37:04');
INSERT INTO `attendances` VALUES ('2793', '26', '772', '17', '1', '2024-10-14', '', '12', '2024-10-14 08:37:04', '2024-10-14 08:37:04');
INSERT INTO `attendances` VALUES ('2794', '26', '774', '17', '1', '2024-10-14', '', '12', '2024-10-14 08:37:04', '2024-10-14 08:37:04');
INSERT INTO `attendances` VALUES ('2795', '26', '776', '17', '1', '2024-10-14', '', '12', '2024-10-14 08:37:04', '2024-10-14 08:37:04');
INSERT INTO `attendances` VALUES ('2796', '26', '778', '17', '1', '2024-10-14', '', '12', '2024-10-14 08:37:04', '2024-10-14 08:37:04');
INSERT INTO `attendances` VALUES ('2797', '26', '780', '17', '1', '2024-10-14', '', '12', '2024-10-14 08:37:04', '2024-10-14 08:37:04');
INSERT INTO `attendances` VALUES ('2798', '26', '782', '17', '1', '2024-10-14', '', '12', '2024-10-14 08:37:04', '2024-10-14 08:37:04');
INSERT INTO `attendances` VALUES ('2799', '26', '784', '17', '1', '2024-10-14', '', '12', '2024-10-14 08:37:04', '2024-10-14 08:37:04');
INSERT INTO `attendances` VALUES ('2800', '26', '786', '17', '1', '2024-10-14', '', '12', '2024-10-14 08:37:04', '2024-10-14 08:37:04');
INSERT INTO `attendances` VALUES ('2801', '26', '788', '17', '1', '2024-10-14', '', '12', '2024-10-14 08:37:04', '2024-10-14 08:37:04');
INSERT INTO `attendances` VALUES ('2802', '26', '790', '17', '1', '2024-10-14', '', '12', '2024-10-14 08:37:04', '2024-10-14 08:37:04');
INSERT INTO `attendances` VALUES ('2803', '26', '792', '17', '1', '2024-10-14', '', '12', '2024-10-14 08:37:04', '2024-10-14 08:37:04');
INSERT INTO `attendances` VALUES ('2804', '26', '794', '17', '0', '2024-10-14', '', '12', '2024-10-14 08:37:04', '2024-10-15 01:29:48');
INSERT INTO `attendances` VALUES ('2805', '26', '796', '17', '1', '2024-10-14', '', '12', '2024-10-14 08:37:04', '2024-10-14 08:37:04');
INSERT INTO `attendances` VALUES ('2806', '26', '798', '17', '1', '2024-10-14', '', '12', '2024-10-14 08:37:04', '2024-10-14 08:37:04');
INSERT INTO `attendances` VALUES ('2807', '26', '800', '17', '1', '2024-10-14', '', '12', '2024-10-14 08:37:04', '2024-10-14 08:37:04');
INSERT INTO `attendances` VALUES ('2808', '26', '802', '17', '1', '2024-10-14', '', '12', '2024-10-14 08:37:04', '2024-10-14 08:37:04');
INSERT INTO `attendances` VALUES ('2809', '26', '337', '17', '1', '2024-10-15', '', '12', '2024-10-15 08:15:29', '2024-10-15 08:15:29');
INSERT INTO `attendances` VALUES ('2810', '26', '744', '17', '0', '2024-10-15', '', '12', '2024-10-15 08:15:29', '2024-10-15 22:49:47');
INSERT INTO `attendances` VALUES ('2811', '26', '746', '17', '0', '2024-10-15', '', '12', '2024-10-15 08:15:29', '2024-10-15 15:47:58');
INSERT INTO `attendances` VALUES ('2812', '26', '748', '17', '0', '2024-10-15', '', '12', '2024-10-15 08:15:29', '2024-10-15 15:47:58');
INSERT INTO `attendances` VALUES ('2813', '26', '750', '17', '1', '2024-10-15', '', '12', '2024-10-15 08:15:29', '2024-10-15 08:15:29');
INSERT INTO `attendances` VALUES ('2814', '26', '752', '17', '1', '2024-10-15', '', '12', '2024-10-15 08:15:29', '2024-10-15 08:15:29');
INSERT INTO `attendances` VALUES ('2815', '26', '754', '17', '1', '2024-10-15', '', '12', '2024-10-15 08:15:29', '2024-10-15 08:15:29');
INSERT INTO `attendances` VALUES ('2816', '26', '756', '17', '1', '2024-10-15', '', '12', '2024-10-15 08:15:29', '2024-10-15 08:15:29');
INSERT INTO `attendances` VALUES ('2817', '26', '758', '17', '1', '2024-10-15', '', '12', '2024-10-15 08:15:29', '2024-10-15 08:15:29');
INSERT INTO `attendances` VALUES ('2818', '26', '760', '17', '1', '2024-10-15', '', '12', '2024-10-15 08:15:29', '2024-10-15 08:15:29');
INSERT INTO `attendances` VALUES ('2819', '26', '762', '17', '1', '2024-10-15', '', '12', '2024-10-15 08:15:29', '2024-10-15 08:15:29');
INSERT INTO `attendances` VALUES ('2820', '26', '764', '17', '1', '2024-10-15', '', '12', '2024-10-15 08:15:29', '2024-10-15 08:15:29');
INSERT INTO `attendances` VALUES ('2821', '26', '766', '17', '1', '2024-10-15', '', '12', '2024-10-15 08:15:29', '2024-10-15 08:15:29');
INSERT INTO `attendances` VALUES ('2822', '26', '768', '17', '1', '2024-10-15', '', '12', '2024-10-15 08:15:29', '2024-10-15 08:15:29');
INSERT INTO `attendances` VALUES ('2823', '26', '770', '17', '1', '2024-10-15', '', '12', '2024-10-15 08:15:29', '2024-10-15 08:15:29');
INSERT INTO `attendances` VALUES ('2824', '26', '772', '17', '1', '2024-10-15', '', '12', '2024-10-15 08:15:29', '2024-10-15 08:15:29');
INSERT INTO `attendances` VALUES ('2825', '26', '774', '17', '1', '2024-10-15', '', '12', '2024-10-15 08:15:29', '2024-10-15 08:15:29');
INSERT INTO `attendances` VALUES ('2826', '26', '776', '17', '1', '2024-10-15', '', '12', '2024-10-15 08:15:29', '2024-10-15 08:15:29');
INSERT INTO `attendances` VALUES ('2827', '26', '778', '17', '1', '2024-10-15', '', '12', '2024-10-15 08:15:29', '2024-10-15 08:15:29');
INSERT INTO `attendances` VALUES ('2828', '26', '780', '17', '1', '2024-10-15', '', '12', '2024-10-15 08:15:29', '2024-10-15 08:15:29');
INSERT INTO `attendances` VALUES ('2829', '26', '782', '17', '1', '2024-10-15', '', '12', '2024-10-15 08:15:29', '2024-10-15 08:15:29');
INSERT INTO `attendances` VALUES ('2830', '26', '784', '17', '1', '2024-10-15', '', '12', '2024-10-15 08:15:29', '2024-10-15 08:15:29');
INSERT INTO `attendances` VALUES ('2831', '26', '786', '17', '1', '2024-10-15', '', '12', '2024-10-15 08:15:29', '2024-10-15 08:15:29');
INSERT INTO `attendances` VALUES ('2832', '26', '788', '17', '1', '2024-10-15', '', '12', '2024-10-15 08:15:29', '2024-10-15 08:15:29');
INSERT INTO `attendances` VALUES ('2833', '26', '790', '17', '1', '2024-10-15', '', '12', '2024-10-15 08:15:29', '2024-10-15 08:15:29');
INSERT INTO `attendances` VALUES ('2834', '26', '792', '17', '1', '2024-10-15', '', '12', '2024-10-15 08:15:29', '2024-10-15 08:15:29');
INSERT INTO `attendances` VALUES ('2835', '26', '794', '17', '1', '2024-10-15', '', '12', '2024-10-15 08:15:29', '2024-10-15 08:15:29');
INSERT INTO `attendances` VALUES ('2836', '26', '796', '17', '1', '2024-10-15', '', '12', '2024-10-15 08:15:29', '2024-10-15 08:15:29');
INSERT INTO `attendances` VALUES ('2837', '26', '798', '17', '1', '2024-10-15', '', '12', '2024-10-15 08:15:29', '2024-10-15 08:15:29');
INSERT INTO `attendances` VALUES ('2838', '26', '800', '17', '0', '2024-10-15', '', '12', '2024-10-15 08:15:29', '2024-10-15 15:47:58');
INSERT INTO `attendances` VALUES ('2839', '26', '802', '17', '1', '2024-10-15', '', '12', '2024-10-15 08:15:29', '2024-10-15 08:15:29');
INSERT INTO `attendances` VALUES ('2840', '21', '371', '17', '0', '2024-10-16', '', '12', '2024-10-16 04:26:37', '2024-10-16 04:26:37');
INSERT INTO `attendances` VALUES ('2841', '21', '377', '17', '1', '2024-10-16', '', '12', '2024-10-16 04:26:37', '2024-10-16 04:26:37');
INSERT INTO `attendances` VALUES ('2842', '21', '381', '17', '1', '2024-10-16', '', '12', '2024-10-16 04:26:37', '2024-10-16 04:26:37');
INSERT INTO `attendances` VALUES ('2843', '21', '387', '17', '1', '2024-10-16', '', '12', '2024-10-16 04:26:37', '2024-10-16 04:26:37');
INSERT INTO `attendances` VALUES ('2844', '21', '403', '17', '1', '2024-10-16', '', '12', '2024-10-16 04:26:37', '2024-10-16 04:26:37');
INSERT INTO `attendances` VALUES ('2845', '21', '407', '17', '1', '2024-10-16', '', '12', '2024-10-16 04:26:37', '2024-10-16 04:26:37');
INSERT INTO `attendances` VALUES ('2846', '21', '409', '17', '1', '2024-10-16', '', '12', '2024-10-16 04:26:37', '2024-10-16 04:26:37');
INSERT INTO `attendances` VALUES ('2847', '21', '417', '17', '0', '2024-10-16', '', '12', '2024-10-16 04:26:37', '2024-10-16 04:26:37');
INSERT INTO `attendances` VALUES ('2848', '21', '419', '17', '1', '2024-10-16', '', '12', '2024-10-16 04:26:37', '2024-10-16 04:26:37');
INSERT INTO `attendances` VALUES ('2849', '21', '421', '17', '1', '2024-10-16', '', '12', '2024-10-16 04:26:37', '2024-10-16 04:26:37');
INSERT INTO `attendances` VALUES ('2850', '21', '423', '17', '1', '2024-10-16', '', '12', '2024-10-16 04:26:37', '2024-10-16 04:26:37');
INSERT INTO `attendances` VALUES ('2851', '21', '425', '17', '1', '2024-10-16', '', '12', '2024-10-16 04:26:37', '2024-10-16 04:26:37');
INSERT INTO `attendances` VALUES ('2852', '21', '427', '17', '1', '2024-10-16', '', '12', '2024-10-16 04:26:37', '2024-10-16 04:26:37');
INSERT INTO `attendances` VALUES ('2853', '21', '429', '17', '1', '2024-10-16', '', '12', '2024-10-16 04:26:37', '2024-10-16 04:26:37');
INSERT INTO `attendances` VALUES ('2854', '21', '431', '17', '1', '2024-10-16', '', '12', '2024-10-16 04:26:37', '2024-10-16 04:26:37');
INSERT INTO `attendances` VALUES ('2855', '21', '433', '17', '1', '2024-10-16', '', '12', '2024-10-16 04:26:37', '2024-10-16 04:26:37');
INSERT INTO `attendances` VALUES ('2856', '21', '435', '17', '1', '2024-10-16', '', '12', '2024-10-16 04:26:37', '2024-10-16 04:26:37');
INSERT INTO `attendances` VALUES ('2857', '21', '437', '17', '1', '2024-10-16', '', '12', '2024-10-16 04:26:37', '2024-10-16 04:26:37');
INSERT INTO `attendances` VALUES ('2858', '21', '439', '17', '1', '2024-10-16', '', '12', '2024-10-16 04:26:37', '2024-10-16 04:26:37');
INSERT INTO `attendances` VALUES ('2859', '21', '441', '17', '1', '2024-10-16', '', '12', '2024-10-16 04:26:37', '2024-10-16 04:26:37');
INSERT INTO `attendances` VALUES ('2860', '21', '443', '17', '1', '2024-10-16', '', '12', '2024-10-16 04:26:37', '2024-10-16 04:26:37');
INSERT INTO `attendances` VALUES ('2861', '21', '445', '17', '1', '2024-10-16', '', '12', '2024-10-16 04:26:37', '2024-10-16 04:26:37');
INSERT INTO `attendances` VALUES ('2862', '21', '447', '17', '1', '2024-10-16', '', '12', '2024-10-16 04:26:37', '2024-10-16 04:26:37');
INSERT INTO `attendances` VALUES ('2863', '21', '449', '17', '1', '2024-10-16', '', '12', '2024-10-16 04:26:37', '2024-10-16 04:26:37');
INSERT INTO `attendances` VALUES ('2864', '21', '451', '17', '1', '2024-10-16', '', '12', '2024-10-16 04:26:37', '2024-10-16 04:26:37');
INSERT INTO `attendances` VALUES ('2865', '21', '453', '17', '1', '2024-10-16', '', '12', '2024-10-16 04:26:37', '2024-10-16 04:26:37');
INSERT INTO `attendances` VALUES ('2866', '21', '455', '17', '1', '2024-10-16', '', '12', '2024-10-16 04:26:37', '2024-10-16 04:26:37');
INSERT INTO `attendances` VALUES ('2867', '21', '457', '17', '1', '2024-10-16', '', '12', '2024-10-16 04:26:37', '2024-10-16 04:26:37');
INSERT INTO `attendances` VALUES ('2868', '21', '459', '17', '1', '2024-10-16', '', '12', '2024-10-16 04:26:37', '2024-10-16 04:26:37');
INSERT INTO `attendances` VALUES ('2869', '21', '461', '17', '1', '2024-10-16', '', '12', '2024-10-16 04:26:37', '2024-10-16 04:26:37');
INSERT INTO `attendances` VALUES ('2870', '21', '463', '17', '1', '2024-10-16', '', '12', '2024-10-16 04:26:37', '2024-10-16 04:26:37');
INSERT INTO `attendances` VALUES ('2871', '21', '465', '17', '1', '2024-10-16', '', '12', '2024-10-16 04:26:37', '2024-10-16 04:26:37');
INSERT INTO `attendances` VALUES ('2872', '21', '467', '17', '0', '2024-10-16', '', '12', '2024-10-16 04:26:37', '2024-10-16 04:26:58');
INSERT INTO `attendances` VALUES ('2873', '26', '337', '17', '0', '2024-10-16', '', '12', '2024-10-16 09:02:03', '2024-10-16 14:54:19');
INSERT INTO `attendances` VALUES ('2874', '26', '744', '17', '1', '2024-10-16', '', '12', '2024-10-16 09:02:03', '2024-10-16 09:02:03');
INSERT INTO `attendances` VALUES ('2875', '26', '746', '17', '1', '2024-10-16', '', '12', '2024-10-16 09:02:03', '2024-10-16 09:02:03');
INSERT INTO `attendances` VALUES ('2876', '26', '748', '17', '1', '2024-10-16', '', '12', '2024-10-16 09:02:03', '2024-10-16 09:02:03');
INSERT INTO `attendances` VALUES ('2877', '26', '750', '17', '0', '2024-10-16', '', '12', '2024-10-16 09:02:03', '2024-10-16 09:02:03');
INSERT INTO `attendances` VALUES ('2878', '26', '752', '17', '1', '2024-10-16', '', '12', '2024-10-16 09:02:03', '2024-10-16 09:02:03');
INSERT INTO `attendances` VALUES ('2879', '26', '754', '17', '1', '2024-10-16', '', '12', '2024-10-16 09:02:03', '2024-10-16 09:02:03');
INSERT INTO `attendances` VALUES ('2880', '26', '756', '17', '1', '2024-10-16', '', '12', '2024-10-16 09:02:03', '2024-10-16 09:02:03');
INSERT INTO `attendances` VALUES ('2881', '26', '758', '17', '1', '2024-10-16', '', '12', '2024-10-16 09:02:03', '2024-10-16 09:02:03');
INSERT INTO `attendances` VALUES ('2882', '26', '760', '17', '1', '2024-10-16', '', '12', '2024-10-16 09:02:03', '2024-10-16 09:02:03');
INSERT INTO `attendances` VALUES ('2883', '26', '762', '17', '1', '2024-10-16', '', '12', '2024-10-16 09:02:03', '2024-10-16 09:02:03');
INSERT INTO `attendances` VALUES ('2884', '26', '764', '17', '1', '2024-10-16', '', '12', '2024-10-16 09:02:03', '2024-10-16 09:02:03');
INSERT INTO `attendances` VALUES ('2885', '26', '766', '17', '1', '2024-10-16', '', '12', '2024-10-16 09:02:03', '2024-10-16 09:02:03');
INSERT INTO `attendances` VALUES ('2886', '26', '768', '17', '1', '2024-10-16', '', '12', '2024-10-16 09:02:03', '2024-10-16 09:02:03');
INSERT INTO `attendances` VALUES ('2887', '26', '770', '17', '1', '2024-10-16', '', '12', '2024-10-16 09:02:03', '2024-10-16 09:02:03');
INSERT INTO `attendances` VALUES ('2888', '26', '772', '17', '1', '2024-10-16', '', '12', '2024-10-16 09:02:03', '2024-10-16 09:02:03');
INSERT INTO `attendances` VALUES ('2889', '26', '774', '17', '1', '2024-10-16', '', '12', '2024-10-16 09:02:03', '2024-10-16 09:02:03');
INSERT INTO `attendances` VALUES ('2890', '26', '776', '17', '1', '2024-10-16', '', '12', '2024-10-16 09:02:03', '2024-10-16 09:02:03');
INSERT INTO `attendances` VALUES ('2891', '26', '778', '17', '1', '2024-10-16', '', '12', '2024-10-16 09:02:03', '2024-10-16 09:02:03');
INSERT INTO `attendances` VALUES ('2892', '26', '780', '17', '1', '2024-10-16', '', '12', '2024-10-16 09:02:03', '2024-10-16 09:02:03');
INSERT INTO `attendances` VALUES ('2893', '26', '782', '17', '1', '2024-10-16', '', '12', '2024-10-16 09:02:03', '2024-10-16 09:02:03');
INSERT INTO `attendances` VALUES ('2894', '26', '784', '17', '1', '2024-10-16', '', '12', '2024-10-16 09:02:03', '2024-10-16 09:02:03');
INSERT INTO `attendances` VALUES ('2895', '26', '786', '17', '1', '2024-10-16', '', '12', '2024-10-16 09:02:03', '2024-10-16 09:02:03');
INSERT INTO `attendances` VALUES ('2896', '26', '788', '17', '1', '2024-10-16', '', '12', '2024-10-16 09:02:03', '2024-10-16 09:02:03');
INSERT INTO `attendances` VALUES ('2897', '26', '790', '17', '1', '2024-10-16', '', '12', '2024-10-16 09:02:03', '2024-10-16 09:02:03');
INSERT INTO `attendances` VALUES ('2898', '26', '792', '17', '1', '2024-10-16', '', '12', '2024-10-16 09:02:03', '2024-10-16 09:02:03');
INSERT INTO `attendances` VALUES ('2899', '26', '794', '17', '1', '2024-10-16', '', '12', '2024-10-16 09:02:03', '2024-10-16 09:02:03');
INSERT INTO `attendances` VALUES ('2900', '26', '796', '17', '1', '2024-10-16', '', '12', '2024-10-16 09:02:03', '2024-10-16 09:02:03');
INSERT INTO `attendances` VALUES ('2901', '26', '798', '17', '1', '2024-10-16', '', '12', '2024-10-16 09:02:03', '2024-10-16 09:02:03');
INSERT INTO `attendances` VALUES ('2902', '26', '800', '17', '1', '2024-10-16', '', '12', '2024-10-16 09:02:03', '2024-10-16 09:02:03');
INSERT INTO `attendances` VALUES ('2903', '26', '802', '17', '1', '2024-10-16', '', '12', '2024-10-16 09:02:03', '2024-10-16 09:02:03');
INSERT INTO `attendances` VALUES ('2904', '26', '337', '17', '1', '2024-10-17', '', '12', '2024-10-17 00:33:09', '2024-10-17 00:33:09');
INSERT INTO `attendances` VALUES ('2905', '26', '744', '17', '1', '2024-10-17', '', '12', '2024-10-17 00:33:09', '2024-10-17 00:33:09');
INSERT INTO `attendances` VALUES ('2906', '26', '746', '17', '1', '2024-10-17', '', '12', '2024-10-17 00:33:09', '2024-10-17 00:33:09');
INSERT INTO `attendances` VALUES ('2907', '26', '748', '17', '1', '2024-10-17', '', '12', '2024-10-17 00:33:09', '2024-10-17 00:33:09');
INSERT INTO `attendances` VALUES ('2908', '26', '750', '17', '1', '2024-10-17', '', '12', '2024-10-17 00:33:09', '2024-10-17 00:33:09');
INSERT INTO `attendances` VALUES ('2909', '26', '752', '17', '1', '2024-10-17', '', '12', '2024-10-17 00:33:09', '2024-10-17 00:33:09');
INSERT INTO `attendances` VALUES ('2910', '26', '754', '17', '1', '2024-10-17', '', '12', '2024-10-17 00:33:09', '2024-10-17 00:33:09');
INSERT INTO `attendances` VALUES ('2911', '26', '756', '17', '1', '2024-10-17', '', '12', '2024-10-17 00:33:09', '2024-10-17 00:33:09');
INSERT INTO `attendances` VALUES ('2912', '26', '758', '17', '1', '2024-10-17', '', '12', '2024-10-17 00:33:09', '2024-10-17 00:33:09');
INSERT INTO `attendances` VALUES ('2913', '26', '760', '17', '1', '2024-10-17', '', '12', '2024-10-17 00:33:09', '2024-10-17 00:33:09');
INSERT INTO `attendances` VALUES ('2914', '26', '762', '17', '1', '2024-10-17', '', '12', '2024-10-17 00:33:09', '2024-10-17 00:33:09');
INSERT INTO `attendances` VALUES ('2915', '26', '764', '17', '1', '2024-10-17', '', '12', '2024-10-17 00:33:09', '2024-10-17 00:33:09');
INSERT INTO `attendances` VALUES ('2916', '26', '766', '17', '1', '2024-10-17', '', '12', '2024-10-17 00:33:09', '2024-10-17 00:33:09');
INSERT INTO `attendances` VALUES ('2917', '26', '768', '17', '1', '2024-10-17', '', '12', '2024-10-17 00:33:09', '2024-10-17 00:33:09');
INSERT INTO `attendances` VALUES ('2918', '26', '770', '17', '1', '2024-10-17', '', '12', '2024-10-17 00:33:09', '2024-10-17 00:33:09');
INSERT INTO `attendances` VALUES ('2919', '26', '772', '17', '1', '2024-10-17', '', '12', '2024-10-17 00:33:09', '2024-10-17 00:33:09');
INSERT INTO `attendances` VALUES ('2920', '26', '774', '17', '1', '2024-10-17', '', '12', '2024-10-17 00:33:09', '2024-10-17 00:33:09');
INSERT INTO `attendances` VALUES ('2921', '26', '776', '17', '1', '2024-10-17', '', '12', '2024-10-17 00:33:09', '2024-10-17 00:33:09');
INSERT INTO `attendances` VALUES ('2922', '26', '778', '17', '1', '2024-10-17', '', '12', '2024-10-17 00:33:09', '2024-10-17 00:33:09');
INSERT INTO `attendances` VALUES ('2923', '26', '780', '17', '1', '2024-10-17', '', '12', '2024-10-17 00:33:09', '2024-10-17 00:33:09');
INSERT INTO `attendances` VALUES ('2924', '26', '782', '17', '1', '2024-10-17', '', '12', '2024-10-17 00:33:09', '2024-10-17 00:33:09');
INSERT INTO `attendances` VALUES ('2925', '26', '784', '17', '1', '2024-10-17', '', '12', '2024-10-17 00:33:09', '2024-10-17 00:33:09');
INSERT INTO `attendances` VALUES ('2926', '26', '786', '17', '1', '2024-10-17', '', '12', '2024-10-17 00:33:09', '2024-10-17 00:33:09');
INSERT INTO `attendances` VALUES ('2927', '26', '788', '17', '1', '2024-10-17', '', '12', '2024-10-17 00:33:09', '2024-10-17 00:33:09');
INSERT INTO `attendances` VALUES ('2928', '26', '790', '17', '1', '2024-10-17', '', '12', '2024-10-17 00:33:09', '2024-10-17 00:33:09');
INSERT INTO `attendances` VALUES ('2929', '26', '792', '17', '1', '2024-10-17', '', '12', '2024-10-17 00:33:09', '2024-10-17 00:33:09');
INSERT INTO `attendances` VALUES ('2930', '26', '794', '17', '1', '2024-10-17', '', '12', '2024-10-17 00:33:09', '2024-10-17 00:33:09');
INSERT INTO `attendances` VALUES ('2931', '26', '796', '17', '1', '2024-10-17', '', '12', '2024-10-17 00:33:09', '2024-10-17 00:33:09');
INSERT INTO `attendances` VALUES ('2932', '26', '798', '17', '1', '2024-10-17', '', '12', '2024-10-17 00:33:09', '2024-10-17 00:33:09');
INSERT INTO `attendances` VALUES ('2933', '26', '800', '17', '1', '2024-10-17', '', '12', '2024-10-17 00:33:09', '2024-10-17 00:33:09');
INSERT INTO `attendances` VALUES ('2934', '26', '802', '17', '1', '2024-10-17', '', '12', '2024-10-17 00:33:09', '2024-10-17 00:33:09');
INSERT INTO `attendances` VALUES ('2935', '26', '337', '17', '0', '2024-10-18', '', '12', '2024-10-18 20:51:05', '2024-10-18 20:51:05');
INSERT INTO `attendances` VALUES ('2936', '26', '744', '17', '1', '2024-10-18', '', '12', '2024-10-18 20:51:05', '2024-10-18 20:51:05');
INSERT INTO `attendances` VALUES ('2937', '26', '746', '17', '1', '2024-10-18', '', '12', '2024-10-18 20:51:05', '2024-10-18 20:51:05');
INSERT INTO `attendances` VALUES ('2938', '26', '748', '17', '1', '2024-10-18', '', '12', '2024-10-18 20:51:05', '2024-10-18 20:51:05');
INSERT INTO `attendances` VALUES ('2939', '26', '750', '17', '1', '2024-10-18', '', '12', '2024-10-18 20:51:05', '2024-10-18 20:51:05');
INSERT INTO `attendances` VALUES ('2940', '26', '752', '17', '1', '2024-10-18', '', '12', '2024-10-18 20:51:05', '2024-10-18 20:51:05');
INSERT INTO `attendances` VALUES ('2941', '26', '754', '17', '1', '2024-10-18', '', '12', '2024-10-18 20:51:05', '2024-10-18 20:51:05');
INSERT INTO `attendances` VALUES ('2942', '26', '756', '17', '1', '2024-10-18', '', '12', '2024-10-18 20:51:05', '2024-10-18 20:51:05');
INSERT INTO `attendances` VALUES ('2943', '26', '758', '17', '1', '2024-10-18', '', '12', '2024-10-18 20:51:05', '2024-10-18 20:51:05');
INSERT INTO `attendances` VALUES ('2944', '26', '760', '17', '1', '2024-10-18', '', '12', '2024-10-18 20:51:05', '2024-10-18 20:51:05');
INSERT INTO `attendances` VALUES ('2945', '26', '762', '17', '1', '2024-10-18', '', '12', '2024-10-18 20:51:05', '2024-10-18 20:51:05');
INSERT INTO `attendances` VALUES ('2946', '26', '764', '17', '1', '2024-10-18', '', '12', '2024-10-18 20:51:05', '2024-10-18 20:51:05');
INSERT INTO `attendances` VALUES ('2947', '26', '766', '17', '1', '2024-10-18', '', '12', '2024-10-18 20:51:05', '2024-10-18 20:51:05');
INSERT INTO `attendances` VALUES ('2948', '26', '768', '17', '1', '2024-10-18', '', '12', '2024-10-18 20:51:05', '2024-10-18 20:51:05');
INSERT INTO `attendances` VALUES ('2949', '26', '770', '17', '1', '2024-10-18', '', '12', '2024-10-18 20:51:05', '2024-10-18 20:51:05');
INSERT INTO `attendances` VALUES ('2950', '26', '772', '17', '1', '2024-10-18', '', '12', '2024-10-18 20:51:05', '2024-10-18 20:51:05');
INSERT INTO `attendances` VALUES ('2951', '26', '774', '17', '1', '2024-10-18', '', '12', '2024-10-18 20:51:05', '2024-10-18 20:51:05');
INSERT INTO `attendances` VALUES ('2952', '26', '776', '17', '1', '2024-10-18', '', '12', '2024-10-18 20:51:05', '2024-10-18 20:51:05');
INSERT INTO `attendances` VALUES ('2953', '26', '778', '17', '1', '2024-10-18', '', '12', '2024-10-18 20:51:05', '2024-10-18 20:51:05');
INSERT INTO `attendances` VALUES ('2954', '26', '780', '17', '1', '2024-10-18', '', '12', '2024-10-18 20:51:05', '2024-10-18 20:51:05');
INSERT INTO `attendances` VALUES ('2955', '26', '782', '17', '1', '2024-10-18', '', '12', '2024-10-18 20:51:05', '2024-10-18 20:51:05');
INSERT INTO `attendances` VALUES ('2956', '26', '784', '17', '1', '2024-10-18', '', '12', '2024-10-18 20:51:05', '2024-10-18 20:51:05');
INSERT INTO `attendances` VALUES ('2957', '26', '786', '17', '1', '2024-10-18', '', '12', '2024-10-18 20:51:05', '2024-10-18 20:51:05');
INSERT INTO `attendances` VALUES ('2958', '26', '788', '17', '1', '2024-10-18', '', '12', '2024-10-18 20:51:05', '2024-10-18 20:51:05');
INSERT INTO `attendances` VALUES ('2959', '26', '790', '17', '1', '2024-10-18', '', '12', '2024-10-18 20:51:05', '2024-10-18 20:51:05');
INSERT INTO `attendances` VALUES ('2960', '26', '792', '17', '1', '2024-10-18', '', '12', '2024-10-18 20:51:05', '2024-10-18 20:51:05');
INSERT INTO `attendances` VALUES ('2961', '26', '794', '17', '1', '2024-10-18', '', '12', '2024-10-18 20:51:05', '2024-10-18 20:51:05');
INSERT INTO `attendances` VALUES ('2962', '26', '796', '17', '1', '2024-10-18', '', '12', '2024-10-18 20:51:05', '2024-10-18 20:51:05');
INSERT INTO `attendances` VALUES ('2963', '26', '798', '17', '1', '2024-10-18', '', '12', '2024-10-18 20:51:05', '2024-10-18 20:51:05');
INSERT INTO `attendances` VALUES ('2964', '26', '800', '17', '1', '2024-10-18', '', '12', '2024-10-18 20:51:05', '2024-10-18 20:51:05');
INSERT INTO `attendances` VALUES ('2965', '26', '802', '17', '1', '2024-10-18', '', '12', '2024-10-18 20:51:05', '2024-10-18 20:51:05');
INSERT INTO `attendances` VALUES ('2966', '26', '337', '17', '1', '2024-10-23', '', '12', '2024-10-23 14:04:55', '2024-10-23 14:04:55');
INSERT INTO `attendances` VALUES ('2967', '26', '744', '17', '1', '2024-10-23', '', '12', '2024-10-23 14:04:56', '2024-10-23 14:04:56');
INSERT INTO `attendances` VALUES ('2968', '26', '746', '17', '1', '2024-10-23', '', '12', '2024-10-23 14:04:56', '2024-10-23 14:04:56');
INSERT INTO `attendances` VALUES ('2969', '26', '748', '17', '1', '2024-10-23', '', '12', '2024-10-23 14:04:56', '2024-10-23 14:04:56');
INSERT INTO `attendances` VALUES ('2970', '26', '750', '17', '1', '2024-10-23', '', '12', '2024-10-23 14:04:56', '2024-10-23 14:04:56');
INSERT INTO `attendances` VALUES ('2971', '26', '752', '17', '1', '2024-10-23', '', '12', '2024-10-23 14:04:56', '2024-10-23 14:04:56');
INSERT INTO `attendances` VALUES ('2972', '26', '754', '17', '1', '2024-10-23', '', '12', '2024-10-23 14:04:56', '2024-10-23 14:04:56');
INSERT INTO `attendances` VALUES ('2973', '26', '756', '17', '1', '2024-10-23', '', '12', '2024-10-23 14:04:56', '2024-10-23 14:04:56');
INSERT INTO `attendances` VALUES ('2974', '26', '758', '17', '1', '2024-10-23', '', '12', '2024-10-23 14:04:56', '2024-10-23 14:04:56');
INSERT INTO `attendances` VALUES ('2975', '26', '760', '17', '1', '2024-10-23', '', '12', '2024-10-23 14:04:56', '2024-10-23 14:04:56');
INSERT INTO `attendances` VALUES ('2976', '26', '762', '17', '1', '2024-10-23', '', '12', '2024-10-23 14:04:56', '2024-10-23 14:04:56');
INSERT INTO `attendances` VALUES ('2977', '26', '764', '17', '1', '2024-10-23', '', '12', '2024-10-23 14:04:56', '2024-10-23 14:04:56');
INSERT INTO `attendances` VALUES ('2978', '26', '766', '17', '1', '2024-10-23', '', '12', '2024-10-23 14:04:56', '2024-10-23 14:04:56');
INSERT INTO `attendances` VALUES ('2979', '26', '768', '17', '0', '2024-10-23', '', '12', '2024-10-23 14:04:56', '2024-10-23 14:04:56');
INSERT INTO `attendances` VALUES ('2980', '26', '770', '17', '1', '2024-10-23', '', '12', '2024-10-23 14:04:56', '2024-10-23 14:04:56');
INSERT INTO `attendances` VALUES ('2981', '26', '772', '17', '1', '2024-10-23', '', '12', '2024-10-23 14:04:56', '2024-10-23 14:04:56');
INSERT INTO `attendances` VALUES ('2982', '26', '774', '17', '1', '2024-10-23', '', '12', '2024-10-23 14:04:56', '2024-10-23 14:04:56');
INSERT INTO `attendances` VALUES ('2983', '26', '776', '17', '1', '2024-10-23', '', '12', '2024-10-23 14:04:56', '2024-10-23 14:04:56');
INSERT INTO `attendances` VALUES ('2984', '26', '778', '17', '1', '2024-10-23', '', '12', '2024-10-23 14:04:56', '2024-10-23 14:04:56');
INSERT INTO `attendances` VALUES ('2985', '26', '780', '17', '1', '2024-10-23', '', '12', '2024-10-23 14:04:56', '2024-10-23 14:04:56');
INSERT INTO `attendances` VALUES ('2986', '26', '782', '17', '1', '2024-10-23', '', '12', '2024-10-23 14:04:56', '2024-10-23 14:04:56');
INSERT INTO `attendances` VALUES ('2987', '26', '784', '17', '1', '2024-10-23', '', '12', '2024-10-23 14:04:56', '2024-10-23 14:04:56');
INSERT INTO `attendances` VALUES ('2988', '26', '786', '17', '1', '2024-10-23', '', '12', '2024-10-23 14:04:56', '2024-10-23 14:04:56');
INSERT INTO `attendances` VALUES ('2989', '26', '788', '17', '1', '2024-10-23', '', '12', '2024-10-23 14:04:56', '2024-10-23 14:04:56');
INSERT INTO `attendances` VALUES ('2990', '26', '790', '17', '1', '2024-10-23', '', '12', '2024-10-23 14:04:56', '2024-10-23 14:04:56');
INSERT INTO `attendances` VALUES ('2991', '26', '792', '17', '1', '2024-10-23', '', '12', '2024-10-23 14:04:56', '2024-10-23 14:04:56');
INSERT INTO `attendances` VALUES ('2992', '26', '794', '17', '1', '2024-10-23', '', '12', '2024-10-23 14:04:56', '2024-10-23 14:04:56');
INSERT INTO `attendances` VALUES ('2993', '26', '796', '17', '1', '2024-10-23', '', '12', '2024-10-23 14:04:56', '2024-10-23 14:04:56');
INSERT INTO `attendances` VALUES ('2994', '26', '798', '17', '1', '2024-10-23', '', '12', '2024-10-23 14:04:56', '2024-10-23 14:04:56');
INSERT INTO `attendances` VALUES ('2995', '26', '800', '17', '1', '2024-10-23', '', '12', '2024-10-23 14:04:56', '2024-10-23 14:04:56');
INSERT INTO `attendances` VALUES ('2996', '26', '802', '17', '1', '2024-10-23', '', '12', '2024-10-23 14:04:56', '2024-10-23 14:04:56');
INSERT INTO `attendances` VALUES ('2997', '26', '337', '17', '0', '2024-10-26', '', '12', '2024-10-26 20:05:24', '2024-10-26 21:03:40');
INSERT INTO `attendances` VALUES ('2998', '26', '744', '17', '0', '2024-10-26', '', '12', '2024-10-26 20:05:24', '2024-10-26 20:05:24');
INSERT INTO `attendances` VALUES ('2999', '26', '746', '17', '0', '2024-10-26', '', '12', '2024-10-26 20:05:24', '2024-10-26 21:03:40');
INSERT INTO `attendances` VALUES ('3000', '26', '748', '17', '1', '2024-10-26', '', '12', '2024-10-26 20:05:24', '2024-10-26 20:05:24');
INSERT INTO `attendances` VALUES ('3001', '26', '750', '17', '1', '2024-10-26', '', '12', '2024-10-26 20:05:24', '2024-10-26 20:05:24');
INSERT INTO `attendances` VALUES ('3002', '26', '752', '17', '1', '2024-10-26', '', '12', '2024-10-26 20:05:24', '2024-10-26 20:05:24');
INSERT INTO `attendances` VALUES ('3003', '26', '754', '17', '1', '2024-10-26', '', '12', '2024-10-26 20:05:24', '2024-10-26 20:05:24');
INSERT INTO `attendances` VALUES ('3004', '26', '756', '17', '1', '2024-10-26', '', '12', '2024-10-26 20:05:24', '2024-10-26 20:05:24');
INSERT INTO `attendances` VALUES ('3005', '26', '758', '17', '1', '2024-10-26', '', '12', '2024-10-26 20:05:24', '2024-10-26 20:05:24');
INSERT INTO `attendances` VALUES ('3006', '26', '760', '17', '1', '2024-10-26', '', '12', '2024-10-26 20:05:24', '2024-10-26 20:05:24');
INSERT INTO `attendances` VALUES ('3007', '26', '762', '17', '1', '2024-10-26', '', '12', '2024-10-26 20:05:24', '2024-10-26 20:05:24');
INSERT INTO `attendances` VALUES ('3008', '26', '764', '17', '1', '2024-10-26', '', '12', '2024-10-26 20:05:24', '2024-10-26 20:05:24');
INSERT INTO `attendances` VALUES ('3009', '26', '766', '17', '1', '2024-10-26', '', '12', '2024-10-26 20:05:24', '2024-10-26 20:05:24');
INSERT INTO `attendances` VALUES ('3010', '26', '768', '17', '1', '2024-10-26', '', '12', '2024-10-26 20:05:24', '2024-10-26 20:05:24');
INSERT INTO `attendances` VALUES ('3011', '26', '770', '17', '1', '2024-10-26', '', '12', '2024-10-26 20:05:24', '2024-10-26 20:05:24');
INSERT INTO `attendances` VALUES ('3012', '26', '772', '17', '1', '2024-10-26', '', '12', '2024-10-26 20:05:24', '2024-10-26 20:05:24');
INSERT INTO `attendances` VALUES ('3013', '26', '774', '17', '1', '2024-10-26', '', '12', '2024-10-26 20:05:24', '2024-10-26 20:05:24');
INSERT INTO `attendances` VALUES ('3014', '26', '776', '17', '1', '2024-10-26', '', '12', '2024-10-26 20:05:24', '2024-10-26 20:05:24');
INSERT INTO `attendances` VALUES ('3015', '26', '778', '17', '1', '2024-10-26', '', '12', '2024-10-26 20:05:24', '2024-10-26 20:05:24');
INSERT INTO `attendances` VALUES ('3016', '26', '780', '17', '1', '2024-10-26', '', '12', '2024-10-26 20:05:24', '2024-10-26 20:05:24');
INSERT INTO `attendances` VALUES ('3017', '26', '782', '17', '1', '2024-10-26', '', '12', '2024-10-26 20:05:24', '2024-10-26 20:05:24');
INSERT INTO `attendances` VALUES ('3018', '26', '784', '17', '1', '2024-10-26', '', '12', '2024-10-26 20:05:24', '2024-10-26 20:05:24');
INSERT INTO `attendances` VALUES ('3019', '26', '786', '17', '1', '2024-10-26', '', '12', '2024-10-26 20:05:24', '2024-10-26 20:05:24');
INSERT INTO `attendances` VALUES ('3020', '26', '788', '17', '1', '2024-10-26', '', '12', '2024-10-26 20:05:24', '2024-10-26 20:05:24');
INSERT INTO `attendances` VALUES ('3021', '26', '790', '17', '1', '2024-10-26', '', '12', '2024-10-26 20:05:24', '2024-10-26 20:05:24');
INSERT INTO `attendances` VALUES ('3022', '26', '792', '17', '1', '2024-10-26', '', '12', '2024-10-26 20:05:24', '2024-10-26 20:05:24');
INSERT INTO `attendances` VALUES ('3023', '26', '794', '17', '1', '2024-10-26', '', '12', '2024-10-26 20:05:24', '2024-10-26 20:05:24');
INSERT INTO `attendances` VALUES ('3024', '26', '796', '17', '0', '2024-10-26', '', '12', '2024-10-26 20:05:24', '2024-10-26 20:05:24');
INSERT INTO `attendances` VALUES ('3025', '26', '798', '17', '1', '2024-10-26', '', '12', '2024-10-26 20:05:24', '2024-10-26 20:05:24');
INSERT INTO `attendances` VALUES ('3026', '26', '800', '17', '1', '2024-10-26', '', '12', '2024-10-26 20:05:24', '2024-10-26 20:05:24');
INSERT INTO `attendances` VALUES ('3027', '26', '802', '17', '1', '2024-10-26', '', '12', '2024-10-26 20:05:24', '2024-10-26 20:05:24');
INSERT INTO `attendances` VALUES ('3028', '26', '337', '17', '1', '2024-11-02', '', '12', '2024-11-02 07:48:38', '2024-11-02 07:48:38');
INSERT INTO `attendances` VALUES ('3029', '26', '744', '17', '1', '2024-11-02', '', '12', '2024-11-02 07:48:39', '2024-11-02 07:48:39');
INSERT INTO `attendances` VALUES ('3030', '26', '746', '17', '1', '2024-11-02', '', '12', '2024-11-02 07:48:39', '2024-11-02 07:48:39');
INSERT INTO `attendances` VALUES ('3031', '26', '748', '17', '1', '2024-11-02', '', '12', '2024-11-02 07:48:39', '2024-11-02 07:48:39');
INSERT INTO `attendances` VALUES ('3032', '26', '750', '17', '1', '2024-11-02', '', '12', '2024-11-02 07:48:39', '2024-11-02 07:48:39');
INSERT INTO `attendances` VALUES ('3033', '26', '752', '17', '1', '2024-11-02', '', '12', '2024-11-02 07:48:39', '2024-11-02 07:48:39');
INSERT INTO `attendances` VALUES ('3034', '26', '754', '17', '1', '2024-11-02', '', '12', '2024-11-02 07:48:39', '2024-11-02 07:48:39');
INSERT INTO `attendances` VALUES ('3035', '26', '756', '17', '1', '2024-11-02', '', '12', '2024-11-02 07:48:39', '2024-11-02 07:48:39');
INSERT INTO `attendances` VALUES ('3036', '26', '758', '17', '1', '2024-11-02', '', '12', '2024-11-02 07:48:39', '2024-11-02 07:48:39');
INSERT INTO `attendances` VALUES ('3037', '26', '760', '17', '1', '2024-11-02', '', '12', '2024-11-02 07:48:39', '2024-11-02 07:48:39');
INSERT INTO `attendances` VALUES ('3038', '26', '762', '17', '1', '2024-11-02', '', '12', '2024-11-02 07:48:39', '2024-11-02 07:48:39');
INSERT INTO `attendances` VALUES ('3039', '26', '764', '17', '1', '2024-11-02', '', '12', '2024-11-02 07:48:39', '2024-11-02 07:48:39');
INSERT INTO `attendances` VALUES ('3040', '26', '766', '17', '1', '2024-11-02', '', '12', '2024-11-02 07:48:39', '2024-11-02 07:48:39');
INSERT INTO `attendances` VALUES ('3041', '26', '768', '17', '1', '2024-11-02', '', '12', '2024-11-02 07:48:39', '2024-11-02 07:48:39');
INSERT INTO `attendances` VALUES ('3042', '26', '770', '17', '1', '2024-11-02', '', '12', '2024-11-02 07:48:39', '2024-11-02 07:48:39');
INSERT INTO `attendances` VALUES ('3043', '26', '772', '17', '1', '2024-11-02', '', '12', '2024-11-02 07:48:39', '2024-11-02 07:48:39');
INSERT INTO `attendances` VALUES ('3044', '26', '774', '17', '1', '2024-11-02', '', '12', '2024-11-02 07:48:39', '2024-11-02 07:48:39');
INSERT INTO `attendances` VALUES ('3045', '26', '776', '17', '1', '2024-11-02', '', '12', '2024-11-02 07:48:39', '2024-11-02 07:48:39');
INSERT INTO `attendances` VALUES ('3046', '26', '778', '17', '1', '2024-11-02', '', '12', '2024-11-02 07:48:39', '2024-11-02 07:48:39');
INSERT INTO `attendances` VALUES ('3047', '26', '780', '17', '1', '2024-11-02', '', '12', '2024-11-02 07:48:39', '2024-11-02 07:48:39');
INSERT INTO `attendances` VALUES ('3048', '26', '782', '17', '1', '2024-11-02', '', '12', '2024-11-02 07:48:39', '2024-11-02 07:48:39');
INSERT INTO `attendances` VALUES ('3049', '26', '784', '17', '1', '2024-11-02', '', '12', '2024-11-02 07:48:39', '2024-11-02 07:48:39');
INSERT INTO `attendances` VALUES ('3050', '26', '786', '17', '1', '2024-11-02', '', '12', '2024-11-02 07:48:39', '2024-11-02 07:48:39');
INSERT INTO `attendances` VALUES ('3051', '26', '788', '17', '1', '2024-11-02', '', '12', '2024-11-02 07:48:39', '2024-11-02 07:48:39');
INSERT INTO `attendances` VALUES ('3052', '26', '790', '17', '1', '2024-11-02', '', '12', '2024-11-02 07:48:39', '2024-11-02 07:48:39');
INSERT INTO `attendances` VALUES ('3053', '26', '792', '17', '1', '2024-11-02', '', '12', '2024-11-02 07:48:39', '2024-11-02 07:48:39');
INSERT INTO `attendances` VALUES ('3054', '26', '794', '17', '1', '2024-11-02', '', '12', '2024-11-02 07:48:39', '2024-11-02 07:48:39');
INSERT INTO `attendances` VALUES ('3055', '26', '796', '17', '1', '2024-11-02', '', '12', '2024-11-02 07:48:39', '2024-11-02 07:48:39');
INSERT INTO `attendances` VALUES ('3056', '26', '798', '17', '1', '2024-11-02', '', '12', '2024-11-02 07:48:39', '2024-11-02 07:48:39');
INSERT INTO `attendances` VALUES ('3057', '26', '800', '17', '1', '2024-11-02', '', '12', '2024-11-02 07:48:39', '2024-11-02 07:48:39');
INSERT INTO `attendances` VALUES ('3058', '26', '802', '17', '1', '2024-11-02', '', '12', '2024-11-02 07:48:39', '2024-11-02 07:48:39');
INSERT INTO `attendances` VALUES ('3059', '26', '337', '17', '0', '2024-11-14', '', '12', '2024-11-14 08:47:58', '2024-11-14 12:53:54');
INSERT INTO `attendances` VALUES ('3060', '26', '744', '17', '1', '2024-11-14', '', '12', '2024-11-14 08:47:58', '2024-11-14 12:53:54');
INSERT INTO `attendances` VALUES ('3061', '26', '746', '17', '0', '2024-11-14', '', '12', '2024-11-14 08:47:58', '2024-11-14 08:47:58');
INSERT INTO `attendances` VALUES ('3062', '26', '748', '17', '1', '2024-11-14', '', '12', '2024-11-14 08:47:58', '2024-11-14 08:47:58');
INSERT INTO `attendances` VALUES ('3063', '26', '750', '17', '0', '2024-11-14', '', '12', '2024-11-14 08:47:58', '2024-11-14 08:47:58');
INSERT INTO `attendances` VALUES ('3064', '26', '752', '17', '1', '2024-11-14', '', '12', '2024-11-14 08:47:58', '2024-11-14 08:47:58');
INSERT INTO `attendances` VALUES ('3065', '26', '754', '17', '0', '2024-11-14', '', '12', '2024-11-14 08:47:58', '2024-11-14 08:47:58');
INSERT INTO `attendances` VALUES ('3066', '26', '756', '17', '1', '2024-11-14', '', '12', '2024-11-14 08:47:58', '2024-11-14 08:47:58');
INSERT INTO `attendances` VALUES ('3067', '26', '758', '17', '1', '2024-11-14', '', '12', '2024-11-14 08:47:58', '2024-11-14 08:47:58');
INSERT INTO `attendances` VALUES ('3068', '26', '760', '17', '1', '2024-11-14', '', '12', '2024-11-14 08:47:58', '2024-11-14 08:47:58');
INSERT INTO `attendances` VALUES ('3069', '26', '762', '17', '1', '2024-11-14', '', '12', '2024-11-14 08:47:58', '2024-11-14 08:47:58');
INSERT INTO `attendances` VALUES ('3070', '26', '764', '17', '1', '2024-11-14', '', '12', '2024-11-14 08:47:58', '2024-11-14 08:47:58');
INSERT INTO `attendances` VALUES ('3071', '26', '766', '17', '1', '2024-11-14', '', '12', '2024-11-14 08:47:58', '2024-11-14 08:47:58');
INSERT INTO `attendances` VALUES ('3072', '26', '768', '17', '1', '2024-11-14', '', '12', '2024-11-14 08:47:58', '2024-11-14 08:47:58');
INSERT INTO `attendances` VALUES ('3073', '26', '770', '17', '1', '2024-11-14', '', '12', '2024-11-14 08:47:58', '2024-11-14 08:47:58');
INSERT INTO `attendances` VALUES ('3074', '26', '772', '17', '1', '2024-11-14', '', '12', '2024-11-14 08:47:58', '2024-11-14 08:47:58');
INSERT INTO `attendances` VALUES ('3075', '26', '774', '17', '1', '2024-11-14', '', '12', '2024-11-14 08:47:58', '2024-11-14 08:47:58');
INSERT INTO `attendances` VALUES ('3076', '26', '776', '17', '1', '2024-11-14', '', '12', '2024-11-14 08:47:58', '2024-11-14 08:47:58');
INSERT INTO `attendances` VALUES ('3077', '26', '778', '17', '1', '2024-11-14', '', '12', '2024-11-14 08:47:58', '2024-11-14 08:47:58');
INSERT INTO `attendances` VALUES ('3078', '26', '780', '17', '0', '2024-11-14', '', '12', '2024-11-14 08:47:58', '2024-11-14 08:47:58');
INSERT INTO `attendances` VALUES ('3079', '26', '782', '17', '1', '2024-11-14', '', '12', '2024-11-14 08:47:58', '2024-11-14 08:47:58');
INSERT INTO `attendances` VALUES ('3080', '26', '784', '17', '0', '2024-11-14', '', '12', '2024-11-14 08:47:58', '2024-11-14 08:47:58');
INSERT INTO `attendances` VALUES ('3081', '26', '786', '17', '1', '2024-11-14', '', '12', '2024-11-14 08:47:58', '2024-11-14 08:47:58');
INSERT INTO `attendances` VALUES ('3082', '26', '788', '17', '1', '2024-11-14', '', '12', '2024-11-14 08:47:58', '2024-11-14 08:47:58');
INSERT INTO `attendances` VALUES ('3083', '26', '790', '17', '1', '2024-11-14', '', '12', '2024-11-14 08:47:58', '2024-11-14 08:47:58');
INSERT INTO `attendances` VALUES ('3084', '26', '792', '17', '1', '2024-11-14', '', '12', '2024-11-14 08:47:58', '2024-11-14 08:47:58');
INSERT INTO `attendances` VALUES ('3085', '26', '794', '17', '1', '2024-11-14', '', '12', '2024-11-14 08:47:58', '2024-11-14 08:47:58');
INSERT INTO `attendances` VALUES ('3086', '26', '796', '17', '1', '2024-11-14', '', '12', '2024-11-14 08:47:58', '2024-11-14 08:47:58');
INSERT INTO `attendances` VALUES ('3087', '26', '798', '17', '1', '2024-11-14', '', '12', '2024-11-14 08:47:58', '2024-11-14 08:47:58');
INSERT INTO `attendances` VALUES ('3088', '26', '800', '17', '1', '2024-11-14', '', '12', '2024-11-14 08:47:58', '2024-11-14 08:47:58');
INSERT INTO `attendances` VALUES ('3089', '26', '802', '17', '1', '2024-11-14', '', '12', '2024-11-14 08:47:58', '2024-11-14 08:47:58');
INSERT INTO `attendances` VALUES ('3090', '26', '337', '17', '0', '2024-11-21', '', '12', '2024-11-21 20:52:07', '2024-11-21 20:52:26');
INSERT INTO `attendances` VALUES ('3091', '26', '744', '17', '1', '2024-11-21', '', '12', '2024-11-21 20:52:07', '2024-11-21 20:52:07');
INSERT INTO `attendances` VALUES ('3092', '26', '746', '17', '1', '2024-11-21', '', '12', '2024-11-21 20:52:07', '2024-11-21 20:52:07');
INSERT INTO `attendances` VALUES ('3093', '26', '748', '17', '1', '2024-11-21', '', '12', '2024-11-21 20:52:07', '2024-11-21 20:52:07');
INSERT INTO `attendances` VALUES ('3094', '26', '750', '17', '1', '2024-11-21', '', '12', '2024-11-21 20:52:07', '2024-11-21 20:52:07');
INSERT INTO `attendances` VALUES ('3095', '26', '752', '17', '1', '2024-11-21', '', '12', '2024-11-21 20:52:07', '2024-11-21 20:52:07');
INSERT INTO `attendances` VALUES ('3096', '26', '754', '17', '1', '2024-11-21', '', '12', '2024-11-21 20:52:07', '2024-11-21 20:52:07');
INSERT INTO `attendances` VALUES ('3097', '26', '756', '17', '1', '2024-11-21', '', '12', '2024-11-21 20:52:07', '2024-11-21 20:52:07');
INSERT INTO `attendances` VALUES ('3098', '26', '758', '17', '1', '2024-11-21', '', '12', '2024-11-21 20:52:07', '2024-11-21 20:52:07');
INSERT INTO `attendances` VALUES ('3099', '26', '760', '17', '1', '2024-11-21', '', '12', '2024-11-21 20:52:07', '2024-11-21 20:52:07');
INSERT INTO `attendances` VALUES ('3100', '26', '762', '17', '1', '2024-11-21', '', '12', '2024-11-21 20:52:07', '2024-11-21 20:52:07');
INSERT INTO `attendances` VALUES ('3101', '26', '764', '17', '1', '2024-11-21', '', '12', '2024-11-21 20:52:07', '2024-11-21 20:52:07');
INSERT INTO `attendances` VALUES ('3102', '26', '766', '17', '1', '2024-11-21', '', '12', '2024-11-21 20:52:07', '2024-11-21 20:52:07');
INSERT INTO `attendances` VALUES ('3103', '26', '768', '17', '1', '2024-11-21', '', '12', '2024-11-21 20:52:07', '2024-11-21 20:52:07');
INSERT INTO `attendances` VALUES ('3104', '26', '770', '17', '1', '2024-11-21', '', '12', '2024-11-21 20:52:07', '2024-11-21 20:52:07');
INSERT INTO `attendances` VALUES ('3105', '26', '772', '17', '1', '2024-11-21', '', '12', '2024-11-21 20:52:07', '2024-11-21 20:52:07');
INSERT INTO `attendances` VALUES ('3106', '26', '774', '17', '1', '2024-11-21', '', '12', '2024-11-21 20:52:07', '2024-11-21 20:52:07');
INSERT INTO `attendances` VALUES ('3107', '26', '776', '17', '1', '2024-11-21', '', '12', '2024-11-21 20:52:07', '2024-11-21 20:52:07');
INSERT INTO `attendances` VALUES ('3108', '26', '778', '17', '1', '2024-11-21', '', '12', '2024-11-21 20:52:07', '2024-11-21 20:52:07');
INSERT INTO `attendances` VALUES ('3109', '26', '780', '17', '1', '2024-11-21', '', '12', '2024-11-21 20:52:07', '2024-11-21 20:52:07');
INSERT INTO `attendances` VALUES ('3110', '26', '782', '17', '1', '2024-11-21', '', '12', '2024-11-21 20:52:07', '2024-11-21 20:52:07');
INSERT INTO `attendances` VALUES ('3111', '26', '784', '17', '1', '2024-11-21', '', '12', '2024-11-21 20:52:07', '2024-11-21 20:52:07');
INSERT INTO `attendances` VALUES ('3112', '26', '786', '17', '1', '2024-11-21', '', '12', '2024-11-21 20:52:07', '2024-11-21 20:52:07');
INSERT INTO `attendances` VALUES ('3113', '26', '788', '17', '1', '2024-11-21', '', '12', '2024-11-21 20:52:07', '2024-11-21 20:52:07');
INSERT INTO `attendances` VALUES ('3114', '26', '790', '17', '1', '2024-11-21', '', '12', '2024-11-21 20:52:07', '2024-11-21 20:52:07');
INSERT INTO `attendances` VALUES ('3115', '26', '792', '17', '1', '2024-11-21', '', '12', '2024-11-21 20:52:07', '2024-11-21 20:52:07');
INSERT INTO `attendances` VALUES ('3116', '26', '794', '17', '1', '2024-11-21', '', '12', '2024-11-21 20:52:07', '2024-11-21 20:52:07');
INSERT INTO `attendances` VALUES ('3117', '26', '796', '17', '1', '2024-11-21', '', '12', '2024-11-21 20:52:07', '2024-11-21 20:52:07');
INSERT INTO `attendances` VALUES ('3118', '26', '798', '17', '1', '2024-11-21', '', '12', '2024-11-21 20:52:07', '2024-11-21 20:52:07');
INSERT INTO `attendances` VALUES ('3119', '26', '800', '17', '1', '2024-11-21', '', '12', '2024-11-21 20:52:07', '2024-11-21 20:52:07');
INSERT INTO `attendances` VALUES ('3120', '26', '802', '17', '1', '2024-11-21', '', '12', '2024-11-21 20:52:07', '2024-11-21 20:52:07');
INSERT INTO `attendances` VALUES ('3121', '21', '371', '17', '0', '2024-11-22', '', '12', '2024-11-23 15:25:06', '2024-11-23 15:25:06');
INSERT INTO `attendances` VALUES ('3122', '21', '377', '17', '1', '2024-11-22', '', '12', '2024-11-23 15:25:06', '2024-11-23 15:25:06');
INSERT INTO `attendances` VALUES ('3123', '21', '381', '17', '0', '2024-11-22', '', '12', '2024-11-23 15:25:06', '2024-11-23 15:25:06');
INSERT INTO `attendances` VALUES ('3124', '21', '387', '17', '1', '2024-11-22', '', '12', '2024-11-23 15:25:06', '2024-11-23 15:25:06');
INSERT INTO `attendances` VALUES ('3125', '21', '403', '17', '1', '2024-11-22', '', '12', '2024-11-23 15:25:06', '2024-11-23 15:25:06');
INSERT INTO `attendances` VALUES ('3126', '21', '407', '17', '1', '2024-11-22', '', '12', '2024-11-23 15:25:06', '2024-11-23 15:25:06');
INSERT INTO `attendances` VALUES ('3127', '21', '409', '17', '1', '2024-11-22', '', '12', '2024-11-23 15:25:06', '2024-11-23 15:25:06');
INSERT INTO `attendances` VALUES ('3128', '21', '417', '17', '1', '2024-11-22', '', '12', '2024-11-23 15:25:06', '2024-11-23 15:25:06');
INSERT INTO `attendances` VALUES ('3129', '21', '419', '17', '1', '2024-11-22', '', '12', '2024-11-23 15:25:06', '2024-11-23 15:25:06');
INSERT INTO `attendances` VALUES ('3130', '21', '421', '17', '1', '2024-11-22', '', '12', '2024-11-23 15:25:06', '2024-11-23 15:25:06');
INSERT INTO `attendances` VALUES ('3131', '21', '423', '17', '1', '2024-11-22', '', '12', '2024-11-23 15:25:06', '2024-11-23 15:25:06');
INSERT INTO `attendances` VALUES ('3132', '21', '425', '17', '1', '2024-11-22', '', '12', '2024-11-23 15:25:06', '2024-11-23 15:25:06');
INSERT INTO `attendances` VALUES ('3133', '21', '427', '17', '1', '2024-11-22', '', '12', '2024-11-23 15:25:06', '2024-11-23 15:25:06');
INSERT INTO `attendances` VALUES ('3134', '21', '429', '17', '1', '2024-11-22', '', '12', '2024-11-23 15:25:06', '2024-11-23 15:25:06');
INSERT INTO `attendances` VALUES ('3135', '21', '431', '17', '1', '2024-11-22', '', '12', '2024-11-23 15:25:06', '2024-11-23 15:25:06');
INSERT INTO `attendances` VALUES ('3136', '21', '433', '17', '1', '2024-11-22', '', '12', '2024-11-23 15:25:06', '2024-11-23 15:25:06');
INSERT INTO `attendances` VALUES ('3137', '21', '435', '17', '1', '2024-11-22', '', '12', '2024-11-23 15:25:06', '2024-11-23 15:25:06');
INSERT INTO `attendances` VALUES ('3138', '21', '437', '17', '1', '2024-11-22', '', '12', '2024-11-23 15:25:06', '2024-11-23 15:25:06');
INSERT INTO `attendances` VALUES ('3139', '21', '439', '17', '1', '2024-11-22', '', '12', '2024-11-23 15:25:06', '2024-11-23 15:25:06');
INSERT INTO `attendances` VALUES ('3140', '21', '441', '17', '1', '2024-11-22', '', '12', '2024-11-23 15:25:06', '2024-11-23 15:25:06');
INSERT INTO `attendances` VALUES ('3141', '21', '443', '17', '1', '2024-11-22', '', '12', '2024-11-23 15:25:06', '2024-11-23 15:25:06');
INSERT INTO `attendances` VALUES ('3142', '21', '445', '17', '1', '2024-11-22', '', '12', '2024-11-23 15:25:06', '2024-11-23 15:25:06');
INSERT INTO `attendances` VALUES ('3143', '21', '447', '17', '1', '2024-11-22', '', '12', '2024-11-23 15:25:06', '2024-11-23 15:25:06');
INSERT INTO `attendances` VALUES ('3144', '21', '449', '17', '1', '2024-11-22', '', '12', '2024-11-23 15:25:06', '2024-11-23 15:25:06');
INSERT INTO `attendances` VALUES ('3145', '21', '451', '17', '1', '2024-11-22', '', '12', '2024-11-23 15:25:06', '2024-11-23 15:25:06');
INSERT INTO `attendances` VALUES ('3146', '21', '453', '17', '1', '2024-11-22', '', '12', '2024-11-23 15:25:06', '2024-11-23 15:25:06');
INSERT INTO `attendances` VALUES ('3147', '21', '455', '17', '1', '2024-11-22', '', '12', '2024-11-23 15:25:06', '2024-11-23 15:25:06');
INSERT INTO `attendances` VALUES ('3148', '21', '457', '17', '1', '2024-11-22', '', '12', '2024-11-23 15:25:06', '2024-11-23 15:25:06');
INSERT INTO `attendances` VALUES ('3149', '21', '459', '17', '1', '2024-11-22', '', '12', '2024-11-23 15:25:06', '2024-11-23 15:25:06');
INSERT INTO `attendances` VALUES ('3150', '21', '461', '17', '1', '2024-11-22', '', '12', '2024-11-23 15:25:06', '2024-11-23 15:25:06');
INSERT INTO `attendances` VALUES ('3151', '21', '463', '17', '1', '2024-11-22', '', '12', '2024-11-23 15:25:06', '2024-11-23 15:25:06');
INSERT INTO `attendances` VALUES ('3152', '21', '465', '17', '1', '2024-11-22', '', '12', '2024-11-23 15:25:06', '2024-11-23 15:25:06');
INSERT INTO `attendances` VALUES ('3153', '21', '467', '17', '1', '2024-11-22', '', '12', '2024-11-23 15:25:06', '2024-11-23 15:25:06');
INSERT INTO `attendances` VALUES ('3154', '26', '337', '17', '0', '2024-12-10', '', '12', '2024-12-10 04:51:39', '2024-12-10 04:51:39');
INSERT INTO `attendances` VALUES ('3155', '26', '744', '17', '1', '2024-12-10', '', '12', '2024-12-10 04:51:39', '2024-12-10 04:51:39');
INSERT INTO `attendances` VALUES ('3156', '26', '746', '17', '1', '2024-12-10', '', '12', '2024-12-10 04:51:39', '2024-12-10 04:51:39');
INSERT INTO `attendances` VALUES ('3157', '26', '748', '17', '1', '2024-12-10', '', '12', '2024-12-10 04:51:39', '2024-12-10 04:51:39');
INSERT INTO `attendances` VALUES ('3158', '26', '750', '17', '1', '2024-12-10', '', '12', '2024-12-10 04:51:39', '2024-12-10 04:51:39');
INSERT INTO `attendances` VALUES ('3159', '26', '752', '17', '1', '2024-12-10', '', '12', '2024-12-10 04:51:39', '2024-12-10 04:51:39');
INSERT INTO `attendances` VALUES ('3160', '26', '754', '17', '1', '2024-12-10', '', '12', '2024-12-10 04:51:39', '2024-12-10 04:51:39');
INSERT INTO `attendances` VALUES ('3161', '26', '756', '17', '1', '2024-12-10', '', '12', '2024-12-10 04:51:39', '2024-12-10 04:51:39');
INSERT INTO `attendances` VALUES ('3162', '26', '758', '17', '1', '2024-12-10', '', '12', '2024-12-10 04:51:39', '2024-12-10 04:51:39');
INSERT INTO `attendances` VALUES ('3163', '26', '760', '17', '1', '2024-12-10', '', '12', '2024-12-10 04:51:39', '2024-12-10 04:51:39');
INSERT INTO `attendances` VALUES ('3164', '26', '762', '17', '1', '2024-12-10', '', '12', '2024-12-10 04:51:39', '2024-12-10 04:51:39');
INSERT INTO `attendances` VALUES ('3165', '26', '764', '17', '1', '2024-12-10', '', '12', '2024-12-10 04:51:39', '2024-12-10 04:51:39');
INSERT INTO `attendances` VALUES ('3166', '26', '766', '17', '0', '2024-12-10', '', '12', '2024-12-10 04:51:39', '2024-12-10 04:51:39');
INSERT INTO `attendances` VALUES ('3167', '26', '768', '17', '1', '2024-12-10', '', '12', '2024-12-10 04:51:39', '2024-12-10 04:51:39');
INSERT INTO `attendances` VALUES ('3168', '26', '770', '17', '1', '2024-12-10', '', '12', '2024-12-10 04:51:39', '2024-12-10 04:51:39');
INSERT INTO `attendances` VALUES ('3169', '26', '772', '17', '1', '2024-12-10', '', '12', '2024-12-10 04:51:39', '2024-12-10 04:51:39');
INSERT INTO `attendances` VALUES ('3170', '26', '774', '17', '1', '2024-12-10', '', '12', '2024-12-10 04:51:39', '2024-12-10 04:51:39');
INSERT INTO `attendances` VALUES ('3171', '26', '776', '17', '1', '2024-12-10', '', '12', '2024-12-10 04:51:39', '2024-12-10 04:51:39');
INSERT INTO `attendances` VALUES ('3172', '26', '778', '17', '1', '2024-12-10', '', '12', '2024-12-10 04:51:39', '2024-12-10 04:51:39');
INSERT INTO `attendances` VALUES ('3173', '26', '780', '17', '1', '2024-12-10', '', '12', '2024-12-10 04:51:39', '2024-12-10 04:51:39');
INSERT INTO `attendances` VALUES ('3174', '26', '782', '17', '1', '2024-12-10', '', '12', '2024-12-10 04:51:39', '2024-12-10 04:51:39');
INSERT INTO `attendances` VALUES ('3175', '26', '784', '17', '1', '2024-12-10', '', '12', '2024-12-10 04:51:39', '2024-12-10 04:51:39');
INSERT INTO `attendances` VALUES ('3176', '26', '786', '17', '1', '2024-12-10', '', '12', '2024-12-10 04:51:39', '2024-12-10 04:51:39');
INSERT INTO `attendances` VALUES ('3177', '26', '788', '17', '1', '2024-12-10', '', '12', '2024-12-10 04:51:39', '2024-12-10 04:51:39');
INSERT INTO `attendances` VALUES ('3178', '26', '790', '17', '1', '2024-12-10', '', '12', '2024-12-10 04:51:39', '2024-12-10 04:51:39');
INSERT INTO `attendances` VALUES ('3179', '26', '792', '17', '1', '2024-12-10', '', '12', '2024-12-10 04:51:39', '2024-12-10 04:51:39');
INSERT INTO `attendances` VALUES ('3180', '26', '794', '17', '1', '2024-12-10', '', '12', '2024-12-10 04:51:39', '2024-12-10 04:51:39');
INSERT INTO `attendances` VALUES ('3181', '26', '796', '17', '1', '2024-12-10', '', '12', '2024-12-10 04:51:39', '2024-12-10 04:51:39');
INSERT INTO `attendances` VALUES ('3182', '26', '798', '17', '1', '2024-12-10', '', '12', '2024-12-10 04:51:39', '2024-12-10 04:51:39');
INSERT INTO `attendances` VALUES ('3183', '26', '800', '17', '1', '2024-12-10', '', '12', '2024-12-10 04:51:39', '2024-12-10 04:51:39');
INSERT INTO `attendances` VALUES ('3184', '26', '802', '17', '1', '2024-12-10', '', '12', '2024-12-10 04:51:39', '2024-12-10 04:51:39');
INSERT INTO `attendances` VALUES ('3185', '31', '341', '17', '3', '2024-12-10', '', '12', '2024-12-10 16:21:08', '2024-12-10 16:21:08');
INSERT INTO `attendances` VALUES ('3186', '31', '1004', '17', '3', '2024-12-10', '', '12', '2024-12-10 16:21:08', '2024-12-10 16:21:08');
INSERT INTO `attendances` VALUES ('3187', '31', '1006', '17', '3', '2024-12-10', '', '12', '2024-12-10 16:21:08', '2024-12-10 16:21:08');
INSERT INTO `attendances` VALUES ('3188', '31', '1008', '17', '3', '2024-12-10', '', '12', '2024-12-10 16:21:08', '2024-12-10 16:21:08');
INSERT INTO `attendances` VALUES ('3189', '31', '1010', '17', '3', '2024-12-10', '', '12', '2024-12-10 16:21:08', '2024-12-10 16:21:08');
INSERT INTO `attendances` VALUES ('3190', '31', '1012', '17', '3', '2024-12-10', '', '12', '2024-12-10 16:21:08', '2024-12-10 16:21:08');
INSERT INTO `attendances` VALUES ('3191', '31', '1014', '17', '3', '2024-12-10', '', '12', '2024-12-10 16:21:08', '2024-12-10 16:21:08');
INSERT INTO `attendances` VALUES ('3192', '31', '1016', '17', '3', '2024-12-10', '', '12', '2024-12-10 16:21:08', '2024-12-10 16:21:08');
INSERT INTO `attendances` VALUES ('3193', '31', '1018', '17', '3', '2024-12-10', '', '12', '2024-12-10 16:21:08', '2024-12-10 16:21:08');
INSERT INTO `attendances` VALUES ('3194', '31', '1020', '17', '3', '2024-12-10', '', '12', '2024-12-10 16:21:08', '2024-12-10 16:21:08');
INSERT INTO `attendances` VALUES ('3195', '31', '1022', '17', '3', '2024-12-10', '', '12', '2024-12-10 16:21:08', '2024-12-10 16:21:08');
INSERT INTO `attendances` VALUES ('3196', '31', '1024', '17', '3', '2024-12-10', '', '12', '2024-12-10 16:21:08', '2024-12-10 16:21:08');
INSERT INTO `attendances` VALUES ('3197', '31', '1026', '17', '3', '2024-12-10', '', '12', '2024-12-10 16:21:08', '2024-12-10 16:21:08');
INSERT INTO `attendances` VALUES ('3198', '31', '1028', '17', '3', '2024-12-10', '', '12', '2024-12-10 16:21:08', '2024-12-10 16:21:08');
INSERT INTO `attendances` VALUES ('3199', '31', '1030', '17', '3', '2024-12-10', '', '12', '2024-12-10 16:21:08', '2024-12-10 16:21:08');
INSERT INTO `attendances` VALUES ('3200', '31', '1032', '17', '3', '2024-12-10', '', '12', '2024-12-10 16:21:08', '2024-12-10 16:21:08');
INSERT INTO `attendances` VALUES ('3201', '31', '1034', '17', '3', '2024-12-10', '', '12', '2024-12-10 16:21:08', '2024-12-10 16:21:08');
INSERT INTO `attendances` VALUES ('3202', '31', '1036', '17', '3', '2024-12-10', '', '12', '2024-12-10 16:21:08', '2024-12-10 16:21:08');
INSERT INTO `attendances` VALUES ('3203', '31', '1038', '17', '3', '2024-12-10', '', '12', '2024-12-10 16:21:08', '2024-12-10 16:21:08');
INSERT INTO `attendances` VALUES ('3204', '31', '1040', '17', '3', '2024-12-10', '', '12', '2024-12-10 16:21:08', '2024-12-10 16:21:08');
INSERT INTO `attendances` VALUES ('3205', '31', '1042', '17', '3', '2024-12-10', '', '12', '2024-12-10 16:21:08', '2024-12-10 16:21:08');
INSERT INTO `attendances` VALUES ('3206', '31', '1044', '17', '3', '2024-12-10', '', '12', '2024-12-10 16:21:08', '2024-12-10 16:21:08');
INSERT INTO `attendances` VALUES ('3207', '31', '1046', '17', '3', '2024-12-10', '', '12', '2024-12-10 16:21:08', '2024-12-10 16:21:08');
INSERT INTO `attendances` VALUES ('3208', '31', '1048', '17', '3', '2024-12-10', '', '12', '2024-12-10 16:21:08', '2024-12-10 16:21:08');
INSERT INTO `attendances` VALUES ('3209', '31', '1050', '17', '3', '2024-12-10', '', '12', '2024-12-10 16:21:08', '2024-12-10 16:21:08');
INSERT INTO `attendances` VALUES ('3210', '31', '1052', '17', '3', '2024-12-10', '', '12', '2024-12-10 16:21:08', '2024-12-10 16:21:08');
INSERT INTO `attendances` VALUES ('3211', '31', '1054', '17', '3', '2024-12-10', '', '12', '2024-12-10 16:21:08', '2024-12-10 16:21:08');
INSERT INTO `attendances` VALUES ('3212', '31', '1056', '17', '3', '2024-12-10', '', '12', '2024-12-10 16:21:08', '2024-12-10 16:21:08');
INSERT INTO `attendances` VALUES ('3213', '31', '1058', '17', '3', '2024-12-10', '', '12', '2024-12-10 16:21:08', '2024-12-10 16:21:08');
INSERT INTO `attendances` VALUES ('3214', '31', '1060', '17', '3', '2024-12-10', '', '12', '2024-12-10 16:21:08', '2024-12-10 16:21:08');
INSERT INTO `attendances` VALUES ('3215', '31', '1062', '17', '3', '2024-12-10', '', '12', '2024-12-10 16:21:08', '2024-12-10 16:21:08');
INSERT INTO `attendances` VALUES ('3216', '31', '341', '17', '3', '2024-12-11', '', '12', '2024-12-11 00:53:51', '2024-12-11 06:27:50');
INSERT INTO `attendances` VALUES ('3217', '31', '1004', '17', '3', '2024-12-11', '', '12', '2024-12-11 00:53:51', '2024-12-11 06:27:50');
INSERT INTO `attendances` VALUES ('3218', '31', '1006', '17', '3', '2024-12-11', '', '12', '2024-12-11 00:53:51', '2024-12-11 06:27:50');
INSERT INTO `attendances` VALUES ('3219', '31', '1008', '17', '3', '2024-12-11', '', '12', '2024-12-11 00:53:51', '2024-12-11 06:27:50');
INSERT INTO `attendances` VALUES ('3220', '31', '1010', '17', '3', '2024-12-11', '', '12', '2024-12-11 00:53:51', '2024-12-11 06:27:50');
INSERT INTO `attendances` VALUES ('3221', '31', '1012', '17', '3', '2024-12-11', '', '12', '2024-12-11 00:53:51', '2024-12-11 06:27:50');
INSERT INTO `attendances` VALUES ('3222', '31', '1014', '17', '3', '2024-12-11', '', '12', '2024-12-11 00:53:51', '2024-12-11 06:27:50');
INSERT INTO `attendances` VALUES ('3223', '31', '1016', '17', '3', '2024-12-11', '', '12', '2024-12-11 00:53:51', '2024-12-11 06:27:50');
INSERT INTO `attendances` VALUES ('3224', '31', '1018', '17', '3', '2024-12-11', '', '12', '2024-12-11 00:53:51', '2024-12-11 06:27:50');
INSERT INTO `attendances` VALUES ('3225', '31', '1020', '17', '3', '2024-12-11', '', '12', '2024-12-11 00:53:51', '2024-12-11 06:27:50');
INSERT INTO `attendances` VALUES ('3226', '31', '1022', '17', '3', '2024-12-11', '', '12', '2024-12-11 00:53:51', '2024-12-11 06:27:50');
INSERT INTO `attendances` VALUES ('3227', '31', '1024', '17', '3', '2024-12-11', '', '12', '2024-12-11 00:53:51', '2024-12-11 06:27:50');
INSERT INTO `attendances` VALUES ('3228', '31', '1026', '17', '3', '2024-12-11', '', '12', '2024-12-11 00:53:51', '2024-12-11 06:27:50');
INSERT INTO `attendances` VALUES ('3229', '31', '1028', '17', '3', '2024-12-11', '', '12', '2024-12-11 00:53:51', '2024-12-11 06:27:50');
INSERT INTO `attendances` VALUES ('3230', '31', '1030', '17', '3', '2024-12-11', '', '12', '2024-12-11 00:53:51', '2024-12-11 06:27:50');
INSERT INTO `attendances` VALUES ('3231', '31', '1032', '17', '3', '2024-12-11', '', '12', '2024-12-11 00:53:51', '2024-12-11 06:27:50');
INSERT INTO `attendances` VALUES ('3232', '31', '1034', '17', '3', '2024-12-11', '', '12', '2024-12-11 00:53:51', '2024-12-11 06:27:50');
INSERT INTO `attendances` VALUES ('3233', '31', '1036', '17', '3', '2024-12-11', '', '12', '2024-12-11 00:53:51', '2024-12-11 06:27:50');
INSERT INTO `attendances` VALUES ('3234', '31', '1038', '17', '3', '2024-12-11', '', '12', '2024-12-11 00:53:51', '2024-12-11 06:27:50');
INSERT INTO `attendances` VALUES ('3235', '31', '1040', '17', '3', '2024-12-11', '', '12', '2024-12-11 00:53:51', '2024-12-11 06:27:50');
INSERT INTO `attendances` VALUES ('3236', '31', '1042', '17', '3', '2024-12-11', '', '12', '2024-12-11 00:53:51', '2024-12-11 06:27:50');
INSERT INTO `attendances` VALUES ('3237', '31', '1044', '17', '3', '2024-12-11', '', '12', '2024-12-11 00:53:51', '2024-12-11 06:27:50');
INSERT INTO `attendances` VALUES ('3238', '31', '1046', '17', '3', '2024-12-11', '', '12', '2024-12-11 00:53:51', '2024-12-11 06:27:50');
INSERT INTO `attendances` VALUES ('3239', '31', '1048', '17', '3', '2024-12-11', '', '12', '2024-12-11 00:53:51', '2024-12-11 06:27:50');
INSERT INTO `attendances` VALUES ('3240', '31', '1050', '17', '3', '2024-12-11', '', '12', '2024-12-11 00:53:51', '2024-12-11 06:27:50');
INSERT INTO `attendances` VALUES ('3241', '31', '1052', '17', '3', '2024-12-11', '', '12', '2024-12-11 00:53:51', '2024-12-11 06:27:50');
INSERT INTO `attendances` VALUES ('3242', '31', '1054', '17', '3', '2024-12-11', '', '12', '2024-12-11 00:53:51', '2024-12-11 06:27:50');
INSERT INTO `attendances` VALUES ('3243', '31', '1056', '17', '3', '2024-12-11', '', '12', '2024-12-11 00:53:51', '2024-12-11 06:27:50');
INSERT INTO `attendances` VALUES ('3244', '31', '1058', '17', '3', '2024-12-11', '', '12', '2024-12-11 00:53:51', '2024-12-11 06:27:50');
INSERT INTO `attendances` VALUES ('3245', '31', '1060', '17', '3', '2024-12-11', '', '12', '2024-12-11 00:53:51', '2024-12-11 06:27:50');
INSERT INTO `attendances` VALUES ('3246', '31', '1062', '17', '3', '2024-12-11', '', '12', '2024-12-11 00:53:51', '2024-12-11 06:27:50');
INSERT INTO `attendances` VALUES ('3247', '31', '341', '17', '1', '2024-12-12', '', '12', '2024-12-12 13:19:11', '2024-12-12 13:19:11');
INSERT INTO `attendances` VALUES ('3248', '31', '1004', '17', '1', '2024-12-12', '', '12', '2024-12-12 13:19:11', '2024-12-12 13:19:11');
INSERT INTO `attendances` VALUES ('3249', '31', '1006', '17', '1', '2024-12-12', '', '12', '2024-12-12 13:19:11', '2024-12-12 13:19:29');
INSERT INTO `attendances` VALUES ('3250', '31', '1008', '17', '1', '2024-12-12', '', '12', '2024-12-12 13:19:11', '2024-12-12 13:19:29');
INSERT INTO `attendances` VALUES ('3251', '31', '1010', '17', '1', '2024-12-12', '', '12', '2024-12-12 13:19:11', '2024-12-12 13:19:11');
INSERT INTO `attendances` VALUES ('3252', '31', '1012', '17', '1', '2024-12-12', '', '12', '2024-12-12 13:19:11', '2024-12-12 13:19:11');
INSERT INTO `attendances` VALUES ('3253', '31', '1014', '17', '1', '2024-12-12', '', '12', '2024-12-12 13:19:11', '2024-12-12 13:19:11');
INSERT INTO `attendances` VALUES ('3254', '31', '1016', '17', '1', '2024-12-12', '', '12', '2024-12-12 13:19:11', '2024-12-12 13:19:11');
INSERT INTO `attendances` VALUES ('3255', '31', '1018', '17', '1', '2024-12-12', '', '12', '2024-12-12 13:19:11', '2024-12-12 13:19:11');
INSERT INTO `attendances` VALUES ('3256', '31', '1020', '17', '1', '2024-12-12', '', '12', '2024-12-12 13:19:11', '2024-12-12 13:19:11');
INSERT INTO `attendances` VALUES ('3257', '31', '1022', '17', '1', '2024-12-12', '', '12', '2024-12-12 13:19:11', '2024-12-12 13:19:29');
INSERT INTO `attendances` VALUES ('3258', '31', '1024', '17', '1', '2024-12-12', '', '12', '2024-12-12 13:19:11', '2024-12-12 13:19:11');
INSERT INTO `attendances` VALUES ('3259', '31', '1026', '17', '1', '2024-12-12', '', '12', '2024-12-12 13:19:11', '2024-12-12 13:19:11');
INSERT INTO `attendances` VALUES ('3260', '31', '1028', '17', '1', '2024-12-12', '', '12', '2024-12-12 13:19:11', '2024-12-12 13:19:11');
INSERT INTO `attendances` VALUES ('3261', '31', '1030', '17', '1', '2024-12-12', '', '12', '2024-12-12 13:19:11', '2024-12-12 13:19:11');
INSERT INTO `attendances` VALUES ('3262', '31', '1032', '17', '1', '2024-12-12', '', '12', '2024-12-12 13:19:11', '2024-12-12 13:19:11');
INSERT INTO `attendances` VALUES ('3263', '31', '1034', '17', '1', '2024-12-12', '', '12', '2024-12-12 13:19:11', '2024-12-12 13:19:11');
INSERT INTO `attendances` VALUES ('3264', '31', '1036', '17', '1', '2024-12-12', '', '12', '2024-12-12 13:19:11', '2024-12-12 13:19:11');
INSERT INTO `attendances` VALUES ('3265', '31', '1038', '17', '1', '2024-12-12', '', '12', '2024-12-12 13:19:11', '2024-12-12 13:19:11');
INSERT INTO `attendances` VALUES ('3266', '31', '1040', '17', '1', '2024-12-12', '', '12', '2024-12-12 13:19:11', '2024-12-12 13:19:11');
INSERT INTO `attendances` VALUES ('3267', '31', '1042', '17', '1', '2024-12-12', '', '12', '2024-12-12 13:19:11', '2024-12-12 13:19:11');
INSERT INTO `attendances` VALUES ('3268', '31', '1044', '17', '1', '2024-12-12', '', '12', '2024-12-12 13:19:11', '2024-12-12 13:19:11');
INSERT INTO `attendances` VALUES ('3269', '31', '1046', '17', '1', '2024-12-12', '', '12', '2024-12-12 13:19:11', '2024-12-12 13:19:11');
INSERT INTO `attendances` VALUES ('3270', '31', '1048', '17', '1', '2024-12-12', '', '12', '2024-12-12 13:19:11', '2024-12-12 13:19:11');
INSERT INTO `attendances` VALUES ('3271', '31', '1050', '17', '1', '2024-12-12', '', '12', '2024-12-12 13:19:11', '2024-12-12 13:19:11');
INSERT INTO `attendances` VALUES ('3272', '31', '1052', '17', '1', '2024-12-12', '', '12', '2024-12-12 13:19:11', '2024-12-12 13:19:11');
INSERT INTO `attendances` VALUES ('3273', '31', '1054', '17', '1', '2024-12-12', '', '12', '2024-12-12 13:19:11', '2024-12-12 13:19:11');
INSERT INTO `attendances` VALUES ('3274', '31', '1056', '17', '1', '2024-12-12', '', '12', '2024-12-12 13:19:11', '2024-12-12 13:19:11');
INSERT INTO `attendances` VALUES ('3275', '31', '1058', '17', '1', '2024-12-12', '', '12', '2024-12-12 13:19:11', '2024-12-12 13:19:11');
INSERT INTO `attendances` VALUES ('3276', '31', '1060', '17', '1', '2024-12-12', '', '12', '2024-12-12 13:19:11', '2024-12-12 13:19:11');
INSERT INTO `attendances` VALUES ('3277', '31', '1062', '17', '1', '2024-12-12', '', '12', '2024-12-12 13:19:11', '2024-12-12 13:19:11');
INSERT INTO `attendances` VALUES ('3278', '21', '371', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:45:03', '2024-12-14 04:45:03');
INSERT INTO `attendances` VALUES ('3279', '21', '377', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:45:03', '2024-12-14 04:45:03');
INSERT INTO `attendances` VALUES ('3280', '21', '381', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:45:03', '2024-12-14 04:45:03');
INSERT INTO `attendances` VALUES ('3281', '21', '387', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:45:03', '2024-12-14 04:45:03');
INSERT INTO `attendances` VALUES ('3282', '21', '403', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:45:03', '2024-12-14 04:45:03');
INSERT INTO `attendances` VALUES ('3283', '21', '407', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:45:03', '2024-12-14 04:45:03');
INSERT INTO `attendances` VALUES ('3284', '21', '409', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:45:03', '2024-12-14 04:45:03');
INSERT INTO `attendances` VALUES ('3285', '21', '417', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:45:03', '2024-12-14 04:45:03');
INSERT INTO `attendances` VALUES ('3286', '21', '419', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:45:03', '2024-12-14 04:45:03');
INSERT INTO `attendances` VALUES ('3287', '21', '421', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:45:03', '2024-12-14 04:45:03');
INSERT INTO `attendances` VALUES ('3288', '21', '423', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:45:03', '2024-12-14 04:45:03');
INSERT INTO `attendances` VALUES ('3289', '21', '425', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:45:03', '2024-12-14 04:45:03');
INSERT INTO `attendances` VALUES ('3290', '21', '427', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:45:03', '2024-12-14 04:45:03');
INSERT INTO `attendances` VALUES ('3291', '21', '429', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:45:03', '2024-12-14 04:45:03');
INSERT INTO `attendances` VALUES ('3292', '21', '431', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:45:03', '2024-12-14 04:45:03');
INSERT INTO `attendances` VALUES ('3293', '21', '433', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:45:03', '2024-12-14 04:45:03');
INSERT INTO `attendances` VALUES ('3294', '21', '435', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:45:03', '2024-12-14 04:45:03');
INSERT INTO `attendances` VALUES ('3295', '21', '437', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:45:03', '2024-12-14 04:45:03');
INSERT INTO `attendances` VALUES ('3296', '21', '439', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:45:03', '2024-12-14 04:45:03');
INSERT INTO `attendances` VALUES ('3297', '21', '441', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:45:03', '2024-12-14 04:45:03');
INSERT INTO `attendances` VALUES ('3298', '21', '443', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:45:03', '2024-12-14 04:45:03');
INSERT INTO `attendances` VALUES ('3299', '21', '445', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:45:03', '2024-12-14 04:45:03');
INSERT INTO `attendances` VALUES ('3300', '21', '447', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:45:03', '2024-12-14 04:45:03');
INSERT INTO `attendances` VALUES ('3301', '21', '449', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:45:03', '2024-12-14 04:45:03');
INSERT INTO `attendances` VALUES ('3302', '21', '451', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:45:03', '2024-12-14 04:45:03');
INSERT INTO `attendances` VALUES ('3303', '21', '453', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:45:03', '2024-12-14 04:45:03');
INSERT INTO `attendances` VALUES ('3304', '21', '455', '17', '0', '2024-12-14', '', '12', '2024-12-14 04:45:03', '2024-12-14 04:45:03');
INSERT INTO `attendances` VALUES ('3305', '21', '457', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:45:03', '2024-12-14 04:45:03');
INSERT INTO `attendances` VALUES ('3306', '21', '459', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:45:03', '2024-12-14 04:45:03');
INSERT INTO `attendances` VALUES ('3307', '21', '461', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:45:03', '2024-12-14 04:45:03');
INSERT INTO `attendances` VALUES ('3308', '21', '463', '17', '0', '2024-12-14', '', '12', '2024-12-14 04:45:03', '2024-12-14 04:45:03');
INSERT INTO `attendances` VALUES ('3309', '21', '465', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:45:03', '2024-12-14 04:45:03');
INSERT INTO `attendances` VALUES ('3310', '21', '467', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:45:03', '2024-12-14 04:45:03');
INSERT INTO `attendances` VALUES ('3311', '55', '331', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:47:34', '2024-12-14 04:47:34');
INSERT INTO `attendances` VALUES ('3312', '55', '349', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:47:34', '2024-12-14 04:47:34');
INSERT INTO `attendances` VALUES ('3313', '55', '351', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:47:34', '2024-12-14 04:47:34');
INSERT INTO `attendances` VALUES ('3314', '55', '353', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:47:34', '2024-12-14 04:47:34');
INSERT INTO `attendances` VALUES ('3315', '55', '355', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:47:34', '2024-12-14 04:47:34');
INSERT INTO `attendances` VALUES ('3316', '55', '357', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:47:34', '2024-12-14 04:47:34');
INSERT INTO `attendances` VALUES ('3317', '55', '359', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:47:34', '2024-12-14 04:47:34');
INSERT INTO `attendances` VALUES ('3318', '55', '361', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:47:34', '2024-12-14 04:47:34');
INSERT INTO `attendances` VALUES ('3319', '55', '363', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:47:34', '2024-12-14 04:47:34');
INSERT INTO `attendances` VALUES ('3320', '55', '365', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:47:34', '2024-12-14 04:47:34');
INSERT INTO `attendances` VALUES ('3321', '55', '367', '17', '1', '2024-12-14', '', '12', '2024-12-14 04:47:34', '2024-12-14 04:47:34');
INSERT INTO `attendances` VALUES ('3322', '31', '341', '17', '1', '2024-12-15', '', '12', '2024-12-15 11:01:11', '2024-12-15 11:01:11');
INSERT INTO `attendances` VALUES ('3323', '31', '1004', '17', '1', '2024-12-15', '', '12', '2024-12-15 11:01:11', '2024-12-15 11:01:11');
INSERT INTO `attendances` VALUES ('3324', '31', '1006', '17', '1', '2024-12-15', '', '12', '2024-12-15 11:01:11', '2024-12-15 11:01:11');
INSERT INTO `attendances` VALUES ('3325', '31', '1008', '17', '1', '2024-12-15', '', '12', '2024-12-15 11:01:11', '2024-12-15 11:01:11');
INSERT INTO `attendances` VALUES ('3326', '31', '1010', '17', '1', '2024-12-15', '', '12', '2024-12-15 11:01:11', '2024-12-15 11:01:11');
INSERT INTO `attendances` VALUES ('3327', '31', '1012', '17', '1', '2024-12-15', '', '12', '2024-12-15 11:01:11', '2024-12-15 11:01:11');
INSERT INTO `attendances` VALUES ('3328', '31', '1014', '17', '1', '2024-12-15', '', '12', '2024-12-15 11:01:11', '2024-12-15 11:01:11');
INSERT INTO `attendances` VALUES ('3329', '31', '1016', '17', '1', '2024-12-15', '', '12', '2024-12-15 11:01:11', '2024-12-15 11:01:11');
INSERT INTO `attendances` VALUES ('3330', '31', '1018', '17', '1', '2024-12-15', '', '12', '2024-12-15 11:01:11', '2024-12-15 11:01:11');
INSERT INTO `attendances` VALUES ('3331', '31', '1020', '17', '1', '2024-12-15', '', '12', '2024-12-15 11:01:11', '2024-12-15 11:01:11');
INSERT INTO `attendances` VALUES ('3332', '31', '1022', '17', '1', '2024-12-15', '', '12', '2024-12-15 11:01:11', '2024-12-15 11:01:11');
INSERT INTO `attendances` VALUES ('3333', '31', '1024', '17', '1', '2024-12-15', '', '12', '2024-12-15 11:01:11', '2024-12-15 11:01:11');
INSERT INTO `attendances` VALUES ('3334', '31', '1026', '17', '1', '2024-12-15', '', '12', '2024-12-15 11:01:11', '2024-12-15 11:01:11');
INSERT INTO `attendances` VALUES ('3335', '31', '1028', '17', '1', '2024-12-15', '', '12', '2024-12-15 11:01:11', '2024-12-15 11:01:11');
INSERT INTO `attendances` VALUES ('3336', '31', '1030', '17', '1', '2024-12-15', '', '12', '2024-12-15 11:01:11', '2024-12-15 11:01:11');
INSERT INTO `attendances` VALUES ('3337', '31', '1032', '17', '1', '2024-12-15', '', '12', '2024-12-15 11:01:11', '2024-12-15 11:01:11');
INSERT INTO `attendances` VALUES ('3338', '31', '1034', '17', '1', '2024-12-15', '', '12', '2024-12-15 11:01:11', '2024-12-15 11:01:11');
INSERT INTO `attendances` VALUES ('3339', '31', '1036', '17', '1', '2024-12-15', '', '12', '2024-12-15 11:01:11', '2024-12-15 11:01:11');
INSERT INTO `attendances` VALUES ('3340', '31', '1038', '17', '1', '2024-12-15', '', '12', '2024-12-15 11:01:11', '2024-12-15 11:01:11');
INSERT INTO `attendances` VALUES ('3341', '31', '1040', '17', '1', '2024-12-15', '', '12', '2024-12-15 11:01:11', '2024-12-15 11:01:11');
INSERT INTO `attendances` VALUES ('3342', '31', '1042', '17', '1', '2024-12-15', '', '12', '2024-12-15 11:01:11', '2024-12-15 11:01:11');
INSERT INTO `attendances` VALUES ('3343', '31', '1044', '17', '0', '2024-12-15', '', '12', '2024-12-15 11:01:11', '2024-12-15 11:01:11');
INSERT INTO `attendances` VALUES ('3344', '31', '1046', '17', '1', '2024-12-15', '', '12', '2024-12-15 11:01:11', '2024-12-15 11:01:11');
INSERT INTO `attendances` VALUES ('3345', '31', '1048', '17', '1', '2024-12-15', '', '12', '2024-12-15 11:01:11', '2024-12-15 11:01:11');
INSERT INTO `attendances` VALUES ('3346', '31', '1050', '17', '1', '2024-12-15', '', '12', '2024-12-15 11:01:11', '2024-12-15 11:01:11');
INSERT INTO `attendances` VALUES ('3347', '31', '1052', '17', '1', '2024-12-15', '', '12', '2024-12-15 11:01:11', '2024-12-15 11:01:11');
INSERT INTO `attendances` VALUES ('3348', '31', '1054', '17', '1', '2024-12-15', '', '12', '2024-12-15 11:01:11', '2024-12-15 11:01:11');
INSERT INTO `attendances` VALUES ('3349', '31', '1056', '17', '1', '2024-12-15', '', '12', '2024-12-15 11:01:11', '2024-12-15 11:01:11');
INSERT INTO `attendances` VALUES ('3350', '31', '1058', '17', '0', '2024-12-15', '', '12', '2024-12-15 11:01:11', '2024-12-15 11:01:11');
INSERT INTO `attendances` VALUES ('3351', '31', '1060', '17', '1', '2024-12-15', '', '12', '2024-12-15 11:01:11', '2024-12-15 11:01:11');
INSERT INTO `attendances` VALUES ('3352', '31', '1062', '17', '1', '2024-12-15', '', '12', '2024-12-15 11:01:11', '2024-12-15 11:01:11');
INSERT INTO `attendances` VALUES ('3353', '31', '341', '17', '1', '2024-12-16', '', '12', '2024-12-16 02:01:08', '2024-12-16 02:01:08');
INSERT INTO `attendances` VALUES ('3354', '31', '1004', '17', '0', '2024-12-16', '', '12', '2024-12-16 02:01:09', '2024-12-16 02:01:09');
INSERT INTO `attendances` VALUES ('3355', '31', '1006', '17', '1', '2024-12-16', '', '12', '2024-12-16 02:01:09', '2024-12-16 02:01:09');
INSERT INTO `attendances` VALUES ('3356', '31', '1008', '17', '1', '2024-12-16', '', '12', '2024-12-16 02:01:09', '2024-12-16 02:01:09');
INSERT INTO `attendances` VALUES ('3357', '31', '1010', '17', '1', '2024-12-16', '', '12', '2024-12-16 02:01:09', '2024-12-16 02:01:09');
INSERT INTO `attendances` VALUES ('3358', '31', '1012', '17', '1', '2024-12-16', '', '12', '2024-12-16 02:01:09', '2024-12-16 02:01:09');
INSERT INTO `attendances` VALUES ('3359', '31', '1014', '17', '1', '2024-12-16', '', '12', '2024-12-16 02:01:09', '2024-12-16 02:01:09');
INSERT INTO `attendances` VALUES ('3360', '31', '1016', '17', '1', '2024-12-16', '', '12', '2024-12-16 02:01:09', '2024-12-16 02:01:09');
INSERT INTO `attendances` VALUES ('3361', '31', '1018', '17', '1', '2024-12-16', '', '12', '2024-12-16 02:01:09', '2024-12-16 02:01:09');
INSERT INTO `attendances` VALUES ('3362', '31', '1020', '17', '1', '2024-12-16', '', '12', '2024-12-16 02:01:09', '2024-12-16 02:01:09');
INSERT INTO `attendances` VALUES ('3363', '31', '1022', '17', '1', '2024-12-16', '', '12', '2024-12-16 02:01:09', '2024-12-16 02:01:09');
INSERT INTO `attendances` VALUES ('3364', '31', '1024', '17', '1', '2024-12-16', '', '12', '2024-12-16 02:01:09', '2024-12-16 02:01:09');
INSERT INTO `attendances` VALUES ('3365', '31', '1026', '17', '1', '2024-12-16', '', '12', '2024-12-16 02:01:09', '2024-12-16 02:01:09');
INSERT INTO `attendances` VALUES ('3366', '31', '1028', '17', '1', '2024-12-16', '', '12', '2024-12-16 02:01:09', '2024-12-16 02:01:09');
INSERT INTO `attendances` VALUES ('3367', '31', '1030', '17', '1', '2024-12-16', '', '12', '2024-12-16 02:01:09', '2024-12-16 02:01:09');
INSERT INTO `attendances` VALUES ('3368', '31', '1032', '17', '1', '2024-12-16', '', '12', '2024-12-16 02:01:09', '2024-12-16 02:01:09');
INSERT INTO `attendances` VALUES ('3369', '31', '1034', '17', '1', '2024-12-16', '', '12', '2024-12-16 02:01:09', '2024-12-16 02:01:09');
INSERT INTO `attendances` VALUES ('3370', '31', '1036', '17', '1', '2024-12-16', '', '12', '2024-12-16 02:01:09', '2024-12-16 02:01:09');
INSERT INTO `attendances` VALUES ('3371', '31', '1038', '17', '1', '2024-12-16', '', '12', '2024-12-16 02:01:09', '2024-12-16 02:01:09');
INSERT INTO `attendances` VALUES ('3372', '31', '1040', '17', '1', '2024-12-16', '', '12', '2024-12-16 02:01:09', '2024-12-16 02:01:09');
INSERT INTO `attendances` VALUES ('3373', '31', '1042', '17', '1', '2024-12-16', '', '12', '2024-12-16 02:01:09', '2024-12-16 02:01:09');
INSERT INTO `attendances` VALUES ('3374', '31', '1044', '17', '1', '2024-12-16', '', '12', '2024-12-16 02:01:09', '2024-12-16 02:01:09');
INSERT INTO `attendances` VALUES ('3375', '31', '1046', '17', '1', '2024-12-16', '', '12', '2024-12-16 02:01:09', '2024-12-16 02:01:09');
INSERT INTO `attendances` VALUES ('3376', '31', '1048', '17', '1', '2024-12-16', '', '12', '2024-12-16 02:01:09', '2024-12-16 02:01:09');
INSERT INTO `attendances` VALUES ('3377', '31', '1050', '17', '1', '2024-12-16', '', '12', '2024-12-16 02:01:09', '2024-12-16 02:01:09');
INSERT INTO `attendances` VALUES ('3378', '31', '1052', '17', '1', '2024-12-16', '', '12', '2024-12-16 02:01:09', '2024-12-16 02:01:09');
INSERT INTO `attendances` VALUES ('3379', '31', '1054', '17', '1', '2024-12-16', '', '12', '2024-12-16 02:01:09', '2024-12-16 02:01:09');
INSERT INTO `attendances` VALUES ('3380', '31', '1056', '17', '0', '2024-12-16', '', '12', '2024-12-16 02:01:09', '2024-12-16 22:04:53');
INSERT INTO `attendances` VALUES ('3381', '31', '1058', '17', '0', '2024-12-16', '', '12', '2024-12-16 02:01:09', '2024-12-16 22:04:53');
INSERT INTO `attendances` VALUES ('3382', '31', '1060', '17', '1', '2024-12-16', '', '12', '2024-12-16 02:01:09', '2024-12-16 02:01:09');
INSERT INTO `attendances` VALUES ('3383', '31', '1062', '17', '1', '2024-12-16', '', '12', '2024-12-16 02:01:09', '2024-12-16 02:01:09');
INSERT INTO `attendances` VALUES ('3384', '55', '331', '17', '0', '2024-12-16', '', '12', '2024-12-16 22:05:25', '2024-12-16 22:05:25');
INSERT INTO `attendances` VALUES ('3385', '55', '349', '17', '1', '2024-12-16', '', '12', '2024-12-16 22:05:25', '2024-12-16 22:05:25');
INSERT INTO `attendances` VALUES ('3386', '55', '351', '17', '1', '2024-12-16', '', '12', '2024-12-16 22:05:25', '2024-12-16 22:05:25');
INSERT INTO `attendances` VALUES ('3387', '55', '353', '17', '1', '2024-12-16', '', '12', '2024-12-16 22:05:25', '2024-12-16 22:05:25');
INSERT INTO `attendances` VALUES ('3388', '55', '355', '17', '1', '2024-12-16', '', '12', '2024-12-16 22:05:25', '2024-12-16 22:05:25');
INSERT INTO `attendances` VALUES ('3389', '55', '357', '17', '1', '2024-12-16', '', '12', '2024-12-16 22:05:25', '2024-12-16 22:05:25');
INSERT INTO `attendances` VALUES ('3390', '55', '359', '17', '1', '2024-12-16', '', '12', '2024-12-16 22:05:25', '2024-12-16 22:05:25');
INSERT INTO `attendances` VALUES ('3391', '55', '361', '17', '1', '2024-12-16', '', '12', '2024-12-16 22:05:25', '2024-12-16 22:05:25');
INSERT INTO `attendances` VALUES ('3392', '55', '363', '17', '1', '2024-12-16', '', '12', '2024-12-16 22:05:25', '2024-12-16 22:05:25');
INSERT INTO `attendances` VALUES ('3393', '55', '365', '17', '1', '2024-12-16', '', '12', '2024-12-16 22:05:25', '2024-12-16 22:05:25');
INSERT INTO `attendances` VALUES ('3394', '55', '367', '17', '1', '2024-12-16', '', '12', '2024-12-16 22:05:25', '2024-12-16 22:05:25');
INSERT INTO `attendances` VALUES ('3395', '26', '337', '17', '0', '2024-12-17', '', '12', '2024-12-17 04:59:27', '2024-12-17 04:59:27');
INSERT INTO `attendances` VALUES ('3396', '26', '744', '17', '1', '2024-12-17', '', '12', '2024-12-17 04:59:27', '2024-12-17 04:59:27');
INSERT INTO `attendances` VALUES ('3397', '26', '746', '17', '1', '2024-12-17', '', '12', '2024-12-17 04:59:27', '2024-12-17 04:59:27');
INSERT INTO `attendances` VALUES ('3398', '26', '748', '17', '1', '2024-12-17', '', '12', '2024-12-17 04:59:27', '2024-12-17 04:59:27');
INSERT INTO `attendances` VALUES ('3399', '26', '750', '17', '1', '2024-12-17', '', '12', '2024-12-17 04:59:27', '2024-12-17 04:59:27');
INSERT INTO `attendances` VALUES ('3400', '26', '752', '17', '1', '2024-12-17', '', '12', '2024-12-17 04:59:27', '2024-12-17 04:59:27');
INSERT INTO `attendances` VALUES ('3401', '26', '754', '17', '1', '2024-12-17', '', '12', '2024-12-17 04:59:27', '2024-12-17 04:59:27');
INSERT INTO `attendances` VALUES ('3402', '26', '756', '17', '1', '2024-12-17', '', '12', '2024-12-17 04:59:27', '2024-12-17 04:59:27');
INSERT INTO `attendances` VALUES ('3403', '26', '758', '17', '1', '2024-12-17', '', '12', '2024-12-17 04:59:27', '2024-12-17 04:59:27');
INSERT INTO `attendances` VALUES ('3404', '26', '760', '17', '1', '2024-12-17', '', '12', '2024-12-17 04:59:27', '2024-12-17 04:59:27');
INSERT INTO `attendances` VALUES ('3405', '26', '762', '17', '1', '2024-12-17', '', '12', '2024-12-17 04:59:27', '2024-12-17 04:59:27');
INSERT INTO `attendances` VALUES ('3406', '26', '764', '17', '1', '2024-12-17', '', '12', '2024-12-17 04:59:27', '2024-12-17 04:59:27');
INSERT INTO `attendances` VALUES ('3407', '26', '766', '17', '1', '2024-12-17', '', '12', '2024-12-17 04:59:27', '2024-12-17 04:59:27');
INSERT INTO `attendances` VALUES ('3408', '26', '768', '17', '1', '2024-12-17', '', '12', '2024-12-17 04:59:27', '2024-12-17 04:59:27');
INSERT INTO `attendances` VALUES ('3409', '26', '770', '17', '1', '2024-12-17', '', '12', '2024-12-17 04:59:27', '2024-12-17 04:59:27');
INSERT INTO `attendances` VALUES ('3410', '26', '772', '17', '1', '2024-12-17', '', '12', '2024-12-17 04:59:27', '2024-12-17 04:59:27');
INSERT INTO `attendances` VALUES ('3411', '26', '774', '17', '1', '2024-12-17', '', '12', '2024-12-17 04:59:27', '2024-12-17 04:59:27');
INSERT INTO `attendances` VALUES ('3412', '26', '776', '17', '1', '2024-12-17', '', '12', '2024-12-17 04:59:27', '2024-12-17 04:59:27');
INSERT INTO `attendances` VALUES ('3413', '26', '778', '17', '1', '2024-12-17', '', '12', '2024-12-17 04:59:27', '2024-12-17 04:59:27');
INSERT INTO `attendances` VALUES ('3414', '26', '780', '17', '1', '2024-12-17', '', '12', '2024-12-17 04:59:27', '2024-12-17 04:59:27');
INSERT INTO `attendances` VALUES ('3415', '26', '782', '17', '1', '2024-12-17', '', '12', '2024-12-17 04:59:27', '2024-12-17 04:59:27');
INSERT INTO `attendances` VALUES ('3416', '26', '784', '17', '1', '2024-12-17', '', '12', '2024-12-17 04:59:27', '2024-12-17 04:59:27');
INSERT INTO `attendances` VALUES ('3417', '26', '786', '17', '1', '2024-12-17', '', '12', '2024-12-17 04:59:27', '2024-12-17 04:59:27');
INSERT INTO `attendances` VALUES ('3418', '26', '788', '17', '1', '2024-12-17', '', '12', '2024-12-17 04:59:27', '2024-12-17 04:59:27');
INSERT INTO `attendances` VALUES ('3419', '26', '790', '17', '1', '2024-12-17', '', '12', '2024-12-17 04:59:27', '2024-12-17 04:59:27');
INSERT INTO `attendances` VALUES ('3420', '26', '792', '17', '1', '2024-12-17', '', '12', '2024-12-17 04:59:27', '2024-12-17 04:59:27');
INSERT INTO `attendances` VALUES ('3421', '26', '794', '17', '1', '2024-12-17', '', '12', '2024-12-17 04:59:27', '2024-12-17 04:59:27');
INSERT INTO `attendances` VALUES ('3422', '26', '796', '17', '1', '2024-12-17', '', '12', '2024-12-17 04:59:27', '2024-12-17 04:59:27');
INSERT INTO `attendances` VALUES ('3423', '26', '798', '17', '1', '2024-12-17', '', '12', '2024-12-17 04:59:27', '2024-12-17 04:59:27');
INSERT INTO `attendances` VALUES ('3424', '26', '800', '17', '1', '2024-12-17', '', '12', '2024-12-17 04:59:27', '2024-12-17 04:59:27');
INSERT INTO `attendances` VALUES ('3425', '26', '802', '17', '1', '2024-12-17', '', '12', '2024-12-17 04:59:27', '2024-12-17 04:59:27');
INSERT INTO `attendances` VALUES ('3426', '31', '341', '17', '0', '2024-12-18', '', '12', '2024-12-18 13:17:57', '2024-12-18 13:17:57');
INSERT INTO `attendances` VALUES ('3427', '31', '1004', '17', '1', '2024-12-18', '', '12', '2024-12-18 13:17:57', '2024-12-18 13:17:57');
INSERT INTO `attendances` VALUES ('3428', '31', '1006', '17', '1', '2024-12-18', '', '12', '2024-12-18 13:17:57', '2024-12-18 13:17:57');
INSERT INTO `attendances` VALUES ('3429', '31', '1008', '17', '1', '2024-12-18', '', '12', '2024-12-18 13:17:57', '2024-12-18 13:17:57');
INSERT INTO `attendances` VALUES ('3430', '31', '1010', '17', '1', '2024-12-18', '', '12', '2024-12-18 13:17:57', '2024-12-18 13:17:57');
INSERT INTO `attendances` VALUES ('3431', '31', '1012', '17', '1', '2024-12-18', '', '12', '2024-12-18 13:17:57', '2024-12-18 13:17:57');
INSERT INTO `attendances` VALUES ('3432', '31', '1014', '17', '1', '2024-12-18', '', '12', '2024-12-18 13:17:57', '2024-12-18 13:17:57');
INSERT INTO `attendances` VALUES ('3433', '31', '1016', '17', '1', '2024-12-18', '', '12', '2024-12-18 13:17:57', '2024-12-18 13:17:57');
INSERT INTO `attendances` VALUES ('3434', '31', '1018', '17', '1', '2024-12-18', '', '12', '2024-12-18 13:17:57', '2024-12-18 13:17:57');
INSERT INTO `attendances` VALUES ('3435', '31', '1020', '17', '1', '2024-12-18', '', '12', '2024-12-18 13:17:57', '2024-12-18 13:17:57');
INSERT INTO `attendances` VALUES ('3436', '31', '1022', '17', '1', '2024-12-18', '', '12', '2024-12-18 13:17:57', '2024-12-18 13:17:57');
INSERT INTO `attendances` VALUES ('3437', '31', '1024', '17', '1', '2024-12-18', '', '12', '2024-12-18 13:17:57', '2024-12-18 13:17:57');
INSERT INTO `attendances` VALUES ('3438', '31', '1026', '17', '1', '2024-12-18', '', '12', '2024-12-18 13:17:57', '2024-12-18 13:17:57');
INSERT INTO `attendances` VALUES ('3439', '31', '1028', '17', '1', '2024-12-18', '', '12', '2024-12-18 13:17:57', '2024-12-18 13:17:57');
INSERT INTO `attendances` VALUES ('3440', '31', '1030', '17', '1', '2024-12-18', '', '12', '2024-12-18 13:17:57', '2024-12-18 13:17:57');
INSERT INTO `attendances` VALUES ('3441', '31', '1032', '17', '1', '2024-12-18', '', '12', '2024-12-18 13:17:57', '2024-12-18 13:17:57');
INSERT INTO `attendances` VALUES ('3442', '31', '1034', '17', '1', '2024-12-18', '', '12', '2024-12-18 13:17:57', '2024-12-18 13:17:57');
INSERT INTO `attendances` VALUES ('3443', '31', '1036', '17', '1', '2024-12-18', '', '12', '2024-12-18 13:17:57', '2024-12-18 13:17:57');
INSERT INTO `attendances` VALUES ('3444', '31', '1038', '17', '1', '2024-12-18', '', '12', '2024-12-18 13:17:57', '2024-12-18 13:17:57');
INSERT INTO `attendances` VALUES ('3445', '31', '1040', '17', '1', '2024-12-18', '', '12', '2024-12-18 13:17:57', '2024-12-18 13:17:57');
INSERT INTO `attendances` VALUES ('3446', '31', '1042', '17', '1', '2024-12-18', '', '12', '2024-12-18 13:17:57', '2024-12-18 13:17:57');
INSERT INTO `attendances` VALUES ('3447', '31', '1044', '17', '1', '2024-12-18', '', '12', '2024-12-18 13:17:57', '2024-12-18 13:17:57');
INSERT INTO `attendances` VALUES ('3448', '31', '1046', '17', '1', '2024-12-18', '', '12', '2024-12-18 13:17:57', '2024-12-18 13:17:57');
INSERT INTO `attendances` VALUES ('3449', '31', '1048', '17', '1', '2024-12-18', '', '12', '2024-12-18 13:17:57', '2024-12-18 13:17:57');
INSERT INTO `attendances` VALUES ('3450', '31', '1050', '17', '1', '2024-12-18', '', '12', '2024-12-18 13:17:57', '2024-12-18 13:17:57');
INSERT INTO `attendances` VALUES ('3451', '31', '1052', '17', '1', '2024-12-18', '', '12', '2024-12-18 13:17:57', '2024-12-18 13:17:57');
INSERT INTO `attendances` VALUES ('3452', '31', '1054', '17', '1', '2024-12-18', '', '12', '2024-12-18 13:17:57', '2024-12-18 13:17:57');
INSERT INTO `attendances` VALUES ('3453', '31', '1056', '17', '1', '2024-12-18', '', '12', '2024-12-18 13:17:57', '2024-12-18 13:17:57');
INSERT INTO `attendances` VALUES ('3454', '31', '1058', '17', '1', '2024-12-18', '', '12', '2024-12-18 13:17:57', '2024-12-18 13:17:57');
INSERT INTO `attendances` VALUES ('3455', '31', '1060', '17', '1', '2024-12-18', '', '12', '2024-12-18 13:17:57', '2024-12-18 13:17:57');
INSERT INTO `attendances` VALUES ('3456', '31', '1062', '17', '1', '2024-12-18', '', '12', '2024-12-18 13:17:57', '2024-12-18 13:17:57');
INSERT INTO `attendances` VALUES ('3457', '55', '331', '17', '0', '2024-12-19', '', '12', '2024-12-19 10:03:25', '2024-12-19 10:03:25');
INSERT INTO `attendances` VALUES ('3458', '55', '349', '17', '1', '2024-12-19', '', '12', '2024-12-19 10:03:25', '2024-12-19 10:03:25');
INSERT INTO `attendances` VALUES ('3459', '55', '351', '17', '1', '2024-12-19', '', '12', '2024-12-19 10:03:25', '2024-12-19 10:03:25');
INSERT INTO `attendances` VALUES ('3460', '55', '353', '17', '0', '2024-12-19', '', '12', '2024-12-19 10:03:25', '2024-12-19 10:03:25');
INSERT INTO `attendances` VALUES ('3461', '55', '355', '17', '1', '2024-12-19', '', '12', '2024-12-19 10:03:25', '2024-12-19 10:03:25');
INSERT INTO `attendances` VALUES ('3462', '55', '357', '17', '1', '2024-12-19', '', '12', '2024-12-19 10:03:25', '2024-12-19 10:03:25');
INSERT INTO `attendances` VALUES ('3463', '55', '359', '17', '1', '2024-12-19', '', '12', '2024-12-19 10:03:25', '2024-12-19 10:03:25');
INSERT INTO `attendances` VALUES ('3464', '55', '361', '17', '1', '2024-12-19', '', '12', '2024-12-19 10:03:25', '2024-12-19 10:03:25');
INSERT INTO `attendances` VALUES ('3465', '55', '363', '17', '1', '2024-12-19', '', '12', '2024-12-19 10:03:25', '2024-12-19 10:03:25');
INSERT INTO `attendances` VALUES ('3466', '55', '365', '17', '1', '2024-12-19', '', '12', '2024-12-19 10:03:25', '2024-12-19 10:03:25');
INSERT INTO `attendances` VALUES ('3467', '55', '367', '17', '1', '2024-12-19', '', '12', '2024-12-19 10:03:25', '2024-12-19 10:03:25');
INSERT INTO `attendances` VALUES ('3468', '31', '341', '17', '0', '2024-12-19', '', '12', '2024-12-19 10:06:14', '2024-12-19 10:41:34');
INSERT INTO `attendances` VALUES ('3469', '31', '1004', '17', '1', '2024-12-19', '', '12', '2024-12-19 10:06:14', '2024-12-19 10:06:14');
INSERT INTO `attendances` VALUES ('3470', '31', '1006', '17', '1', '2024-12-19', '', '12', '2024-12-19 10:06:14', '2024-12-19 10:06:14');
INSERT INTO `attendances` VALUES ('3471', '31', '1008', '17', '1', '2024-12-19', '', '12', '2024-12-19 10:06:14', '2024-12-19 10:06:14');
INSERT INTO `attendances` VALUES ('3472', '31', '1010', '17', '1', '2024-12-19', '', '12', '2024-12-19 10:06:14', '2024-12-19 10:06:14');
INSERT INTO `attendances` VALUES ('3473', '31', '1012', '17', '1', '2024-12-19', '', '12', '2024-12-19 10:06:14', '2024-12-19 10:06:14');
INSERT INTO `attendances` VALUES ('3474', '31', '1014', '17', '1', '2024-12-19', '', '12', '2024-12-19 10:06:14', '2024-12-19 10:06:14');
INSERT INTO `attendances` VALUES ('3475', '31', '1016', '17', '1', '2024-12-19', '', '12', '2024-12-19 10:06:14', '2024-12-19 10:06:14');
INSERT INTO `attendances` VALUES ('3476', '31', '1018', '17', '1', '2024-12-19', '', '12', '2024-12-19 10:06:14', '2024-12-19 10:06:14');
INSERT INTO `attendances` VALUES ('3477', '31', '1020', '17', '1', '2024-12-19', '', '12', '2024-12-19 10:06:14', '2024-12-19 10:06:14');
INSERT INTO `attendances` VALUES ('3478', '31', '1022', '17', '1', '2024-12-19', '', '12', '2024-12-19 10:06:14', '2024-12-19 10:06:14');
INSERT INTO `attendances` VALUES ('3479', '31', '1024', '17', '1', '2024-12-19', '', '12', '2024-12-19 10:06:14', '2024-12-19 10:06:14');
INSERT INTO `attendances` VALUES ('3480', '31', '1026', '17', '1', '2024-12-19', '', '12', '2024-12-19 10:06:14', '2024-12-19 10:06:14');
INSERT INTO `attendances` VALUES ('3481', '31', '1028', '17', '1', '2024-12-19', '', '12', '2024-12-19 10:06:14', '2024-12-19 10:06:14');
INSERT INTO `attendances` VALUES ('3482', '31', '1030', '17', '1', '2024-12-19', '', '12', '2024-12-19 10:06:14', '2024-12-19 10:06:14');
INSERT INTO `attendances` VALUES ('3483', '31', '1032', '17', '1', '2024-12-19', '', '12', '2024-12-19 10:06:14', '2024-12-19 10:06:14');
INSERT INTO `attendances` VALUES ('3484', '31', '1034', '17', '1', '2024-12-19', '', '12', '2024-12-19 10:06:14', '2024-12-19 10:06:14');
INSERT INTO `attendances` VALUES ('3485', '31', '1036', '17', '1', '2024-12-19', '', '12', '2024-12-19 10:06:14', '2024-12-19 10:06:14');
INSERT INTO `attendances` VALUES ('3486', '31', '1038', '17', '1', '2024-12-19', '', '12', '2024-12-19 10:06:14', '2024-12-19 10:06:14');
INSERT INTO `attendances` VALUES ('3487', '31', '1040', '17', '1', '2024-12-19', '', '12', '2024-12-19 10:06:14', '2024-12-19 10:06:14');
INSERT INTO `attendances` VALUES ('3488', '31', '1042', '17', '1', '2024-12-19', '', '12', '2024-12-19 10:06:14', '2024-12-19 10:06:14');
INSERT INTO `attendances` VALUES ('3489', '31', '1044', '17', '1', '2024-12-19', '', '12', '2024-12-19 10:06:14', '2024-12-19 10:06:14');
INSERT INTO `attendances` VALUES ('3490', '31', '1046', '17', '1', '2024-12-19', '', '12', '2024-12-19 10:06:14', '2024-12-19 10:06:14');
INSERT INTO `attendances` VALUES ('3491', '31', '1048', '17', '1', '2024-12-19', '', '12', '2024-12-19 10:06:14', '2024-12-19 10:06:14');
INSERT INTO `attendances` VALUES ('3492', '31', '1050', '17', '1', '2024-12-19', '', '12', '2024-12-19 10:06:14', '2024-12-19 10:06:14');
INSERT INTO `attendances` VALUES ('3493', '31', '1052', '17', '1', '2024-12-19', '', '12', '2024-12-19 10:06:14', '2024-12-19 10:06:14');
INSERT INTO `attendances` VALUES ('3494', '31', '1054', '17', '1', '2024-12-19', '', '12', '2024-12-19 10:06:14', '2024-12-19 10:06:14');
INSERT INTO `attendances` VALUES ('3495', '31', '1056', '17', '0', '2024-12-19', '', '12', '2024-12-19 10:06:14', '2024-12-19 10:41:34');
INSERT INTO `attendances` VALUES ('3496', '31', '1058', '17', '0', '2024-12-19', '', '12', '2024-12-19 10:06:14', '2024-12-19 10:41:34');
INSERT INTO `attendances` VALUES ('3497', '31', '1060', '17', '1', '2024-12-19', '', '12', '2024-12-19 10:06:14', '2024-12-19 10:06:14');
INSERT INTO `attendances` VALUES ('3498', '31', '1062', '17', '1', '2024-12-19', '', '12', '2024-12-19 10:06:14', '2024-12-19 10:06:14');
INSERT INTO `attendances` VALUES ('3499', '55', '331', '17', '1', '2024-12-20', '', '12', '2024-12-20 06:21:35', '2024-12-20 12:27:50');
INSERT INTO `attendances` VALUES ('3500', '55', '349', '17', '1', '2024-12-20', '', '12', '2024-12-20 06:21:35', '2024-12-20 12:27:50');
INSERT INTO `attendances` VALUES ('3501', '55', '351', '17', '1', '2024-12-20', '', '12', '2024-12-20 06:21:35', '2024-12-20 06:21:35');
INSERT INTO `attendances` VALUES ('3502', '55', '353', '17', '0', '2024-12-20', '', '12', '2024-12-20 06:21:35', '2024-12-20 12:28:05');
INSERT INTO `attendances` VALUES ('3503', '55', '355', '17', '1', '2024-12-20', '', '12', '2024-12-20 06:21:35', '2024-12-20 06:21:35');
INSERT INTO `attendances` VALUES ('3504', '55', '357', '17', '1', '2024-12-20', '', '12', '2024-12-20 06:21:35', '2024-12-20 06:21:35');
INSERT INTO `attendances` VALUES ('3505', '55', '359', '17', '1', '2024-12-20', '', '12', '2024-12-20 06:21:35', '2024-12-20 06:21:35');
INSERT INTO `attendances` VALUES ('3506', '55', '361', '17', '1', '2024-12-20', '', '12', '2024-12-20 06:21:35', '2024-12-20 06:21:35');
INSERT INTO `attendances` VALUES ('3507', '55', '363', '17', '1', '2024-12-20', '', '12', '2024-12-20 06:21:35', '2024-12-20 06:21:35');
INSERT INTO `attendances` VALUES ('3508', '55', '365', '17', '1', '2024-12-20', '', '12', '2024-12-20 06:21:35', '2024-12-20 06:21:35');
INSERT INTO `attendances` VALUES ('3509', '55', '367', '17', '1', '2024-12-20', '', '12', '2024-12-20 06:21:35', '2024-12-20 06:21:35');
INSERT INTO `attendances` VALUES ('3510', '21', '369', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:53', '2024-12-20 06:26:53');
INSERT INTO `attendances` VALUES ('3511', '21', '371', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:53', '2024-12-20 06:26:53');
INSERT INTO `attendances` VALUES ('3512', '21', '373', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:53', '2024-12-20 06:26:53');
INSERT INTO `attendances` VALUES ('3513', '21', '375', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:53', '2024-12-20 06:26:53');
INSERT INTO `attendances` VALUES ('3514', '21', '377', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:53', '2024-12-20 06:26:53');
INSERT INTO `attendances` VALUES ('3515', '21', '379', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:53', '2024-12-20 06:26:53');
INSERT INTO `attendances` VALUES ('3516', '21', '381', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:53', '2024-12-20 06:26:53');
INSERT INTO `attendances` VALUES ('3517', '21', '383', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:53', '2024-12-20 06:26:53');
INSERT INTO `attendances` VALUES ('3518', '21', '385', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:53', '2024-12-20 06:26:53');
INSERT INTO `attendances` VALUES ('3519', '21', '387', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:53', '2024-12-20 06:26:53');
INSERT INTO `attendances` VALUES ('3520', '21', '389', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:53', '2024-12-20 06:26:53');
INSERT INTO `attendances` VALUES ('3521', '21', '391', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:53', '2024-12-20 06:26:53');
INSERT INTO `attendances` VALUES ('3522', '21', '393', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:53', '2024-12-20 06:26:53');
INSERT INTO `attendances` VALUES ('3523', '21', '395', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:53', '2024-12-20 06:26:53');
INSERT INTO `attendances` VALUES ('3524', '21', '397', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:53', '2024-12-20 06:26:53');
INSERT INTO `attendances` VALUES ('3525', '21', '399', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:53', '2024-12-20 06:26:53');
INSERT INTO `attendances` VALUES ('3526', '21', '401', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:53', '2024-12-20 06:26:53');
INSERT INTO `attendances` VALUES ('3527', '21', '403', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:53', '2024-12-20 06:26:53');
INSERT INTO `attendances` VALUES ('3528', '21', '405', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:53', '2024-12-20 06:26:53');
INSERT INTO `attendances` VALUES ('3529', '21', '407', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:53', '2024-12-20 06:26:53');
INSERT INTO `attendances` VALUES ('3530', '21', '409', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:53', '2024-12-20 06:26:53');
INSERT INTO `attendances` VALUES ('3531', '21', '411', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:53', '2024-12-20 06:26:53');
INSERT INTO `attendances` VALUES ('3532', '21', '413', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:53', '2024-12-20 06:26:53');
INSERT INTO `attendances` VALUES ('3533', '21', '415', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:53', '2024-12-20 06:26:53');
INSERT INTO `attendances` VALUES ('3534', '21', '417', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:53', '2024-12-20 06:26:53');
INSERT INTO `attendances` VALUES ('3535', '21', '419', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:53', '2024-12-20 06:26:53');
INSERT INTO `attendances` VALUES ('3536', '21', '421', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:53', '2024-12-20 06:26:53');
INSERT INTO `attendances` VALUES ('3537', '21', '423', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:53', '2024-12-20 06:26:53');
INSERT INTO `attendances` VALUES ('3538', '21', '425', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:53', '2024-12-20 06:26:53');
INSERT INTO `attendances` VALUES ('3539', '21', '427', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:53', '2024-12-20 06:26:53');
INSERT INTO `attendances` VALUES ('3540', '21', '429', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:53', '2024-12-20 06:26:53');
INSERT INTO `attendances` VALUES ('3541', '21', '431', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:53', '2024-12-20 06:26:53');
INSERT INTO `attendances` VALUES ('3542', '21', '433', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:53', '2024-12-20 06:26:53');
INSERT INTO `attendances` VALUES ('3543', '21', '435', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:54', '2024-12-20 06:26:54');
INSERT INTO `attendances` VALUES ('3544', '21', '437', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:54', '2024-12-20 06:26:54');
INSERT INTO `attendances` VALUES ('3545', '21', '439', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:54', '2024-12-20 06:26:54');
INSERT INTO `attendances` VALUES ('3546', '21', '441', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:54', '2024-12-20 06:26:54');
INSERT INTO `attendances` VALUES ('3547', '21', '443', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:54', '2024-12-20 06:26:54');
INSERT INTO `attendances` VALUES ('3548', '21', '445', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:54', '2024-12-20 06:26:54');
INSERT INTO `attendances` VALUES ('3549', '21', '447', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:54', '2024-12-20 06:26:54');
INSERT INTO `attendances` VALUES ('3550', '21', '449', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:54', '2024-12-20 06:26:54');
INSERT INTO `attendances` VALUES ('3551', '21', '451', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:54', '2024-12-20 06:26:54');
INSERT INTO `attendances` VALUES ('3552', '21', '453', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:54', '2024-12-20 06:26:54');
INSERT INTO `attendances` VALUES ('3553', '21', '455', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:54', '2024-12-20 06:26:54');
INSERT INTO `attendances` VALUES ('3554', '21', '457', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:54', '2024-12-20 06:26:54');
INSERT INTO `attendances` VALUES ('3555', '21', '459', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:54', '2024-12-20 06:26:54');
INSERT INTO `attendances` VALUES ('3556', '21', '461', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:54', '2024-12-20 06:26:54');
INSERT INTO `attendances` VALUES ('3557', '21', '463', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:54', '2024-12-20 06:26:54');
INSERT INTO `attendances` VALUES ('3558', '21', '465', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:54', '2024-12-20 06:26:54');
INSERT INTO `attendances` VALUES ('3559', '21', '467', '17', '3', '2024-12-20', '', '12', '2024-12-20 06:26:54', '2024-12-20 06:26:54');
INSERT INTO `attendances` VALUES ('3560', '31', '341', '17', '1', '2024-12-20', '', '12', '2024-12-20 12:26:54', '2024-12-22 07:23:10');
INSERT INTO `attendances` VALUES ('3561', '31', '1004', '17', '1', '2024-12-20', '', '12', '2024-12-20 12:26:54', '2024-12-22 07:23:10');
INSERT INTO `attendances` VALUES ('3562', '31', '1006', '17', '1', '2024-12-20', '', '12', '2024-12-20 12:26:54', '2024-12-20 12:26:54');
INSERT INTO `attendances` VALUES ('3563', '31', '1008', '17', '1', '2024-12-20', '', '12', '2024-12-20 12:26:54', '2024-12-20 12:26:54');
INSERT INTO `attendances` VALUES ('3564', '31', '1010', '17', '0', '2024-12-20', '', '12', '2024-12-20 12:26:54', '2024-12-20 12:26:54');
INSERT INTO `attendances` VALUES ('3565', '31', '1012', '17', '0', '2024-12-20', '', '12', '2024-12-20 12:26:54', '2024-12-20 19:16:42');
INSERT INTO `attendances` VALUES ('3566', '31', '1014', '17', '1', '2024-12-20', '', '12', '2024-12-20 12:26:54', '2024-12-20 12:26:54');
INSERT INTO `attendances` VALUES ('3567', '31', '1016', '17', '1', '2024-12-20', '', '12', '2024-12-20 12:26:54', '2024-12-20 12:26:54');
INSERT INTO `attendances` VALUES ('3568', '31', '1018', '17', '1', '2024-12-20', '', '12', '2024-12-20 12:26:54', '2024-12-20 12:26:54');
INSERT INTO `attendances` VALUES ('3569', '31', '1020', '17', '1', '2024-12-20', '', '12', '2024-12-20 12:26:54', '2024-12-20 12:26:54');
INSERT INTO `attendances` VALUES ('3570', '31', '1022', '17', '0', '2024-12-20', '', '12', '2024-12-20 12:26:54', '2024-12-20 12:26:54');
INSERT INTO `attendances` VALUES ('3571', '31', '1024', '17', '1', '2024-12-20', '', '12', '2024-12-20 12:26:54', '2024-12-20 12:26:54');
INSERT INTO `attendances` VALUES ('3572', '31', '1026', '17', '1', '2024-12-20', '', '12', '2024-12-20 12:26:54', '2024-12-20 12:26:54');
INSERT INTO `attendances` VALUES ('3573', '31', '1028', '17', '1', '2024-12-20', '', '12', '2024-12-20 12:26:54', '2024-12-20 12:26:54');
INSERT INTO `attendances` VALUES ('3574', '31', '1030', '17', '1', '2024-12-20', '', '12', '2024-12-20 12:26:54', '2024-12-20 12:26:54');
INSERT INTO `attendances` VALUES ('3575', '31', '1032', '17', '1', '2024-12-20', '', '12', '2024-12-20 12:26:54', '2024-12-20 12:26:54');
INSERT INTO `attendances` VALUES ('3576', '31', '1034', '17', '1', '2024-12-20', '', '12', '2024-12-20 12:26:54', '2024-12-20 12:26:54');
INSERT INTO `attendances` VALUES ('3577', '31', '1036', '17', '1', '2024-12-20', '', '12', '2024-12-20 12:26:54', '2024-12-20 12:26:54');
INSERT INTO `attendances` VALUES ('3578', '31', '1038', '17', '1', '2024-12-20', '', '12', '2024-12-20 12:26:54', '2024-12-20 12:26:54');
INSERT INTO `attendances` VALUES ('3579', '31', '1040', '17', '1', '2024-12-20', '', '12', '2024-12-20 12:26:54', '2024-12-20 12:26:54');
INSERT INTO `attendances` VALUES ('3580', '31', '1042', '17', '1', '2024-12-20', '', '12', '2024-12-20 12:26:54', '2024-12-20 12:26:54');
INSERT INTO `attendances` VALUES ('3581', '31', '1044', '17', '1', '2024-12-20', '', '12', '2024-12-20 12:26:54', '2024-12-20 12:26:54');
INSERT INTO `attendances` VALUES ('3582', '31', '1046', '17', '1', '2024-12-20', '', '12', '2024-12-20 12:26:54', '2024-12-20 12:26:54');
INSERT INTO `attendances` VALUES ('3583', '31', '1048', '17', '1', '2024-12-20', '', '12', '2024-12-20 12:26:54', '2024-12-20 12:26:54');
INSERT INTO `attendances` VALUES ('3584', '31', '1050', '17', '1', '2024-12-20', '', '12', '2024-12-20 12:26:54', '2024-12-20 12:26:54');
INSERT INTO `attendances` VALUES ('3585', '31', '1052', '17', '1', '2024-12-20', '', '12', '2024-12-20 12:26:54', '2024-12-20 12:26:54');
INSERT INTO `attendances` VALUES ('3586', '31', '1054', '17', '1', '2024-12-20', '', '12', '2024-12-20 12:26:54', '2024-12-20 12:26:54');
INSERT INTO `attendances` VALUES ('3587', '31', '1056', '17', '1', '2024-12-20', '', '12', '2024-12-20 12:26:54', '2024-12-20 12:26:54');
INSERT INTO `attendances` VALUES ('3588', '31', '1058', '17', '1', '2024-12-20', '', '12', '2024-12-20 12:26:54', '2024-12-20 12:26:54');
INSERT INTO `attendances` VALUES ('3589', '31', '1060', '17', '1', '2024-12-20', '', '12', '2024-12-20 12:26:54', '2024-12-20 12:26:54');
INSERT INTO `attendances` VALUES ('3590', '31', '1062', '17', '1', '2024-12-20', '', '12', '2024-12-20 12:26:54', '2024-12-22 07:23:10');
INSERT INTO `attendances` VALUES ('3591', '21', '371', '17', '1', '2024-12-21', '', '12', '2024-12-21 07:29:07', '2024-12-21 07:29:07');
INSERT INTO `attendances` VALUES ('3592', '21', '377', '17', '1', '2024-12-21', '', '12', '2024-12-21 07:29:07', '2024-12-21 07:29:07');
INSERT INTO `attendances` VALUES ('3593', '21', '381', '17', '1', '2024-12-21', '', '12', '2024-12-21 07:29:07', '2024-12-21 07:29:07');
INSERT INTO `attendances` VALUES ('3594', '21', '387', '17', '1', '2024-12-21', '', '12', '2024-12-21 07:29:07', '2024-12-21 07:29:07');
INSERT INTO `attendances` VALUES ('3595', '21', '403', '17', '1', '2024-12-21', '', '12', '2024-12-21 07:29:07', '2024-12-21 07:29:07');
INSERT INTO `attendances` VALUES ('3596', '21', '407', '17', '1', '2024-12-21', '', '12', '2024-12-21 07:29:07', '2024-12-21 07:29:07');
INSERT INTO `attendances` VALUES ('3597', '21', '409', '17', '1', '2024-12-21', '', '12', '2024-12-21 07:29:07', '2024-12-21 07:29:07');
INSERT INTO `attendances` VALUES ('3598', '21', '417', '17', '1', '2024-12-21', '', '12', '2024-12-21 07:29:07', '2024-12-21 07:29:07');
INSERT INTO `attendances` VALUES ('3599', '21', '419', '17', '1', '2024-12-21', '', '12', '2024-12-21 07:29:07', '2024-12-21 07:29:07');
INSERT INTO `attendances` VALUES ('3600', '21', '421', '17', '1', '2024-12-21', '', '12', '2024-12-21 07:29:07', '2024-12-21 07:29:07');
INSERT INTO `attendances` VALUES ('3601', '21', '423', '17', '1', '2024-12-21', '', '12', '2024-12-21 07:29:07', '2024-12-21 07:29:07');
INSERT INTO `attendances` VALUES ('3602', '21', '425', '17', '1', '2024-12-21', '', '12', '2024-12-21 07:29:07', '2024-12-21 07:29:07');
INSERT INTO `attendances` VALUES ('3603', '21', '427', '17', '1', '2024-12-21', '', '12', '2024-12-21 07:29:07', '2024-12-21 07:29:07');
INSERT INTO `attendances` VALUES ('3604', '21', '429', '17', '1', '2024-12-21', '', '12', '2024-12-21 07:29:07', '2024-12-21 07:29:07');
INSERT INTO `attendances` VALUES ('3605', '21', '431', '17', '1', '2024-12-21', '', '12', '2024-12-21 07:29:07', '2024-12-21 07:29:07');
INSERT INTO `attendances` VALUES ('3606', '21', '433', '17', '1', '2024-12-21', '', '12', '2024-12-21 07:29:07', '2024-12-21 07:29:07');
INSERT INTO `attendances` VALUES ('3607', '21', '435', '17', '1', '2024-12-21', '', '12', '2024-12-21 07:29:07', '2024-12-21 07:29:07');
INSERT INTO `attendances` VALUES ('3608', '21', '437', '17', '1', '2024-12-21', '', '12', '2024-12-21 07:29:07', '2024-12-21 07:29:07');
INSERT INTO `attendances` VALUES ('3609', '21', '439', '17', '1', '2024-12-21', '', '12', '2024-12-21 07:29:07', '2024-12-21 07:29:07');
INSERT INTO `attendances` VALUES ('3610', '21', '441', '17', '1', '2024-12-21', '', '12', '2024-12-21 07:29:07', '2024-12-21 07:29:07');
INSERT INTO `attendances` VALUES ('3611', '21', '443', '17', '1', '2024-12-21', '', '12', '2024-12-21 07:29:07', '2024-12-21 07:29:07');
INSERT INTO `attendances` VALUES ('3612', '21', '445', '17', '1', '2024-12-21', '', '12', '2024-12-21 07:29:07', '2024-12-21 07:29:07');
INSERT INTO `attendances` VALUES ('3613', '21', '447', '17', '1', '2024-12-21', '', '12', '2024-12-21 07:29:07', '2024-12-21 07:29:07');
INSERT INTO `attendances` VALUES ('3614', '21', '449', '17', '1', '2024-12-21', '', '12', '2024-12-21 07:29:07', '2024-12-21 07:29:07');
INSERT INTO `attendances` VALUES ('3615', '21', '451', '17', '0', '2024-12-21', '', '12', '2024-12-21 07:29:07', '2024-12-21 07:29:07');
INSERT INTO `attendances` VALUES ('3616', '21', '453', '17', '1', '2024-12-21', '', '12', '2024-12-21 07:29:07', '2024-12-21 07:29:07');
INSERT INTO `attendances` VALUES ('3617', '21', '455', '17', '1', '2024-12-21', '', '12', '2024-12-21 07:29:07', '2024-12-21 07:29:07');
INSERT INTO `attendances` VALUES ('3618', '21', '457', '17', '1', '2024-12-21', '', '12', '2024-12-21 07:29:07', '2024-12-21 07:29:07');
INSERT INTO `attendances` VALUES ('3619', '21', '459', '17', '1', '2024-12-21', '', '12', '2024-12-21 07:29:07', '2024-12-21 07:29:07');
INSERT INTO `attendances` VALUES ('3620', '21', '461', '17', '1', '2024-12-21', '', '12', '2024-12-21 07:29:07', '2024-12-21 07:29:07');
INSERT INTO `attendances` VALUES ('3621', '21', '463', '17', '1', '2024-12-21', '', '12', '2024-12-21 07:29:07', '2024-12-21 07:29:07');
INSERT INTO `attendances` VALUES ('3622', '21', '465', '17', '1', '2024-12-21', '', '12', '2024-12-21 07:29:07', '2024-12-21 07:29:07');
INSERT INTO `attendances` VALUES ('3623', '21', '467', '17', '0', '2024-12-21', '', '12', '2024-12-21 07:29:07', '2024-12-21 07:29:07');
INSERT INTO `attendances` VALUES ('3624', '31', '341', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:02', '2024-12-21 21:58:18');
INSERT INTO `attendances` VALUES ('3625', '31', '1004', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:02', '2024-12-21 21:15:02');
INSERT INTO `attendances` VALUES ('3626', '31', '1006', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:02', '2024-12-21 21:58:18');
INSERT INTO `attendances` VALUES ('3627', '31', '1008', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:02', '2024-12-21 21:15:02');
INSERT INTO `attendances` VALUES ('3628', '31', '1010', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:02', '2024-12-21 21:15:02');
INSERT INTO `attendances` VALUES ('3629', '31', '1012', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:02', '2024-12-21 21:15:02');
INSERT INTO `attendances` VALUES ('3630', '31', '1014', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:02', '2024-12-21 21:15:02');
INSERT INTO `attendances` VALUES ('3631', '31', '1016', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:02', '2024-12-21 21:15:02');
INSERT INTO `attendances` VALUES ('3632', '31', '1018', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:02', '2024-12-21 21:15:02');
INSERT INTO `attendances` VALUES ('3633', '31', '1020', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:02', '2024-12-21 21:15:02');
INSERT INTO `attendances` VALUES ('3634', '31', '1022', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:02', '2024-12-21 21:15:02');
INSERT INTO `attendances` VALUES ('3635', '31', '1024', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:02', '2024-12-21 21:15:02');
INSERT INTO `attendances` VALUES ('3636', '31', '1026', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:02', '2024-12-21 21:15:02');
INSERT INTO `attendances` VALUES ('3637', '31', '1028', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:02', '2024-12-21 21:15:02');
INSERT INTO `attendances` VALUES ('3638', '31', '1030', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:02', '2024-12-21 21:15:02');
INSERT INTO `attendances` VALUES ('3639', '31', '1032', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:02', '2024-12-21 21:15:02');
INSERT INTO `attendances` VALUES ('3640', '31', '1034', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:02', '2024-12-21 21:15:02');
INSERT INTO `attendances` VALUES ('3641', '31', '1036', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:02', '2024-12-21 21:15:02');
INSERT INTO `attendances` VALUES ('3642', '31', '1038', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:02', '2024-12-21 21:15:02');
INSERT INTO `attendances` VALUES ('3643', '31', '1040', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:02', '2024-12-21 21:15:02');
INSERT INTO `attendances` VALUES ('3644', '31', '1042', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:02', '2024-12-21 21:15:02');
INSERT INTO `attendances` VALUES ('3645', '31', '1044', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:02', '2024-12-21 21:15:02');
INSERT INTO `attendances` VALUES ('3646', '31', '1046', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:02', '2024-12-21 21:15:02');
INSERT INTO `attendances` VALUES ('3647', '31', '1048', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:02', '2024-12-21 21:15:02');
INSERT INTO `attendances` VALUES ('3648', '31', '1050', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:02', '2024-12-21 21:15:02');
INSERT INTO `attendances` VALUES ('3649', '31', '1052', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:02', '2024-12-21 21:15:02');
INSERT INTO `attendances` VALUES ('3650', '31', '1054', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:02', '2024-12-21 21:15:02');
INSERT INTO `attendances` VALUES ('3651', '31', '1056', '17', '0', '2024-12-21', '', '12', '2024-12-21 21:15:02', '2024-12-21 21:15:02');
INSERT INTO `attendances` VALUES ('3652', '31', '1058', '17', '0', '2024-12-21', '', '12', '2024-12-21 21:15:02', '2024-12-21 21:15:02');
INSERT INTO `attendances` VALUES ('3653', '31', '1060', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:02', '2024-12-21 21:15:02');
INSERT INTO `attendances` VALUES ('3654', '31', '1062', '17', '0', '2024-12-21', '', '12', '2024-12-21 21:15:02', '2024-12-21 21:15:02');
INSERT INTO `attendances` VALUES ('3655', '55', '331', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:10', '2024-12-21 21:15:10');
INSERT INTO `attendances` VALUES ('3656', '55', '349', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:10', '2024-12-21 21:15:10');
INSERT INTO `attendances` VALUES ('3657', '55', '351', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:10', '2024-12-21 21:15:10');
INSERT INTO `attendances` VALUES ('3658', '55', '353', '17', '0', '2024-12-21', '', '12', '2024-12-21 21:15:10', '2024-12-21 21:15:10');
INSERT INTO `attendances` VALUES ('3659', '55', '355', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:10', '2024-12-21 21:15:10');
INSERT INTO `attendances` VALUES ('3660', '55', '357', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:10', '2024-12-21 21:15:10');
INSERT INTO `attendances` VALUES ('3661', '55', '359', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:10', '2024-12-21 21:15:10');
INSERT INTO `attendances` VALUES ('3662', '55', '361', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:10', '2024-12-21 21:15:10');
INSERT INTO `attendances` VALUES ('3663', '55', '363', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:10', '2024-12-21 21:15:10');
INSERT INTO `attendances` VALUES ('3664', '55', '365', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:10', '2024-12-21 21:15:10');
INSERT INTO `attendances` VALUES ('3665', '55', '367', '17', '1', '2024-12-21', '', '12', '2024-12-21 21:15:10', '2024-12-21 21:15:10');
INSERT INTO `attendances` VALUES ('3666', '31', '341', '17', '0', '2024-12-23', '', '12', '2024-12-23 11:54:45', '2024-12-23 11:54:45');
INSERT INTO `attendances` VALUES ('3667', '31', '1004', '17', '0', '2024-12-23', '', '12', '2024-12-23 11:54:45', '2024-12-23 11:54:45');
INSERT INTO `attendances` VALUES ('3668', '31', '1006', '17', '1', '2024-12-23', '', '12', '2024-12-23 11:54:45', '2024-12-23 11:54:45');
INSERT INTO `attendances` VALUES ('3669', '31', '1008', '17', '1', '2024-12-23', '', '12', '2024-12-23 11:54:45', '2024-12-23 11:54:45');
INSERT INTO `attendances` VALUES ('3670', '31', '1010', '17', '1', '2024-12-23', '', '12', '2024-12-23 11:54:45', '2024-12-23 11:54:45');
INSERT INTO `attendances` VALUES ('3671', '31', '1012', '17', '1', '2024-12-23', '', '12', '2024-12-23 11:54:46', '2024-12-23 11:54:46');
INSERT INTO `attendances` VALUES ('3672', '31', '1014', '17', '1', '2024-12-23', '', '12', '2024-12-23 11:54:46', '2024-12-23 11:54:46');
INSERT INTO `attendances` VALUES ('3673', '31', '1016', '17', '1', '2024-12-23', '', '12', '2024-12-23 11:54:46', '2024-12-23 11:54:46');
INSERT INTO `attendances` VALUES ('3674', '31', '1018', '17', '1', '2024-12-23', '', '12', '2024-12-23 11:54:46', '2024-12-23 11:54:46');
INSERT INTO `attendances` VALUES ('3675', '31', '1020', '17', '1', '2024-12-23', '', '12', '2024-12-23 11:54:46', '2024-12-23 11:54:46');
INSERT INTO `attendances` VALUES ('3676', '31', '1022', '17', '1', '2024-12-23', '', '12', '2024-12-23 11:54:46', '2024-12-23 11:54:46');
INSERT INTO `attendances` VALUES ('3677', '31', '1024', '17', '1', '2024-12-23', '', '12', '2024-12-23 11:54:46', '2024-12-23 11:54:46');
INSERT INTO `attendances` VALUES ('3678', '31', '1026', '17', '1', '2024-12-23', '', '12', '2024-12-23 11:54:46', '2024-12-23 11:54:46');
INSERT INTO `attendances` VALUES ('3679', '31', '1028', '17', '1', '2024-12-23', '', '12', '2024-12-23 11:54:46', '2024-12-23 11:54:46');
INSERT INTO `attendances` VALUES ('3680', '31', '1030', '17', '1', '2024-12-23', '', '12', '2024-12-23 11:54:46', '2024-12-23 11:54:46');
INSERT INTO `attendances` VALUES ('3681', '31', '1032', '17', '1', '2024-12-23', '', '12', '2024-12-23 11:54:46', '2024-12-23 11:54:46');
INSERT INTO `attendances` VALUES ('3682', '31', '1034', '17', '1', '2024-12-23', '', '12', '2024-12-23 11:54:46', '2024-12-23 11:54:46');
INSERT INTO `attendances` VALUES ('3683', '31', '1036', '17', '1', '2024-12-23', '', '12', '2024-12-23 11:54:46', '2024-12-23 11:54:46');
INSERT INTO `attendances` VALUES ('3684', '31', '1038', '17', '1', '2024-12-23', '', '12', '2024-12-23 11:54:46', '2024-12-23 11:54:46');
INSERT INTO `attendances` VALUES ('3685', '31', '1040', '17', '1', '2024-12-23', '', '12', '2024-12-23 11:54:46', '2024-12-23 11:54:46');
INSERT INTO `attendances` VALUES ('3686', '31', '1042', '17', '1', '2024-12-23', '', '12', '2024-12-23 11:54:46', '2024-12-23 11:54:46');
INSERT INTO `attendances` VALUES ('3687', '31', '1044', '17', '1', '2024-12-23', '', '12', '2024-12-23 11:54:46', '2024-12-23 11:54:46');
INSERT INTO `attendances` VALUES ('3688', '31', '1046', '17', '1', '2024-12-23', '', '12', '2024-12-23 11:54:46', '2024-12-23 11:54:46');
INSERT INTO `attendances` VALUES ('3689', '31', '1048', '17', '1', '2024-12-23', '', '12', '2024-12-23 11:54:46', '2024-12-23 11:54:46');
INSERT INTO `attendances` VALUES ('3690', '31', '1050', '17', '1', '2024-12-23', '', '12', '2024-12-23 11:54:46', '2024-12-23 11:54:46');
INSERT INTO `attendances` VALUES ('3691', '31', '1052', '17', '1', '2024-12-23', '', '12', '2024-12-23 11:54:46', '2024-12-23 11:54:46');
INSERT INTO `attendances` VALUES ('3692', '31', '1054', '17', '1', '2024-12-23', '', '12', '2024-12-23 11:54:46', '2024-12-23 11:54:46');
INSERT INTO `attendances` VALUES ('3693', '31', '1056', '17', '1', '2024-12-23', '', '12', '2024-12-23 11:54:46', '2024-12-23 11:54:46');
INSERT INTO `attendances` VALUES ('3694', '31', '1058', '17', '0', '2024-12-23', '', '12', '2024-12-23 11:54:46', '2024-12-23 11:54:46');
INSERT INTO `attendances` VALUES ('3695', '31', '1060', '17', '1', '2024-12-23', '', '12', '2024-12-23 11:54:46', '2024-12-23 11:54:46');
INSERT INTO `attendances` VALUES ('3696', '31', '1062', '17', '1', '2024-12-23', '', '12', '2024-12-23 11:54:46', '2024-12-23 11:54:46');
INSERT INTO `attendances` VALUES ('3697', '55', '331', '17', '0', '2024-12-23', '', '12', '2024-12-23 11:55:16', '2024-12-23 11:55:16');
INSERT INTO `attendances` VALUES ('3698', '55', '349', '17', '1', '2024-12-23', '', '12', '2024-12-23 11:55:16', '2024-12-23 11:55:16');
INSERT INTO `attendances` VALUES ('3699', '55', '351', '17', '0', '2024-12-23', '', '12', '2024-12-23 11:55:16', '2024-12-23 11:55:16');
INSERT INTO `attendances` VALUES ('3700', '55', '353', '17', '1', '2024-12-23', '', '12', '2024-12-23 11:55:16', '2024-12-23 11:55:16');
INSERT INTO `attendances` VALUES ('3701', '55', '355', '17', '1', '2024-12-23', '', '12', '2024-12-23 11:55:16', '2024-12-23 11:55:16');
INSERT INTO `attendances` VALUES ('3702', '55', '357', '17', '1', '2024-12-23', '', '12', '2024-12-23 11:55:16', '2024-12-23 11:55:16');
INSERT INTO `attendances` VALUES ('3703', '55', '359', '17', '1', '2024-12-23', '', '12', '2024-12-23 11:55:16', '2024-12-23 11:55:16');
INSERT INTO `attendances` VALUES ('3704', '55', '361', '17', '1', '2024-12-23', '', '12', '2024-12-23 11:55:16', '2024-12-23 11:55:16');
INSERT INTO `attendances` VALUES ('3705', '55', '363', '17', '1', '2024-12-23', '', '12', '2024-12-23 11:55:16', '2024-12-23 11:55:16');
INSERT INTO `attendances` VALUES ('3706', '55', '365', '17', '1', '2024-12-23', '', '12', '2024-12-23 11:55:16', '2024-12-23 11:55:16');
INSERT INTO `attendances` VALUES ('3707', '55', '367', '17', '1', '2024-12-23', '', '12', '2024-12-23 11:55:16', '2024-12-23 11:55:16');
INSERT INTO `attendances` VALUES ('3708', '31', '341', '17', '0', '2024-12-24', '', '12', '2024-12-24 05:11:41', '2024-12-24 22:58:27');
INSERT INTO `attendances` VALUES ('3709', '31', '1004', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:41', '2024-12-24 05:11:41');
INSERT INTO `attendances` VALUES ('3710', '31', '1006', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:41', '2024-12-24 05:11:41');
INSERT INTO `attendances` VALUES ('3711', '31', '1008', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:41', '2024-12-24 05:11:41');
INSERT INTO `attendances` VALUES ('3712', '31', '1010', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:41', '2024-12-24 05:11:41');
INSERT INTO `attendances` VALUES ('3713', '31', '1012', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:41', '2024-12-24 22:58:17');
INSERT INTO `attendances` VALUES ('3714', '31', '1014', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:41', '2024-12-24 05:11:41');
INSERT INTO `attendances` VALUES ('3715', '31', '1016', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:41', '2024-12-24 05:11:41');
INSERT INTO `attendances` VALUES ('3716', '31', '1018', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:41', '2024-12-24 05:11:41');
INSERT INTO `attendances` VALUES ('3717', '31', '1020', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:41', '2024-12-24 05:11:41');
INSERT INTO `attendances` VALUES ('3718', '31', '1022', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:41', '2024-12-24 05:11:41');
INSERT INTO `attendances` VALUES ('3719', '31', '1024', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:41', '2024-12-24 05:11:41');
INSERT INTO `attendances` VALUES ('3720', '31', '1026', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:41', '2024-12-24 05:11:41');
INSERT INTO `attendances` VALUES ('3721', '31', '1028', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:41', '2024-12-24 05:11:41');
INSERT INTO `attendances` VALUES ('3722', '31', '1030', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:41', '2024-12-24 05:11:41');
INSERT INTO `attendances` VALUES ('3723', '31', '1032', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:41', '2024-12-24 05:11:41');
INSERT INTO `attendances` VALUES ('3724', '31', '1034', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:41', '2024-12-24 05:11:41');
INSERT INTO `attendances` VALUES ('3725', '31', '1036', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:41', '2024-12-24 05:11:41');
INSERT INTO `attendances` VALUES ('3726', '31', '1038', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:41', '2024-12-24 05:11:41');
INSERT INTO `attendances` VALUES ('3727', '31', '1040', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:41', '2024-12-24 05:11:41');
INSERT INTO `attendances` VALUES ('3728', '31', '1042', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:41', '2024-12-24 05:11:41');
INSERT INTO `attendances` VALUES ('3729', '31', '1044', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:41', '2024-12-24 05:11:41');
INSERT INTO `attendances` VALUES ('3730', '31', '1046', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:41', '2024-12-24 05:11:41');
INSERT INTO `attendances` VALUES ('3731', '31', '1048', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:41', '2024-12-24 05:11:41');
INSERT INTO `attendances` VALUES ('3732', '31', '1050', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:41', '2024-12-24 05:11:41');
INSERT INTO `attendances` VALUES ('3733', '31', '1052', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:41', '2024-12-24 05:11:41');
INSERT INTO `attendances` VALUES ('3734', '31', '1054', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:41', '2024-12-24 05:11:41');
INSERT INTO `attendances` VALUES ('3735', '31', '1056', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:41', '2024-12-24 05:11:41');
INSERT INTO `attendances` VALUES ('3736', '31', '1058', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:41', '2024-12-24 05:11:41');
INSERT INTO `attendances` VALUES ('3737', '31', '1060', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:41', '2024-12-24 05:11:41');
INSERT INTO `attendances` VALUES ('3738', '31', '1062', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:41', '2024-12-24 05:11:41');
INSERT INTO `attendances` VALUES ('3739', '55', '331', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:57', '2024-12-24 19:29:06');
INSERT INTO `attendances` VALUES ('3740', '55', '349', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:57', '2024-12-24 05:11:57');
INSERT INTO `attendances` VALUES ('3741', '55', '351', '17', '0', '2024-12-24', '', '12', '2024-12-24 05:11:57', '2024-12-24 05:11:57');
INSERT INTO `attendances` VALUES ('3742', '55', '353', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:57', '2024-12-24 05:11:57');
INSERT INTO `attendances` VALUES ('3743', '55', '355', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:57', '2024-12-24 05:11:57');
INSERT INTO `attendances` VALUES ('3744', '55', '357', '17', '0', '2024-12-24', '', '12', '2024-12-24 05:11:57', '2024-12-24 05:11:57');
INSERT INTO `attendances` VALUES ('3745', '55', '359', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:57', '2024-12-24 05:11:57');
INSERT INTO `attendances` VALUES ('3746', '55', '361', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:57', '2024-12-24 05:11:57');
INSERT INTO `attendances` VALUES ('3747', '55', '363', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:57', '2024-12-24 05:11:57');
INSERT INTO `attendances` VALUES ('3748', '55', '365', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:57', '2024-12-24 05:11:57');
INSERT INTO `attendances` VALUES ('3749', '55', '367', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:11:57', '2024-12-24 05:11:57');
INSERT INTO `attendances` VALUES ('3750', '21', '371', '17', '0', '2024-12-24', '', '12', '2024-12-24 05:14:05', '2024-12-24 05:14:05');
INSERT INTO `attendances` VALUES ('3751', '21', '377', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:14:05', '2024-12-24 05:14:05');
INSERT INTO `attendances` VALUES ('3752', '21', '381', '17', '0', '2024-12-24', '', '12', '2024-12-24 05:14:05', '2024-12-24 05:14:05');
INSERT INTO `attendances` VALUES ('3753', '21', '387', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:14:05', '2024-12-24 05:14:05');
INSERT INTO `attendances` VALUES ('3754', '21', '403', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:14:05', '2024-12-24 05:14:05');
INSERT INTO `attendances` VALUES ('3755', '21', '407', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:14:05', '2024-12-24 05:14:05');
INSERT INTO `attendances` VALUES ('3756', '21', '409', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:14:05', '2024-12-24 05:14:05');
INSERT INTO `attendances` VALUES ('3757', '21', '417', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:14:05', '2024-12-24 05:14:05');
INSERT INTO `attendances` VALUES ('3758', '21', '419', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:14:05', '2024-12-24 05:14:05');
INSERT INTO `attendances` VALUES ('3759', '21', '421', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:14:05', '2024-12-24 05:14:05');
INSERT INTO `attendances` VALUES ('3760', '21', '423', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:14:05', '2024-12-24 05:14:05');
INSERT INTO `attendances` VALUES ('3761', '21', '425', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:14:05', '2024-12-24 05:14:05');
INSERT INTO `attendances` VALUES ('3762', '21', '427', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:14:05', '2024-12-24 05:14:05');
INSERT INTO `attendances` VALUES ('3763', '21', '429', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:14:05', '2024-12-24 05:14:05');
INSERT INTO `attendances` VALUES ('3764', '21', '431', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:14:05', '2024-12-24 05:14:05');
INSERT INTO `attendances` VALUES ('3765', '21', '433', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:14:05', '2024-12-24 05:14:05');
INSERT INTO `attendances` VALUES ('3766', '21', '435', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:14:05', '2024-12-24 05:14:05');
INSERT INTO `attendances` VALUES ('3767', '21', '437', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:14:05', '2024-12-24 05:14:05');
INSERT INTO `attendances` VALUES ('3768', '21', '439', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:14:05', '2024-12-24 05:14:05');
INSERT INTO `attendances` VALUES ('3769', '21', '441', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:14:05', '2024-12-24 05:14:05');
INSERT INTO `attendances` VALUES ('3770', '21', '443', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:14:05', '2024-12-24 05:14:05');
INSERT INTO `attendances` VALUES ('3771', '21', '445', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:14:05', '2024-12-24 05:14:05');
INSERT INTO `attendances` VALUES ('3772', '21', '447', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:14:05', '2024-12-24 05:14:05');
INSERT INTO `attendances` VALUES ('3773', '21', '449', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:14:05', '2024-12-24 05:14:05');
INSERT INTO `attendances` VALUES ('3774', '21', '451', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:14:05', '2024-12-24 05:14:05');
INSERT INTO `attendances` VALUES ('3775', '21', '453', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:14:05', '2024-12-24 05:14:05');
INSERT INTO `attendances` VALUES ('3776', '21', '455', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:14:05', '2024-12-24 05:14:05');
INSERT INTO `attendances` VALUES ('3777', '21', '457', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:14:05', '2024-12-24 05:14:05');
INSERT INTO `attendances` VALUES ('3778', '21', '459', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:14:05', '2024-12-24 05:14:05');
INSERT INTO `attendances` VALUES ('3779', '21', '461', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:14:05', '2024-12-24 05:14:05');
INSERT INTO `attendances` VALUES ('3780', '21', '463', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:14:05', '2024-12-24 05:14:05');
INSERT INTO `attendances` VALUES ('3781', '21', '465', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:14:05', '2024-12-24 05:14:05');
INSERT INTO `attendances` VALUES ('3782', '21', '467', '17', '1', '2024-12-24', '', '12', '2024-12-24 05:14:05', '2024-12-24 05:14:05');
INSERT INTO `attendances` VALUES ('3783', '31', '341', '17', '0', '2024-12-25', '', '12', '2024-12-25 04:15:31', '2024-12-25 04:15:31');
INSERT INTO `attendances` VALUES ('3784', '31', '1004', '17', '0', '2024-12-25', '', '12', '2024-12-25 04:15:31', '2024-12-25 04:15:31');
INSERT INTO `attendances` VALUES ('3785', '31', '1006', '17', '0', '2024-12-25', '', '12', '2024-12-25 04:15:31', '2024-12-25 07:38:12');
INSERT INTO `attendances` VALUES ('3786', '31', '1008', '17', '1', '2024-12-25', '', '12', '2024-12-25 04:15:31', '2024-12-25 04:15:31');
INSERT INTO `attendances` VALUES ('3787', '31', '1010', '17', '1', '2024-12-25', '', '12', '2024-12-25 04:15:31', '2024-12-25 04:15:31');
INSERT INTO `attendances` VALUES ('3788', '31', '1012', '17', '1', '2024-12-25', '', '12', '2024-12-25 04:15:31', '2024-12-25 04:15:31');
INSERT INTO `attendances` VALUES ('3789', '31', '1014', '17', '1', '2024-12-25', '', '12', '2024-12-25 04:15:31', '2024-12-25 04:15:31');
INSERT INTO `attendances` VALUES ('3790', '31', '1016', '17', '1', '2024-12-25', '', '12', '2024-12-25 04:15:31', '2024-12-25 04:15:31');
INSERT INTO `attendances` VALUES ('3791', '31', '1018', '17', '1', '2024-12-25', '', '12', '2024-12-25 04:15:31', '2024-12-25 04:15:31');
INSERT INTO `attendances` VALUES ('3792', '31', '1020', '17', '1', '2024-12-25', '', '12', '2024-12-25 04:15:31', '2024-12-25 04:15:31');
INSERT INTO `attendances` VALUES ('3793', '31', '1022', '17', '1', '2024-12-25', '', '12', '2024-12-25 04:15:31', '2024-12-25 04:15:31');
INSERT INTO `attendances` VALUES ('3794', '31', '1024', '17', '1', '2024-12-25', '', '12', '2024-12-25 04:15:31', '2024-12-25 04:15:31');
INSERT INTO `attendances` VALUES ('3795', '31', '1026', '17', '1', '2024-12-25', '', '12', '2024-12-25 04:15:31', '2024-12-25 04:15:31');
INSERT INTO `attendances` VALUES ('3796', '31', '1028', '17', '1', '2024-12-25', '', '12', '2024-12-25 04:15:31', '2024-12-25 04:15:31');
INSERT INTO `attendances` VALUES ('3797', '31', '1030', '17', '1', '2024-12-25', '', '12', '2024-12-25 04:15:31', '2024-12-25 04:15:31');
INSERT INTO `attendances` VALUES ('3798', '31', '1032', '17', '1', '2024-12-25', '', '12', '2024-12-25 04:15:31', '2024-12-25 04:15:31');
INSERT INTO `attendances` VALUES ('3799', '31', '1034', '17', '1', '2024-12-25', '', '12', '2024-12-25 04:15:31', '2024-12-25 04:15:31');
INSERT INTO `attendances` VALUES ('3800', '31', '1036', '17', '1', '2024-12-25', '', '12', '2024-12-25 04:15:31', '2024-12-25 04:15:31');
INSERT INTO `attendances` VALUES ('3801', '31', '1038', '17', '1', '2024-12-25', '', '12', '2024-12-25 04:15:31', '2024-12-25 04:15:31');
INSERT INTO `attendances` VALUES ('3802', '31', '1040', '17', '1', '2024-12-25', '', '12', '2024-12-25 04:15:31', '2024-12-25 04:15:31');
INSERT INTO `attendances` VALUES ('3803', '31', '1042', '17', '1', '2024-12-25', '', '12', '2024-12-25 04:15:31', '2024-12-25 04:15:31');
INSERT INTO `attendances` VALUES ('3804', '31', '1044', '17', '1', '2024-12-25', '', '12', '2024-12-25 04:15:31', '2024-12-25 04:15:31');
INSERT INTO `attendances` VALUES ('3805', '31', '1046', '17', '1', '2024-12-25', '', '12', '2024-12-25 04:15:31', '2024-12-25 04:15:31');
INSERT INTO `attendances` VALUES ('3806', '31', '1048', '17', '1', '2024-12-25', '', '12', '2024-12-25 04:15:31', '2024-12-25 04:15:31');
INSERT INTO `attendances` VALUES ('3807', '31', '1050', '17', '1', '2024-12-25', '', '12', '2024-12-25 04:15:31', '2024-12-25 04:15:31');
INSERT INTO `attendances` VALUES ('3808', '31', '1052', '17', '1', '2024-12-25', '', '12', '2024-12-25 04:15:31', '2024-12-25 04:15:31');
INSERT INTO `attendances` VALUES ('3809', '31', '1054', '17', '1', '2024-12-25', '', '12', '2024-12-25 04:15:31', '2024-12-25 04:15:31');
INSERT INTO `attendances` VALUES ('3810', '31', '1056', '17', '1', '2024-12-25', '', '12', '2024-12-25 04:15:31', '2024-12-25 04:15:31');
INSERT INTO `attendances` VALUES ('3811', '31', '1058', '17', '1', '2024-12-25', '', '12', '2024-12-25 04:15:31', '2024-12-25 04:15:31');
INSERT INTO `attendances` VALUES ('3812', '31', '1060', '17', '1', '2024-12-25', '', '12', '2024-12-25 04:15:31', '2024-12-25 04:15:31');
INSERT INTO `attendances` VALUES ('3813', '31', '1062', '17', '1', '2024-12-25', '', '12', '2024-12-25 04:15:31', '2024-12-25 04:15:31');
INSERT INTO `attendances` VALUES ('3814', '31', '341', '17', '1', '2024-12-26', '', '12', '2024-12-26 00:36:26', '2024-12-26 00:36:44');
INSERT INTO `attendances` VALUES ('3815', '31', '1004', '17', '0', '2024-12-26', '', '12', '2024-12-26 00:36:26', '2024-12-26 00:36:35');
INSERT INTO `attendances` VALUES ('3816', '31', '1006', '17', '0', '2024-12-26', '', '12', '2024-12-26 00:36:26', '2024-12-26 16:14:30');
INSERT INTO `attendances` VALUES ('3817', '31', '1008', '17', '1', '2024-12-26', '', '12', '2024-12-26 00:36:26', '2024-12-26 00:36:26');
INSERT INTO `attendances` VALUES ('3818', '31', '1010', '17', '1', '2024-12-26', '', '12', '2024-12-26 00:36:26', '2024-12-26 00:36:26');
INSERT INTO `attendances` VALUES ('3819', '31', '1012', '17', '1', '2024-12-26', '', '12', '2024-12-26 00:36:26', '2024-12-26 00:36:26');
INSERT INTO `attendances` VALUES ('3820', '31', '1014', '17', '1', '2024-12-26', '', '12', '2024-12-26 00:36:26', '2024-12-26 00:36:26');
INSERT INTO `attendances` VALUES ('3821', '31', '1016', '17', '1', '2024-12-26', '', '12', '2024-12-26 00:36:26', '2024-12-26 00:36:26');
INSERT INTO `attendances` VALUES ('3822', '31', '1018', '17', '1', '2024-12-26', '', '12', '2024-12-26 00:36:26', '2024-12-26 00:36:26');
INSERT INTO `attendances` VALUES ('3823', '31', '1020', '17', '1', '2024-12-26', '', '12', '2024-12-26 00:36:26', '2024-12-26 00:36:26');
INSERT INTO `attendances` VALUES ('3824', '31', '1022', '17', '1', '2024-12-26', '', '12', '2024-12-26 00:36:26', '2024-12-26 00:36:26');
INSERT INTO `attendances` VALUES ('3825', '31', '1024', '17', '1', '2024-12-26', '', '12', '2024-12-26 00:36:26', '2024-12-26 00:36:26');
INSERT INTO `attendances` VALUES ('3826', '31', '1026', '17', '1', '2024-12-26', '', '12', '2024-12-26 00:36:26', '2024-12-26 00:36:26');
INSERT INTO `attendances` VALUES ('3827', '31', '1028', '17', '1', '2024-12-26', '', '12', '2024-12-26 00:36:26', '2024-12-26 00:36:26');
INSERT INTO `attendances` VALUES ('3828', '31', '1030', '17', '1', '2024-12-26', '', '12', '2024-12-26 00:36:26', '2024-12-26 00:36:26');
INSERT INTO `attendances` VALUES ('3829', '31', '1032', '17', '1', '2024-12-26', '', '12', '2024-12-26 00:36:26', '2024-12-26 00:36:26');
INSERT INTO `attendances` VALUES ('3830', '31', '1034', '17', '1', '2024-12-26', '', '12', '2024-12-26 00:36:26', '2024-12-26 00:36:26');
INSERT INTO `attendances` VALUES ('3831', '31', '1036', '17', '1', '2024-12-26', '', '12', '2024-12-26 00:36:26', '2024-12-26 00:36:26');
INSERT INTO `attendances` VALUES ('3832', '31', '1038', '17', '1', '2024-12-26', '', '12', '2024-12-26 00:36:26', '2024-12-26 00:36:26');
INSERT INTO `attendances` VALUES ('3833', '31', '1040', '17', '1', '2024-12-26', '', '12', '2024-12-26 00:36:26', '2024-12-26 00:36:26');
INSERT INTO `attendances` VALUES ('3834', '31', '1042', '17', '0', '2024-12-26', '', '12', '2024-12-26 00:36:26', '2024-12-26 16:14:30');
INSERT INTO `attendances` VALUES ('3835', '31', '1044', '17', '1', '2024-12-26', '', '12', '2024-12-26 00:36:26', '2024-12-26 00:36:26');
INSERT INTO `attendances` VALUES ('3836', '31', '1046', '17', '1', '2024-12-26', '', '12', '2024-12-26 00:36:26', '2024-12-26 00:36:26');
INSERT INTO `attendances` VALUES ('3837', '31', '1048', '17', '1', '2024-12-26', '', '12', '2024-12-26 00:36:26', '2024-12-26 00:36:26');
INSERT INTO `attendances` VALUES ('3838', '31', '1050', '17', '1', '2024-12-26', '', '12', '2024-12-26 00:36:26', '2024-12-26 00:36:26');
INSERT INTO `attendances` VALUES ('3839', '31', '1052', '17', '1', '2024-12-26', '', '12', '2024-12-26 00:36:26', '2024-12-26 00:36:26');
INSERT INTO `attendances` VALUES ('3840', '31', '1054', '17', '1', '2024-12-26', '', '12', '2024-12-26 00:36:26', '2024-12-26 00:36:26');
INSERT INTO `attendances` VALUES ('3841', '31', '1056', '17', '1', '2024-12-26', '', '12', '2024-12-26 00:36:26', '2024-12-26 00:36:26');
INSERT INTO `attendances` VALUES ('3842', '31', '1058', '17', '1', '2024-12-26', '', '12', '2024-12-26 00:36:26', '2024-12-26 00:36:26');
INSERT INTO `attendances` VALUES ('3843', '31', '1060', '17', '1', '2024-12-26', '', '12', '2024-12-26 00:36:26', '2024-12-26 00:36:26');
INSERT INTO `attendances` VALUES ('3844', '31', '1062', '17', '1', '2024-12-26', '', '12', '2024-12-26 00:36:26', '2024-12-26 00:36:26');
INSERT INTO `attendances` VALUES ('3845', '55', '331', '17', '3', '2024-12-26', '', '12', '2024-12-26 19:25:50', '2024-12-26 22:15:31');
INSERT INTO `attendances` VALUES ('3846', '55', '349', '17', '3', '2024-12-26', '', '12', '2024-12-26 19:25:50', '2024-12-26 22:15:31');
INSERT INTO `attendances` VALUES ('3847', '55', '351', '17', '3', '2024-12-26', '', '12', '2024-12-26 19:25:50', '2024-12-26 22:15:31');
INSERT INTO `attendances` VALUES ('3848', '55', '353', '17', '3', '2024-12-26', '', '12', '2024-12-26 19:25:50', '2024-12-26 22:15:31');
INSERT INTO `attendances` VALUES ('3849', '55', '355', '17', '3', '2024-12-26', '', '12', '2024-12-26 19:25:50', '2024-12-26 22:15:31');
INSERT INTO `attendances` VALUES ('3850', '55', '357', '17', '3', '2024-12-26', '', '12', '2024-12-26 19:25:50', '2024-12-26 22:15:31');
INSERT INTO `attendances` VALUES ('3851', '55', '359', '17', '3', '2024-12-26', '', '12', '2024-12-26 19:25:50', '2024-12-26 22:15:31');
INSERT INTO `attendances` VALUES ('3852', '55', '361', '17', '3', '2024-12-26', '', '12', '2024-12-26 19:25:50', '2024-12-26 22:15:31');
INSERT INTO `attendances` VALUES ('3853', '55', '363', '17', '3', '2024-12-26', '', '12', '2024-12-26 19:25:50', '2024-12-26 22:15:31');
INSERT INTO `attendances` VALUES ('3854', '55', '365', '17', '3', '2024-12-26', '', '12', '2024-12-26 19:25:50', '2024-12-26 22:15:31');
INSERT INTO `attendances` VALUES ('3855', '55', '367', '17', '3', '2024-12-26', '', '12', '2024-12-26 19:25:50', '2024-12-26 22:15:31');
INSERT INTO `attendances` VALUES ('3856', '55', '331', '17', '0', '2024-11-28', '', '12', '2024-12-26 22:13:53', '2024-12-26 22:13:53');
INSERT INTO `attendances` VALUES ('3857', '55', '349', '17', '1', '2024-11-28', '', '12', '2024-12-26 22:13:53', '2024-12-26 22:13:53');
INSERT INTO `attendances` VALUES ('3858', '55', '351', '17', '1', '2024-11-28', '', '12', '2024-12-26 22:13:53', '2024-12-26 22:13:53');
INSERT INTO `attendances` VALUES ('3859', '55', '353', '17', '1', '2024-11-28', '', '12', '2024-12-26 22:13:53', '2024-12-26 22:13:53');
INSERT INTO `attendances` VALUES ('3860', '55', '355', '17', '1', '2024-11-28', '', '12', '2024-12-26 22:13:53', '2024-12-26 22:13:53');
INSERT INTO `attendances` VALUES ('3861', '55', '357', '17', '1', '2024-11-28', '', '12', '2024-12-26 22:13:53', '2024-12-26 22:13:53');
INSERT INTO `attendances` VALUES ('3862', '55', '359', '17', '1', '2024-11-28', '', '12', '2024-12-26 22:13:53', '2024-12-26 22:13:53');
INSERT INTO `attendances` VALUES ('3863', '55', '361', '17', '1', '2024-11-28', '', '12', '2024-12-26 22:13:53', '2024-12-26 22:13:53');
INSERT INTO `attendances` VALUES ('3864', '55', '363', '17', '1', '2024-11-28', '', '12', '2024-12-26 22:13:53', '2024-12-26 22:13:53');
INSERT INTO `attendances` VALUES ('3865', '55', '365', '17', '1', '2024-11-28', '', '12', '2024-12-26 22:13:53', '2024-12-26 22:13:53');
INSERT INTO `attendances` VALUES ('3866', '55', '367', '17', '1', '2024-11-28', '', '12', '2024-12-26 22:13:53', '2024-12-26 22:13:53');
INSERT INTO `attendances` VALUES ('3867', '55', '331', '17', '0', '2024-12-27', '', '12', '2024-12-27 12:33:12', '2024-12-27 12:33:12');
INSERT INTO `attendances` VALUES ('3868', '55', '349', '17', '1', '2024-12-27', '', '12', '2024-12-27 12:33:12', '2024-12-27 12:33:12');
INSERT INTO `attendances` VALUES ('3869', '55', '351', '17', '0', '2024-12-27', '', '12', '2024-12-27 12:33:12', '2024-12-27 12:33:12');
INSERT INTO `attendances` VALUES ('3870', '55', '353', '17', '1', '2024-12-27', '', '12', '2024-12-27 12:33:12', '2024-12-27 12:33:12');
INSERT INTO `attendances` VALUES ('3871', '55', '355', '17', '1', '2024-12-27', '', '12', '2024-12-27 12:33:12', '2024-12-27 12:33:12');
INSERT INTO `attendances` VALUES ('3872', '55', '357', '17', '1', '2024-12-27', '', '12', '2024-12-27 12:33:12', '2024-12-27 12:33:12');
INSERT INTO `attendances` VALUES ('3873', '55', '359', '17', '1', '2024-12-27', '', '12', '2024-12-27 12:33:12', '2024-12-27 12:33:12');
INSERT INTO `attendances` VALUES ('3874', '55', '361', '17', '1', '2024-12-27', '', '12', '2024-12-27 12:33:12', '2024-12-27 12:33:12');
INSERT INTO `attendances` VALUES ('3875', '55', '363', '17', '0', '2024-12-27', '', '12', '2024-12-27 12:33:12', '2024-12-27 12:33:12');
INSERT INTO `attendances` VALUES ('3876', '55', '365', '17', '1', '2024-12-27', '', '12', '2024-12-27 12:33:12', '2024-12-27 12:33:12');
INSERT INTO `attendances` VALUES ('3877', '55', '367', '17', '1', '2024-12-27', '', '12', '2024-12-27 12:33:12', '2024-12-27 12:33:12');
INSERT INTO `attendances` VALUES ('3878', '31', '341', '17', '1', '2024-12-28', '', '12', '2024-12-28 22:23:11', '2024-12-28 22:23:11');
INSERT INTO `attendances` VALUES ('3879', '31', '1004', '17', '0', '2024-12-28', '', '12', '2024-12-28 22:23:11', '2024-12-28 22:23:11');
INSERT INTO `attendances` VALUES ('3880', '31', '1006', '17', '1', '2024-12-28', '', '12', '2024-12-28 22:23:11', '2024-12-28 22:23:11');
INSERT INTO `attendances` VALUES ('3881', '31', '1008', '17', '1', '2024-12-28', '', '12', '2024-12-28 22:23:11', '2024-12-28 22:23:11');
INSERT INTO `attendances` VALUES ('3882', '31', '1010', '17', '1', '2024-12-28', '', '12', '2024-12-28 22:23:11', '2024-12-28 22:23:11');
INSERT INTO `attendances` VALUES ('3883', '31', '1012', '17', '1', '2024-12-28', '', '12', '2024-12-28 22:23:11', '2024-12-28 22:23:11');
INSERT INTO `attendances` VALUES ('3884', '31', '1014', '17', '1', '2024-12-28', '', '12', '2024-12-28 22:23:11', '2024-12-28 22:23:11');
INSERT INTO `attendances` VALUES ('3885', '31', '1016', '17', '1', '2024-12-28', '', '12', '2024-12-28 22:23:11', '2024-12-28 22:23:11');
INSERT INTO `attendances` VALUES ('3886', '31', '1018', '17', '1', '2024-12-28', '', '12', '2024-12-28 22:23:11', '2024-12-28 22:23:11');
INSERT INTO `attendances` VALUES ('3887', '31', '1020', '17', '1', '2024-12-28', '', '12', '2024-12-28 22:23:11', '2024-12-28 22:23:11');
INSERT INTO `attendances` VALUES ('3888', '31', '1022', '17', '1', '2024-12-28', '', '12', '2024-12-28 22:23:11', '2024-12-28 22:23:11');
INSERT INTO `attendances` VALUES ('3889', '31', '1024', '17', '1', '2024-12-28', '', '12', '2024-12-28 22:23:11', '2024-12-28 22:23:11');
INSERT INTO `attendances` VALUES ('3890', '31', '1026', '17', '1', '2024-12-28', '', '12', '2024-12-28 22:23:11', '2024-12-28 22:23:11');
INSERT INTO `attendances` VALUES ('3891', '31', '1028', '17', '1', '2024-12-28', '', '12', '2024-12-28 22:23:11', '2024-12-28 22:23:11');
INSERT INTO `attendances` VALUES ('3892', '31', '1030', '17', '1', '2024-12-28', '', '12', '2024-12-28 22:23:11', '2024-12-28 22:23:11');
INSERT INTO `attendances` VALUES ('3893', '31', '1032', '17', '1', '2024-12-28', '', '12', '2024-12-28 22:23:11', '2024-12-28 22:23:11');
INSERT INTO `attendances` VALUES ('3894', '31', '1034', '17', '1', '2024-12-28', '', '12', '2024-12-28 22:23:11', '2024-12-28 22:23:11');
INSERT INTO `attendances` VALUES ('3895', '31', '1036', '17', '1', '2024-12-28', '', '12', '2024-12-28 22:23:11', '2024-12-28 22:23:11');
INSERT INTO `attendances` VALUES ('3896', '31', '1038', '17', '1', '2024-12-28', '', '12', '2024-12-28 22:23:11', '2024-12-28 22:23:11');
INSERT INTO `attendances` VALUES ('3897', '31', '1040', '17', '1', '2024-12-28', '', '12', '2024-12-28 22:23:11', '2024-12-28 22:23:11');
INSERT INTO `attendances` VALUES ('3898', '31', '1042', '17', '1', '2024-12-28', '', '12', '2024-12-28 22:23:11', '2024-12-28 22:23:11');
INSERT INTO `attendances` VALUES ('3899', '31', '1044', '17', '1', '2024-12-28', '', '12', '2024-12-28 22:23:11', '2024-12-28 22:23:11');
INSERT INTO `attendances` VALUES ('3900', '31', '1046', '17', '1', '2024-12-28', '', '12', '2024-12-28 22:23:11', '2024-12-28 22:23:11');
INSERT INTO `attendances` VALUES ('3901', '31', '1048', '17', '1', '2024-12-28', '', '12', '2024-12-28 22:23:11', '2024-12-28 22:23:11');
INSERT INTO `attendances` VALUES ('3902', '31', '1050', '17', '1', '2024-12-28', '', '12', '2024-12-28 22:23:11', '2024-12-28 22:23:11');
INSERT INTO `attendances` VALUES ('3903', '31', '1052', '17', '1', '2024-12-28', '', '12', '2024-12-28 22:23:11', '2024-12-28 22:23:11');
INSERT INTO `attendances` VALUES ('3904', '31', '1054', '17', '1', '2024-12-28', '', '12', '2024-12-28 22:23:11', '2024-12-28 22:23:11');
INSERT INTO `attendances` VALUES ('3905', '31', '1056', '17', '1', '2024-12-28', '', '12', '2024-12-28 22:23:11', '2024-12-28 22:23:11');
INSERT INTO `attendances` VALUES ('3906', '31', '1058', '17', '1', '2024-12-28', '', '12', '2024-12-28 22:23:11', '2024-12-28 22:23:11');
INSERT INTO `attendances` VALUES ('3907', '31', '1060', '17', '1', '2024-12-28', '', '12', '2024-12-28 22:23:11', '2024-12-28 22:23:11');
INSERT INTO `attendances` VALUES ('3908', '31', '1062', '17', '1', '2024-12-28', '', '12', '2024-12-28 22:23:11', '2024-12-28 22:23:11');
INSERT INTO `attendances` VALUES ('3909', '31', '341', '17', '1', '2024-12-29', '', '12', '2024-12-29 01:56:17', '2024-12-30 01:48:12');
INSERT INTO `attendances` VALUES ('3910', '31', '1004', '17', '0', '2024-12-29', '', '12', '2024-12-29 01:56:17', '2024-12-29 01:56:17');
INSERT INTO `attendances` VALUES ('3911', '31', '1006', '17', '0', '2024-12-29', '', '12', '2024-12-29 01:56:17', '2024-12-29 01:56:17');
INSERT INTO `attendances` VALUES ('3912', '31', '1008', '17', '0', '2024-12-29', '', '12', '2024-12-29 01:56:17', '2024-12-29 01:56:17');
INSERT INTO `attendances` VALUES ('3913', '31', '1010', '17', '0', '2024-12-29', '', '12', '2024-12-29 01:56:17', '2024-12-29 01:56:17');
INSERT INTO `attendances` VALUES ('3914', '31', '1012', '17', '1', '2024-12-29', '', '12', '2024-12-29 01:56:17', '2024-12-29 01:56:17');
INSERT INTO `attendances` VALUES ('3915', '31', '1014', '17', '1', '2024-12-29', '', '12', '2024-12-29 01:56:17', '2024-12-29 01:56:17');
INSERT INTO `attendances` VALUES ('3916', '31', '1016', '17', '1', '2024-12-29', '', '12', '2024-12-29 01:56:17', '2024-12-29 01:56:17');
INSERT INTO `attendances` VALUES ('3917', '31', '1018', '17', '1', '2024-12-29', '', '12', '2024-12-29 01:56:17', '2024-12-29 01:56:17');
INSERT INTO `attendances` VALUES ('3918', '31', '1020', '17', '1', '2024-12-29', '', '12', '2024-12-29 01:56:17', '2024-12-29 01:56:17');
INSERT INTO `attendances` VALUES ('3919', '31', '1022', '17', '1', '2024-12-29', '', '12', '2024-12-29 01:56:17', '2024-12-29 01:56:17');
INSERT INTO `attendances` VALUES ('3920', '31', '1024', '17', '1', '2024-12-29', '', '12', '2024-12-29 01:56:17', '2024-12-29 01:56:17');
INSERT INTO `attendances` VALUES ('3921', '31', '1026', '17', '1', '2024-12-29', '', '12', '2024-12-29 01:56:17', '2024-12-29 01:56:17');
INSERT INTO `attendances` VALUES ('3922', '31', '1028', '17', '1', '2024-12-29', '', '12', '2024-12-29 01:56:17', '2024-12-29 01:56:17');
INSERT INTO `attendances` VALUES ('3923', '31', '1030', '17', '1', '2024-12-29', '', '12', '2024-12-29 01:56:17', '2024-12-29 01:56:17');
INSERT INTO `attendances` VALUES ('3924', '31', '1032', '17', '1', '2024-12-29', '', '12', '2024-12-29 01:56:17', '2024-12-29 01:56:17');
INSERT INTO `attendances` VALUES ('3925', '31', '1034', '17', '1', '2024-12-29', '', '12', '2024-12-29 01:56:17', '2024-12-29 01:56:17');
INSERT INTO `attendances` VALUES ('3926', '31', '1036', '17', '1', '2024-12-29', '', '12', '2024-12-29 01:56:17', '2024-12-29 01:56:17');
INSERT INTO `attendances` VALUES ('3927', '31', '1038', '17', '1', '2024-12-29', '', '12', '2024-12-29 01:56:17', '2024-12-29 01:56:17');
INSERT INTO `attendances` VALUES ('3928', '31', '1040', '17', '1', '2024-12-29', '', '12', '2024-12-29 01:56:17', '2024-12-29 01:56:17');
INSERT INTO `attendances` VALUES ('3929', '31', '1042', '17', '1', '2024-12-29', '', '12', '2024-12-29 01:56:17', '2024-12-29 01:56:17');
INSERT INTO `attendances` VALUES ('3930', '31', '1044', '17', '1', '2024-12-29', '', '12', '2024-12-29 01:56:17', '2024-12-29 01:56:17');
INSERT INTO `attendances` VALUES ('3931', '31', '1046', '17', '1', '2024-12-29', '', '12', '2024-12-29 01:56:17', '2024-12-29 01:56:17');
INSERT INTO `attendances` VALUES ('3932', '31', '1048', '17', '1', '2024-12-29', '', '12', '2024-12-29 01:56:17', '2024-12-29 01:56:17');
INSERT INTO `attendances` VALUES ('3933', '31', '1050', '17', '1', '2024-12-29', '', '12', '2024-12-29 01:56:17', '2024-12-29 01:56:17');
INSERT INTO `attendances` VALUES ('3934', '31', '1052', '17', '1', '2024-12-29', '', '12', '2024-12-29 01:56:17', '2024-12-29 01:56:17');
INSERT INTO `attendances` VALUES ('3935', '31', '1054', '17', '1', '2024-12-29', '', '12', '2024-12-29 01:56:17', '2024-12-29 01:56:17');
INSERT INTO `attendances` VALUES ('3936', '31', '1056', '17', '1', '2024-12-29', '', '12', '2024-12-29 01:56:17', '2024-12-29 01:56:17');
INSERT INTO `attendances` VALUES ('3937', '31', '1058', '17', '1', '2024-12-29', '', '12', '2024-12-29 01:56:17', '2024-12-29 01:56:17');
INSERT INTO `attendances` VALUES ('3938', '31', '1060', '17', '1', '2024-12-29', '', '12', '2024-12-29 01:56:17', '2024-12-29 01:56:17');
INSERT INTO `attendances` VALUES ('3939', '31', '1062', '17', '1', '2024-12-29', '', '12', '2024-12-29 01:56:17', '2024-12-29 01:56:17');
INSERT INTO `attendances` VALUES ('3940', '55', '331', '17', '0', '2024-12-29', '', '12', '2024-12-29 13:22:59', '2024-12-29 13:22:59');
INSERT INTO `attendances` VALUES ('3941', '55', '349', '17', '0', '2024-12-29', '', '12', '2024-12-29 13:22:59', '2024-12-29 13:22:59');
INSERT INTO `attendances` VALUES ('3942', '55', '351', '17', '1', '2024-12-29', '', '12', '2024-12-29 13:22:59', '2024-12-29 13:22:59');
INSERT INTO `attendances` VALUES ('3943', '55', '353', '17', '1', '2024-12-29', '', '12', '2024-12-29 13:22:59', '2024-12-29 13:22:59');
INSERT INTO `attendances` VALUES ('3944', '55', '355', '17', '1', '2024-12-29', '', '12', '2024-12-29 13:22:59', '2024-12-29 13:22:59');
INSERT INTO `attendances` VALUES ('3945', '55', '357', '17', '1', '2024-12-29', '', '12', '2024-12-29 13:22:59', '2024-12-29 13:22:59');
INSERT INTO `attendances` VALUES ('3946', '55', '359', '17', '1', '2024-12-29', '', '12', '2024-12-29 13:22:59', '2024-12-29 13:22:59');
INSERT INTO `attendances` VALUES ('3947', '55', '361', '17', '0', '2024-12-29', '', '12', '2024-12-29 13:22:59', '2024-12-29 13:22:59');
INSERT INTO `attendances` VALUES ('3948', '55', '363', '17', '0', '2024-12-29', '', '12', '2024-12-29 13:22:59', '2024-12-29 13:22:59');
INSERT INTO `attendances` VALUES ('3949', '55', '365', '17', '0', '2024-12-29', '', '12', '2024-12-29 13:22:59', '2024-12-29 13:22:59');
INSERT INTO `attendances` VALUES ('3950', '55', '367', '17', '0', '2024-12-29', '', '12', '2024-12-29 13:22:59', '2024-12-29 13:22:59');
INSERT INTO `attendances` VALUES ('3951', '31', '341', '17', '0', '2024-12-30', '', '12', '2024-12-30 12:30:24', '2024-12-30 13:12:51');
INSERT INTO `attendances` VALUES ('3952', '31', '1004', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:24', '2024-12-30 12:30:24');
INSERT INTO `attendances` VALUES ('3953', '31', '1006', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:24', '2024-12-30 12:30:24');
INSERT INTO `attendances` VALUES ('3954', '31', '1008', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:24', '2024-12-30 12:30:24');
INSERT INTO `attendances` VALUES ('3955', '31', '1010', '17', '0', '2024-12-30', '', '12', '2024-12-30 12:30:24', '2024-12-30 21:39:43');
INSERT INTO `attendances` VALUES ('3956', '31', '1012', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:24', '2024-12-30 12:30:24');
INSERT INTO `attendances` VALUES ('3957', '31', '1014', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:24', '2024-12-30 12:30:24');
INSERT INTO `attendances` VALUES ('3958', '31', '1016', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:24', '2024-12-30 12:30:24');
INSERT INTO `attendances` VALUES ('3959', '31', '1018', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:24', '2024-12-30 12:30:24');
INSERT INTO `attendances` VALUES ('3960', '31', '1020', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:24', '2024-12-30 12:30:24');
INSERT INTO `attendances` VALUES ('3961', '31', '1022', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:24', '2024-12-30 12:30:24');
INSERT INTO `attendances` VALUES ('3962', '31', '1024', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:24', '2024-12-30 12:30:24');
INSERT INTO `attendances` VALUES ('3963', '31', '1026', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:24', '2024-12-30 12:30:24');
INSERT INTO `attendances` VALUES ('3964', '31', '1028', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:24', '2024-12-30 12:30:24');
INSERT INTO `attendances` VALUES ('3965', '31', '1030', '17', '0', '2024-12-30', '', '12', '2024-12-30 12:30:24', '2024-12-30 13:12:51');
INSERT INTO `attendances` VALUES ('3966', '31', '1032', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:24', '2024-12-30 12:30:24');
INSERT INTO `attendances` VALUES ('3967', '31', '1034', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:24', '2024-12-30 12:30:24');
INSERT INTO `attendances` VALUES ('3968', '31', '1036', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:24', '2024-12-30 12:30:24');
INSERT INTO `attendances` VALUES ('3969', '31', '1038', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:24', '2024-12-30 12:30:24');
INSERT INTO `attendances` VALUES ('3970', '31', '1040', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:24', '2024-12-30 12:30:24');
INSERT INTO `attendances` VALUES ('3971', '31', '1042', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:24', '2024-12-30 12:30:24');
INSERT INTO `attendances` VALUES ('3972', '31', '1044', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:24', '2024-12-30 12:30:24');
INSERT INTO `attendances` VALUES ('3973', '31', '1046', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:24', '2024-12-30 12:30:24');
INSERT INTO `attendances` VALUES ('3974', '31', '1048', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:24', '2024-12-30 12:30:24');
INSERT INTO `attendances` VALUES ('3975', '31', '1050', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:24', '2024-12-30 12:30:24');
INSERT INTO `attendances` VALUES ('3976', '31', '1052', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:24', '2024-12-30 12:30:24');
INSERT INTO `attendances` VALUES ('3977', '31', '1054', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:24', '2024-12-30 12:30:24');
INSERT INTO `attendances` VALUES ('3978', '31', '1056', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:24', '2024-12-30 12:30:24');
INSERT INTO `attendances` VALUES ('3979', '31', '1058', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:24', '2024-12-30 12:30:24');
INSERT INTO `attendances` VALUES ('3980', '31', '1060', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:24', '2024-12-30 12:30:24');
INSERT INTO `attendances` VALUES ('3981', '31', '1062', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:24', '2024-12-30 12:30:24');
INSERT INTO `attendances` VALUES ('3982', '55', '331', '17', '0', '2024-12-30', '', '12', '2024-12-30 12:30:44', '2024-12-30 12:30:44');
INSERT INTO `attendances` VALUES ('3983', '55', '349', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:44', '2024-12-30 12:30:44');
INSERT INTO `attendances` VALUES ('3984', '55', '351', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:44', '2024-12-30 12:30:44');
INSERT INTO `attendances` VALUES ('3985', '55', '353', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:44', '2024-12-30 12:30:44');
INSERT INTO `attendances` VALUES ('3986', '55', '355', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:44', '2024-12-30 12:30:44');
INSERT INTO `attendances` VALUES ('3987', '55', '357', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:44', '2024-12-30 12:30:44');
INSERT INTO `attendances` VALUES ('3988', '55', '359', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:44', '2024-12-30 12:30:44');
INSERT INTO `attendances` VALUES ('3989', '55', '361', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:44', '2024-12-30 12:30:44');
INSERT INTO `attendances` VALUES ('3990', '55', '363', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:44', '2024-12-30 12:30:44');
INSERT INTO `attendances` VALUES ('3991', '55', '365', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:44', '2024-12-30 12:30:44');
INSERT INTO `attendances` VALUES ('3992', '55', '367', '17', '1', '2024-12-30', '', '12', '2024-12-30 12:30:44', '2024-12-30 12:30:44');
INSERT INTO `attendances` VALUES ('3993', '31', '341', '17', '0', '2024-12-31', '', '12', '2024-12-31 19:37:22', '2024-12-31 19:37:22');
INSERT INTO `attendances` VALUES ('3994', '31', '1004', '17', '0', '2024-12-31', '', '12', '2024-12-31 19:37:22', '2024-12-31 19:37:22');
INSERT INTO `attendances` VALUES ('3995', '31', '1006', '17', '0', '2024-12-31', '', '12', '2024-12-31 19:37:22', '2024-12-31 19:37:22');
INSERT INTO `attendances` VALUES ('3996', '31', '1008', '17', '1', '2024-12-31', '', '12', '2024-12-31 19:37:22', '2024-12-31 19:37:22');
INSERT INTO `attendances` VALUES ('3997', '31', '1010', '17', '1', '2024-12-31', '', '12', '2024-12-31 19:37:22', '2024-12-31 19:37:22');
INSERT INTO `attendances` VALUES ('3998', '31', '1012', '17', '0', '2024-12-31', '', '12', '2024-12-31 19:37:22', '2024-12-31 19:37:22');
INSERT INTO `attendances` VALUES ('3999', '31', '1014', '17', '1', '2024-12-31', '', '12', '2024-12-31 19:37:22', '2024-12-31 19:37:22');
INSERT INTO `attendances` VALUES ('4000', '31', '1016', '17', '1', '2024-12-31', '', '12', '2024-12-31 19:37:22', '2024-12-31 19:37:22');
INSERT INTO `attendances` VALUES ('4001', '31', '1018', '17', '1', '2024-12-31', '', '12', '2024-12-31 19:37:22', '2024-12-31 19:37:22');
INSERT INTO `attendances` VALUES ('4002', '31', '1020', '17', '1', '2024-12-31', '', '12', '2024-12-31 19:37:22', '2024-12-31 19:37:22');
INSERT INTO `attendances` VALUES ('4003', '31', '1022', '17', '1', '2024-12-31', '', '12', '2024-12-31 19:37:22', '2024-12-31 19:37:22');
INSERT INTO `attendances` VALUES ('4004', '31', '1024', '17', '1', '2024-12-31', '', '12', '2024-12-31 19:37:22', '2024-12-31 19:37:22');
INSERT INTO `attendances` VALUES ('4005', '31', '1026', '17', '1', '2024-12-31', '', '12', '2024-12-31 19:37:22', '2024-12-31 19:37:22');
INSERT INTO `attendances` VALUES ('4006', '31', '1028', '17', '1', '2024-12-31', '', '12', '2024-12-31 19:37:22', '2024-12-31 19:37:22');
INSERT INTO `attendances` VALUES ('4007', '31', '1030', '17', '1', '2024-12-31', '', '12', '2024-12-31 19:37:22', '2024-12-31 19:37:22');
INSERT INTO `attendances` VALUES ('4008', '31', '1032', '17', '1', '2024-12-31', '', '12', '2024-12-31 19:37:22', '2024-12-31 19:37:22');
INSERT INTO `attendances` VALUES ('4009', '31', '1034', '17', '1', '2024-12-31', '', '12', '2024-12-31 19:37:22', '2024-12-31 19:37:22');
INSERT INTO `attendances` VALUES ('4010', '31', '1036', '17', '1', '2024-12-31', '', '12', '2024-12-31 19:37:22', '2024-12-31 19:37:22');
INSERT INTO `attendances` VALUES ('4011', '31', '1038', '17', '1', '2024-12-31', '', '12', '2024-12-31 19:37:22', '2024-12-31 19:37:22');
INSERT INTO `attendances` VALUES ('4012', '31', '1040', '17', '1', '2024-12-31', '', '12', '2024-12-31 19:37:22', '2024-12-31 19:37:22');
INSERT INTO `attendances` VALUES ('4013', '31', '1042', '17', '1', '2024-12-31', '', '12', '2024-12-31 19:37:22', '2024-12-31 19:37:22');
INSERT INTO `attendances` VALUES ('4014', '31', '1044', '17', '1', '2024-12-31', '', '12', '2024-12-31 19:37:22', '2024-12-31 19:37:22');
INSERT INTO `attendances` VALUES ('4015', '31', '1046', '17', '1', '2024-12-31', '', '12', '2024-12-31 19:37:22', '2024-12-31 19:37:22');
INSERT INTO `attendances` VALUES ('4016', '31', '1048', '17', '1', '2024-12-31', '', '12', '2024-12-31 19:37:22', '2024-12-31 19:37:22');
INSERT INTO `attendances` VALUES ('4017', '31', '1050', '17', '1', '2024-12-31', '', '12', '2024-12-31 19:37:22', '2024-12-31 19:37:22');
INSERT INTO `attendances` VALUES ('4018', '31', '1052', '17', '1', '2024-12-31', '', '12', '2024-12-31 19:37:22', '2024-12-31 19:37:22');
INSERT INTO `attendances` VALUES ('4019', '31', '1054', '17', '1', '2024-12-31', '', '12', '2024-12-31 19:37:22', '2024-12-31 19:37:22');
INSERT INTO `attendances` VALUES ('4020', '31', '1056', '17', '1', '2024-12-31', '', '12', '2024-12-31 19:37:22', '2024-12-31 19:37:22');
INSERT INTO `attendances` VALUES ('4021', '31', '1058', '17', '1', '2024-12-31', '', '12', '2024-12-31 19:37:22', '2024-12-31 19:37:22');
INSERT INTO `attendances` VALUES ('4022', '31', '1060', '17', '1', '2024-12-31', '', '12', '2024-12-31 19:37:22', '2024-12-31 19:37:22');
INSERT INTO `attendances` VALUES ('4023', '31', '1062', '17', '1', '2024-12-31', '', '12', '2024-12-31 19:37:22', '2024-12-31 19:37:22');
INSERT INTO `attendances` VALUES ('4024', '31', '341', '17', '3', '2025-01-01', '', '12', '2025-01-01 12:52:01', '2025-01-01 12:52:01');
INSERT INTO `attendances` VALUES ('4025', '31', '1004', '17', '3', '2025-01-01', '', '12', '2025-01-01 12:52:01', '2025-01-01 12:52:01');
INSERT INTO `attendances` VALUES ('4026', '31', '1006', '17', '3', '2025-01-01', '', '12', '2025-01-01 12:52:01', '2025-01-01 12:52:01');
INSERT INTO `attendances` VALUES ('4027', '31', '1008', '17', '3', '2025-01-01', '', '12', '2025-01-01 12:52:01', '2025-01-01 12:52:01');
INSERT INTO `attendances` VALUES ('4028', '31', '1010', '17', '3', '2025-01-01', '', '12', '2025-01-01 12:52:01', '2025-01-01 12:52:01');
INSERT INTO `attendances` VALUES ('4029', '31', '1012', '17', '3', '2025-01-01', '', '12', '2025-01-01 12:52:01', '2025-01-01 12:52:01');
INSERT INTO `attendances` VALUES ('4030', '31', '1014', '17', '3', '2025-01-01', '', '12', '2025-01-01 12:52:01', '2025-01-01 12:52:01');
INSERT INTO `attendances` VALUES ('4031', '31', '1016', '17', '3', '2025-01-01', '', '12', '2025-01-01 12:52:01', '2025-01-01 12:52:01');
INSERT INTO `attendances` VALUES ('4032', '31', '1018', '17', '3', '2025-01-01', '', '12', '2025-01-01 12:52:01', '2025-01-01 12:52:01');
INSERT INTO `attendances` VALUES ('4033', '31', '1020', '17', '3', '2025-01-01', '', '12', '2025-01-01 12:52:01', '2025-01-01 12:52:01');
INSERT INTO `attendances` VALUES ('4034', '31', '1022', '17', '3', '2025-01-01', '', '12', '2025-01-01 12:52:01', '2025-01-01 12:52:01');
INSERT INTO `attendances` VALUES ('4035', '31', '1024', '17', '3', '2025-01-01', '', '12', '2025-01-01 12:52:01', '2025-01-01 12:52:01');
INSERT INTO `attendances` VALUES ('4036', '31', '1026', '17', '3', '2025-01-01', '', '12', '2025-01-01 12:52:01', '2025-01-01 12:52:01');
INSERT INTO `attendances` VALUES ('4037', '31', '1028', '17', '3', '2025-01-01', '', '12', '2025-01-01 12:52:01', '2025-01-01 12:52:01');
INSERT INTO `attendances` VALUES ('4038', '31', '1030', '17', '3', '2025-01-01', '', '12', '2025-01-01 12:52:01', '2025-01-01 12:52:01');
INSERT INTO `attendances` VALUES ('4039', '31', '1032', '17', '3', '2025-01-01', '', '12', '2025-01-01 12:52:01', '2025-01-01 12:52:01');
INSERT INTO `attendances` VALUES ('4040', '31', '1034', '17', '3', '2025-01-01', '', '12', '2025-01-01 12:52:01', '2025-01-01 12:52:01');
INSERT INTO `attendances` VALUES ('4041', '31', '1036', '17', '3', '2025-01-01', '', '12', '2025-01-01 12:52:01', '2025-01-01 12:52:01');
INSERT INTO `attendances` VALUES ('4042', '31', '1038', '17', '3', '2025-01-01', '', '12', '2025-01-01 12:52:01', '2025-01-01 12:52:01');
INSERT INTO `attendances` VALUES ('4043', '31', '1040', '17', '3', '2025-01-01', '', '12', '2025-01-01 12:52:01', '2025-01-01 12:52:01');
INSERT INTO `attendances` VALUES ('4044', '31', '1042', '17', '3', '2025-01-01', '', '12', '2025-01-01 12:52:01', '2025-01-01 12:52:01');
INSERT INTO `attendances` VALUES ('4045', '31', '1044', '17', '3', '2025-01-01', '', '12', '2025-01-01 12:52:01', '2025-01-01 12:52:01');
INSERT INTO `attendances` VALUES ('4046', '31', '1046', '17', '3', '2025-01-01', '', '12', '2025-01-01 12:52:01', '2025-01-01 12:52:01');
INSERT INTO `attendances` VALUES ('4047', '31', '1048', '17', '3', '2025-01-01', '', '12', '2025-01-01 12:52:01', '2025-01-01 12:52:01');
INSERT INTO `attendances` VALUES ('4048', '31', '1050', '17', '3', '2025-01-01', '', '12', '2025-01-01 12:52:02', '2025-01-01 12:52:02');
INSERT INTO `attendances` VALUES ('4049', '31', '1052', '17', '3', '2025-01-01', '', '12', '2025-01-01 12:52:02', '2025-01-01 12:52:02');
INSERT INTO `attendances` VALUES ('4050', '31', '1054', '17', '3', '2025-01-01', '', '12', '2025-01-01 12:52:02', '2025-01-01 12:52:02');
INSERT INTO `attendances` VALUES ('4051', '31', '1056', '17', '3', '2025-01-01', '', '12', '2025-01-01 12:52:02', '2025-01-01 12:52:02');
INSERT INTO `attendances` VALUES ('4052', '31', '1058', '17', '3', '2025-01-01', '', '12', '2025-01-01 12:52:02', '2025-01-01 12:52:02');
INSERT INTO `attendances` VALUES ('4053', '31', '1060', '17', '3', '2025-01-01', '', '12', '2025-01-01 12:52:02', '2025-01-01 12:52:02');
INSERT INTO `attendances` VALUES ('4054', '31', '1062', '17', '3', '2025-01-01', '', '12', '2025-01-01 12:52:02', '2025-01-01 12:52:02');
INSERT INTO `attendances` VALUES ('4055', '31', '341', '17', '0', '2025-01-02', '', '12', '2025-01-02 15:54:25', '2025-01-02 15:54:25');
INSERT INTO `attendances` VALUES ('4056', '31', '1004', '17', '0', '2025-01-02', '', '12', '2025-01-02 15:54:25', '2025-01-02 15:54:25');
INSERT INTO `attendances` VALUES ('4057', '31', '1006', '17', '1', '2025-01-02', '', '12', '2025-01-02 15:54:25', '2025-01-02 15:54:25');
INSERT INTO `attendances` VALUES ('4058', '31', '1008', '17', '0', '2025-01-02', '', '12', '2025-01-02 15:54:25', '2025-01-02 15:54:25');
INSERT INTO `attendances` VALUES ('4059', '31', '1010', '17', '1', '2025-01-02', '', '12', '2025-01-02 15:54:25', '2025-01-02 15:54:25');
INSERT INTO `attendances` VALUES ('4060', '31', '1012', '17', '1', '2025-01-02', '', '12', '2025-01-02 15:54:25', '2025-01-02 15:54:25');
INSERT INTO `attendances` VALUES ('4061', '31', '1014', '17', '1', '2025-01-02', '', '12', '2025-01-02 15:54:25', '2025-01-02 15:54:25');
INSERT INTO `attendances` VALUES ('4062', '31', '1016', '17', '1', '2025-01-02', '', '12', '2025-01-02 15:54:25', '2025-01-02 15:54:25');
INSERT INTO `attendances` VALUES ('4063', '31', '1018', '17', '1', '2025-01-02', '', '12', '2025-01-02 15:54:25', '2025-01-02 15:54:25');
INSERT INTO `attendances` VALUES ('4064', '31', '1020', '17', '1', '2025-01-02', '', '12', '2025-01-02 15:54:25', '2025-01-02 15:54:25');
INSERT INTO `attendances` VALUES ('4065', '31', '1022', '17', '1', '2025-01-02', '', '12', '2025-01-02 15:54:25', '2025-01-02 15:54:25');
INSERT INTO `attendances` VALUES ('4066', '31', '1024', '17', '1', '2025-01-02', '', '12', '2025-01-02 15:54:25', '2025-01-02 15:54:25');
INSERT INTO `attendances` VALUES ('4067', '31', '1026', '17', '0', '2025-01-02', '', '12', '2025-01-02 15:54:25', '2025-01-02 15:54:25');
INSERT INTO `attendances` VALUES ('4068', '31', '1028', '17', '1', '2025-01-02', '', '12', '2025-01-02 15:54:25', '2025-01-02 15:54:25');
INSERT INTO `attendances` VALUES ('4069', '31', '1030', '17', '0', '2025-01-02', '', '12', '2025-01-02 15:54:25', '2025-01-02 15:54:25');
INSERT INTO `attendances` VALUES ('4070', '31', '1032', '17', '1', '2025-01-02', '', '12', '2025-01-02 15:54:25', '2025-01-02 15:54:25');
INSERT INTO `attendances` VALUES ('4071', '31', '1034', '17', '1', '2025-01-02', '', '12', '2025-01-02 15:54:25', '2025-01-02 15:54:25');
INSERT INTO `attendances` VALUES ('4072', '31', '1036', '17', '1', '2025-01-02', '', '12', '2025-01-02 15:54:25', '2025-01-02 15:54:25');
INSERT INTO `attendances` VALUES ('4073', '31', '1038', '17', '1', '2025-01-02', '', '12', '2025-01-02 15:54:25', '2025-01-02 15:54:25');
INSERT INTO `attendances` VALUES ('4074', '31', '1040', '17', '1', '2025-01-02', '', '12', '2025-01-02 15:54:25', '2025-01-02 15:54:25');
INSERT INTO `attendances` VALUES ('4075', '31', '1042', '17', '1', '2025-01-02', '', '12', '2025-01-02 15:54:25', '2025-01-02 15:54:25');
INSERT INTO `attendances` VALUES ('4076', '31', '1044', '17', '0', '2025-01-02', '', '12', '2025-01-02 15:54:25', '2025-01-02 15:54:25');
INSERT INTO `attendances` VALUES ('4077', '31', '1046', '17', '1', '2025-01-02', '', '12', '2025-01-02 15:54:25', '2025-01-02 15:54:25');
INSERT INTO `attendances` VALUES ('4078', '31', '1048', '17', '0', '2025-01-02', '', '12', '2025-01-02 15:54:25', '2025-01-02 15:54:25');
INSERT INTO `attendances` VALUES ('4079', '31', '1050', '17', '1', '2025-01-02', '', '12', '2025-01-02 15:54:25', '2025-01-02 15:54:25');
INSERT INTO `attendances` VALUES ('4080', '31', '1052', '17', '1', '2025-01-02', '', '12', '2025-01-02 15:54:25', '2025-01-02 15:54:25');
INSERT INTO `attendances` VALUES ('4081', '31', '1054', '17', '1', '2025-01-02', '', '12', '2025-01-02 15:54:25', '2025-01-02 15:54:25');
INSERT INTO `attendances` VALUES ('4082', '31', '1056', '17', '1', '2025-01-02', '', '12', '2025-01-02 15:54:25', '2025-01-02 15:54:25');
INSERT INTO `attendances` VALUES ('4083', '31', '1058', '17', '0', '2025-01-02', '', '12', '2025-01-02 15:54:25', '2025-01-02 15:54:25');
INSERT INTO `attendances` VALUES ('4084', '31', '1060', '17', '1', '2025-01-02', '', '12', '2025-01-02 15:54:25', '2025-01-02 15:54:25');
INSERT INTO `attendances` VALUES ('4085', '31', '1062', '17', '1', '2025-01-02', '', '12', '2025-01-02 15:54:25', '2025-01-02 15:54:25');
INSERT INTO `attendances` VALUES ('4086', '31', '341', '17', '0', '2025-01-03', '', '12', '2025-01-03 12:55:06', '2025-01-03 12:55:06');
INSERT INTO `attendances` VALUES ('4087', '31', '1004', '17', '1', '2025-01-03', '', '12', '2025-01-03 12:55:06', '2025-01-03 12:55:06');
INSERT INTO `attendances` VALUES ('4088', '31', '1006', '17', '1', '2025-01-03', '', '12', '2025-01-03 12:55:06', '2025-01-03 12:55:06');
INSERT INTO `attendances` VALUES ('4089', '31', '1008', '17', '1', '2025-01-03', '', '12', '2025-01-03 12:55:06', '2025-01-03 12:55:06');
INSERT INTO `attendances` VALUES ('4090', '31', '1010', '17', '1', '2025-01-03', '', '12', '2025-01-03 12:55:06', '2025-01-03 12:55:06');
INSERT INTO `attendances` VALUES ('4091', '31', '1012', '17', '1', '2025-01-03', '', '12', '2025-01-03 12:55:06', '2025-01-03 12:55:06');
INSERT INTO `attendances` VALUES ('4092', '31', '1014', '17', '1', '2025-01-03', '', '12', '2025-01-03 12:55:06', '2025-01-03 12:55:06');
INSERT INTO `attendances` VALUES ('4093', '31', '1016', '17', '1', '2025-01-03', '', '12', '2025-01-03 12:55:06', '2025-01-03 12:55:06');
INSERT INTO `attendances` VALUES ('4094', '31', '1018', '17', '1', '2025-01-03', '', '12', '2025-01-03 12:55:06', '2025-01-03 12:55:06');
INSERT INTO `attendances` VALUES ('4095', '31', '1020', '17', '1', '2025-01-03', '', '12', '2025-01-03 12:55:06', '2025-01-03 12:55:06');
INSERT INTO `attendances` VALUES ('4096', '31', '1022', '17', '1', '2025-01-03', '', '12', '2025-01-03 12:55:06', '2025-01-03 12:55:06');
INSERT INTO `attendances` VALUES ('4097', '31', '1024', '17', '1', '2025-01-03', '', '12', '2025-01-03 12:55:06', '2025-01-03 12:55:06');
INSERT INTO `attendances` VALUES ('4098', '31', '1026', '17', '1', '2025-01-03', '', '12', '2025-01-03 12:55:06', '2025-01-03 12:55:06');
INSERT INTO `attendances` VALUES ('4099', '31', '1028', '17', '1', '2025-01-03', '', '12', '2025-01-03 12:55:06', '2025-01-03 12:55:06');
INSERT INTO `attendances` VALUES ('4100', '31', '1030', '17', '1', '2025-01-03', '', '12', '2025-01-03 12:55:06', '2025-01-03 12:55:06');
INSERT INTO `attendances` VALUES ('4101', '31', '1032', '17', '1', '2025-01-03', '', '12', '2025-01-03 12:55:06', '2025-01-03 12:55:06');
INSERT INTO `attendances` VALUES ('4102', '31', '1034', '17', '1', '2025-01-03', '', '12', '2025-01-03 12:55:06', '2025-01-03 12:55:06');
INSERT INTO `attendances` VALUES ('4103', '31', '1036', '17', '1', '2025-01-03', '', '12', '2025-01-03 12:55:06', '2025-01-03 12:55:06');
INSERT INTO `attendances` VALUES ('4104', '31', '1038', '17', '1', '2025-01-03', '', '12', '2025-01-03 12:55:06', '2025-01-03 12:55:06');
INSERT INTO `attendances` VALUES ('4105', '31', '1040', '17', '1', '2025-01-03', '', '12', '2025-01-03 12:55:06', '2025-01-03 12:55:06');
INSERT INTO `attendances` VALUES ('4106', '31', '1042', '17', '1', '2025-01-03', '', '12', '2025-01-03 12:55:06', '2025-01-03 12:55:06');
INSERT INTO `attendances` VALUES ('4107', '31', '1044', '17', '1', '2025-01-03', '', '12', '2025-01-03 12:55:06', '2025-01-03 12:55:06');
INSERT INTO `attendances` VALUES ('4108', '31', '1046', '17', '1', '2025-01-03', '', '12', '2025-01-03 12:55:06', '2025-01-03 12:55:06');
INSERT INTO `attendances` VALUES ('4109', '31', '1048', '17', '1', '2025-01-03', '', '12', '2025-01-03 12:55:06', '2025-01-03 12:55:06');
INSERT INTO `attendances` VALUES ('4110', '31', '1050', '17', '1', '2025-01-03', '', '12', '2025-01-03 12:55:06', '2025-01-03 12:55:06');
INSERT INTO `attendances` VALUES ('4111', '31', '1052', '17', '1', '2025-01-03', '', '12', '2025-01-03 12:55:06', '2025-01-03 12:55:06');
INSERT INTO `attendances` VALUES ('4112', '31', '1054', '17', '1', '2025-01-03', '', '12', '2025-01-03 12:55:06', '2025-01-03 12:55:06');
INSERT INTO `attendances` VALUES ('4113', '31', '1056', '17', '1', '2025-01-03', '', '12', '2025-01-03 12:55:06', '2025-01-03 12:55:06');
INSERT INTO `attendances` VALUES ('4114', '31', '1058', '17', '1', '2025-01-03', '', '12', '2025-01-03 12:55:06', '2025-01-03 12:55:06');
INSERT INTO `attendances` VALUES ('4115', '31', '1060', '17', '1', '2025-01-03', '', '12', '2025-01-03 12:55:06', '2025-01-03 12:55:06');
INSERT INTO `attendances` VALUES ('4116', '31', '1062', '17', '1', '2025-01-03', '', '12', '2025-01-03 12:55:06', '2025-01-03 12:55:06');
INSERT INTO `attendances` VALUES ('4117', '31', '341', '17', '0', '2025-01-06', '', '12', '2025-01-06 15:57:03', '2025-01-06 19:14:46');
INSERT INTO `attendances` VALUES ('4118', '31', '1004', '17', '0', '2025-01-06', '', '12', '2025-01-06 15:57:03', '2025-01-06 19:14:22');
INSERT INTO `attendances` VALUES ('4119', '31', '1006', '17', '0', '2025-01-06', '', '12', '2025-01-06 15:57:03', '2025-01-06 19:14:22');
INSERT INTO `attendances` VALUES ('4120', '31', '1008', '17', '0', '2025-01-06', '', '12', '2025-01-06 15:57:03', '2025-01-06 19:14:22');
INSERT INTO `attendances` VALUES ('4121', '31', '1010', '17', '0', '2025-01-06', '', '12', '2025-01-06 15:57:03', '2025-01-06 19:14:22');
INSERT INTO `attendances` VALUES ('4122', '31', '1012', '17', '0', '2025-01-06', '', '12', '2025-01-06 15:57:03', '2025-01-06 19:14:22');
INSERT INTO `attendances` VALUES ('4123', '31', '1014', '17', '1', '2025-01-06', '', '12', '2025-01-06 15:57:03', '2025-01-06 15:57:03');
INSERT INTO `attendances` VALUES ('4124', '31', '1016', '17', '1', '2025-01-06', '', '12', '2025-01-06 15:57:03', '2025-01-06 15:57:03');
INSERT INTO `attendances` VALUES ('4125', '31', '1018', '17', '1', '2025-01-06', '', '12', '2025-01-06 15:57:03', '2025-01-06 15:57:03');
INSERT INTO `attendances` VALUES ('4126', '31', '1020', '17', '1', '2025-01-06', '', '12', '2025-01-06 15:57:03', '2025-01-06 15:57:03');
INSERT INTO `attendances` VALUES ('4127', '31', '1022', '17', '1', '2025-01-06', '', '12', '2025-01-06 15:57:03', '2025-01-06 15:57:03');
INSERT INTO `attendances` VALUES ('4128', '31', '1024', '17', '1', '2025-01-06', '', '12', '2025-01-06 15:57:03', '2025-01-06 15:57:03');
INSERT INTO `attendances` VALUES ('4129', '31', '1026', '17', '1', '2025-01-06', '', '12', '2025-01-06 15:57:03', '2025-01-06 15:57:03');
INSERT INTO `attendances` VALUES ('4130', '31', '1028', '17', '1', '2025-01-06', '', '12', '2025-01-06 15:57:03', '2025-01-06 15:57:03');
INSERT INTO `attendances` VALUES ('4131', '31', '1030', '17', '1', '2025-01-06', '', '12', '2025-01-06 15:57:03', '2025-01-06 15:57:03');
INSERT INTO `attendances` VALUES ('4132', '31', '1032', '17', '1', '2025-01-06', '', '12', '2025-01-06 15:57:03', '2025-01-06 15:57:03');
INSERT INTO `attendances` VALUES ('4133', '31', '1034', '17', '1', '2025-01-06', '', '12', '2025-01-06 15:57:03', '2025-01-06 15:57:03');
INSERT INTO `attendances` VALUES ('4134', '31', '1036', '17', '1', '2025-01-06', '', '12', '2025-01-06 15:57:03', '2025-01-06 15:57:03');
INSERT INTO `attendances` VALUES ('4135', '31', '1038', '17', '1', '2025-01-06', '', '12', '2025-01-06 15:57:03', '2025-01-06 15:57:03');
INSERT INTO `attendances` VALUES ('4136', '31', '1040', '17', '1', '2025-01-06', '', '12', '2025-01-06 15:57:03', '2025-01-06 15:57:03');
INSERT INTO `attendances` VALUES ('4137', '31', '1042', '17', '1', '2025-01-06', '', '12', '2025-01-06 15:57:03', '2025-01-06 15:57:03');
INSERT INTO `attendances` VALUES ('4138', '31', '1044', '17', '1', '2025-01-06', '', '12', '2025-01-06 15:57:03', '2025-01-06 15:57:03');
INSERT INTO `attendances` VALUES ('4139', '31', '1046', '17', '1', '2025-01-06', '', '12', '2025-01-06 15:57:03', '2025-01-06 15:57:03');
INSERT INTO `attendances` VALUES ('4140', '31', '1048', '17', '1', '2025-01-06', '', '12', '2025-01-06 15:57:03', '2025-01-06 15:57:03');
INSERT INTO `attendances` VALUES ('4141', '31', '1050', '17', '1', '2025-01-06', '', '12', '2025-01-06 15:57:03', '2025-01-06 15:57:03');
INSERT INTO `attendances` VALUES ('4142', '31', '1052', '17', '1', '2025-01-06', '', '12', '2025-01-06 15:57:03', '2025-01-06 15:57:03');
INSERT INTO `attendances` VALUES ('4143', '31', '1054', '17', '1', '2025-01-06', '', '12', '2025-01-06 15:57:03', '2025-01-06 15:57:03');
INSERT INTO `attendances` VALUES ('4144', '31', '1056', '17', '1', '2025-01-06', '', '12', '2025-01-06 15:57:03', '2025-01-06 15:57:03');
INSERT INTO `attendances` VALUES ('4145', '31', '1058', '17', '1', '2025-01-06', '', '12', '2025-01-06 15:57:03', '2025-01-06 15:57:03');
INSERT INTO `attendances` VALUES ('4146', '31', '1060', '17', '1', '2025-01-06', '', '12', '2025-01-06 15:57:03', '2025-01-06 15:57:03');
INSERT INTO `attendances` VALUES ('4147', '31', '1062', '17', '0', '2025-01-06', '', '12', '2025-01-06 15:57:03', '2025-01-06 18:20:15');
INSERT INTO `attendances` VALUES ('4148', '31', '341', '17', '0', '2025-01-07', '', '12', '2025-01-07 06:45:45', '2025-01-07 06:45:45');
INSERT INTO `attendances` VALUES ('4149', '31', '1004', '17', '0', '2025-01-07', '', '12', '2025-01-07 06:45:45', '2025-01-07 06:45:45');
INSERT INTO `attendances` VALUES ('4150', '31', '1006', '17', '1', '2025-01-07', '', '12', '2025-01-07 06:45:45', '2025-01-07 06:45:45');
INSERT INTO `attendances` VALUES ('4151', '31', '1008', '17', '1', '2025-01-07', '', '12', '2025-01-07 06:45:45', '2025-01-07 06:45:45');
INSERT INTO `attendances` VALUES ('4152', '31', '1010', '17', '1', '2025-01-07', '', '12', '2025-01-07 06:45:45', '2025-01-07 06:45:45');
INSERT INTO `attendances` VALUES ('4153', '31', '1012', '17', '1', '2025-01-07', '', '12', '2025-01-07 06:45:45', '2025-01-07 06:45:45');
INSERT INTO `attendances` VALUES ('4154', '31', '1014', '17', '1', '2025-01-07', '', '12', '2025-01-07 06:45:45', '2025-01-07 06:45:45');
INSERT INTO `attendances` VALUES ('4155', '31', '1016', '17', '1', '2025-01-07', '', '12', '2025-01-07 06:45:45', '2025-01-07 06:45:45');
INSERT INTO `attendances` VALUES ('4156', '31', '1018', '17', '1', '2025-01-07', '', '12', '2025-01-07 06:45:45', '2025-01-07 06:45:45');
INSERT INTO `attendances` VALUES ('4157', '31', '1020', '17', '1', '2025-01-07', '', '12', '2025-01-07 06:45:45', '2025-01-07 06:45:45');
INSERT INTO `attendances` VALUES ('4158', '31', '1022', '17', '1', '2025-01-07', '', '12', '2025-01-07 06:45:45', '2025-01-07 06:45:45');
INSERT INTO `attendances` VALUES ('4159', '31', '1024', '17', '1', '2025-01-07', '', '12', '2025-01-07 06:45:45', '2025-01-07 06:45:45');
INSERT INTO `attendances` VALUES ('4160', '31', '1026', '17', '1', '2025-01-07', '', '12', '2025-01-07 06:45:45', '2025-01-07 06:45:45');
INSERT INTO `attendances` VALUES ('4161', '31', '1028', '17', '1', '2025-01-07', '', '12', '2025-01-07 06:45:45', '2025-01-07 06:45:45');
INSERT INTO `attendances` VALUES ('4162', '31', '1030', '17', '1', '2025-01-07', '', '12', '2025-01-07 06:45:45', '2025-01-07 06:45:45');
INSERT INTO `attendances` VALUES ('4163', '31', '1032', '17', '1', '2025-01-07', '', '12', '2025-01-07 06:45:45', '2025-01-07 06:45:45');
INSERT INTO `attendances` VALUES ('4164', '31', '1034', '17', '1', '2025-01-07', '', '12', '2025-01-07 06:45:45', '2025-01-07 06:45:45');
INSERT INTO `attendances` VALUES ('4165', '31', '1036', '17', '1', '2025-01-07', '', '12', '2025-01-07 06:45:45', '2025-01-07 06:45:45');
INSERT INTO `attendances` VALUES ('4166', '31', '1038', '17', '1', '2025-01-07', '', '12', '2025-01-07 06:45:45', '2025-01-07 06:45:45');
INSERT INTO `attendances` VALUES ('4167', '31', '1040', '17', '1', '2025-01-07', '', '12', '2025-01-07 06:45:45', '2025-01-07 06:45:45');
INSERT INTO `attendances` VALUES ('4168', '31', '1042', '17', '1', '2025-01-07', '', '12', '2025-01-07 06:45:45', '2025-01-07 06:45:45');
INSERT INTO `attendances` VALUES ('4169', '31', '1044', '17', '1', '2025-01-07', '', '12', '2025-01-07 06:45:45', '2025-01-07 06:45:45');
INSERT INTO `attendances` VALUES ('4170', '31', '1046', '17', '1', '2025-01-07', '', '12', '2025-01-07 06:45:45', '2025-01-07 06:45:45');
INSERT INTO `attendances` VALUES ('4171', '31', '1048', '17', '1', '2025-01-07', '', '12', '2025-01-07 06:45:45', '2025-01-07 06:45:45');
INSERT INTO `attendances` VALUES ('4172', '31', '1050', '17', '1', '2025-01-07', '', '12', '2025-01-07 06:45:45', '2025-01-07 06:45:45');
INSERT INTO `attendances` VALUES ('4173', '31', '1052', '17', '1', '2025-01-07', '', '12', '2025-01-07 06:45:45', '2025-01-07 06:45:45');
INSERT INTO `attendances` VALUES ('4174', '31', '1054', '17', '1', '2025-01-07', '', '12', '2025-01-07 06:45:45', '2025-01-07 06:45:45');
INSERT INTO `attendances` VALUES ('4175', '31', '1056', '17', '1', '2025-01-07', '', '12', '2025-01-07 06:45:45', '2025-01-07 06:45:45');
INSERT INTO `attendances` VALUES ('4176', '31', '1058', '17', '1', '2025-01-07', '', '12', '2025-01-07 06:45:45', '2025-01-07 06:45:45');
INSERT INTO `attendances` VALUES ('4177', '31', '1060', '17', '1', '2025-01-07', '', '12', '2025-01-07 06:45:45', '2025-01-07 06:45:45');
INSERT INTO `attendances` VALUES ('4178', '31', '1062', '17', '1', '2025-01-07', '', '12', '2025-01-07 06:45:45', '2025-01-07 06:45:45');
INSERT INTO `attendances` VALUES ('4179', '31', '341', '17', '1', '2025-01-08', '', '12', '2025-01-08 03:38:12', '2025-01-08 03:38:12');
INSERT INTO `attendances` VALUES ('4180', '31', '1004', '17', '1', '2025-01-08', '', '12', '2025-01-08 03:38:13', '2025-01-08 03:38:13');
INSERT INTO `attendances` VALUES ('4181', '31', '1006', '17', '1', '2025-01-08', '', '12', '2025-01-08 03:38:13', '2025-01-08 03:38:13');
INSERT INTO `attendances` VALUES ('4182', '31', '1008', '17', '1', '2025-01-08', '', '12', '2025-01-08 03:38:13', '2025-01-08 03:38:13');
INSERT INTO `attendances` VALUES ('4183', '31', '1010', '17', '1', '2025-01-08', '', '12', '2025-01-08 03:38:13', '2025-01-08 03:38:13');
INSERT INTO `attendances` VALUES ('4184', '31', '1012', '17', '1', '2025-01-08', '', '12', '2025-01-08 03:38:13', '2025-01-08 03:38:13');
INSERT INTO `attendances` VALUES ('4185', '31', '1014', '17', '1', '2025-01-08', '', '12', '2025-01-08 03:38:13', '2025-01-08 03:38:13');
INSERT INTO `attendances` VALUES ('4186', '31', '1016', '17', '1', '2025-01-08', '', '12', '2025-01-08 03:38:13', '2025-01-08 03:38:13');
INSERT INTO `attendances` VALUES ('4187', '31', '1018', '17', '1', '2025-01-08', '', '12', '2025-01-08 03:38:13', '2025-01-08 03:38:13');
INSERT INTO `attendances` VALUES ('4188', '31', '1020', '17', '1', '2025-01-08', '', '12', '2025-01-08 03:38:13', '2025-01-08 03:38:13');
INSERT INTO `attendances` VALUES ('4189', '31', '1022', '17', '1', '2025-01-08', '', '12', '2025-01-08 03:38:13', '2025-01-08 03:38:13');
INSERT INTO `attendances` VALUES ('4190', '31', '1024', '17', '1', '2025-01-08', '', '12', '2025-01-08 03:38:13', '2025-01-08 03:38:13');
INSERT INTO `attendances` VALUES ('4191', '31', '1026', '17', '1', '2025-01-08', '', '12', '2025-01-08 03:38:13', '2025-01-08 03:38:13');
INSERT INTO `attendances` VALUES ('4192', '31', '1028', '17', '1', '2025-01-08', '', '12', '2025-01-08 03:38:13', '2025-01-08 03:38:13');
INSERT INTO `attendances` VALUES ('4193', '31', '1030', '17', '1', '2025-01-08', '', '12', '2025-01-08 03:38:13', '2025-01-08 03:38:13');
INSERT INTO `attendances` VALUES ('4194', '31', '1032', '17', '1', '2025-01-08', '', '12', '2025-01-08 03:38:13', '2025-01-08 03:38:13');
INSERT INTO `attendances` VALUES ('4195', '31', '1034', '17', '1', '2025-01-08', '', '12', '2025-01-08 03:38:13', '2025-01-08 03:38:13');
INSERT INTO `attendances` VALUES ('4196', '31', '1036', '17', '1', '2025-01-08', '', '12', '2025-01-08 03:38:13', '2025-01-08 03:38:13');
INSERT INTO `attendances` VALUES ('4197', '31', '1038', '17', '0', '2025-01-08', '', '12', '2025-01-08 03:38:13', '2025-01-08 03:57:57');
INSERT INTO `attendances` VALUES ('4198', '31', '1040', '17', '1', '2025-01-08', '', '12', '2025-01-08 03:38:13', '2025-01-08 03:38:13');
INSERT INTO `attendances` VALUES ('4199', '31', '1042', '17', '1', '2025-01-08', '', '12', '2025-01-08 03:38:13', '2025-01-08 03:38:13');
INSERT INTO `attendances` VALUES ('4200', '31', '1044', '17', '1', '2025-01-08', '', '12', '2025-01-08 03:38:13', '2025-01-08 03:38:13');
INSERT INTO `attendances` VALUES ('4201', '31', '1046', '17', '1', '2025-01-08', '', '12', '2025-01-08 03:38:13', '2025-01-08 03:38:13');
INSERT INTO `attendances` VALUES ('4202', '31', '1048', '17', '1', '2025-01-08', '', '12', '2025-01-08 03:38:13', '2025-01-08 03:38:13');
INSERT INTO `attendances` VALUES ('4203', '31', '1050', '17', '1', '2025-01-08', '', '12', '2025-01-08 03:38:13', '2025-01-08 03:38:13');
INSERT INTO `attendances` VALUES ('4204', '31', '1052', '17', '1', '2025-01-08', '', '12', '2025-01-08 03:38:13', '2025-01-08 03:38:13');
INSERT INTO `attendances` VALUES ('4205', '31', '1054', '17', '1', '2025-01-08', '', '12', '2025-01-08 03:38:13', '2025-01-08 03:38:13');
INSERT INTO `attendances` VALUES ('4206', '31', '1056', '17', '1', '2025-01-08', '', '12', '2025-01-08 03:38:13', '2025-01-08 03:38:13');
INSERT INTO `attendances` VALUES ('4207', '31', '1058', '17', '1', '2025-01-08', '', '12', '2025-01-08 03:38:13', '2025-01-08 03:38:13');
INSERT INTO `attendances` VALUES ('4208', '31', '1060', '17', '0', '2025-01-08', '', '12', '2025-01-08 03:38:13', '2025-01-08 03:57:58');
INSERT INTO `attendances` VALUES ('4209', '31', '1062', '17', '1', '2025-01-08', '', '12', '2025-01-08 03:38:13', '2025-01-08 03:38:13');

CREATE TABLE IF NOT EXISTS `certificate_templates` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(191) NOT NULL,
  `page_layout` varchar(191) NOT NULL COMMENT 'A4 Portrait, A4 Landscape, Custom',
  `height` double(8,2) DEFAULT NULL,
  `width` double(8,2) DEFAULT NULL,
  `user_image_shape` varchar(191) NOT NULL COMMENT 'Round, Square',
  `image_size` double(8,2) DEFAULT NULL,
  `background_image` varchar(191) DEFAULT NULL,
  `description` text DEFAULT NULL,
  `fields` varchar(191) DEFAULT NULL,
  `style` longtext CHARACTER SET utf8mb4 COLLATE utf8mb4_bin DEFAULT NULL CHECK (json_valid(`style`)),
  `type` varchar(191) DEFAULT NULL COMMENT 'Student, Staff',
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `certificate_templates_school_id_foreign` (`school_id`),
  CONSTRAINT `certificate_templates_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=4 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `certificate_templates` VALUES ('1', 'Teacher Of The Year', 'A4 Landscape', '210', '297', 'Round', '100', '12/certificate/chwl0QtkfuPpeedOaLMsgYWNsxVwky9lrHOk8D3P.svg', '<p style=\"text-align: center;\"><span style=\"font-family: \'Pinyon Script\'; font-size: 18pt;\">Presented to <strong>{full_name}</strong>, Email: <strong>{email}</strong>, Date of Birth: <strong>{dob}</strong>. This award recognizes your exceptional dedication, innovative teaching methods, and unwavering commitment to student success. Your passion for education and ability to inspire students have set a remarkable standard for excellence. Congratulations on being named Best Teacher of the Year!... total&nbsp; </span><span style=\"font-family: \'Pinyon Script\';\"><span style=\"font-size: 18pt;\">experience is </span><strong><span style=\"font-size: 18pt;\">{experience}</span>.</strong></span>&nbsp;<span style=\"font-family: \'Pinyon Script\'; font-size: 18pt;\"> Gender = <strong>{gender}</strong>, Joining date = <strong>{joining_date}</strong>, Roles = <strong>{role}</strong>, Qualification =&nbsp;<strong>{qualification}</strong>, Mobile No. =&nbsp;<strong>{mobile}</strong>, Current Address =&nbsp;<strong>{current_address}</strong>, Permanent address =&nbsp;<strong>{permanent_address},&nbsp;</strong>Session Year = <strong>{session_year}.</strong></span></p>', 'school_logo,signature,issue_date,user_image', '{\"title\": \"style=\\\"position:absolute; left: 145px;top: 290px\\\"\", \"signature\": \"style=\\\"position:absolute; left: 729px;top: 569px\\\"\", \"issue_date\": \"style=\\\"position:absolute; left: 288px;top: 624px\\\"\", \"user_image\": \"style=\\\"position:absolute; left: 526px;top: 598px\\\"\", \"description\": \"style=\\\"position:absolute; left: 131px;top: 320px\\\"\", \"school_logo\": \"style=\\\"position:absolute; left: 833px;top: 109px\\\"\", \"school_name\": \"style=\\\"position:absolute; left: 480px;top: 60px\\\"\", \"school_email\": \"style=\\\"position:absolute; left: 125px;top: 175px\\\"\", \"school_mobile\": \"style=\\\"position:absolute; left: 125px;top: 130px\\\"\", \"school_address\": \"style=\\\"position:absolute; left: 125px;top: 85px\\\"\"}', 'Staff', '12', '2024-06-29 13:02:21', '2024-09-30 13:04:18');
INSERT INTO `certificate_templates` VALUES ('2', 'School Leaving Certificate', 'A4 Portrait', '297', '210', 'Round', '100', '12/certificate/Sr7UrhBrjvjlbt1GQQaYzlI4j0ZqZEFTmZqKpNWO.jpg', '<p style=\"text-align: center;\"><span style=\"font-size: 24pt; font-family: \'Pinyon Script\';\"><strong>Matru Shree R.D. Varsani Kumar Vidhalay - Bhuj</strong></span></p>
<table style=\"border-collapse: collapse; width: 100%; height: 116.125px; border-width: 0px; border-spacing: 5px;\" border=\"1\"><colgroup><col style=\"width: 15.337%;\"><col style=\"width: 73.315%;\"><col style=\"width: 11.348%;\"></colgroup>
<tbody>
<tr style=\"height: 36.375px;\">
<td style=\"height: 36.375px; border-width: 0px; padding: 5px;\"><span style=\"font-size: 10pt;\"><strong>Address&nbsp;</strong></span></td>
<td style=\"height: 36.375px; border-width: 0px; padding: 5px;\"><span style=\"font-size: 10pt;\">Sardar Patel, Vidya Sankul, Mundra Road, Bhuj, Bhuj, Gujarat 370040</span></td>
<td style=\"height: 116.125px; border-width: 0px; padding: 5px;\" rowspan=\"3\"><img src=\"storage/school-settings/655c4a39862746.922441361700547129.svg\" alt=\"\" width=\"201\" height=\"63\"></td>
</tr>
<tr style=\"height: 39.375px;\">
<td style=\"height: 39.375px; border-width: 0px; padding: 5px;\"><span style=\"font-size: 10pt;\"><strong>Email</strong></span></td>
<td style=\"height: 39.375px; border-width: 0px; padding: 5px;\"><span style=\"font-size: 10pt;\">er.varsani@gmail.com</span></td>
</tr>
<tr style=\"height: 40.375px;\">
<td style=\"height: 40.375px; border-width: 0px; padding: 5px;\"><span style=\"font-size: 10pt;\"><strong>Mobile No.</strong></span></td>
<td style=\"height: 40.375px; border-width: 0px; padding: 5px;\"><span style=\"font-size: 10pt;\">9685968596</span></td>
</tr>
</tbody>
</table>
<hr>
<p style=\"text-align: center;\"><span style=\"font-family: lato; font-size: 18pt;\"><strong>SCHOOL LEAVING CERTIFICATE</strong></span></p>
<table style=\"border-collapse: collapse; width: 100%; height: 376.875px; border-width: 1px;\" border=\"1\"><colgroup><col style=\"width: 26.0899%;\"><col style=\"width: 73.9101%;\"></colgroup>
<tbody>
<tr style=\"height: 34.375px;\">
<td style=\"height: 34.375px; border-width: 1px; padding: 2px;\"><strong>Admission No.</strong></td>
<td style=\"height: 34.375px; border-width: 1px; padding: 2px;\">&nbsp; : {admission_no}</td>
</tr>
<tr style=\"height: 30.375px;\">
<td style=\"height: 30.375px; border-width: 1px; padding: 2px;\"><strong>Student Name</strong></td>
<td style=\"height: 30.375px; border-width: 1px; padding: 2px;\">&nbsp; : {full_name}</td>
</tr>
<tr style=\"height: 34.375px;\">
<td style=\"height: 34.375px; border-width: 1px; padding: 2px;\"><strong>Guardian Name</strong></td>
<td style=\"height: 34.375px; border-width: 1px; padding: 2px;\">&nbsp; : {guardian_name}</td>
</tr>
<tr style=\"height: 29.375px;\">
<td style=\"height: 29.375px; border-width: 1px; padding: 2px;\"><strong>Surname</strong></td>
<td style=\"height: 29.375px; border-width: 1px; padding: 2px;\">&nbsp; : {last_name}</td>
</tr>
<tr style=\"height: 27.375px;\">
<td style=\"height: 27.375px; border-width: 1px; padding: 2px;\"><strong>Nationality</strong></td>
<td style=\"height: 27.375px; border-width: 1px; padding: 2px;\">&nbsp; : Indian</td>
</tr>
<tr style=\"height: 26.375px;\">
<td style=\"height: 26.375px; border-width: 1px; padding: 2px;\"><strong>Religion</strong></td>
<td style=\"height: 26.375px; border-width: 1px; padding: 2px;\">&nbsp; :&nbsp;</td>
</tr>
<tr style=\"height: 28.375px;\">
<td style=\"height: 28.375px; border-width: 1px; padding: 2px;\"><strong>Caste</strong></td>
<td style=\"height: 28.375px; border-width: 1px; padding: 2px;\">&nbsp; :&nbsp;</td>
</tr>
<tr style=\"height: 29.375px;\">
<td style=\"height: 29.375px; border-width: 1px; padding: 2px;\"><strong>DOB</strong></td>
<td style=\"height: 29.375px; border-width: 1px; padding: 2px;\">&nbsp; : {dob}</td>
</tr>
<tr style=\"height: 29.375px;\">
<td style=\"height: 29.375px; border-width: 1px; padding: 2px;\"><strong>Class Section</strong></td>
<td style=\"height: 29.375px; border-width: 1px; padding: 2px;\">&nbsp; : {class_section}</td>
</tr>
<tr style=\"height: 26.375px;\">
<td style=\"height: 26.375px; border-width: 1px; padding: 2px;\"><strong>Admission Date</strong></td>
<td style=\"height: 26.375px; border-width: 1px; padding: 2px;\">&nbsp; : {admission_date}</td>
</tr>
<tr style=\"height: 27.375px;\">
<td style=\"height: 27.375px; border-width: 1px; padding: 2px;\"><strong>Gender</strong></td>
<td style=\"height: 27.375px; border-width: 1px; padding: 2px;\">&nbsp; : {gender}</td>
</tr>
<tr style=\"height: 29.375px;\">
<td style=\"height: 29.375px; border-width: 1px; padding: 2px;\"><strong>Remarks</strong></td>
<td style=\"height: 29.375px; border-width: 1px; padding: 2px;\">&nbsp; : Good</td>
</tr>
<tr style=\"height: 24.375px;\">
<td style=\"height: 24.375px; border-width: 1px; padding: 2px;\"><strong>Session Year</strong></td>
<td style=\"height: 24.375px; border-width: 1px; padding: 2px;\">&nbsp; : {session_year}</td>
</tr>
</tbody>
</table>
<p>Certified that the above information in accordance with the school general register.</p>', 'signature,issue_date,user_image', '{\"title\": \"style=\\\"position:absolute; left: 145px;top: 290px\\\"\", \"signature\": \"style=\\\"position:absolute; left: 504px;top: 888px\\\"\", \"issue_date\": \"style=\\\"position:absolute; left: 97px;top: 928px\\\"\", \"user_image\": \"style=\\\"position:absolute; left: 329px;top: 891px\\\"\", \"description\": \"style=\\\"position:absolute; left: 97px;top: 89px\\\"\", \"school_logo\": \"style=\\\"position:absolute; left: 525px;top: 75px\\\"\", \"school_name\": \"style=\\\"position:absolute; left: 480px;top: 60px\\\"\", \"school_email\": \"style=\\\"position:absolute; left: 125px;top: 175px\\\"\", \"school_mobile\": \"style=\\\"position:absolute; left: 125px;top: 130px\\\"\", \"school_address\": \"style=\\\"position:absolute; left: 125px;top: 85px\\\"\"}', 'Student', '12', '2024-06-29 13:12:28', '2024-09-30 13:04:19');
INSERT INTO `certificate_templates` VALUES ('3', 'Annaul Exam Certificate', 'A4 Landscape', '210', '297', 'Round', '100', '12/certificate/swfUmewEc13WzI3BhhzomPoYL89hsSMWa1JTiRaL.jpg', '<div style=\"text-align: center;\"><strong><span style=\"font-family: \'Pinyon Script\'; font-size: 24pt;\">Annaul Exam Certificate</span></strong></div>
<div style=\"text-align: center;\"><span style=\"font-family: \'Pinyon Script\'; font-size: 18pt;\">This Is To Certify That &nbsp;<strong>{full_name}</strong>&nbsp;And Of He/she Is Gender As <strong>{gender}</strong> &nbsp;Son/daughter Of &nbsp;<strong>{guardian_name}</strong>. Bearing Roll- <strong>{roll_no}</strong> &amp;Class <strong>{class_section}</strong> Dulg Passed. Exam = <strong>{exam}&nbsp;</strong>Obtained marks&nbsp;<strong>{obtain_marks} / {total_marks}&nbsp;</strong>and grade is&nbsp;<strong>{grade}.&nbsp;</strong>School name \"Matru Shree R.D. Varsani kumar vidhalay Bhuj - Kutch\".</span></div>', 'signature,issue_date,user_image', '{\"title\": \"style=\\\"position:absolute; left: 145px;top: 290px\\\"\", \"signature\": \"style=\\\"position:absolute; left: 648px;top: 551px\\\"\", \"issue_date\": \"style=\\\"position:absolute; left: 357px;top: 611px\\\"\", \"user_image\": \"style=\\\"position:absolute; left: 517px;top: 516px\\\"\", \"description\": \"style=\\\"position:absolute; left: 145px;top: 317px\\\"\", \"school_logo\": \"style=\\\"position:absolute; left: 525px;top: 75px\\\"\", \"school_name\": \"style=\\\"position:absolute; left: 480px;top: 60px\\\"\", \"school_email\": \"style=\\\"position:absolute; left: 125px;top: 175px\\\"\", \"school_mobile\": \"style=\\\"position:absolute; left: 125px;top: 130px\\\"\", \"school_address\": \"style=\\\"position:absolute; left: 125px;top: 85px\\\"\"}', 'Student', '12', '2024-07-01 10:49:56', '2024-09-30 13:04:19');

CREATE TABLE IF NOT EXISTS `class_groups` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(191) DEFAULT NULL,
  `description` text DEFAULT NULL,
  `image` varchar(191) DEFAULT NULL,
  `class_ids` varchar(191) DEFAULT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `class_groups_school_id_foreign` (`school_id`),
  CONSTRAINT `class_groups_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=5 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `class_groups` VALUES ('1', 'Pre - Primary school', 'This Highlights the playful environment and focus', '12/class_group/6683ed25afb3d1.285979441719921957.jpg', '13,14,15', '12', '2024-07-02 17:35:58', '2024-09-30 13:04:18');
INSERT INTO `class_groups` VALUES ('2', 'Primary school', 'This Highlights the playful environment and focus', '12/class_group/6683ed4f3889f8.944429231719921999.jpg', '16,17,18', '12', '2024-07-02 17:36:39', '2024-09-30 13:04:18');
INSERT INTO `class_groups` VALUES ('3', 'Secondary  School', 'This Highlights the playful environment and focus', '12/class_group/6683ed6fa99f80.737317911719922031.jpg', '19,20,21', '12', '2024-07-02 17:37:12', '2024-09-30 13:04:18');
INSERT INTO `class_groups` VALUES ('4', 'Higher Secondary School', 'This Highlights the playful environment and focus', '12/class_group/6683ed871f58f2.513785541719922055.jpg', '23,24,27', '12', '2024-07-02 17:37:35', '2024-09-30 13:04:18');

CREATE TABLE IF NOT EXISTS `class_sections` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `class_id` bigint(20) unsigned NOT NULL,
  `section_id` bigint(20) unsigned NOT NULL,
  `medium_id` bigint(20) unsigned NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `unique_id` (`class_id`,`section_id`,`medium_id`),
  KEY `class_sections_school_id_foreign` (`school_id`),
  KEY `class_sections_section_id_foreign` (`section_id`),
  KEY `class_sections_medium_id_foreign` (`medium_id`),
  CONSTRAINT `class_sections_class_id_foreign` FOREIGN KEY (`class_id`) REFERENCES `classes` (`id`) ON DELETE CASCADE,
  CONSTRAINT `class_sections_medium_id_foreign` FOREIGN KEY (`medium_id`) REFERENCES `mediums` (`id`) ON DELETE CASCADE,
  CONSTRAINT `class_sections_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `class_sections_section_id_foreign` FOREIGN KEY (`section_id`) REFERENCES `sections` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=61 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `class_sections` VALUES ('21', '13', '10', '10', '12', NULL, NULL, NULL);
INSERT INTO `class_sections` VALUES ('22', '14', '10', '10', '12', NULL, NULL, NULL);
INSERT INTO `class_sections` VALUES ('23', '15', '10', '10', '12', NULL, NULL, NULL);
INSERT INTO `class_sections` VALUES ('24', '16', '10', '10', '12', NULL, NULL, NULL);
INSERT INTO `class_sections` VALUES ('25', '17', '10', '10', '12', NULL, NULL, NULL);
INSERT INTO `class_sections` VALUES ('26', '18', '10', '10', '12', NULL, NULL, NULL);
INSERT INTO `class_sections` VALUES ('27', '19', '10', '10', '12', NULL, NULL, NULL);
INSERT INTO `class_sections` VALUES ('28', '20', '10', '10', '12', NULL, NULL, NULL);
INSERT INTO `class_sections` VALUES ('29', '21', '10', '10', '12', NULL, NULL, NULL);
INSERT INTO `class_sections` VALUES ('31', '23', '10', '10', '12', NULL, NULL, NULL);
INSERT INTO `class_sections` VALUES ('32', '24', '10', '10', '12', NULL, NULL, NULL);
INSERT INTO `class_sections` VALUES ('33', '25', '10', '10', '12', NULL, NULL, NULL);
INSERT INTO `class_sections` VALUES ('34', '26', '10', '10', '12', NULL, NULL, NULL);
INSERT INTO `class_sections` VALUES ('35', '27', '10', '10', '12', NULL, NULL, NULL);
INSERT INTO `class_sections` VALUES ('36', '28', '10', '10', '12', NULL, NULL, NULL);
INSERT INTO `class_sections` VALUES ('37', '29', '10', '10', '12', NULL, NULL, NULL);
INSERT INTO `class_sections` VALUES ('55', '13', '11', '10', '12', '2024-01-25 05:28:36', '2024-01-25 05:28:36', NULL);
INSERT INTO `class_sections` VALUES ('56', '13', '12', '10', '12', '2024-01-25 05:28:36', '2024-01-25 05:28:36', NULL);
INSERT INTO `class_sections` VALUES ('57', '14', '11', '10', '12', '2024-01-25 05:28:51', '2024-01-25 05:28:51', NULL);
INSERT INTO `class_sections` VALUES ('58', '14', '12', '10', '12', '2024-01-25 05:28:51', '2024-01-25 05:28:51', NULL);
INSERT INTO `class_sections` VALUES ('59', '15', '11', '10', '12', '2024-01-25 05:29:06', '2024-01-25 05:29:06', NULL);
INSERT INTO `class_sections` VALUES ('60', '15', '12', '10', '12', '2024-01-25 05:29:06', '2024-01-25 05:29:06', NULL);

CREATE TABLE IF NOT EXISTS `class_subjects` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `class_id` bigint(20) unsigned NOT NULL,
  `subject_id` bigint(20) unsigned NOT NULL,
  `type` varchar(32) NOT NULL COMMENT 'Compulsory / Elective',
  `elective_subject_group_id` bigint(20) unsigned DEFAULT NULL COMMENT 'if type=Elective',
  `semester_id` bigint(20) unsigned DEFAULT NULL,
  `virtual_semester_id` int(11) GENERATED ALWAYS AS (case when `semester_id` is not null then `semester_id` else 0 end) VIRTUAL,
  `school_id` bigint(20) unsigned NOT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `unique_ids` (`class_id`,`subject_id`,`virtual_semester_id`),
  KEY `class_subjects_elective_subject_group_id_foreign` (`elective_subject_group_id`),
  KEY `class_subjects_school_id_foreign` (`school_id`),
  KEY `class_subjects_subject_id_foreign` (`subject_id`),
  KEY `class_subjects_semester_id_foreign` (`semester_id`),
  CONSTRAINT `class_subjects_class_id_foreign` FOREIGN KEY (`class_id`) REFERENCES `classes` (`id`) ON DELETE CASCADE,
  CONSTRAINT `class_subjects_elective_subject_group_id_foreign` FOREIGN KEY (`elective_subject_group_id`) REFERENCES `elective_subject_groups` (`id`) ON DELETE CASCADE,
  CONSTRAINT `class_subjects_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `class_subjects_semester_id_foreign` FOREIGN KEY (`semester_id`) REFERENCES `semesters` (`id`) ON DELETE CASCADE,
  CONSTRAINT `class_subjects_subject_id_foreign` FOREIGN KEY (`subject_id`) REFERENCES `subjects` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=201 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `class_subjects` VALUES ('46', '13', '19', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:27:35', '2024-01-25 06:21:27');
INSERT INTO `class_subjects` VALUES ('47', '13', '25', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:27:35', '2024-01-25 06:21:27');
INSERT INTO `class_subjects` VALUES ('48', '13', '20', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:27:35', '2024-01-25 06:21:27');
INSERT INTO `class_subjects` VALUES ('49', '13', '26', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:27:35', '2024-01-25 06:21:27');
INSERT INTO `class_subjects` VALUES ('50', '13', '27', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:27:35', '2024-01-25 06:21:27');
INSERT INTO `class_subjects` VALUES ('51', '13', '23', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:27:35', '2024-01-25 06:21:27');
INSERT INTO `class_subjects` VALUES ('52', '13', '28', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:27:35', '2024-01-25 06:21:27');
INSERT INTO `class_subjects` VALUES ('53', '13', '29', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:27:35', '2024-01-25 06:21:27');
INSERT INTO `class_subjects` VALUES ('54', '13', '30', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:27:35', '2024-01-25 06:21:27');
INSERT INTO `class_subjects` VALUES ('55', '14', '19', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:29:11', '2024-01-25 06:21:40');
INSERT INTO `class_subjects` VALUES ('56', '14', '25', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:29:11', '2024-01-25 06:21:40');
INSERT INTO `class_subjects` VALUES ('57', '14', '20', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:29:11', '2024-01-25 06:21:40');
INSERT INTO `class_subjects` VALUES ('58', '14', '26', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:29:11', '2024-01-25 06:21:40');
INSERT INTO `class_subjects` VALUES ('59', '14', '27', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:29:11', '2024-01-25 06:21:40');
INSERT INTO `class_subjects` VALUES ('60', '14', '23', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:29:11', '2024-01-25 06:21:40');
INSERT INTO `class_subjects` VALUES ('61', '14', '28', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:29:11', '2024-01-25 06:21:40');
INSERT INTO `class_subjects` VALUES ('62', '14', '29', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:29:11', '2024-01-25 06:21:40');
INSERT INTO `class_subjects` VALUES ('63', '14', '30', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:29:11', '2024-01-25 06:21:40');
INSERT INTO `class_subjects` VALUES ('64', '15', '19', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:30:29', '2023-11-18 04:30:29');
INSERT INTO `class_subjects` VALUES ('65', '15', '25', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:30:29', '2023-11-18 04:30:29');
INSERT INTO `class_subjects` VALUES ('66', '15', '20', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:30:29', '2023-11-18 04:30:29');
INSERT INTO `class_subjects` VALUES ('67', '15', '26', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:30:29', '2023-11-18 04:30:29');
INSERT INTO `class_subjects` VALUES ('68', '15', '27', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:30:29', '2023-11-18 04:30:29');
INSERT INTO `class_subjects` VALUES ('69', '15', '23', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:30:29', '2023-11-18 04:30:29');
INSERT INTO `class_subjects` VALUES ('70', '15', '28', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:30:29', '2023-11-18 04:30:29');
INSERT INTO `class_subjects` VALUES ('71', '15', '29', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:30:29', '2023-11-18 04:30:29');
INSERT INTO `class_subjects` VALUES ('72', '15', '30', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:30:29', '2023-11-18 04:30:29');
INSERT INTO `class_subjects` VALUES ('73', '16', '19', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:32:11', '2023-11-18 04:32:11');
INSERT INTO `class_subjects` VALUES ('74', '16', '25', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:32:11', '2023-11-18 04:32:11');
INSERT INTO `class_subjects` VALUES ('75', '16', '20', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:32:11', '2023-11-18 04:32:11');
INSERT INTO `class_subjects` VALUES ('76', '16', '26', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:32:11', '2023-11-18 04:32:11');
INSERT INTO `class_subjects` VALUES ('77', '16', '27', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:32:11', '2023-11-18 04:32:11');
INSERT INTO `class_subjects` VALUES ('78', '16', '23', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:32:11', '2023-11-18 04:32:11');
INSERT INTO `class_subjects` VALUES ('79', '16', '28', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:32:11', '2023-11-18 04:32:11');
INSERT INTO `class_subjects` VALUES ('80', '16', '29', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:32:11', '2023-11-18 04:32:11');
INSERT INTO `class_subjects` VALUES ('81', '16', '30', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:32:11', '2023-11-18 04:32:11');
INSERT INTO `class_subjects` VALUES ('82', '17', '19', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:32:58', '2023-11-18 04:32:58');
INSERT INTO `class_subjects` VALUES ('83', '17', '25', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:32:58', '2023-11-18 04:32:58');
INSERT INTO `class_subjects` VALUES ('84', '17', '20', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:32:58', '2023-11-18 04:32:58');
INSERT INTO `class_subjects` VALUES ('85', '17', '26', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:32:58', '2023-11-18 04:32:58');
INSERT INTO `class_subjects` VALUES ('86', '17', '27', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:32:58', '2023-11-18 04:32:58');
INSERT INTO `class_subjects` VALUES ('87', '17', '23', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:32:58', '2023-11-18 04:32:58');
INSERT INTO `class_subjects` VALUES ('88', '17', '28', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:32:58', '2023-11-18 04:32:58');
INSERT INTO `class_subjects` VALUES ('89', '17', '29', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:32:58', '2023-11-18 04:32:58');
INSERT INTO `class_subjects` VALUES ('90', '17', '30', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:32:58', '2023-11-18 04:32:58');
INSERT INTO `class_subjects` VALUES ('91', '18', '19', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:38:35', '2023-11-18 04:38:35');
INSERT INTO `class_subjects` VALUES ('92', '18', '20', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:38:35', '2023-11-18 04:38:35');
INSERT INTO `class_subjects` VALUES ('93', '18', '21', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:38:35', '2023-11-18 04:38:35');
INSERT INTO `class_subjects` VALUES ('94', '18', '32', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:38:35', '2023-11-18 04:38:35');
INSERT INTO `class_subjects` VALUES ('95', '18', '33', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:38:35', '2023-11-18 04:38:35');
INSERT INTO `class_subjects` VALUES ('96', '18', '27', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:38:35', '2023-11-18 04:38:35');
INSERT INTO `class_subjects` VALUES ('97', '18', '23', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:38:35', '2023-11-18 04:38:35');
INSERT INTO `class_subjects` VALUES ('98', '18', '28', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:38:35', '2023-11-18 04:38:35');
INSERT INTO `class_subjects` VALUES ('99', '18', '29', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:38:35', '2023-11-18 04:38:35');
INSERT INTO `class_subjects` VALUES ('100', '18', '30', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:38:35', '2023-11-18 04:38:35');
INSERT INTO `class_subjects` VALUES ('101', '18', '25', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:38:35', '2023-11-18 04:38:35');
INSERT INTO `class_subjects` VALUES ('102', '18', '31', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:38:35', '2023-11-18 04:38:35');
INSERT INTO `class_subjects` VALUES ('103', '19', '19', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:40:40', '2023-11-18 04:40:40');
INSERT INTO `class_subjects` VALUES ('104', '19', '25', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:40:40', '2023-11-18 04:40:40');
INSERT INTO `class_subjects` VALUES ('105', '19', '31', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:40:40', '2023-11-18 04:40:40');
INSERT INTO `class_subjects` VALUES ('106', '19', '21', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:40:40', '2023-11-18 04:40:40');
INSERT INTO `class_subjects` VALUES ('107', '19', '20', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:40:40', '2023-11-18 04:40:40');
INSERT INTO `class_subjects` VALUES ('108', '19', '32', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:40:40', '2023-11-18 04:40:40');
INSERT INTO `class_subjects` VALUES ('109', '19', '33', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:40:40', '2023-11-18 04:40:40');
INSERT INTO `class_subjects` VALUES ('110', '19', '27', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:40:40', '2023-11-18 04:40:40');
INSERT INTO `class_subjects` VALUES ('111', '19', '23', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:40:40', '2023-11-18 04:40:40');
INSERT INTO `class_subjects` VALUES ('112', '19', '28', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:40:40', '2023-11-18 04:40:40');
INSERT INTO `class_subjects` VALUES ('113', '19', '29', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:40:40', '2023-11-18 04:40:40');
INSERT INTO `class_subjects` VALUES ('114', '19', '30', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:40:40', '2023-11-18 04:40:40');
INSERT INTO `class_subjects` VALUES ('115', '20', '19', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:43:27', '2023-11-18 04:43:27');
INSERT INTO `class_subjects` VALUES ('116', '20', '25', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:43:27', '2023-11-18 04:43:27');
INSERT INTO `class_subjects` VALUES ('117', '20', '31', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:43:27', '2023-11-18 04:43:27');
INSERT INTO `class_subjects` VALUES ('118', '20', '20', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:43:27', '2023-11-18 04:43:27');
INSERT INTO `class_subjects` VALUES ('119', '20', '21', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:43:27', '2023-11-18 04:43:27');
INSERT INTO `class_subjects` VALUES ('120', '20', '32', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:43:27', '2023-11-18 04:43:27');
INSERT INTO `class_subjects` VALUES ('121', '20', '33', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:43:27', '2023-11-18 04:43:27');
INSERT INTO `class_subjects` VALUES ('122', '20', '27', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:43:27', '2023-11-18 04:43:27');
INSERT INTO `class_subjects` VALUES ('123', '20', '23', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:43:27', '2023-11-18 04:43:27');
INSERT INTO `class_subjects` VALUES ('124', '20', '28', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:43:27', '2023-11-18 04:43:27');
INSERT INTO `class_subjects` VALUES ('125', '20', '29', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:43:27', '2023-11-18 04:43:27');
INSERT INTO `class_subjects` VALUES ('126', '20', '30', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:43:27', '2023-11-18 04:43:27');
INSERT INTO `class_subjects` VALUES ('127', '21', '19', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:52:42', '2023-11-18 04:52:42');
INSERT INTO `class_subjects` VALUES ('128', '21', '25', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:52:42', '2023-11-18 04:52:42');
INSERT INTO `class_subjects` VALUES ('129', '21', '31', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:52:42', '2023-11-18 04:52:42');
INSERT INTO `class_subjects` VALUES ('130', '21', '20', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:52:42', '2023-11-18 04:52:42');
INSERT INTO `class_subjects` VALUES ('131', '21', '21', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:52:42', '2023-11-18 04:52:42');
INSERT INTO `class_subjects` VALUES ('132', '21', '32', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:52:42', '2023-11-18 04:52:42');
INSERT INTO `class_subjects` VALUES ('133', '21', '34', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:52:42', '2023-11-18 04:52:42');
INSERT INTO `class_subjects` VALUES ('134', '21', '35', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:52:42', '2023-11-18 04:52:42');
INSERT INTO `class_subjects` VALUES ('135', '21', '23', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:52:42', '2023-11-18 04:52:42');
INSERT INTO `class_subjects` VALUES ('136', '21', '36', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:52:42', '2023-11-18 04:52:42');
INSERT INTO `class_subjects` VALUES ('137', '21', '37', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:52:42', '2023-11-18 04:52:42');
INSERT INTO `class_subjects` VALUES ('138', '21', '38', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:52:42', '2023-11-18 04:52:42');
INSERT INTO `class_subjects` VALUES ('139', '21', '39', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:52:42', '2023-11-18 04:52:42');
INSERT INTO `class_subjects` VALUES ('140', '21', '28', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:52:42', '2023-11-18 04:52:42');
INSERT INTO `class_subjects` VALUES ('141', '21', '29', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:52:42', '2023-11-18 04:52:42');
INSERT INTO `class_subjects` VALUES ('142', '21', '40', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:52:42', '2023-11-18 04:52:42');
INSERT INTO `class_subjects` VALUES ('143', '23', '19', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:54:26', '2023-11-18 04:54:26');
INSERT INTO `class_subjects` VALUES ('144', '23', '25', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:54:26', '2023-11-18 04:54:26');
INSERT INTO `class_subjects` VALUES ('145', '23', '31', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:54:26', '2023-11-18 04:54:26');
INSERT INTO `class_subjects` VALUES ('146', '23', '20', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:54:26', '2023-11-18 04:54:26');
INSERT INTO `class_subjects` VALUES ('147', '23', '21', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:54:26', '2023-11-18 04:54:26');
INSERT INTO `class_subjects` VALUES ('148', '23', '32', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:54:26', '2023-11-18 04:54:26');
INSERT INTO `class_subjects` VALUES ('149', '23', '34', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:54:26', '2023-11-18 04:54:26');
INSERT INTO `class_subjects` VALUES ('150', '23', '35', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:54:26', '2023-11-18 04:54:26');
INSERT INTO `class_subjects` VALUES ('151', '23', '23', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:54:26', '2023-11-18 04:54:26');
INSERT INTO `class_subjects` VALUES ('152', '23', '36', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:54:26', '2023-11-18 04:54:26');
INSERT INTO `class_subjects` VALUES ('153', '23', '37', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:54:26', '2023-11-18 04:54:26');
INSERT INTO `class_subjects` VALUES ('154', '23', '38', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:54:26', '2023-11-18 04:54:26');
INSERT INTO `class_subjects` VALUES ('155', '23', '39', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:54:26', '2023-11-18 04:54:26');
INSERT INTO `class_subjects` VALUES ('156', '23', '28', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:54:26', '2023-11-18 04:54:26');
INSERT INTO `class_subjects` VALUES ('157', '23', '29', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:54:26', '2023-11-18 04:54:26');
INSERT INTO `class_subjects` VALUES ('158', '23', '40', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 04:54:26', '2023-11-18 04:54:26');
INSERT INTO `class_subjects` VALUES ('159', '24', '38', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 10:07:46', '2023-11-18 10:07:46');
INSERT INTO `class_subjects` VALUES ('160', '24', '37', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 10:07:46', '2023-11-18 10:07:46');
INSERT INTO `class_subjects` VALUES ('161', '24', '36', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 10:07:46', '2023-11-18 10:07:46');
INSERT INTO `class_subjects` VALUES ('162', '24', '19', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 10:07:46', '2023-11-18 10:07:46');
INSERT INTO `class_subjects` VALUES ('163', '24', '20', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 10:07:46', '2023-11-18 10:07:46');
INSERT INTO `class_subjects` VALUES ('164', '24', '23', 'Elective', '6', NULL, '0', '12', NULL, '2023-11-18 10:07:46', '2023-11-18 10:07:46');
INSERT INTO `class_subjects` VALUES ('165', '24', '44', 'Elective', '6', NULL, '0', '12', NULL, '2023-11-18 10:07:46', '2023-11-18 10:07:46');
INSERT INTO `class_subjects` VALUES ('166', '27', '38', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 10:08:58', '2023-11-18 10:08:58');
INSERT INTO `class_subjects` VALUES ('167', '27', '37', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 10:08:58', '2023-11-18 10:08:58');
INSERT INTO `class_subjects` VALUES ('168', '27', '36', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 10:08:58', '2023-11-18 10:08:58');
INSERT INTO `class_subjects` VALUES ('169', '27', '19', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 10:08:58', '2023-11-18 10:08:58');
INSERT INTO `class_subjects` VALUES ('170', '27', '20', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 10:08:58', '2023-11-18 10:08:58');
INSERT INTO `class_subjects` VALUES ('171', '27', '44', 'Elective', '7', NULL, '0', '12', NULL, '2023-11-18 10:08:58', '2023-11-18 10:08:58');
INSERT INTO `class_subjects` VALUES ('172', '27', '23', 'Elective', '7', NULL, '0', '12', NULL, '2023-11-18 10:08:58', '2023-11-18 10:08:58');
INSERT INTO `class_subjects` VALUES ('173', '26', '41', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 10:12:10', '2023-11-18 10:12:10');
INSERT INTO `class_subjects` VALUES ('174', '26', '42', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 10:12:10', '2023-11-18 10:12:10');
INSERT INTO `class_subjects` VALUES ('175', '26', '19', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 10:12:10', '2023-11-18 10:12:10');
INSERT INTO `class_subjects` VALUES ('176', '26', '43', 'Elective', '8', NULL, '0', '12', NULL, '2023-11-18 10:12:10', '2023-11-18 10:12:10');
INSERT INTO `class_subjects` VALUES ('177', '26', '20', 'Elective', '8', NULL, '0', '12', NULL, '2023-11-18 10:12:10', '2023-11-18 10:12:10');
INSERT INTO `class_subjects` VALUES ('178', '26', '33', 'Elective', '9', NULL, '0', '12', NULL, '2023-11-18 10:12:10', '2023-11-18 10:12:10');
INSERT INTO `class_subjects` VALUES ('179', '26', '44', 'Elective', '9', NULL, '0', '12', NULL, '2023-11-18 10:12:10', '2023-11-18 10:12:10');
INSERT INTO `class_subjects` VALUES ('180', '26', '23', 'Elective', '9', NULL, '0', '12', NULL, '2023-11-18 10:12:10', '2023-11-18 10:12:10');
INSERT INTO `class_subjects` VALUES ('181', '29', '41', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 10:13:34', '2023-11-18 10:13:34');
INSERT INTO `class_subjects` VALUES ('182', '29', '42', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 10:13:34', '2023-11-18 10:13:34');
INSERT INTO `class_subjects` VALUES ('183', '29', '19', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 10:13:34', '2023-11-18 10:13:34');
INSERT INTO `class_subjects` VALUES ('184', '29', '20', 'Elective', '10', NULL, '0', '12', NULL, '2023-11-18 10:13:34', '2023-11-18 10:13:34');
INSERT INTO `class_subjects` VALUES ('185', '29', '43', 'Elective', '10', NULL, '0', '12', NULL, '2023-11-18 10:13:34', '2023-11-18 10:13:34');
INSERT INTO `class_subjects` VALUES ('186', '29', '33', 'Elective', '11', NULL, '0', '12', NULL, '2023-11-18 10:13:34', '2023-11-18 10:13:34');
INSERT INTO `class_subjects` VALUES ('187', '29', '44', 'Elective', '11', NULL, '0', '12', NULL, '2023-11-18 10:13:34', '2023-11-18 10:13:34');
INSERT INTO `class_subjects` VALUES ('188', '29', '23', 'Elective', '11', NULL, '0', '12', NULL, '2023-11-18 10:13:34', '2023-11-18 10:13:34');
INSERT INTO `class_subjects` VALUES ('189', '25', '45', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 10:18:27', '2023-11-18 10:18:27');
INSERT INTO `class_subjects` VALUES ('190', '25', '46', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 10:18:27', '2023-11-18 10:18:27');
INSERT INTO `class_subjects` VALUES ('191', '25', '47', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 10:18:27', '2023-11-18 10:18:27');
INSERT INTO `class_subjects` VALUES ('192', '25', '36', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 10:18:27', '2023-11-18 10:18:27');
INSERT INTO `class_subjects` VALUES ('193', '25', '19', 'Compulsory', NULL, NULL, '0', '12', NULL, '2023-11-18 10:18:27', '2023-11-18 10:18:27');
INSERT INTO `class_subjects` VALUES ('194', '25', '48', 'Elective', '12', NULL, '0', '12', NULL, '2023-11-18 10:18:27', '2023-11-18 10:18:27');
INSERT INTO `class_subjects` VALUES ('195', '25', '49', 'Elective', '12', NULL, '0', '12', NULL, '2023-11-18 10:18:27', '2023-11-18 10:18:27');
INSERT INTO `class_subjects` VALUES ('196', '25', '39', 'Elective', '12', NULL, '0', '12', NULL, '2023-11-18 10:18:27', '2023-11-18 10:18:27');
INSERT INTO `class_subjects` VALUES ('197', '28', '87', 'Compulsory', NULL, NULL, '0', '12', NULL, '2024-03-11 18:07:52', '2024-03-11 18:07:52');
INSERT INTO `class_subjects` VALUES ('198', '28', '27', 'Compulsory', NULL, NULL, '0', '12', NULL, '2024-03-11 18:07:52', '2024-03-11 18:07:52');
INSERT INTO `class_subjects` VALUES ('199', '28', '23', 'Elective', '13', NULL, '0', '12', NULL, '2024-03-11 18:07:52', '2024-03-11 18:07:52');
INSERT INTO `class_subjects` VALUES ('200', '28', '24', 'Elective', '13', NULL, '0', '12', NULL, '2024-03-11 18:07:52', '2024-03-11 18:07:52');

CREATE TABLE IF NOT EXISTS `class_teachers` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `class_section_id` bigint(20) unsigned NOT NULL,
  `teacher_id` bigint(20) unsigned NOT NULL COMMENT 'user_id',
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `unique_id` (`class_section_id`,`teacher_id`),
  KEY `class_teachers_school_id_foreign` (`school_id`),
  KEY `class_teachers_teacher_id_foreign` (`teacher_id`),
  CONSTRAINT `class_teachers_class_section_id_foreign` FOREIGN KEY (`class_section_id`) REFERENCES `class_sections` (`id`) ON DELETE CASCADE,
  CONSTRAINT `class_teachers_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `class_teachers_teacher_id_foreign` FOREIGN KEY (`teacher_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=53 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `class_teachers` VALUES ('29', '31', '42', '12', '2023-11-24 06:12:14', '2023-11-24 06:12:14');
INSERT INTO `class_teachers` VALUES ('35', '21', '42', '12', '2024-07-10 11:23:14', '2024-07-10 11:23:14');
INSERT INTO `class_teachers` VALUES ('36', '22', '43', '12', '2023-11-24 06:54:38', '2023-11-24 06:54:38');
INSERT INTO `class_teachers` VALUES ('37', '23', '44', '12', '2023-11-24 06:54:03', '2023-11-24 06:54:03');
INSERT INTO `class_teachers` VALUES ('38', '24', '45', '12', '2023-11-24 06:55:08', '2023-11-24 06:55:08');
INSERT INTO `class_teachers` VALUES ('39', '25', '46', '12', '2023-11-24 06:55:11', '2023-11-24 06:55:11');
INSERT INTO `class_teachers` VALUES ('45', '26', '49', '12', '2024-07-17 15:07:23', '2024-07-17 15:07:23');
INSERT INTO `class_teachers` VALUES ('46', '21', '49', '12', '2024-07-10 11:23:14', '2024-07-10 11:23:14');
INSERT INTO `class_teachers` VALUES ('47', '55', '42', '12', '2024-07-16 10:00:22', '2024-07-16 10:00:22');
INSERT INTO `class_teachers` VALUES ('48', '60', '48', '12', '2024-03-11 18:18:03', '2024-03-11 18:18:03');
INSERT INTO `class_teachers` VALUES ('49', '59', '47', '12', '2024-03-11 18:18:15', '2024-03-11 18:18:15');
INSERT INTO `class_teachers` VALUES ('50', '58', '49', '12', '2024-03-11 18:18:41', '2024-03-11 18:18:41');
INSERT INTO `class_teachers` VALUES ('51', '57', '47', '12', '2024-03-11 18:19:14', '2024-03-11 18:19:14');
INSERT INTO `class_teachers` VALUES ('52', '56', '46', '12', '2024-03-11 18:19:34', '2024-03-11 18:19:34');

CREATE TABLE IF NOT EXISTS `classes` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(512) NOT NULL,
  `include_semesters` tinyint(4) NOT NULL DEFAULT 0 COMMENT '0 - no 1 - yes',
  `medium_id` bigint(20) unsigned NOT NULL,
  `shift_id` bigint(20) unsigned DEFAULT NULL,
  `stream_id` bigint(20) unsigned DEFAULT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `classes_school_id_foreign` (`school_id`),
  KEY `classes_medium_id_foreign` (`medium_id`),
  KEY `classes_shift_id_foreign` (`shift_id`),
  KEY `classes_stream_id_foreign` (`stream_id`),
  CONSTRAINT `classes_medium_id_foreign` FOREIGN KEY (`medium_id`) REFERENCES `mediums` (`id`) ON DELETE CASCADE,
  CONSTRAINT `classes_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `classes_shift_id_foreign` FOREIGN KEY (`shift_id`) REFERENCES `shifts` (`id`) ON DELETE CASCADE,
  CONSTRAINT `classes_stream_id_foreign` FOREIGN KEY (`stream_id`) REFERENCES `streams` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=30 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `classes` VALUES ('13', '1', '0', '10', NULL, NULL, '12', '2023-11-18 04:04:58', '2023-11-21 06:33:54', NULL);
INSERT INTO `classes` VALUES ('14', '2', '0', '10', NULL, NULL, '12', '2023-11-18 04:05:07', '2023-11-21 06:32:12', NULL);
INSERT INTO `classes` VALUES ('15', '3', '0', '10', NULL, NULL, '12', '2023-11-18 04:05:17', '2023-11-21 06:34:09', NULL);
INSERT INTO `classes` VALUES ('16', '4', '0', '10', NULL, NULL, '12', '2023-11-18 04:05:24', '2023-11-21 06:34:20', NULL);
INSERT INTO `classes` VALUES ('17', '5', '0', '10', NULL, NULL, '12', '2023-11-18 04:05:31', '2023-11-21 06:34:30', NULL);
INSERT INTO `classes` VALUES ('18', '6', '0', '10', NULL, NULL, '12', '2023-11-18 04:05:37', '2023-11-21 06:34:42', NULL);
INSERT INTO `classes` VALUES ('19', '7', '0', '10', NULL, NULL, '12', '2023-11-18 04:05:44', '2023-11-21 06:34:50', NULL);
INSERT INTO `classes` VALUES ('20', '8', '0', '10', NULL, NULL, '12', '2023-11-18 04:05:51', '2023-11-21 06:35:01', NULL);
INSERT INTO `classes` VALUES ('21', '9', '0', '10', NULL, NULL, '12', '2023-11-18 04:06:04', '2023-11-21 06:35:13', NULL);
INSERT INTO `classes` VALUES ('23', '10', '0', '10', NULL, NULL, '12', '2023-11-18 04:10:45', '2023-11-21 06:35:42', NULL);
INSERT INTO `classes` VALUES ('24', '11', '0', '10', NULL, '8', '12', '2023-11-18 04:12:02', '2023-11-21 06:36:00', NULL);
INSERT INTO `classes` VALUES ('25', '11', '0', '10', NULL, '9', '12', '2023-11-18 04:12:02', '2023-11-21 06:36:14', NULL);
INSERT INTO `classes` VALUES ('26', '11', '0', '10', NULL, '10', '12', '2023-11-18 04:12:02', '2023-11-21 06:36:25', NULL);
INSERT INTO `classes` VALUES ('27', '12', '0', '10', NULL, '8', '12', '2023-11-18 04:12:36', '2023-11-21 06:36:40', NULL);
INSERT INTO `classes` VALUES ('28', '12', '0', '10', NULL, '9', '12', '2023-11-18 04:12:36', '2023-11-21 06:36:51', NULL);
INSERT INTO `classes` VALUES ('29', '12', '0', '10', NULL, '10', '12', '2023-11-18 04:12:36', '2023-11-21 06:37:03', NULL);

CREATE TABLE IF NOT EXISTS `compulsory_fees` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `student_id` bigint(20) unsigned NOT NULL COMMENT 'user_id',
  `payment_transaction_id` bigint(20) unsigned DEFAULT NULL,
  `type` enum('Full Payment','Installment Payment') NOT NULL,
  `installment_id` bigint(20) unsigned DEFAULT NULL,
  `mode` enum('Cash','Cheque','Online') NOT NULL,
  `cheque_no` varchar(191) DEFAULT NULL,
  `amount` double(8,2) NOT NULL,
  `due_charges` double(8,2) DEFAULT NULL,
  `fees_paid_id` bigint(20) unsigned DEFAULT NULL,
  `status` enum('Success','Pending','Failed') NOT NULL,
  `date` date NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `compulsory_fees_installment_id_foreign` (`installment_id`),
  KEY `compulsory_fees_school_id_foreign` (`school_id`),
  KEY `compulsory_fees_student_id_foreign` (`student_id`),
  KEY `compulsory_fees_payment_transaction_id_foreign` (`payment_transaction_id`),
  KEY `compulsory_fees_fees_paid_id_foreign` (`fees_paid_id`),
  CONSTRAINT `compulsory_fees_fees_paid_id_foreign` FOREIGN KEY (`fees_paid_id`) REFERENCES `fees_paids` (`id`) ON DELETE CASCADE,
  CONSTRAINT `compulsory_fees_installment_id_foreign` FOREIGN KEY (`installment_id`) REFERENCES `fees_installments` (`id`) ON DELETE CASCADE,
  CONSTRAINT `compulsory_fees_payment_transaction_id_foreign` FOREIGN KEY (`payment_transaction_id`) REFERENCES `payment_transactions` (`id`) ON DELETE CASCADE,
  CONSTRAINT `compulsory_fees_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `compulsory_fees_student_id_foreign` FOREIGN KEY (`student_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=13 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `compulsory_fees` VALUES ('1', '331', NULL, 'Installment Payment', '1', 'Cash', NULL, '2000', '0', '1', 'Success', '2024-01-25', '12', '2024-01-25 05:11:56', '2024-01-25 05:11:56', NULL);
INSERT INTO `compulsory_fees` VALUES ('2', '331', NULL, 'Installment Payment', '2', 'Cash', NULL, '2500', '0', '1', 'Success', '2024-01-25', '12', '2024-01-25 05:12:31', '2024-01-25 05:12:31', NULL);
INSERT INTO `compulsory_fees` VALUES ('3', '467', NULL, 'Full Payment', NULL, 'Cash', NULL, '6000', NULL, '2', 'Success', '2024-05-14', '12', '2024-05-14 12:46:52', '2024-05-14 12:46:52', NULL);
INSERT INTO `compulsory_fees` VALUES ('4', '465', NULL, 'Full Payment', NULL, 'Cash', NULL, '6000', NULL, '3', 'Success', '2024-05-14', '12', '2024-05-14 12:47:11', '2024-05-14 12:47:11', NULL);
INSERT INTO `compulsory_fees` VALUES ('5', '463', NULL, 'Full Payment', NULL, 'Cheque', '1234', '6000', NULL, '4', 'Success', '2024-05-14', '12', '2024-05-14 12:47:35', '2024-05-14 12:47:35', NULL);
INSERT INTO `compulsory_fees` VALUES ('6', '461', NULL, 'Full Payment', NULL, 'Cheque', '2341', '6000', NULL, '5', 'Success', '2024-05-14', '12', '2024-05-14 12:47:50', '2024-05-14 12:47:50', NULL);
INSERT INTO `compulsory_fees` VALUES ('7', '459', NULL, 'Installment Payment', '1', 'Cash', NULL, '2000', '40', '6', 'Success', '2024-05-14', '12', '2024-05-14 12:48:12', '2024-05-14 12:48:12', NULL);
INSERT INTO `compulsory_fees` VALUES ('8', '457', NULL, 'Installment Payment', '1', 'Cash', NULL, '2000', '40', '7', 'Success', '2024-05-14', '12', '2024-05-14 12:48:39', '2024-05-14 12:48:39', NULL);
INSERT INTO `compulsory_fees` VALUES ('9', '455', NULL, 'Full Payment', NULL, 'Cash', NULL, '6000', NULL, '8', 'Success', '2024-05-14', '12', '2024-05-14 12:58:28', '2024-05-14 12:58:28', NULL);
INSERT INTO `compulsory_fees` VALUES ('10', '453', NULL, 'Full Payment', NULL, 'Cash', NULL, '6000', NULL, '9', 'Success', '2024-05-14', '12', '2024-05-14 12:58:41', '2024-05-14 12:58:41', NULL);
INSERT INTO `compulsory_fees` VALUES ('11', '451', NULL, 'Full Payment', NULL, 'Cash', NULL, '6000', NULL, '10', 'Success', '2024-05-14', '12', '2024-05-14 12:58:53', '2024-05-14 12:58:53', NULL);
INSERT INTO `compulsory_fees` VALUES ('12', '449', NULL, 'Full Payment', NULL, 'Cash', NULL, '6000', NULL, '11', 'Success', '2024-05-14', '12', '2024-05-14 12:59:07', '2024-05-14 12:59:07', NULL);

CREATE TABLE IF NOT EXISTS `elective_subject_groups` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `total_subjects` int(11) NOT NULL,
  `total_selectable_subjects` int(11) NOT NULL,
  `class_id` bigint(20) unsigned NOT NULL,
  `semester_id` bigint(20) unsigned DEFAULT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `elective_subject_groups_school_id_foreign` (`school_id`),
  KEY `elective_subject_groups_class_id_foreign` (`class_id`),
  KEY `elective_subject_groups_semester_id_foreign` (`semester_id`),
  CONSTRAINT `elective_subject_groups_class_id_foreign` FOREIGN KEY (`class_id`) REFERENCES `classes` (`id`) ON DELETE CASCADE,
  CONSTRAINT `elective_subject_groups_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `elective_subject_groups_semester_id_foreign` FOREIGN KEY (`semester_id`) REFERENCES `semesters` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=14 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `elective_subject_groups` VALUES ('6', '2', '1', '24', NULL, '12', '2023-11-18 10:07:46', '2023-11-18 10:07:46', NULL);
INSERT INTO `elective_subject_groups` VALUES ('7', '2', '1', '27', NULL, '12', '2023-11-18 10:08:58', '2023-11-18 10:08:58', NULL);
INSERT INTO `elective_subject_groups` VALUES ('8', '2', '1', '26', NULL, '12', '2023-11-18 10:12:10', '2023-11-18 10:12:10', NULL);
INSERT INTO `elective_subject_groups` VALUES ('9', '3', '1', '26', NULL, '12', '2023-11-18 10:12:10', '2023-11-18 10:12:10', NULL);
INSERT INTO `elective_subject_groups` VALUES ('10', '2', '1', '29', NULL, '12', '2023-11-18 10:13:34', '2023-11-18 10:13:34', NULL);
INSERT INTO `elective_subject_groups` VALUES ('11', '3', '1', '29', NULL, '12', '2023-11-18 10:13:34', '2023-11-18 10:13:34', NULL);
INSERT INTO `elective_subject_groups` VALUES ('12', '3', '1', '25', NULL, '12', '2023-11-18 10:18:27', '2023-11-18 10:18:27', NULL);
INSERT INTO `elective_subject_groups` VALUES ('13', '2', '1', '28', NULL, '12', '2024-03-11 18:07:52', '2024-03-11 18:07:52', NULL);

CREATE TABLE IF NOT EXISTS `exam_marks` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `exam_timetable_id` bigint(20) unsigned NOT NULL,
  `student_id` bigint(20) unsigned NOT NULL COMMENT 'user_id',
  `class_subject_id` bigint(20) unsigned NOT NULL,
  `obtained_marks` double(8,2) NOT NULL,
  `teacher_review` varchar(1024) DEFAULT NULL,
  `passing_status` tinyint(1) NOT NULL COMMENT '1=Pass, 0=Fail',
  `session_year_id` bigint(20) unsigned NOT NULL,
  `grade` tinytext DEFAULT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `exam_marks_school_id_foreign` (`school_id`),
  KEY `exam_marks_exam_timetable_id_foreign` (`exam_timetable_id`),
  KEY `exam_marks_student_id_foreign` (`student_id`),
  KEY `exam_marks_class_subject_id_foreign` (`class_subject_id`),
  KEY `exam_marks_session_year_id_foreign` (`session_year_id`),
  CONSTRAINT `exam_marks_class_subject_id_foreign` FOREIGN KEY (`class_subject_id`) REFERENCES `class_subjects` (`id`) ON DELETE CASCADE,
  CONSTRAINT `exam_marks_exam_timetable_id_foreign` FOREIGN KEY (`exam_timetable_id`) REFERENCES `exam_timetables` (`id`) ON DELETE CASCADE,
  CONSTRAINT `exam_marks_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `exam_marks_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE,
  CONSTRAINT `exam_marks_student_id_foreign` FOREIGN KEY (`student_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=712 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `exam_marks` VALUES ('7', '14', '333', '55', '78', NULL, '1', '17', 'B', '12', '2023-11-21 10:54:22', '2023-11-21 10:54:22', NULL);
INSERT INTO `exam_marks` VALUES ('8', '15', '467', '46', '50', NULL, '1', '17', 'D', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('9', '15', '465', '46', '66', NULL, '1', '17', 'C', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('10', '15', '463', '46', '86', NULL, '1', '17', 'B', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('11', '15', '461', '46', '52', NULL, '1', '17', 'D', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('12', '15', '459', '46', '22', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('13', '15', '457', '46', '40', NULL, '1', '17', 'D', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('14', '15', '455', '46', '85', NULL, '1', '17', 'B', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('15', '15', '453', '46', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('16', '15', '451', '46', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('17', '15', '449', '46', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('18', '15', '447', '46', '99', NULL, '1', '17', 'A', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('19', '15', '445', '46', '6', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('20', '15', '443', '46', '32', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('21', '15', '441', '46', '15', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('22', '15', '439', '46', '5', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('23', '15', '437', '46', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('24', '15', '435', '46', '88', NULL, '1', '17', 'B', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('25', '15', '433', '46', '88', NULL, '1', '17', 'B', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('26', '15', '431', '46', '66', NULL, '1', '17', 'C', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('27', '15', '429', '46', '75', NULL, '1', '17', 'C', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('28', '15', '427', '46', '84', NULL, '1', '17', 'B', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('29', '15', '425', '46', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('30', '15', '423', '46', '26', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('31', '15', '421', '46', '35', NULL, '1', '17', 'D', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('32', '15', '419', '46', '38', NULL, '1', '17', 'D', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('33', '15', '417', '46', '87', NULL, '1', '17', 'B', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('34', '15', '415', '46', '88', NULL, '1', '17', 'B', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('35', '15', '413', '46', '76', NULL, '1', '17', 'B', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('36', '15', '411', '46', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('37', '15', '409', '46', '32', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('38', '15', '407', '46', '48', NULL, '1', '17', 'D', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('39', '15', '405', '46', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('40', '15', '403', '46', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('41', '15', '401', '46', '62', NULL, '1', '17', 'C', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('42', '15', '399', '46', '34', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('43', '15', '397', '46', '85', NULL, '1', '17', 'B', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('44', '15', '395', '46', '45', NULL, '1', '17', 'D', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('45', '15', '393', '46', '85', NULL, '1', '17', 'B', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('46', '15', '391', '46', '96', NULL, '1', '17', 'A', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('47', '15', '389', '46', '52', NULL, '1', '17', 'D', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('48', '15', '387', '46', '24', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('49', '15', '385', '46', '66', NULL, '1', '17', 'C', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('50', '15', '383', '46', '88', NULL, '1', '17', 'B', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('51', '15', '381', '46', '90', NULL, '1', '17', 'B', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('52', '15', '379', '46', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('53', '15', '377', '46', '45', NULL, '1', '17', 'D', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('54', '15', '375', '46', '66', NULL, '1', '17', 'C', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('55', '15', '373', '46', '38', NULL, '1', '17', 'D', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('56', '15', '371', '46', '48', NULL, '1', '17', 'D', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('57', '15', '369', '46', '88', NULL, '1', '17', 'B', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('58', '15', '367', '46', '66', NULL, '1', '17', 'C', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('59', '15', '365', '46', '83', NULL, '1', '17', 'B', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('60', '15', '363', '46', '12', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('61', '15', '361', '46', '48', NULL, '1', '17', 'D', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('62', '15', '359', '46', '20', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('63', '15', '357', '46', '35', NULL, '1', '17', 'D', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('64', '15', '355', '46', '25', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('65', '15', '353', '46', '34', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('66', '15', '351', '46', '58', NULL, '1', '17', 'D', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('67', '15', '349', '46', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('69', '15', '331', '46', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:35:10', '2023-11-21 11:35:10', NULL);
INSERT INTO `exam_marks` VALUES ('70', '16', '467', '48', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('71', '16', '465', '48', '56', NULL, '1', '17', 'D', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('72', '16', '463', '48', '57', NULL, '1', '17', 'D', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('73', '16', '461', '48', '58', NULL, '1', '17', 'D', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('74', '16', '459', '48', '59', NULL, '1', '17', 'D', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('75', '16', '457', '48', '62', NULL, '1', '17', 'C', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('76', '16', '455', '48', '63', NULL, '1', '17', 'C', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('77', '16', '453', '48', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('78', '16', '451', '48', '67', NULL, '1', '17', 'C', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('79', '16', '449', '48', '89', NULL, '1', '17', 'B', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('80', '16', '447', '48', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('81', '16', '445', '48', '25', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('82', '16', '443', '48', '48', NULL, '1', '17', 'D', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('83', '16', '441', '48', '32', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('84', '16', '439', '48', '54', NULL, '1', '17', 'D', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('85', '16', '437', '48', '89', NULL, '1', '17', 'B', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('86', '16', '435', '48', '58', NULL, '1', '17', 'D', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('87', '16', '433', '48', '98', NULL, '1', '17', 'A', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('88', '16', '431', '48', '75', NULL, '1', '17', 'C', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('89', '16', '429', '48', '85', NULL, '1', '17', 'B', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('90', '16', '427', '48', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('91', '16', '425', '48', '25', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('92', '16', '423', '48', '34', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('93', '16', '421', '48', '57', NULL, '1', '17', 'D', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('94', '16', '419', '48', '66', NULL, '1', '17', 'C', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('95', '16', '417', '48', '35', NULL, '1', '17', 'D', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('96', '16', '415', '48', '45', NULL, '1', '17', 'D', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('97', '16', '413', '48', '84', NULL, '1', '17', 'B', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('98', '16', '411', '48', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('99', '16', '409', '48', '96', NULL, '1', '17', 'A', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('100', '16', '407', '48', '35', NULL, '1', '17', 'D', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('101', '16', '405', '48', '25', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('102', '16', '403', '48', '45', NULL, '1', '17', 'D', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('103', '16', '401', '48', '25', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('104', '16', '399', '48', '57', NULL, '1', '17', 'D', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('105', '16', '397', '48', '35', NULL, '1', '17', 'D', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('106', '16', '395', '48', '25', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('107', '16', '393', '48', '64', NULL, '1', '17', 'C', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('108', '16', '391', '48', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('109', '16', '389', '48', '84', NULL, '1', '17', 'B', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('110', '16', '387', '48', '95', NULL, '1', '17', 'A', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('111', '16', '385', '48', '15', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('112', '16', '383', '48', '2', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('113', '16', '381', '48', '4', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('114', '16', '379', '48', '36', NULL, '1', '17', 'D', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('115', '16', '377', '48', '5', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('116', '16', '375', '48', '8', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('117', '16', '373', '48', '6', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('118', '16', '371', '48', '56', NULL, '1', '17', 'D', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('119', '16', '369', '48', '48', NULL, '1', '17', 'D', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('120', '16', '367', '48', '59', NULL, '1', '17', 'D', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('121', '16', '365', '48', '7', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('122', '16', '363', '48', '45', NULL, '1', '17', 'D', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('123', '16', '361', '48', '48', NULL, '1', '17', 'D', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('124', '16', '359', '48', '59', NULL, '1', '17', 'D', '12', '2023-11-21 11:41:58', '2023-11-21 11:41:58', NULL);
INSERT INTO `exam_marks` VALUES ('125', '16', '357', '48', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:41:59', '2023-11-21 11:41:59', NULL);
INSERT INTO `exam_marks` VALUES ('126', '16', '355', '48', '45', NULL, '1', '17', 'D', '12', '2023-11-21 11:41:59', '2023-11-21 11:41:59', NULL);
INSERT INTO `exam_marks` VALUES ('127', '16', '353', '48', '58', NULL, '1', '17', 'D', '12', '2023-11-21 11:41:59', '2023-11-21 11:41:59', NULL);
INSERT INTO `exam_marks` VALUES ('128', '16', '351', '48', '96', NULL, '1', '17', 'A', '12', '2023-11-21 11:41:59', '2023-11-21 11:41:59', NULL);
INSERT INTO `exam_marks` VALUES ('129', '16', '349', '48', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:41:59', '2023-11-21 11:41:59', NULL);
INSERT INTO `exam_marks` VALUES ('131', '16', '331', '48', '99', NULL, '1', '17', 'A', '12', '2023-11-21 11:41:59', '2023-11-21 11:41:59', NULL);
INSERT INTO `exam_marks` VALUES ('132', '17', '467', '51', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('133', '17', '465', '51', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('134', '17', '463', '51', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('135', '17', '461', '51', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('136', '17', '459', '51', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('137', '17', '457', '51', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('138', '17', '455', '51', '66', NULL, '1', '17', 'C', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('139', '17', '453', '51', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('140', '17', '451', '51', '66', NULL, '1', '17', 'C', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('141', '17', '449', '51', '99', NULL, '1', '17', 'A', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('142', '17', '447', '51', '88', NULL, '1', '17', 'B', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('143', '17', '445', '51', '77', NULL, '1', '17', 'B', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('144', '17', '443', '51', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('145', '17', '441', '51', '66', NULL, '1', '17', 'C', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('146', '17', '439', '51', '33', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('147', '17', '437', '51', '22', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('148', '17', '435', '51', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('149', '17', '433', '51', '57', NULL, '1', '17', 'D', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('150', '17', '431', '51', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('151', '17', '429', '51', '32', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('152', '17', '427', '51', '32', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('153', '17', '425', '51', '12', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('154', '17', '423', '51', '54', NULL, '1', '17', 'D', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('155', '17', '421', '51', '88', NULL, '1', '17', 'B', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('156', '17', '419', '51', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('157', '17', '417', '51', '66', NULL, '1', '17', 'C', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('158', '17', '415', '51', '33', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('159', '17', '413', '51', '22', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('160', '17', '411', '51', '54', NULL, '1', '17', 'D', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('161', '17', '409', '51', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('162', '17', '407', '51', '88', NULL, '1', '17', 'B', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('163', '17', '405', '51', '75', NULL, '1', '17', 'C', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('164', '17', '403', '51', '6', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('165', '17', '401', '51', '5', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('166', '17', '399', '51', '66', NULL, '1', '17', 'C', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('167', '17', '397', '51', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('168', '17', '395', '51', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('169', '17', '393', '51', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('170', '17', '391', '51', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('171', '17', '389', '51', '88', NULL, '1', '17', 'B', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('172', '17', '387', '51', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('173', '17', '385', '51', '22', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('174', '17', '383', '51', '22', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('175', '17', '381', '51', '33', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('176', '17', '379', '51', '66', NULL, '1', '17', 'C', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('177', '17', '377', '51', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('178', '17', '375', '51', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('179', '17', '373', '51', '88', NULL, '1', '17', 'B', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('180', '17', '371', '51', '77', NULL, '1', '17', 'B', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('181', '17', '369', '51', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('182', '17', '367', '51', '88', NULL, '1', '17', 'B', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('183', '17', '365', '51', '66', NULL, '1', '17', 'C', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('184', '17', '363', '51', '99', NULL, '1', '17', 'A', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('185', '17', '361', '51', '66', NULL, '1', '17', 'C', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('186', '17', '359', '51', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('187', '17', '357', '51', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('188', '17', '355', '51', '77', NULL, '1', '17', 'B', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('189', '17', '353', '51', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('190', '17', '351', '51', '22', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('191', '17', '349', '51', '33', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('193', '17', '331', '51', '95', NULL, '1', '17', 'A', '12', '2023-11-21 11:42:59', '2023-11-21 11:42:59', NULL);
INSERT INTO `exam_marks` VALUES ('194', '18', '467', '47', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('195', '18', '465', '47', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('196', '18', '463', '47', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('197', '18', '461', '47', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('198', '18', '459', '47', '5', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('199', '18', '457', '47', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('200', '18', '455', '47', '66', NULL, '1', '17', 'C', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('201', '18', '453', '47', '66', NULL, '1', '17', 'C', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('202', '18', '451', '47', '6', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('203', '18', '449', '47', '88', NULL, '1', '17', 'B', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('204', '18', '447', '47', '88', NULL, '1', '17', 'B', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('205', '18', '445', '47', '77', NULL, '1', '17', 'B', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('206', '18', '443', '47', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('207', '18', '441', '47', '88', NULL, '1', '17', 'B', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('208', '18', '439', '47', '99', NULL, '1', '17', 'A', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('209', '18', '437', '47', '6', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('210', '18', '435', '47', '69', NULL, '1', '17', 'C', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('211', '18', '433', '47', '66', NULL, '1', '17', 'C', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('212', '18', '431', '47', '66', NULL, '1', '17', 'C', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('213', '18', '429', '47', '33', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('214', '18', '427', '47', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('215', '18', '425', '47', '22', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('216', '18', '423', '47', '22', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('217', '18', '421', '47', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('218', '18', '419', '47', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('219', '18', '417', '47', '4', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('220', '18', '415', '47', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('221', '18', '413', '47', '11', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('222', '18', '411', '47', '22', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('223', '18', '409', '47', '33', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('224', '18', '407', '47', '66', NULL, '1', '17', 'C', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('225', '18', '405', '47', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('226', '18', '403', '47', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('227', '18', '401', '47', '77', NULL, '1', '17', 'B', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('228', '18', '399', '47', '88', NULL, '1', '17', 'B', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('229', '18', '397', '47', '99', NULL, '1', '17', 'A', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('230', '18', '395', '47', '66', NULL, '1', '17', 'C', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('231', '18', '393', '47', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('232', '18', '391', '47', '22', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('233', '18', '389', '47', '33', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('234', '18', '387', '47', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('235', '18', '385', '47', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('236', '18', '383', '47', '6', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('237', '18', '381', '47', '99', NULL, '1', '17', 'A', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('238', '18', '379', '47', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('239', '18', '377', '47', '88', NULL, '1', '17', 'B', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('240', '18', '375', '47', '7', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('241', '18', '373', '47', '7', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('242', '18', '371', '47', '77', NULL, '1', '17', 'B', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('243', '18', '369', '47', '77', NULL, '1', '17', 'B', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('244', '18', '367', '47', '7', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('245', '18', '365', '47', '7', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('246', '18', '363', '47', '8', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('247', '18', '361', '47', '8', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('248', '18', '359', '47', '88', NULL, '1', '17', 'B', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('249', '18', '357', '47', '9', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('250', '18', '355', '47', '6', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('251', '18', '353', '47', '66', NULL, '1', '17', 'C', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('252', '18', '351', '47', '33', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('253', '18', '349', '47', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('255', '18', '331', '47', '97', NULL, '1', '17', 'A', '12', '2023-11-21 11:44:06', '2023-11-21 11:44:06', NULL);
INSERT INTO `exam_marks` VALUES ('256', '19', '467', '49', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:49:02', '2023-11-21 11:49:02', NULL);
INSERT INTO `exam_marks` VALUES ('257', '19', '465', '49', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:49:02', '2023-11-21 11:49:02', NULL);
INSERT INTO `exam_marks` VALUES ('258', '19', '463', '49', '88', NULL, '1', '17', 'B', '12', '2023-11-21 11:49:02', '2023-11-21 11:49:02', NULL);
INSERT INTO `exam_marks` VALUES ('259', '19', '461', '49', '77', NULL, '1', '17', 'B', '12', '2023-11-21 11:49:02', '2023-11-21 11:49:02', NULL);
INSERT INTO `exam_marks` VALUES ('260', '19', '459', '49', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:49:02', '2023-11-21 11:49:02', NULL);
INSERT INTO `exam_marks` VALUES ('261', '19', '457', '49', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:49:02', '2023-11-21 11:49:02', NULL);
INSERT INTO `exam_marks` VALUES ('262', '19', '455', '49', '22', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:49:02', '2023-11-21 11:49:02', NULL);
INSERT INTO `exam_marks` VALUES ('263', '19', '453', '49', '11', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:49:02', '2023-11-21 11:49:02', NULL);
INSERT INTO `exam_marks` VALUES ('264', '19', '451', '49', '33', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:49:02', '2023-11-21 11:49:02', NULL);
INSERT INTO `exam_marks` VALUES ('265', '19', '449', '49', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:49:02', '2023-11-21 11:49:02', NULL);
INSERT INTO `exam_marks` VALUES ('266', '19', '447', '49', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:49:02', '2023-11-21 11:49:02', NULL);
INSERT INTO `exam_marks` VALUES ('267', '19', '445', '49', '11', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:49:02', '2023-11-21 11:49:02', NULL);
INSERT INTO `exam_marks` VALUES ('268', '19', '443', '49', '25', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:49:02', '2023-11-21 11:49:02', NULL);
INSERT INTO `exam_marks` VALUES ('269', '19', '441', '49', '68', NULL, '1', '17', 'C', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('270', '19', '439', '49', '98', NULL, '1', '17', 'A', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('271', '19', '437', '49', '98', NULL, '1', '17', 'A', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('272', '19', '435', '49', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('273', '19', '433', '49', '45', NULL, '1', '17', 'D', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('274', '19', '431', '49', '48', NULL, '1', '17', 'D', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('275', '19', '429', '49', '22', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('276', '19', '427', '49', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('277', '19', '425', '49', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('278', '19', '423', '49', '11', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('279', '19', '421', '49', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('280', '19', '419', '49', '45', NULL, '1', '17', 'D', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('281', '19', '417', '49', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('282', '19', '415', '49', '45', NULL, '1', '17', 'D', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('283', '19', '413', '49', '12', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('284', '19', '411', '49', '45', NULL, '1', '17', 'D', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('285', '19', '409', '49', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('286', '19', '407', '49', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('287', '19', '405', '49', '89', NULL, '1', '17', 'B', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('288', '19', '403', '49', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('289', '19', '401', '49', '45', NULL, '1', '17', 'D', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('290', '19', '399', '49', '56', NULL, '1', '17', 'D', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('291', '19', '397', '49', '12', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('292', '19', '395', '49', '23', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('293', '19', '393', '49', '45', NULL, '1', '17', 'D', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('294', '19', '391', '49', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('295', '19', '389', '49', '89', NULL, '1', '17', 'B', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('296', '19', '387', '49', '56', NULL, '1', '17', 'D', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('297', '19', '385', '49', '23', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('298', '19', '383', '49', '54', NULL, '1', '17', 'D', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('299', '19', '381', '49', '87', NULL, '1', '17', 'B', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('300', '19', '379', '49', '89', NULL, '1', '17', 'B', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('301', '19', '377', '49', '56', NULL, '1', '17', 'D', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('302', '19', '375', '49', '88', NULL, '1', '17', 'B', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('303', '19', '373', '49', '77', NULL, '1', '17', 'B', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('304', '19', '371', '49', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('305', '19', '369', '49', '66', NULL, '1', '17', 'C', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('306', '19', '367', '49', '33', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('307', '19', '365', '49', '22', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('308', '19', '363', '49', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('309', '19', '361', '49', '48', NULL, '1', '17', 'D', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('310', '19', '359', '49', '57', NULL, '1', '17', 'D', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('311', '19', '357', '49', '98', NULL, '1', '17', 'A', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('312', '19', '355', '49', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('313', '19', '353', '49', '22', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('314', '19', '351', '49', '35', NULL, '1', '17', 'D', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('315', '19', '349', '49', '45', NULL, '1', '17', 'D', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('317', '19', '331', '49', '99', NULL, '1', '17', 'A', '12', '2023-11-21 11:49:03', '2023-11-21 11:49:03', NULL);
INSERT INTO `exam_marks` VALUES ('318', '20', '467', '50', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:10', '2023-11-21 11:50:10', NULL);
INSERT INTO `exam_marks` VALUES ('319', '20', '465', '50', '32', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:50:10', '2023-11-21 11:50:10', NULL);
INSERT INTO `exam_marks` VALUES ('320', '20', '463', '50', '35', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:10', '2023-11-21 11:50:10', NULL);
INSERT INTO `exam_marks` VALUES ('321', '20', '461', '50', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:10', '2023-11-21 11:50:10', NULL);
INSERT INTO `exam_marks` VALUES ('322', '20', '459', '50', '6', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:50:10', '2023-11-21 11:50:10', NULL);
INSERT INTO `exam_marks` VALUES ('323', '20', '457', '50', '56', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:10', '2023-11-21 11:50:10', NULL);
INSERT INTO `exam_marks` VALUES ('324', '20', '455', '50', '88', NULL, '1', '17', 'B', '12', '2023-11-21 11:50:10', '2023-11-21 11:50:10', NULL);
INSERT INTO `exam_marks` VALUES ('325', '20', '453', '50', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:10', '2023-11-21 11:50:10', NULL);
INSERT INTO `exam_marks` VALUES ('326', '20', '451', '50', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:10', '2023-11-21 11:50:10', NULL);
INSERT INTO `exam_marks` VALUES ('327', '20', '449', '50', '22', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:50:10', '2023-11-21 11:50:10', NULL);
INSERT INTO `exam_marks` VALUES ('328', '20', '447', '50', '33', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:50:10', '2023-11-21 11:50:10', NULL);
INSERT INTO `exam_marks` VALUES ('329', '20', '445', '50', '22', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:50:10', '2023-11-21 11:50:10', NULL);
INSERT INTO `exam_marks` VALUES ('330', '20', '443', '50', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:10', '2023-11-21 11:50:10', NULL);
INSERT INTO `exam_marks` VALUES ('331', '20', '441', '50', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('332', '20', '439', '50', '88', NULL, '1', '17', 'B', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('333', '20', '437', '50', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('334', '20', '435', '50', '66', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('335', '20', '433', '50', '88', NULL, '1', '17', 'B', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('336', '20', '431', '50', '77', NULL, '1', '17', 'B', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('337', '20', '429', '50', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('338', '20', '427', '50', '99', NULL, '1', '17', 'A', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('339', '20', '425', '50', '66', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('340', '20', '423', '50', '33', NULL, '0', '17', 'Fail', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('341', '20', '421', '50', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('342', '20', '419', '50', '55', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('343', '20', '417', '50', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('344', '20', '415', '50', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('345', '20', '413', '50', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('346', '20', '411', '50', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('347', '20', '409', '50', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('348', '20', '407', '50', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('349', '20', '405', '50', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('350', '20', '403', '50', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('351', '20', '401', '50', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('352', '20', '399', '50', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('353', '20', '397', '50', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('354', '20', '395', '50', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('355', '20', '393', '50', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('356', '20', '391', '50', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('357', '20', '389', '50', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('358', '20', '387', '50', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('359', '20', '385', '50', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('360', '20', '383', '50', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('361', '20', '381', '50', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('362', '20', '379', '50', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('363', '20', '377', '50', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('364', '20', '375', '50', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('365', '20', '373', '50', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('366', '20', '371', '50', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('367', '20', '369', '50', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('368', '20', '367', '50', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('369', '20', '365', '50', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('370', '20', '363', '50', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('371', '20', '361', '50', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('372', '20', '359', '50', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('373', '20', '357', '50', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('374', '20', '355', '50', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('375', '20', '353', '50', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('376', '20', '351', '50', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('377', '20', '349', '50', '44', NULL, '1', '17', 'D', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('379', '20', '331', '50', '88', NULL, '1', '17', 'B', '12', '2023-11-21 11:50:11', '2023-11-21 11:50:11', NULL);
INSERT INTO `exam_marks` VALUES ('380', '21', '467', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:51', '2023-11-21 11:50:51', NULL);
INSERT INTO `exam_marks` VALUES ('381', '21', '465', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:51', '2023-11-21 11:50:51', NULL);
INSERT INTO `exam_marks` VALUES ('382', '21', '463', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:51', '2023-11-21 11:50:51', NULL);
INSERT INTO `exam_marks` VALUES ('383', '21', '461', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:51', '2023-11-21 11:50:51', NULL);
INSERT INTO `exam_marks` VALUES ('384', '21', '459', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:51', '2023-11-21 11:50:51', NULL);
INSERT INTO `exam_marks` VALUES ('385', '21', '457', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:51', '2023-11-21 11:50:51', NULL);
INSERT INTO `exam_marks` VALUES ('386', '21', '455', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:51', '2023-11-21 11:50:51', NULL);
INSERT INTO `exam_marks` VALUES ('387', '21', '453', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:51', '2023-11-21 11:50:51', NULL);
INSERT INTO `exam_marks` VALUES ('388', '21', '451', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:51', '2023-11-21 11:50:51', NULL);
INSERT INTO `exam_marks` VALUES ('389', '21', '449', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:51', '2023-11-21 11:50:51', NULL);
INSERT INTO `exam_marks` VALUES ('390', '21', '447', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:51', '2023-11-21 11:50:51', NULL);
INSERT INTO `exam_marks` VALUES ('391', '21', '445', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:51', '2023-11-21 11:50:51', NULL);
INSERT INTO `exam_marks` VALUES ('392', '21', '443', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:51', '2023-11-21 11:50:51', NULL);
INSERT INTO `exam_marks` VALUES ('393', '21', '441', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:51', '2023-11-21 11:50:51', NULL);
INSERT INTO `exam_marks` VALUES ('394', '21', '439', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:51', '2023-11-21 11:50:51', NULL);
INSERT INTO `exam_marks` VALUES ('395', '21', '437', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:51', '2023-11-21 11:50:51', NULL);
INSERT INTO `exam_marks` VALUES ('396', '21', '435', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('397', '21', '433', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('398', '21', '431', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('399', '21', '429', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('400', '21', '427', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('401', '21', '425', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('402', '21', '423', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('403', '21', '421', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('404', '21', '419', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('405', '21', '417', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('406', '21', '415', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('407', '21', '413', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('408', '21', '411', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('409', '21', '409', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('410', '21', '407', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('411', '21', '405', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('412', '21', '403', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('413', '21', '401', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('414', '21', '399', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('415', '21', '397', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('416', '21', '395', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('417', '21', '393', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('418', '21', '391', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('419', '21', '389', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('420', '21', '387', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('421', '21', '385', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('422', '21', '383', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('423', '21', '381', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('424', '21', '379', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('425', '21', '377', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('426', '21', '375', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('427', '21', '373', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('428', '21', '371', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('429', '21', '369', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('430', '21', '367', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('431', '21', '365', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('432', '21', '363', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('433', '21', '361', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('434', '21', '359', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('435', '21', '357', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('436', '21', '355', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('437', '21', '353', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('438', '21', '351', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('439', '21', '349', '52', '65', NULL, '1', '17', 'C', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('441', '21', '331', '52', '85', NULL, '1', '17', 'B', '12', '2023-11-21 11:50:52', '2023-11-21 11:50:52', NULL);
INSERT INTO `exam_marks` VALUES ('442', '22', '467', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('443', '22', '465', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('444', '22', '463', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('445', '22', '461', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('446', '22', '459', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('447', '22', '457', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('448', '22', '455', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('449', '22', '453', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('450', '22', '451', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('451', '22', '449', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('452', '22', '447', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('453', '22', '445', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('454', '22', '443', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('455', '22', '441', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('456', '22', '439', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('457', '22', '437', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('458', '22', '435', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('459', '22', '433', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('460', '22', '431', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('461', '22', '429', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('462', '22', '427', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('463', '22', '425', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('464', '22', '423', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('465', '22', '421', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('466', '22', '419', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('467', '22', '417', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('468', '22', '415', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('469', '22', '413', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('470', '22', '411', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('471', '22', '409', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('472', '22', '407', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('473', '22', '405', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('474', '22', '403', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('475', '22', '401', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('476', '22', '399', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('477', '22', '397', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('478', '22', '395', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('479', '22', '393', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('480', '22', '391', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('481', '22', '389', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('482', '22', '387', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('483', '22', '385', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('484', '22', '383', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('485', '22', '381', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('486', '22', '379', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('487', '22', '377', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('488', '22', '375', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('489', '22', '373', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('490', '22', '371', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('491', '22', '369', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('492', '22', '367', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('493', '22', '365', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('494', '22', '363', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('495', '22', '361', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('496', '22', '359', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('497', '22', '357', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('498', '22', '355', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('499', '22', '353', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('500', '22', '351', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('501', '22', '349', '53', '78', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('503', '22', '331', '53', '89', NULL, '1', '17', 'B', '12', '2023-11-21 11:51:45', '2023-11-21 11:51:45', NULL);
INSERT INTO `exam_marks` VALUES ('504', '23', '467', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('505', '23', '465', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('506', '23', '463', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('507', '23', '461', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('508', '23', '459', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('509', '23', '457', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('510', '23', '455', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('511', '23', '453', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('512', '23', '451', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('513', '23', '449', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('514', '23', '447', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('515', '23', '445', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('516', '23', '443', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('517', '23', '441', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('518', '23', '439', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('519', '23', '437', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('520', '23', '435', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('521', '23', '433', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('522', '23', '431', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('523', '23', '429', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('524', '23', '427', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('525', '23', '425', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('526', '23', '423', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('527', '23', '421', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('528', '23', '419', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('529', '23', '417', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('530', '23', '415', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('531', '23', '413', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('532', '23', '411', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('533', '23', '409', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('534', '23', '407', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('535', '23', '405', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('536', '23', '403', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('537', '23', '401', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('538', '23', '399', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('539', '23', '397', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('540', '23', '395', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('541', '23', '393', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('542', '23', '391', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('543', '23', '389', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('544', '23', '387', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('545', '23', '385', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:53', '2023-11-21 11:52:53', NULL);
INSERT INTO `exam_marks` VALUES ('546', '23', '383', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:54', '2023-11-21 11:52:54', NULL);
INSERT INTO `exam_marks` VALUES ('547', '23', '381', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:54', '2023-11-21 11:52:54', NULL);
INSERT INTO `exam_marks` VALUES ('548', '23', '379', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:54', '2023-11-21 11:52:54', NULL);
INSERT INTO `exam_marks` VALUES ('549', '23', '377', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:54', '2023-11-21 11:52:54', NULL);
INSERT INTO `exam_marks` VALUES ('550', '23', '375', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:54', '2023-11-21 11:52:54', NULL);
INSERT INTO `exam_marks` VALUES ('551', '23', '373', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:54', '2023-11-21 11:52:54', NULL);
INSERT INTO `exam_marks` VALUES ('552', '23', '371', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:54', '2023-11-21 11:52:54', NULL);
INSERT INTO `exam_marks` VALUES ('553', '23', '369', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:54', '2023-11-21 11:52:54', NULL);
INSERT INTO `exam_marks` VALUES ('554', '23', '367', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:54', '2023-11-21 11:52:54', NULL);
INSERT INTO `exam_marks` VALUES ('555', '23', '365', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:54', '2023-11-21 11:52:54', NULL);
INSERT INTO `exam_marks` VALUES ('556', '23', '363', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:54', '2023-11-21 11:52:54', NULL);
INSERT INTO `exam_marks` VALUES ('557', '23', '361', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:54', '2023-11-21 11:52:54', NULL);
INSERT INTO `exam_marks` VALUES ('558', '23', '359', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:54', '2023-11-21 11:52:54', NULL);
INSERT INTO `exam_marks` VALUES ('559', '23', '357', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:54', '2023-11-21 11:52:54', NULL);
INSERT INTO `exam_marks` VALUES ('560', '23', '355', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:54', '2023-11-21 11:52:54', NULL);
INSERT INTO `exam_marks` VALUES ('561', '23', '353', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:54', '2023-11-21 11:52:54', NULL);
INSERT INTO `exam_marks` VALUES ('562', '23', '351', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:54', '2023-11-21 11:52:54', NULL);
INSERT INTO `exam_marks` VALUES ('563', '23', '349', '54', '92', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:54', '2023-11-21 11:52:54', NULL);
INSERT INTO `exam_marks` VALUES ('565', '23', '331', '54', '98', NULL, '1', '17', 'A', '12', '2023-11-21 11:52:54', '2023-11-21 11:52:54', NULL);
INSERT INTO `exam_marks` VALUES ('566', '26', '334', '64', '50', NULL, '1', '17', 'D', '12', '2023-11-21 12:05:05', '2023-11-21 12:05:05', NULL);
INSERT INTO `exam_marks` VALUES ('567', '27', '334', '66', '80', NULL, '1', '17', 'B', '12', '2023-11-21 12:05:19', '2023-11-21 12:05:19', NULL);
INSERT INTO `exam_marks` VALUES ('568', '14', '488', '55', '85', NULL, '1', '17', 'A2', '12', '2024-05-17 17:26:42', '2025-01-09 13:14:43', NULL);
INSERT INTO `exam_marks` VALUES ('569', '14', '490', '55', '63', NULL, '1', '17', 'C', '12', '2024-05-17 17:26:42', '2025-01-09 13:14:43', NULL);
INSERT INTO `exam_marks` VALUES ('570', '14', '492', '55', '65', NULL, '1', '17', 'C', '12', '2024-05-17 17:26:42', '2025-01-09 13:14:43', NULL);
INSERT INTO `exam_marks` VALUES ('571', '14', '494', '55', '95', NULL, '1', '17', 'A', '12', '2024-05-17 17:26:42', '2025-01-09 13:14:43', NULL);
INSERT INTO `exam_marks` VALUES ('572', '14', '496', '55', '83', NULL, '1', '17', 'A2', '12', '2024-05-17 17:26:42', '2025-01-09 13:14:43', NULL);
INSERT INTO `exam_marks` VALUES ('573', '14', '498', '55', '75', NULL, '1', '17', 'B', '12', '2024-05-17 17:26:42', '2025-01-09 13:14:43', NULL);
INSERT INTO `exam_marks` VALUES ('574', '14', '500', '55', '52', NULL, '1', '17', 'C2', '12', '2024-05-17 17:26:42', '2025-01-09 13:14:43', NULL);
INSERT INTO `exam_marks` VALUES ('575', '14', '502', '55', '76', NULL, '1', '17', 'B', '12', '2024-05-17 17:26:42', '2025-01-09 13:14:43', NULL);
INSERT INTO `exam_marks` VALUES ('576', '14', '504', '55', '65', NULL, '1', '17', 'C', '12', '2024-05-17 17:26:42', '2025-01-09 13:14:43', NULL);
INSERT INTO `exam_marks` VALUES ('577', '14', '506', '55', '90', NULL, '1', '17', 'A2', '12', '2024-05-17 17:26:42', '2025-01-09 13:14:43', NULL);
INSERT INTO `exam_marks` VALUES ('578', '14', '508', '55', '80', NULL, '1', '17', 'B', '12', '2024-05-17 17:26:42', '2025-01-09 13:14:43', NULL);
INSERT INTO `exam_marks` VALUES ('579', '14', '510', '55', '70', NULL, '1', '17', 'B2', '12', '2024-05-17 17:26:42', '2025-01-09 13:14:43', NULL);
INSERT INTO `exam_marks` VALUES ('580', '14', '512', '55', '71', NULL, '1', '17', 'B2', '12', '2024-05-17 17:26:42', '2025-01-09 13:14:43', NULL);
INSERT INTO `exam_marks` VALUES ('581', '14', '514', '55', '82', NULL, '1', '17', 'B', '12', '2024-05-17 17:26:42', '2025-01-09 13:14:43', NULL);
INSERT INTO `exam_marks` VALUES ('582', '14', '516', '55', '72', NULL, '1', '17', 'B2', '12', '2024-05-17 17:26:42', '2025-01-09 13:14:43', NULL);
INSERT INTO `exam_marks` VALUES ('583', '14', '518', '55', '85', NULL, '1', '17', 'A2', '12', '2024-05-17 17:26:42', '2025-01-09 13:14:43', NULL);
INSERT INTO `exam_marks` VALUES ('584', '14', '520', '55', '88', NULL, '1', '17', 'A2', '12', '2024-05-17 17:26:42', '2025-01-09 13:14:43', NULL);
INSERT INTO `exam_marks` VALUES ('585', '14', '522', '55', '72', NULL, '1', '17', 'B2', '12', '2024-05-17 17:26:42', '2025-01-09 13:14:43', NULL);
INSERT INTO `exam_marks` VALUES ('586', '14', '524', '55', '73', NULL, '1', '17', 'B2', '12', '2024-05-17 17:26:42', '2025-01-09 13:14:43', NULL);
INSERT INTO `exam_marks` VALUES ('587', '14', '526', '55', '74', NULL, '1', '17', 'B2', '12', '2024-05-17 17:26:42', '2025-01-09 13:14:43', NULL);
INSERT INTO `exam_marks` VALUES ('588', '30', '802', '91', '90', NULL, '1', '17', 'A2', '12', '2024-07-17 15:06:14', '2024-07-17 15:06:14', NULL);
INSERT INTO `exam_marks` VALUES ('589', '30', '800', '91', '50', NULL, '1', '17', 'D', '12', '2024-07-17 15:06:14', '2024-07-17 15:06:14', NULL);
INSERT INTO `exam_marks` VALUES ('590', '30', '798', '91', '56', NULL, '1', '17', 'C2', '12', '2024-07-17 15:06:14', '2024-07-17 15:06:14', NULL);
INSERT INTO `exam_marks` VALUES ('591', '30', '796', '91', '58', NULL, '1', '17', 'C2', '12', '2024-07-17 15:06:14', '2024-07-17 15:06:14', NULL);
INSERT INTO `exam_marks` VALUES ('592', '30', '794', '91', '77', NULL, '1', '17', 'B', '12', '2024-07-17 15:06:14', '2024-07-17 15:06:14', NULL);
INSERT INTO `exam_marks` VALUES ('593', '30', '792', '91', '74', NULL, '1', '17', 'B2', '12', '2024-07-17 15:06:14', '2024-07-17 15:06:14', NULL);
INSERT INTO `exam_marks` VALUES ('594', '30', '790', '91', '55', NULL, '1', '17', 'C2', '12', '2024-07-17 15:06:14', '2024-07-17 15:06:14', NULL);
INSERT INTO `exam_marks` VALUES ('595', '30', '788', '91', '20', NULL, '0', '17', 'FAIL', '12', '2024-07-17 15:06:14', '2024-07-17 15:06:14', NULL);
INSERT INTO `exam_marks` VALUES ('596', '30', '786', '91', '25', NULL, '0', '17', 'FAIL', '12', '2024-07-17 15:06:14', '2024-07-17 15:06:14', NULL);
INSERT INTO `exam_marks` VALUES ('597', '30', '784', '91', '33', NULL, '1', '17', 'FAIL', '12', '2024-07-17 15:06:14', '2024-07-17 15:06:14', NULL);
INSERT INTO `exam_marks` VALUES ('598', '30', '782', '91', '36', NULL, '1', '17', 'D2', '12', '2024-07-17 15:06:14', '2024-07-17 15:06:14', NULL);
INSERT INTO `exam_marks` VALUES ('599', '30', '780', '91', '55', NULL, '1', '17', 'C2', '12', '2024-07-17 15:06:14', '2024-07-17 15:06:14', NULL);
INSERT INTO `exam_marks` VALUES ('600', '30', '778', '91', '52', NULL, '1', '17', 'C2', '12', '2024-07-17 15:06:14', '2024-07-17 15:06:14', NULL);
INSERT INTO `exam_marks` VALUES ('601', '30', '776', '91', '25', NULL, '0', '17', 'FAIL', '12', '2024-07-17 15:06:14', '2024-07-17 15:06:14', NULL);
INSERT INTO `exam_marks` VALUES ('602', '30', '774', '91', '55', NULL, '1', '17', 'C2', '12', '2024-07-17 15:06:14', '2024-07-17 15:06:14', NULL);
INSERT INTO `exam_marks` VALUES ('603', '30', '772', '91', '85', NULL, '1', '17', 'A2', '12', '2024-07-17 15:06:14', '2024-07-17 15:06:14', NULL);
INSERT INTO `exam_marks` VALUES ('604', '30', '770', '91', '44', NULL, '1', '17', 'D', '12', '2024-07-17 15:06:14', '2024-07-17 15:06:14', NULL);
INSERT INTO `exam_marks` VALUES ('605', '30', '768', '91', '75', NULL, '1', '17', 'B', '12', '2024-07-17 15:06:14', '2024-07-17 15:06:14', NULL);
INSERT INTO `exam_marks` VALUES ('606', '30', '766', '91', '63', NULL, '1', '17', 'C', '12', '2024-07-17 15:06:14', '2024-07-17 15:06:14', NULL);
INSERT INTO `exam_marks` VALUES ('607', '30', '764', '91', '52', NULL, '1', '17', 'C2', '12', '2024-07-17 15:06:14', '2024-07-17 15:06:14', NULL);
INSERT INTO `exam_marks` VALUES ('608', '30', '762', '91', '55', NULL, '1', '17', 'C2', '12', '2024-07-17 15:06:14', '2024-07-17 15:06:14', NULL);
INSERT INTO `exam_marks` VALUES ('609', '30', '760', '91', '25', NULL, '0', '17', 'FAIL', '12', '2024-07-17 15:06:14', '2024-07-17 15:06:14', NULL);
INSERT INTO `exam_marks` VALUES ('610', '30', '758', '91', '55', NULL, '1', '17', 'C2', '12', '2024-07-17 15:06:14', '2024-07-17 15:06:14', NULL);
INSERT INTO `exam_marks` VALUES ('611', '30', '756', '91', '63', NULL, '1', '17', 'C', '12', '2024-07-17 15:06:14', '2024-07-17 15:06:14', NULL);
INSERT INTO `exam_marks` VALUES ('612', '30', '754', '91', '65', NULL, '1', '17', 'C', '12', '2024-07-17 15:06:14', '2024-07-17 15:06:14', NULL);
INSERT INTO `exam_marks` VALUES ('613', '30', '752', '91', '64', NULL, '1', '17', 'C', '12', '2024-07-17 15:06:14', '2024-07-17 15:06:14', NULL);
INSERT INTO `exam_marks` VALUES ('614', '30', '750', '91', '63', NULL, '1', '17', 'C', '12', '2024-07-17 15:06:14', '2024-07-17 15:06:14', NULL);
INSERT INTO `exam_marks` VALUES ('615', '30', '748', '91', '44', NULL, '1', '17', 'D', '12', '2024-07-17 15:06:14', '2024-07-17 15:06:14', NULL);
INSERT INTO `exam_marks` VALUES ('616', '30', '746', '91', '54', NULL, '1', '17', 'C2', '12', '2024-07-17 15:06:14', '2024-07-17 15:06:14', NULL);
INSERT INTO `exam_marks` VALUES ('617', '30', '744', '91', '14', NULL, '0', '17', 'FAIL', '12', '2024-07-17 15:06:14', '2024-07-17 15:06:14', NULL);
INSERT INTO `exam_marks` VALUES ('618', '30', '337', '91', '55', NULL, '1', '17', 'C2', '12', '2024-07-17 15:06:14', '2024-07-17 15:06:14', NULL);
INSERT INTO `exam_marks` VALUES ('619', '31', '802', '92', '100', NULL, '1', '17', 'A', '12', '2024-07-17 15:08:04', '2024-07-17 15:08:04', NULL);
INSERT INTO `exam_marks` VALUES ('620', '31', '800', '92', '85', NULL, '1', '17', 'A2', '12', '2024-07-17 15:08:04', '2024-07-17 15:08:04', NULL);
INSERT INTO `exam_marks` VALUES ('621', '31', '798', '92', '90', NULL, '1', '17', 'A2', '12', '2024-07-17 15:08:04', '2024-07-17 15:08:04', NULL);
INSERT INTO `exam_marks` VALUES ('622', '31', '796', '92', '55', NULL, '1', '17', 'C2', '12', '2024-07-17 15:08:04', '2024-07-17 15:08:04', NULL);
INSERT INTO `exam_marks` VALUES ('623', '31', '794', '92', '58', NULL, '1', '17', 'C2', '12', '2024-07-17 15:08:04', '2024-07-17 15:08:04', NULL);
INSERT INTO `exam_marks` VALUES ('624', '31', '792', '92', '50', NULL, '1', '17', 'D', '12', '2024-07-17 15:08:04', '2024-07-17 15:08:04', NULL);
INSERT INTO `exam_marks` VALUES ('625', '31', '790', '92', '25', NULL, '0', '17', 'FAIL', '12', '2024-07-17 15:08:04', '2024-07-17 15:08:04', NULL);
INSERT INTO `exam_marks` VALUES ('626', '31', '788', '92', '33', NULL, '1', '17', 'FAIL', '12', '2024-07-17 15:08:04', '2024-07-17 15:08:04', NULL);
INSERT INTO `exam_marks` VALUES ('627', '31', '786', '92', '35', NULL, '1', '17', 'D2', '12', '2024-07-17 15:08:04', '2024-07-17 15:08:04', NULL);
INSERT INTO `exam_marks` VALUES ('628', '31', '784', '92', '55', NULL, '1', '17', 'C2', '12', '2024-07-17 15:08:04', '2024-07-17 15:08:04', NULL);
INSERT INTO `exam_marks` VALUES ('629', '31', '782', '92', '56', NULL, '1', '17', 'C2', '12', '2024-07-17 15:08:04', '2024-07-17 15:08:04', NULL);
INSERT INTO `exam_marks` VALUES ('630', '31', '780', '92', '64', NULL, '1', '17', 'C', '12', '2024-07-17 15:08:04', '2024-07-17 15:08:04', NULL);
INSERT INTO `exam_marks` VALUES ('631', '31', '778', '92', '70', NULL, '1', '17', 'B2', '12', '2024-07-17 15:08:04', '2024-07-17 15:08:04', NULL);
INSERT INTO `exam_marks` VALUES ('632', '31', '776', '92', '80', NULL, '1', '17', 'B', '12', '2024-07-17 15:08:04', '2024-07-17 15:08:04', NULL);
INSERT INTO `exam_marks` VALUES ('633', '31', '774', '92', '88', NULL, '1', '17', 'A2', '12', '2024-07-17 15:08:04', '2024-07-17 15:08:04', NULL);
INSERT INTO `exam_marks` VALUES ('634', '31', '772', '92', '55', NULL, '1', '17', 'C2', '12', '2024-07-17 15:08:04', '2024-07-17 15:08:04', NULL);
INSERT INTO `exam_marks` VALUES ('635', '31', '770', '92', '56', NULL, '1', '17', 'C2', '12', '2024-07-17 15:08:04', '2024-07-17 15:08:04', NULL);
INSERT INTO `exam_marks` VALUES ('636', '31', '768', '92', '68', NULL, '1', '17', 'B2', '12', '2024-07-17 15:08:04', '2024-07-17 15:08:04', NULL);
INSERT INTO `exam_marks` VALUES ('637', '31', '766', '92', '44', NULL, '1', '17', 'D', '12', '2024-07-17 15:08:04', '2024-07-17 15:08:04', NULL);
INSERT INTO `exam_marks` VALUES ('638', '31', '764', '92', '58', NULL, '1', '17', 'C2', '12', '2024-07-17 15:08:04', '2024-07-17 15:08:04', NULL);
INSERT INTO `exam_marks` VALUES ('639', '31', '762', '92', '55', NULL, '1', '17', 'C2', '12', '2024-07-17 15:08:04', '2024-07-17 15:08:04', NULL);
INSERT INTO `exam_marks` VALUES ('640', '31', '760', '92', '69', NULL, '1', '17', 'B2', '12', '2024-07-17 15:08:04', '2024-07-17 15:08:04', NULL);
INSERT INTO `exam_marks` VALUES ('641', '31', '758', '92', '50', NULL, '1', '17', 'D', '12', '2024-07-17 15:08:04', '2024-07-17 15:08:04', NULL);
INSERT INTO `exam_marks` VALUES ('642', '31', '756', '92', '55', NULL, '1', '17', 'C2', '12', '2024-07-17 15:08:04', '2024-07-17 15:08:04', NULL);
INSERT INTO `exam_marks` VALUES ('643', '31', '754', '92', '50', NULL, '1', '17', 'D', '12', '2024-07-17 15:08:04', '2024-07-17 15:08:04', NULL);
INSERT INTO `exam_marks` VALUES ('644', '31', '752', '92', '55', NULL, '1', '17', 'C2', '12', '2024-07-17 15:08:04', '2024-07-17 15:08:04', NULL);
INSERT INTO `exam_marks` VALUES ('645', '31', '750', '92', '55', NULL, '1', '17', 'C2', '12', '2024-07-17 15:08:04', '2024-07-17 15:08:04', NULL);
INSERT INTO `exam_marks` VALUES ('646', '31', '748', '92', '58', NULL, '1', '17', 'C2', '12', '2024-07-17 15:08:04', '2024-07-17 15:08:04', NULL);
INSERT INTO `exam_marks` VALUES ('647', '31', '746', '92', '96', NULL, '1', '17', 'A', '12', '2024-07-17 15:08:04', '2024-07-17 15:08:04', NULL);
INSERT INTO `exam_marks` VALUES ('648', '31', '744', '92', '62', NULL, '1', '17', 'C', '12', '2024-07-17 15:08:04', '2024-07-17 15:08:04', NULL);
INSERT INTO `exam_marks` VALUES ('649', '31', '337', '92', '55', NULL, '1', '17', 'C2', '12', '2024-07-17 15:08:04', '2024-07-17 15:08:04', NULL);
INSERT INTO `exam_marks` VALUES ('650', '32', '802', '95', '100', NULL, '1', '17', 'A', '12', '2024-07-17 15:09:18', '2024-07-17 15:09:18', NULL);
INSERT INTO `exam_marks` VALUES ('651', '32', '800', '95', '85', NULL, '1', '17', 'A2', '12', '2024-07-17 15:09:18', '2024-07-17 15:09:18', NULL);
INSERT INTO `exam_marks` VALUES ('652', '32', '798', '95', '96', NULL, '1', '17', 'A', '12', '2024-07-17 15:09:18', '2024-07-17 15:09:18', NULL);
INSERT INTO `exam_marks` VALUES ('653', '32', '796', '95', '96', NULL, '1', '17', 'A', '12', '2024-07-17 15:09:18', '2024-07-17 15:09:18', NULL);
INSERT INTO `exam_marks` VALUES ('654', '32', '794', '95', '85', NULL, '1', '17', 'A2', '12', '2024-07-17 15:09:18', '2024-07-17 15:09:18', NULL);
INSERT INTO `exam_marks` VALUES ('655', '32', '792', '95', '74', NULL, '1', '17', 'B2', '12', '2024-07-17 15:09:18', '2024-07-17 15:09:18', NULL);
INSERT INTO `exam_marks` VALUES ('656', '32', '790', '95', '85', NULL, '1', '17', 'A2', '12', '2024-07-17 15:09:18', '2024-07-17 15:09:18', NULL);
INSERT INTO `exam_marks` VALUES ('657', '32', '788', '95', '88', NULL, '1', '17', 'A2', '12', '2024-07-17 15:09:18', '2024-07-17 15:09:18', NULL);
INSERT INTO `exam_marks` VALUES ('658', '32', '786', '95', '96', NULL, '1', '17', 'A', '12', '2024-07-17 15:09:18', '2024-07-17 15:09:18', NULL);
INSERT INTO `exam_marks` VALUES ('659', '32', '784', '95', '54', NULL, '1', '17', 'C2', '12', '2024-07-17 15:09:18', '2024-07-17 15:09:18', NULL);
INSERT INTO `exam_marks` VALUES ('660', '32', '782', '95', '58', NULL, '1', '17', 'C2', '12', '2024-07-17 15:09:18', '2024-07-17 15:09:18', NULL);
INSERT INTO `exam_marks` VALUES ('661', '32', '780', '95', '88', NULL, '1', '17', 'A2', '12', '2024-07-17 15:09:18', '2024-07-17 15:09:18', NULL);
INSERT INTO `exam_marks` VALUES ('662', '32', '778', '95', '96', NULL, '1', '17', 'A', '12', '2024-07-17 15:09:18', '2024-07-17 15:09:18', NULL);
INSERT INTO `exam_marks` VALUES ('663', '32', '776', '95', '65', NULL, '1', '17', 'C', '12', '2024-07-17 15:09:18', '2024-07-17 15:09:18', NULL);
INSERT INTO `exam_marks` VALUES ('664', '32', '774', '95', '88', NULL, '1', '17', 'A2', '12', '2024-07-17 15:09:18', '2024-07-17 15:09:18', NULL);
INSERT INTO `exam_marks` VALUES ('665', '32', '772', '95', '87', NULL, '1', '17', 'A2', '12', '2024-07-17 15:09:18', '2024-07-17 15:09:18', NULL);
INSERT INTO `exam_marks` VALUES ('666', '32', '770', '95', '85', NULL, '1', '17', 'A2', '12', '2024-07-17 15:09:18', '2024-07-17 15:09:18', NULL);
INSERT INTO `exam_marks` VALUES ('667', '32', '768', '95', '96', NULL, '1', '17', 'A', '12', '2024-07-17 15:09:18', '2024-07-17 15:09:18', NULL);
INSERT INTO `exam_marks` VALUES ('668', '32', '766', '95', '85', NULL, '1', '17', 'A2', '12', '2024-07-17 15:09:18', '2024-07-17 15:09:18', NULL);
INSERT INTO `exam_marks` VALUES ('669', '32', '764', '95', '85', NULL, '1', '17', 'A2', '12', '2024-07-17 15:09:18', '2024-07-17 15:09:18', NULL);
INSERT INTO `exam_marks` VALUES ('670', '32', '762', '95', '69', NULL, '1', '17', 'B2', '12', '2024-07-17 15:09:18', '2024-07-17 15:09:18', NULL);
INSERT INTO `exam_marks` VALUES ('671', '32', '760', '95', '88', NULL, '1', '17', 'A2', '12', '2024-07-17 15:09:18', '2024-07-17 15:09:18', NULL);
INSERT INTO `exam_marks` VALUES ('672', '32', '758', '95', '87', NULL, '1', '17', 'A2', '12', '2024-07-17 15:09:18', '2024-07-17 15:09:18', NULL);
INSERT INTO `exam_marks` VALUES ('673', '32', '756', '95', '74', NULL, '1', '17', 'B2', '12', '2024-07-17 15:09:18', '2024-07-17 15:09:18', NULL);
INSERT INTO `exam_marks` VALUES ('674', '32', '754', '95', '77', NULL, '1', '17', 'B', '12', '2024-07-17 15:09:18', '2024-07-17 15:09:18', NULL);
INSERT INTO `exam_marks` VALUES ('675', '32', '752', '95', '85', NULL, '1', '17', 'A2', '12', '2024-07-17 15:09:18', '2024-07-17 15:09:18', NULL);
INSERT INTO `exam_marks` VALUES ('676', '32', '750', '95', '100', NULL, '1', '17', 'A', '12', '2024-07-17 15:09:18', '2024-07-17 15:09:18', NULL);
INSERT INTO `exam_marks` VALUES ('677', '32', '748', '95', '89', NULL, '1', '17', 'A2', '12', '2024-07-17 15:09:18', '2024-07-17 15:09:18', NULL);
INSERT INTO `exam_marks` VALUES ('678', '32', '746', '95', '88', NULL, '1', '17', 'A2', '12', '2024-07-17 15:09:18', '2024-07-17 15:09:18', NULL);
INSERT INTO `exam_marks` VALUES ('679', '32', '744', '95', '99', NULL, '1', '17', 'A', '12', '2024-07-17 15:09:18', '2024-07-17 15:09:18', NULL);
INSERT INTO `exam_marks` VALUES ('680', '32', '337', '95', '90', NULL, '1', '17', 'A2', '12', '2024-07-17 15:09:18', '2024-07-17 15:09:18', NULL);
INSERT INTO `exam_marks` VALUES ('681', '33', '802', '94', '94', NULL, '1', '17', 'A', '12', '2024-07-17 15:09:52', '2024-07-17 15:09:52', NULL);
INSERT INTO `exam_marks` VALUES ('682', '33', '800', '94', '85', NULL, '1', '17', 'A2', '12', '2024-07-17 15:09:52', '2024-07-17 15:09:52', NULL);
INSERT INTO `exam_marks` VALUES ('683', '33', '798', '94', '86', NULL, '1', '17', 'A2', '12', '2024-07-17 15:09:52', '2024-07-17 15:09:52', NULL);
INSERT INTO `exam_marks` VALUES ('684', '33', '796', '94', '66', NULL, '1', '17', 'C', '12', '2024-07-17 15:09:52', '2024-07-17 15:09:52', NULL);
INSERT INTO `exam_marks` VALUES ('685', '33', '794', '94', '58', NULL, '1', '17', 'C2', '12', '2024-07-17 15:09:52', '2024-07-17 15:09:52', NULL);
INSERT INTO `exam_marks` VALUES ('686', '33', '792', '94', '52', NULL, '1', '17', 'C2', '12', '2024-07-17 15:09:52', '2024-07-17 15:09:52', NULL);
INSERT INTO `exam_marks` VALUES ('687', '33', '790', '94', '55', NULL, '1', '17', 'C2', '12', '2024-07-17 15:09:52', '2024-07-17 15:09:52', NULL);
INSERT INTO `exam_marks` VALUES ('688', '33', '788', '94', '56', NULL, '1', '17', 'C2', '12', '2024-07-17 15:09:52', '2024-07-17 15:09:52', NULL);
INSERT INTO `exam_marks` VALUES ('689', '33', '786', '94', '65', NULL, '1', '17', 'C', '12', '2024-07-17 15:09:52', '2024-07-17 15:09:52', NULL);
INSERT INTO `exam_marks` VALUES ('690', '33', '784', '94', '46', NULL, '1', '17', 'D', '12', '2024-07-17 15:09:52', '2024-07-17 15:09:52', NULL);
INSERT INTO `exam_marks` VALUES ('691', '33', '782', '94', '25', NULL, '0', '17', 'FAIL', '12', '2024-07-17 15:09:52', '2024-07-17 15:09:52', NULL);
INSERT INTO `exam_marks` VALUES ('692', '33', '780', '94', '55', NULL, '1', '17', 'C2', '12', '2024-07-17 15:09:52', '2024-07-17 15:09:52', NULL);
INSERT INTO `exam_marks` VALUES ('693', '33', '778', '94', '58', NULL, '1', '17', 'C2', '12', '2024-07-17 15:09:52', '2024-07-17 15:09:52', NULL);
INSERT INTO `exam_marks` VALUES ('694', '33', '776', '94', '88', NULL, '1', '17', 'A2', '12', '2024-07-17 15:09:52', '2024-07-17 15:09:52', NULL);
INSERT INTO `exam_marks` VALUES ('695', '33', '774', '94', '85', NULL, '1', '17', 'A2', '12', '2024-07-17 15:09:52', '2024-07-17 15:09:52', NULL);
INSERT INTO `exam_marks` VALUES ('696', '33', '772', '94', '65', NULL, '1', '17', 'C', '12', '2024-07-17 15:09:52', '2024-07-17 15:09:52', NULL);
INSERT INTO `exam_marks` VALUES ('697', '33', '770', '94', '87', NULL, '1', '17', 'A2', '12', '2024-07-17 15:09:52', '2024-07-17 15:09:52', NULL);
INSERT INTO `exam_marks` VALUES ('698', '33', '768', '94', '87', NULL, '1', '17', 'A2', '12', '2024-07-17 15:09:52', '2024-07-17 15:09:52', NULL);
INSERT INTO `exam_marks` VALUES ('699', '33', '766', '94', '85', NULL, '1', '17', 'A2', '12', '2024-07-17 15:09:52', '2024-07-17 15:09:52', NULL);
INSERT INTO `exam_marks` VALUES ('700', '33', '764', '94', '89', NULL, '1', '17', 'A2', '12', '2024-07-17 15:09:52', '2024-07-17 15:09:52', NULL);
INSERT INTO `exam_marks` VALUES ('701', '33', '762', '94', '99', NULL, '1', '17', 'A', '12', '2024-07-17 15:09:52', '2024-07-17 15:09:52', NULL);
INSERT INTO `exam_marks` VALUES ('702', '33', '760', '94', '63', NULL, '1', '17', 'C', '12', '2024-07-17 15:09:52', '2024-07-17 15:09:52', NULL);
INSERT INTO `exam_marks` VALUES ('703', '33', '758', '94', '55', NULL, '1', '17', 'C2', '12', '2024-07-17 15:09:52', '2024-07-17 15:09:52', NULL);
INSERT INTO `exam_marks` VALUES ('704', '33', '756', '94', '45', NULL, '1', '17', 'D', '12', '2024-07-17 15:09:52', '2024-07-17 15:09:52', NULL);
INSERT INTO `exam_marks` VALUES ('705', '33', '754', '94', '55', NULL, '1', '17', 'C2', '12', '2024-07-17 15:09:52', '2024-07-17 15:09:52', NULL);
INSERT INTO `exam_marks` VALUES ('706', '33', '752', '94', '52', NULL, '1', '17', 'C2', '12', '2024-07-17 15:09:52', '2024-07-17 15:09:52', NULL);
INSERT INTO `exam_marks` VALUES ('707', '33', '750', '94', '25', NULL, '0', '17', 'FAIL', '12', '2024-07-17 15:09:52', '2024-07-17 15:09:52', NULL);
INSERT INTO `exam_marks` VALUES ('708', '33', '748', '94', '52', NULL, '1', '17', 'C2', '12', '2024-07-17 15:09:52', '2024-07-17 15:09:52', NULL);
INSERT INTO `exam_marks` VALUES ('709', '33', '746', '94', '55', NULL, '1', '17', 'C2', '12', '2024-07-17 15:09:52', '2024-07-17 15:09:52', NULL);
INSERT INTO `exam_marks` VALUES ('710', '33', '744', '94', '58', NULL, '1', '17', 'C2', '12', '2024-07-17 15:09:52', '2024-07-17 15:09:52', NULL);
INSERT INTO `exam_marks` VALUES ('711', '33', '337', '94', '96', NULL, '1', '17', 'A', '12', '2024-07-17 15:09:52', '2024-07-17 15:09:52', NULL);

CREATE TABLE IF NOT EXISTS `exam_results` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `exam_id` bigint(20) unsigned NOT NULL,
  `class_section_id` bigint(20) unsigned NOT NULL,
  `student_id` bigint(20) unsigned NOT NULL COMMENT 'user_id',
  `total_marks` int(11) NOT NULL,
  `obtained_marks` double(8,2) NOT NULL,
  `percentage` double(8,2) NOT NULL,
  `grade` tinytext NOT NULL,
  `status` int(11) NOT NULL DEFAULT 1 COMMENT '0 -> Failed, 1 -> Pass',
  `session_year_id` bigint(20) unsigned NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `exam_results_school_id_foreign` (`school_id`),
  KEY `exam_results_exam_id_foreign` (`exam_id`),
  KEY `exam_results_class_section_id_foreign` (`class_section_id`),
  KEY `exam_results_student_id_foreign` (`student_id`),
  KEY `exam_results_session_year_id_foreign` (`session_year_id`),
  CONSTRAINT `exam_results_class_section_id_foreign` FOREIGN KEY (`class_section_id`) REFERENCES `class_sections` (`id`) ON DELETE CASCADE,
  CONSTRAINT `exam_results_exam_id_foreign` FOREIGN KEY (`exam_id`) REFERENCES `exams` (`id`) ON DELETE CASCADE,
  CONSTRAINT `exam_results_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `exam_results_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE,
  CONSTRAINT `exam_results_student_id_foreign` FOREIGN KEY (`student_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=163 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `exam_results` VALUES ('70', '9', '21', '467', '900', '538', '59.78', 'D', '1', '17', '12', '2023-11-21 11:56:10', '2023-11-21 11:56:10');
INSERT INTO `exam_results` VALUES ('71', '9', '21', '403', '900', '517', '57.44', 'D', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('72', '9', '21', '441', '900', '548', '60.89', 'C', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('73', '9', '21', '377', '900', '528', '58.67', 'D', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('74', '9', '21', '415', '900', '534', '59.33', 'D', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('75', '9', '21', '351', '900', '523', '58.11', 'D', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('76', '9', '21', '453', '900', '541', '60.11', 'D', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('77', '9', '21', '389', '900', '625', '69.44', 'C', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('78', '9', '21', '427', '900', '614', '68.22', 'C', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('79', '9', '21', '363', '900', '487', '54.11', 'D', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('80', '9', '21', '465', '900', '532', '59.11', 'D', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('81', '9', '21', '401', '900', '493', '54.78', 'D', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('82', '9', '21', '439', '900', '612', '68', 'C', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('83', '9', '21', '375', '900', '503', '55.89', 'D', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('84', '9', '21', '413', '900', '484', '53.78', 'D', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('85', '9', '21', '349', '900', '532', '59.11', 'D', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('86', '9', '21', '451', '900', '517', '57.44', 'D', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('87', '9', '21', '387', '900', '553', '61.44', 'C', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('88', '9', '21', '425', '900', '480', '53.33', 'D', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('89', '9', '21', '361', '900', '497', '55.22', 'D', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('90', '9', '21', '463', '900', '589', '65.44', 'C', '1', '17', '12', '2023-11-21 11:56:10', '2023-11-21 11:56:10');
INSERT INTO `exam_results` VALUES ('91', '9', '21', '399', '900', '580', '64.44', 'C', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('92', '9', '21', '437', '900', '560', '62.22', 'C', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('93', '9', '21', '373', '900', '495', '55', 'D', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('94', '9', '21', '411', '900', '543', '60.33', 'D', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('96', '9', '21', '449', '900', '643', '71.44', 'C', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:30');
INSERT INTO `exam_results` VALUES ('97', '9', '21', '385', '900', '460', '51.11', 'D', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('98', '9', '21', '423', '900', '415', '46.11', 'D', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('99', '9', '21', '359', '900', '558', '62', 'C', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('100', '9', '21', '461', '900', '575', '63.89', 'C', '1', '17', '12', '2023-11-21 11:56:10', '2023-11-21 11:56:10');
INSERT INTO `exam_results` VALUES ('101', '9', '21', '397', '900', '565', '62.78', 'C', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('102', '9', '21', '435', '900', '638', '70.89', 'C', '1', '17', '12', '2023-11-21 11:56:10', '2023-11-21 11:56:10');
INSERT INTO `exam_results` VALUES ('103', '9', '21', '371', '900', '602', '66.89', 'C', '1', '17', '12', '2023-11-21 11:56:10', '2023-11-21 11:56:10');
INSERT INTO `exam_results` VALUES ('104', '9', '21', '409', '900', '573', '63.67', 'C', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('105', '9', '21', '331', '900', '842', '93.56', 'A', '1', '17', '12', '2023-11-21 11:56:10', '2023-11-21 11:56:10');
INSERT INTO `exam_results` VALUES ('106', '9', '21', '447', '900', '652', '72.44', 'C', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:30');
INSERT INTO `exam_results` VALUES ('107', '9', '21', '383', '900', '451', '50.11', 'D', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('108', '9', '21', '421', '900', '580', '64.44', 'C', '1', '17', '12', '2023-11-21 11:56:10', '2023-11-21 11:56:10');
INSERT INTO `exam_results` VALUES ('109', '9', '21', '357', '900', '543', '60.33', 'D', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('110', '9', '21', '459', '900', '426', '47.33', 'D', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('111', '9', '21', '395', '900', '482', '53.56', 'D', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('112', '9', '21', '433', '900', '677', '75.22', 'C', '1', '17', '12', '2023-11-21 11:56:10', '2023-11-21 11:56:10');
INSERT INTO `exam_results` VALUES ('113', '9', '21', '369', '900', '613', '68.11', 'C', '1', '17', '12', '2023-11-21 11:56:10', '2023-11-21 11:56:10');
INSERT INTO `exam_results` VALUES ('114', '9', '21', '407', '900', '594', '66', 'C', '1', '17', '12', '2023-11-21 11:56:10', '2023-11-21 11:56:10');
INSERT INTO `exam_results` VALUES ('115', '9', '21', '445', '900', '453', '50.33', 'D', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('116', '9', '21', '381', '900', '592', '65.78', 'C', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('117', '9', '21', '419', '900', '549', '61', 'C', '1', '17', '12', '2023-11-21 11:56:10', '2023-11-21 11:56:10');
INSERT INTO `exam_results` VALUES ('118', '9', '21', '355', '900', '487', '54.11', 'D', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('119', '9', '21', '457', '900', '558', '62', 'C', '1', '17', '12', '2023-11-21 11:56:10', '2023-11-21 11:56:10');
INSERT INTO `exam_results` VALUES ('120', '9', '21', '393', '900', '583', '64.78', 'C', '1', '17', '12', '2023-11-21 11:56:10', '2023-11-21 11:56:10');
INSERT INTO `exam_results` VALUES ('121', '9', '21', '431', '900', '632', '70.22', 'C', '1', '17', '12', '2023-11-21 11:56:10', '2023-11-21 11:56:10');
INSERT INTO `exam_results` VALUES ('122', '9', '21', '367', '900', '532', '59.11', 'D', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('123', '9', '21', '405', '900', '578', '64.22', 'C', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('124', '9', '21', '443', '900', '494', '54.89', 'D', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('125', '9', '21', '379', '900', '617', '68.56', 'C', '1', '17', '12', '2023-11-21 11:56:10', '2023-11-21 11:56:10');
INSERT INTO `exam_results` VALUES ('126', '9', '21', '417', '900', '549', '61', 'C', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('127', '9', '21', '353', '900', '514', '57.11', 'D', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('128', '9', '21', '455', '900', '625', '69.44', 'C', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('129', '9', '21', '391', '900', '608', '67.56', 'C', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('130', '9', '21', '429', '900', '537', '59.67', 'D', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('131', '9', '21', '365', '900', '464', '51.56', 'D', '0', '17', '12', '2023-11-21 11:56:10', '2024-05-14 10:56:29');
INSERT INTO `exam_results` VALUES ('132', '25', '26', '770', '400', '272', '68', 'B2', '1', '17', '12', '2024-07-17 15:10:07', '2024-07-17 15:10:07');
INSERT INTO `exam_results` VALUES ('133', '25', '26', '744', '400', '233', '58.25', '', '0', '17', '12', '2024-07-17 15:10:07', '2024-07-17 15:10:07');
INSERT INTO `exam_results` VALUES ('134', '25', '26', '782', '400', '175', '43.75', 'D', '0', '17', '12', '2024-07-17 15:10:07', '2024-07-17 15:10:07');
INSERT INTO `exam_results` VALUES ('135', '25', '26', '756', '400', '237', '59.25', 'C', '1', '17', '12', '2024-07-17 15:10:07', '2024-07-17 15:10:07');
INSERT INTO `exam_results` VALUES ('136', '25', '26', '794', '400', '278', '69.5', 'B2', '1', '17', '12', '2024-07-17 15:10:07', '2024-07-17 15:10:07');
INSERT INTO `exam_results` VALUES ('137', '25', '26', '768', '400', '326', '81.5', 'B', '1', '17', '12', '2024-07-17 15:10:07', '2024-07-17 15:10:07');
INSERT INTO `exam_results` VALUES ('138', '25', '26', '337', '400', '296', '74', 'B2', '1', '17', '12', '2024-07-17 15:10:07', '2024-07-17 15:10:07');
INSERT INTO `exam_results` VALUES ('139', '25', '26', '780', '400', '262', '65.5', 'C', '1', '17', '12', '2024-07-17 15:10:07', '2024-07-17 15:10:07');
INSERT INTO `exam_results` VALUES ('140', '25', '26', '754', '400', '247', '61.75', 'C', '1', '17', '12', '2024-07-17 15:10:07', '2024-07-17 15:10:07');
INSERT INTO `exam_results` VALUES ('141', '25', '26', '792', '400', '250', '62.5', 'C', '1', '17', '12', '2024-07-17 15:10:07', '2024-07-17 15:10:07');
INSERT INTO `exam_results` VALUES ('142', '25', '26', '766', '400', '277', '69.25', 'B2', '1', '17', '12', '2024-07-17 15:10:07', '2024-07-17 15:10:07');
INSERT INTO `exam_results` VALUES ('143', '25', '26', '778', '400', '276', '69', 'B2', '1', '17', '12', '2024-07-17 15:10:07', '2024-07-17 15:10:07');
INSERT INTO `exam_results` VALUES ('144', '25', '26', '752', '400', '256', '64', 'C', '1', '17', '12', '2024-07-17 15:10:07', '2024-07-17 15:10:07');
INSERT INTO `exam_results` VALUES ('145', '25', '26', '790', '400', '220', '55', 'C2', '0', '17', '12', '2024-07-17 15:10:07', '2024-07-17 15:10:07');
INSERT INTO `exam_results` VALUES ('146', '25', '26', '764', '400', '284', '71', 'B2', '1', '17', '12', '2024-07-17 15:10:07', '2024-07-17 15:10:07');
INSERT INTO `exam_results` VALUES ('147', '25', '26', '802', '400', '384', '96', 'A', '1', '17', '12', '2024-07-17 15:10:07', '2024-07-17 15:10:07');
INSERT INTO `exam_results` VALUES ('148', '25', '26', '776', '400', '258', '64.5', 'C', '0', '17', '12', '2024-07-17 15:10:07', '2024-07-17 15:10:07');
INSERT INTO `exam_results` VALUES ('149', '25', '26', '750', '400', '243', '60.75', 'C', '0', '17', '12', '2024-07-17 15:10:07', '2024-07-17 15:10:07');
INSERT INTO `exam_results` VALUES ('150', '25', '26', '788', '400', '197', '49.25', 'D', '0', '17', '12', '2024-07-17 15:10:07', '2024-07-17 15:10:07');
INSERT INTO `exam_results` VALUES ('151', '25', '26', '762', '400', '278', '69.5', 'B2', '1', '17', '12', '2024-07-17 15:10:07', '2024-07-17 15:10:07');
INSERT INTO `exam_results` VALUES ('152', '25', '26', '800', '400', '305', '76.25', 'B', '1', '17', '12', '2024-07-17 15:10:07', '2024-07-17 15:10:07');
INSERT INTO `exam_results` VALUES ('153', '25', '26', '774', '400', '316', '79', 'B', '1', '17', '12', '2024-07-17 15:10:07', '2024-07-17 15:10:07');
INSERT INTO `exam_results` VALUES ('154', '25', '26', '748', '400', '243', '60.75', 'C', '1', '17', '12', '2024-07-17 15:10:07', '2024-07-17 15:10:07');
INSERT INTO `exam_results` VALUES ('155', '25', '26', '786', '400', '221', '55.25', 'C2', '0', '17', '12', '2024-07-17 15:10:07', '2024-07-17 15:10:07');
INSERT INTO `exam_results` VALUES ('156', '25', '26', '760', '400', '245', '61.25', 'C', '0', '17', '12', '2024-07-17 15:10:07', '2024-07-17 15:10:07');
INSERT INTO `exam_results` VALUES ('157', '25', '26', '798', '400', '328', '82', 'B', '1', '17', '12', '2024-07-17 15:10:07', '2024-07-17 15:10:07');
INSERT INTO `exam_results` VALUES ('158', '25', '26', '772', '400', '292', '73', 'B2', '1', '17', '12', '2024-07-17 15:10:07', '2024-07-17 15:10:07');
INSERT INTO `exam_results` VALUES ('159', '25', '26', '746', '400', '293', '73.25', 'B2', '1', '17', '12', '2024-07-17 15:10:07', '2024-07-17 15:10:07');
INSERT INTO `exam_results` VALUES ('160', '25', '26', '784', '400', '188', '47', 'D', '1', '17', '12', '2024-07-17 15:10:07', '2024-07-17 15:10:07');
INSERT INTO `exam_results` VALUES ('161', '25', '26', '758', '400', '247', '61.75', 'C', '1', '17', '12', '2024-07-17 15:10:07', '2024-07-17 15:10:07');
INSERT INTO `exam_results` VALUES ('162', '25', '26', '796', '400', '275', '68.75', 'B2', '1', '17', '12', '2024-07-17 15:10:07', '2024-07-17 15:10:07');

CREATE TABLE IF NOT EXISTS `exam_timetables` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `exam_id` bigint(20) unsigned NOT NULL,
  `class_subject_id` bigint(20) unsigned NOT NULL,
  `total_marks` double(8,2) NOT NULL,
  `passing_marks` double(8,2) NOT NULL,
  `date` date NOT NULL,
  `start_time` time NOT NULL,
  `end_time` time NOT NULL,
  `session_year_id` bigint(20) unsigned NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `exam_timetables_exam_id_foreign` (`exam_id`),
  KEY `exam_timetables_school_id_foreign` (`school_id`),
  KEY `exam_timetables_class_subject_id_foreign` (`class_subject_id`),
  KEY `exam_timetables_session_year_id_foreign` (`session_year_id`),
  CONSTRAINT `exam_timetables_class_subject_id_foreign` FOREIGN KEY (`class_subject_id`) REFERENCES `class_subjects` (`id`) ON DELETE CASCADE,
  CONSTRAINT `exam_timetables_exam_id_foreign` FOREIGN KEY (`exam_id`) REFERENCES `exams` (`id`) ON DELETE CASCADE,
  CONSTRAINT `exam_timetables_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `exam_timetables_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=34 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `exam_timetables` VALUES ('5', '13', '82', '100', '35', '2023-12-21', '10:30:00', '12:30:00', '17', '12', '2023-11-21 10:43:35', '2023-11-21 10:43:35');
INSERT INTO `exam_timetables` VALUES ('6', '13', '84', '100', '35', '2023-12-22', '10:30:00', '12:30:00', '17', '12', '2023-11-21 10:43:35', '2023-11-21 10:43:35');
INSERT INTO `exam_timetables` VALUES ('7', '13', '87', '100', '35', '2023-12-23', '10:30:00', '12:30:00', '17', '12', '2023-11-21 10:43:35', '2023-11-21 10:43:35');
INSERT INTO `exam_timetables` VALUES ('8', '13', '83', '100', '35', '2023-12-25', '10:30:00', '12:30:00', '17', '12', '2023-11-21 10:43:35', '2023-11-21 10:43:35');
INSERT INTO `exam_timetables` VALUES ('9', '13', '85', '100', '35', '2023-12-26', '10:30:00', '12:30:00', '17', '12', '2023-11-21 10:43:35', '2023-11-21 10:43:35');
INSERT INTO `exam_timetables` VALUES ('10', '13', '86', '100', '35', '2023-12-27', '10:30:00', '12:30:00', '17', '12', '2023-11-21 10:45:17', '2023-11-21 10:45:17');
INSERT INTO `exam_timetables` VALUES ('11', '13', '88', '100', '35', '2023-12-28', '10:30:00', '12:30:00', '17', '12', '2023-11-21 10:45:17', '2023-11-21 10:45:17');
INSERT INTO `exam_timetables` VALUES ('12', '13', '89', '100', '35', '2023-12-29', '10:30:00', '12:30:00', '17', '12', '2023-11-21 10:45:17', '2023-11-21 10:45:17');
INSERT INTO `exam_timetables` VALUES ('13', '13', '90', '100', '35', '2023-12-30', '10:30:00', '12:30:00', '17', '12', '2023-11-21 10:45:17', '2023-11-21 10:45:17');
INSERT INTO `exam_timetables` VALUES ('14', '10', '55', '100', '35', '2023-11-21', '10:10:00', '14:02:00', '17', '12', '2023-11-21 10:46:41', '2023-11-21 10:50:30');
INSERT INTO `exam_timetables` VALUES ('15', '9', '46', '100', '35', '2023-11-01', '10:30:00', '12:30:00', '17', '12', '2023-11-21 11:03:05', '2023-11-21 11:11:54');
INSERT INTO `exam_timetables` VALUES ('16', '9', '48', '100', '35', '2023-11-02', '10:30:00', '12:30:00', '17', '12', '2023-11-21 11:03:05', '2023-11-21 11:11:54');
INSERT INTO `exam_timetables` VALUES ('17', '9', '51', '100', '35', '2023-11-03', '10:30:00', '12:30:00', '17', '12', '2023-11-21 11:03:05', '2023-11-21 11:11:54');
INSERT INTO `exam_timetables` VALUES ('18', '9', '47', '100', '35', '2023-11-04', '10:30:00', '12:30:00', '17', '12', '2023-11-21 11:03:05', '2023-11-21 11:11:54');
INSERT INTO `exam_timetables` VALUES ('19', '9', '49', '100', '35', '2023-11-06', '10:30:00', '12:30:00', '17', '12', '2023-11-21 11:03:05', '2023-11-21 11:31:06');
INSERT INTO `exam_timetables` VALUES ('20', '9', '50', '100', '35', '2023-11-07', '10:30:00', '12:30:00', '17', '12', '2023-11-21 11:03:05', '2023-11-21 11:31:06');
INSERT INTO `exam_timetables` VALUES ('21', '9', '52', '100', '35', '2023-11-08', '10:30:00', '12:30:00', '17', '12', '2023-11-21 11:03:05', '2023-11-21 11:31:06');
INSERT INTO `exam_timetables` VALUES ('22', '9', '53', '100', '35', '2023-11-09', '10:30:00', '23:30:00', '17', '12', '2023-11-21 11:03:05', '2023-11-21 11:31:06');
INSERT INTO `exam_timetables` VALUES ('23', '9', '54', '100', '35', '2023-11-10', '11:30:00', '17:30:00', '17', '12', '2023-11-21 11:03:05', '2023-11-21 11:31:06');
INSERT INTO `exam_timetables` VALUES ('24', '12', '73', '100', '35', '2023-11-22', '10:30:00', '12:30:00', '17', '12', '2023-11-21 11:58:55', '2023-11-21 11:58:55');
INSERT INTO `exam_timetables` VALUES ('25', '12', '75', '100', '35', '2023-11-23', '10:30:00', '12:30:00', '17', '12', '2023-11-21 11:58:55', '2023-11-21 11:58:55');
INSERT INTO `exam_timetables` VALUES ('26', '11', '64', '100', '35', '2023-11-20', '10:30:00', '12:30:00', '17', '12', '2023-11-21 12:04:17', '2023-11-21 12:04:45');
INSERT INTO `exam_timetables` VALUES ('27', '11', '66', '100', '35', '2023-11-23', '10:30:00', '12:30:00', '17', '12', '2023-11-21 12:04:17', '2023-11-21 12:04:17');
INSERT INTO `exam_timetables` VALUES ('28', '14', '46', '100', '35', '2023-12-20', '08:00:00', '10:00:00', '17', '12', '2023-11-23 07:08:18', '2023-11-23 07:08:43');
INSERT INTO `exam_timetables` VALUES ('29', '19', '48', '100', '35', '2023-11-25', '08:00:00', '10:00:00', '17', '12', '2023-11-23 07:09:21', '2023-11-23 07:09:39');
INSERT INTO `exam_timetables` VALUES ('30', '25', '91', '100', '33', '2024-07-01', '10:00:00', '13:00:00', '17', '12', '2024-07-17 15:04:55', '2024-07-17 15:04:55');
INSERT INTO `exam_timetables` VALUES ('31', '25', '92', '100', '33', '2024-07-02', '10:00:00', '13:00:00', '17', '12', '2024-07-17 15:04:55', '2024-07-17 15:04:55');
INSERT INTO `exam_timetables` VALUES ('32', '25', '95', '100', '33', '2024-07-03', '10:00:00', '13:00:00', '17', '12', '2024-07-17 15:04:55', '2024-07-17 15:04:55');
INSERT INTO `exam_timetables` VALUES ('33', '25', '94', '100', '33', '2024-07-04', '10:00:00', '13:00:00', '17', '12', '2024-07-17 15:04:55', '2024-07-17 15:04:55');

CREATE TABLE IF NOT EXISTS `exams` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(128) NOT NULL,
  `description` varchar(1024) DEFAULT NULL,
  `class_id` bigint(20) unsigned NOT NULL,
  `session_year_id` bigint(20) unsigned NOT NULL,
  `start_date` date DEFAULT NULL,
  `end_date` date DEFAULT NULL,
  `last_result_submission_date` date DEFAULT NULL,
  `publish` tinyint(4) NOT NULL DEFAULT 0,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `exams_school_id_foreign` (`school_id`),
  KEY `exams_class_id_foreign` (`class_id`),
  KEY `exams_session_year_id_foreign` (`session_year_id`),
  CONSTRAINT `exams_class_id_foreign` FOREIGN KEY (`class_id`) REFERENCES `classes` (`id`) ON DELETE CASCADE,
  CONSTRAINT `exams_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `exams_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=26 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `exams` VALUES ('9', 'Mid Year Exam 2023', 'Students in primary and secondary school will no longer have to sit for mid-year examinations from 2023.', '13', '17', '2023-11-01', '2023-11-10', NULL, '1', '12', '2023-11-21 10:36:18', '2023-11-21 11:56:10', NULL);
INSERT INTO `exams` VALUES ('10', 'Mid Year Exam 2023', 'Students in primary and secondary school will no longer have to sit for mid-year examinations from 2023.', '14', '17', '2023-11-21', '2023-11-21', NULL, '0', '12', '2023-11-21 10:36:18', '2023-11-21 10:59:35', NULL);
INSERT INTO `exams` VALUES ('11', 'Mid Year Exam 2023', 'Students in primary and secondary school will no longer have to sit for mid-year examinations from 2023.', '15', '17', '2023-11-20', '2023-11-23', NULL, '0', '12', '2023-11-21 10:36:18', '2023-11-21 12:04:45', NULL);
INSERT INTO `exams` VALUES ('12', 'Mid Year Exam 2023', 'Students in primary and secondary school will no longer have to sit for mid-year examinations from 2023.', '16', '17', '2023-11-22', '2023-11-23', NULL, '0', '12', '2023-11-21 10:36:18', '2023-11-21 11:58:55', NULL);
INSERT INTO `exams` VALUES ('13', 'Mid Year Exam 2023', 'Students in primary and secondary school will no longer have to sit for mid-year examinations from 2023.', '17', '17', '2023-12-21', '2023-12-30', NULL, '0', '12', '2023-11-21 10:36:18', '2023-11-21 10:45:17', NULL);
INSERT INTO `exams` VALUES ('14', 'Preliminary Examination', 'A Preliminary Examination for classes 1 to 5 is an introductory assessment to gauge students', '13', '17', '2023-12-20', '2023-12-20', NULL, '0', '12', '2023-11-23 07:03:21', '2023-11-23 07:08:43', NULL);
INSERT INTO `exams` VALUES ('19', 'Term-end Examination', 'Term-end Examination will be start from 5th December', '13', '17', '2023-11-25', '2023-11-25', NULL, '0', '12', '2023-11-23 07:04:04', '2023-11-23 07:09:39', NULL);
INSERT INTO `exams` VALUES ('24', 'Mid-Term Examination', 'Mid-Term Examination is going to starting soon', '13', '17', NULL, NULL, NULL, '0', '12', '2023-11-23 07:04:54', '2023-11-23 07:04:54', NULL);
INSERT INTO `exams` VALUES ('25', 'Mid Term - 1', NULL, '18', '17', '2024-07-01', '2024-07-04', NULL, '1', '12', '2024-07-17 15:03:44', '2024-07-17 15:10:07', NULL);

CREATE TABLE IF NOT EXISTS `expense_categories` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(191) NOT NULL,
  `description` varchar(191) DEFAULT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `expense_categories_school_id_foreign` (`school_id`),
  CONSTRAINT `expense_categories_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=10 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `expense_categories` VALUES ('4', 'Facility Expenses', 'Facilities like Building Maintenance, Utilities (Electricity, Water, Gas), Repairs and Renovations', '12', '2023-11-23 07:47:39', '2023-11-23 07:47:39', NULL);
INSERT INTO `expense_categories` VALUES ('5', 'Educational Resources', 'Resources like Textbooks and Workbooks, Educational Software, Classroom Supplies etc', '12', '2023-11-23 07:48:29', '2023-11-23 07:48:29', NULL);
INSERT INTO `expense_categories` VALUES ('6', 'Technology Expenses', 'Like Computers and Laptops, Software Licenses, Audio-Visual Equipment', '12', '2023-11-23 07:49:02', '2023-11-23 07:49:02', NULL);
INSERT INTO `expense_categories` VALUES ('7', 'Transportation Expenses', 'Like School Bus Maintenance, Fuel Costs, Driver Salaries', '12', '2023-11-23 07:49:53', '2023-11-23 07:49:53', NULL);
INSERT INTO `expense_categories` VALUES ('8', 'Professional Development', 'Teacher Training Programs, Workshops and Seminars, Educational Conferences', '12', '2023-11-23 07:50:16', '2023-11-23 07:50:16', NULL);
INSERT INTO `expense_categories` VALUES ('9', 'Personnel Expenses', 'Monthly salaries for teaching and administrative staff.', '12', '2023-11-23 09:18:08', '2023-11-23 09:18:08', NULL);

CREATE TABLE IF NOT EXISTS `expenses` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `category_id` bigint(20) unsigned DEFAULT NULL,
  `ref_no` varchar(191) DEFAULT NULL,
  `staff_id` bigint(20) unsigned DEFAULT NULL,
  `basic_salary` bigint(20) NOT NULL DEFAULT 0,
  `paid_leaves` double(8,2) NOT NULL DEFAULT 0.00,
  `month` bigint(20) DEFAULT NULL,
  `year` int(11) DEFAULT NULL,
  `title` varchar(512) NOT NULL,
  `description` varchar(191) DEFAULT NULL,
  `amount` double(64,2) NOT NULL,
  `date` date NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `session_year_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `salary_unique_records` (`staff_id`,`month`,`year`),
  KEY `expenses_school_id_foreign` (`school_id`),
  KEY `expenses_category_id_foreign` (`category_id`),
  KEY `expenses_session_year_id_foreign` (`session_year_id`),
  CONSTRAINT `expenses_category_id_foreign` FOREIGN KEY (`category_id`) REFERENCES `expense_categories` (`id`) ON DELETE CASCADE,
  CONSTRAINT `expenses_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `expenses_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE,
  CONSTRAINT `expenses_staff_id_foreign` FOREIGN KEY (`staff_id`) REFERENCES `staffs` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=127 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `expenses` VALUES ('13', '4', 'EXP-002', NULL, '0', '0', NULL, NULL, 'Building Maintenance', 'Building maintenance and utilities for the month.', '1200', '2023-11-01', '12', '17', '2023-11-23 07:55:13', '2023-11-23 07:55:13');
INSERT INTO `expenses` VALUES ('14', '4', 'EXP-010', NULL, '0', '0', NULL, NULL, 'Utilities (Electricity, Water, Gas)', 'Building maintenance and utilities for the month.', '1600', '2023-11-10', '12', '17', '2023-11-23 07:55:50', '2023-11-23 07:55:50');
INSERT INTO `expenses` VALUES ('15', '6', 'EXP-004', NULL, '0', '0', NULL, NULL, 'Computers and Laptop', 'Acquisition of new computers and software licenses.', '2500', '2023-10-10', '12', '17', '2023-11-23 09:14:33', '2023-11-23 09:14:33');
INSERT INTO `expenses` VALUES ('16', '6', 'EXP-001', NULL, '0', '0', NULL, NULL, 'Software Licenses:', 'Acquisition of new computers and software licenses.', '1200', '2023-09-20', '12', '17', '2023-11-23 09:15:26', '2023-11-23 09:15:26');
INSERT INTO `expenses` VALUES ('17', '8', 'EXP-005', NULL, '0', '0', NULL, NULL, 'Administrative Costs', 'Monthly office supplies and printing costs.', '1500', '2023-09-30', '12', '17', '2023-11-23 09:16:16', '2023-11-23 09:16:16');
INSERT INTO `expenses` VALUES ('19', '9', 'EXP-020', NULL, '0', '0', NULL, NULL, 'Teacher\'s Salary', 'Monthly salaries for teaching and administrative staff.', '3000', '2023-11-01', '12', '17', '2023-11-23 09:18:44', '2023-11-23 09:18:44');
INSERT INTO `expenses` VALUES ('20', '9', 'EXP-021', NULL, '0', '0', NULL, NULL, 'Administrative Staff\'s Salary', 'Monthly salaries for administrative staff.', '1000', '2023-11-01', '12', '17', '2023-11-23 09:20:27', '2023-11-23 09:20:27');
INSERT INTO `expenses` VALUES ('21', '9', 'EXP-022', NULL, '0', '0', NULL, NULL, 'Support Staff\'s Salary', 'Support Staff', '500', '2023-11-01', '12', '17', '2023-11-23 09:21:09', '2023-11-23 09:21:09');
INSERT INTO `expenses` VALUES ('22', NULL, NULL, '19', '0', '1.5', '1', '2023', 'January - 2023', 'Salary', '75000', '2023-01-31', '12', '17', '2023-11-23 09:33:10', '2023-11-23 09:33:10');
INSERT INTO `expenses` VALUES ('23', NULL, NULL, '18', '0', '1.5', '1', '2023', 'January - 2023', 'Salary', '70000', '2023-01-31', '12', '17', '2023-11-23 09:33:10', '2023-11-23 09:33:10');
INSERT INTO `expenses` VALUES ('24', NULL, NULL, '17', '0', '1.5', '1', '2023', 'January - 2023', 'Salary', '65000', '2023-01-31', '12', '17', '2023-11-23 09:33:10', '2023-11-23 09:33:10');
INSERT INTO `expenses` VALUES ('25', NULL, NULL, '16', '0', '1.5', '1', '2023', 'January - 2023', 'Salary', '60000', '2023-01-31', '12', '17', '2023-11-23 09:33:10', '2023-11-23 09:33:10');
INSERT INTO `expenses` VALUES ('26', NULL, NULL, '15', '0', '1.5', '1', '2023', 'January - 2023', 'Salary', '55000', '2023-01-31', '12', '17', '2023-11-23 09:33:10', '2023-11-23 09:33:10');
INSERT INTO `expenses` VALUES ('27', NULL, NULL, '14', '0', '1.5', '1', '2023', 'January - 2023', 'Salary', '70000', '2023-01-31', '12', '17', '2023-11-23 09:33:10', '2023-11-23 09:33:10');
INSERT INTO `expenses` VALUES ('28', NULL, NULL, '13', '0', '1.5', '1', '2023', 'January - 2023', 'Salary', '65000', '2023-01-31', '12', '17', '2023-11-23 09:33:10', '2023-11-23 09:33:10');
INSERT INTO `expenses` VALUES ('29', NULL, NULL, '12', '0', '1.5', '1', '2023', 'January - 2023', 'Salary', '55000', '2023-01-31', '12', '17', '2023-11-23 09:33:10', '2023-11-23 09:33:10');
INSERT INTO `expenses` VALUES ('30', NULL, NULL, '19', '0', '1.5', '2', '2023', 'February - 2023', 'Salary', '75000', '2023-02-02', '12', '17', '2023-11-23 09:33:35', '2023-11-23 09:33:35');
INSERT INTO `expenses` VALUES ('31', NULL, NULL, '18', '0', '1.5', '2', '2023', 'February - 2023', 'Salary', '70000', '2023-02-02', '12', '17', '2023-11-23 09:33:35', '2023-11-23 09:33:35');
INSERT INTO `expenses` VALUES ('32', NULL, NULL, '17', '0', '1.5', '2', '2023', 'February - 2023', 'Salary', '65000', '2023-02-02', '12', '17', '2023-11-23 09:33:35', '2023-11-23 09:33:35');
INSERT INTO `expenses` VALUES ('33', NULL, NULL, '16', '0', '1.5', '2', '2023', 'February - 2023', 'Salary', '60000', '2023-02-02', '12', '17', '2023-11-23 09:33:35', '2023-11-23 09:33:35');
INSERT INTO `expenses` VALUES ('34', NULL, NULL, '15', '0', '1.5', '2', '2023', 'February - 2023', 'Salary', '55000', '2023-02-02', '12', '17', '2023-11-23 09:33:35', '2023-11-23 09:33:35');
INSERT INTO `expenses` VALUES ('35', NULL, NULL, '14', '0', '1.5', '2', '2023', 'February - 2023', 'Salary', '70000', '2023-02-02', '12', '17', '2023-11-23 09:33:35', '2023-11-23 09:33:35');
INSERT INTO `expenses` VALUES ('36', NULL, NULL, '13', '0', '1.5', '2', '2023', 'February - 2023', 'Salary', '65000', '2023-02-02', '12', '17', '2023-11-23 09:33:35', '2023-11-23 09:33:35');
INSERT INTO `expenses` VALUES ('37', NULL, NULL, '12', '0', '1.5', '2', '2023', 'February - 2023', 'Salary', '55000', '2023-02-02', '12', '17', '2023-11-23 09:33:35', '2023-11-23 09:33:35');
INSERT INTO `expenses` VALUES ('38', NULL, NULL, '19', '0', '1.5', '3', '2023', 'March - 2023', 'Salary', '75000', '2023-03-02', '12', '17', '2023-11-23 09:33:46', '2023-11-23 09:33:46');
INSERT INTO `expenses` VALUES ('39', NULL, NULL, '18', '0', '1.5', '3', '2023', 'March - 2023', 'Salary', '70000', '2023-03-02', '12', '17', '2023-11-23 09:33:46', '2023-11-23 09:33:46');
INSERT INTO `expenses` VALUES ('40', NULL, NULL, '17', '0', '1.5', '3', '2023', 'March - 2023', 'Salary', '65000', '2023-03-02', '12', '17', '2023-11-23 09:33:46', '2023-11-23 09:33:46');
INSERT INTO `expenses` VALUES ('41', NULL, NULL, '16', '0', '1.5', '3', '2023', 'March - 2023', 'Salary', '60000', '2023-03-02', '12', '17', '2023-11-23 09:33:46', '2023-11-23 09:33:46');
INSERT INTO `expenses` VALUES ('42', NULL, NULL, '15', '0', '1.5', '3', '2023', 'March - 2023', 'Salary', '55000', '2023-03-02', '12', '17', '2023-11-23 09:33:46', '2023-11-23 09:33:46');
INSERT INTO `expenses` VALUES ('43', NULL, NULL, '14', '0', '1.5', '3', '2023', 'March - 2023', 'Salary', '70000', '2023-03-02', '12', '17', '2023-11-23 09:33:46', '2023-11-23 09:33:46');
INSERT INTO `expenses` VALUES ('44', NULL, NULL, '13', '0', '1.5', '3', '2023', 'March - 2023', 'Salary', '65000', '2023-03-02', '12', '17', '2023-11-23 09:33:46', '2023-11-23 09:33:46');
INSERT INTO `expenses` VALUES ('45', NULL, NULL, '12', '0', '1.5', '3', '2023', 'March - 2023', 'Salary', '55000', '2023-03-02', '12', '17', '2023-11-23 09:33:46', '2023-11-23 09:33:46');
INSERT INTO `expenses` VALUES ('46', NULL, NULL, '19', '0', '1.5', '4', '2023', 'April - 2023', 'Salary', '75000', '2023-04-03', '12', '17', '2023-11-23 09:34:00', '2023-11-23 09:34:00');
INSERT INTO `expenses` VALUES ('47', NULL, NULL, '18', '0', '1.5', '4', '2023', 'April - 2023', 'Salary', '70000', '2023-04-03', '12', '17', '2023-11-23 09:34:00', '2023-11-23 09:34:00');
INSERT INTO `expenses` VALUES ('48', NULL, NULL, '17', '0', '1.5', '4', '2023', 'April - 2023', 'Salary', '65000', '2023-04-03', '12', '17', '2023-11-23 09:34:00', '2023-11-23 09:34:00');
INSERT INTO `expenses` VALUES ('49', NULL, NULL, '16', '0', '1.5', '4', '2023', 'April - 2023', 'Salary', '60000', '2023-04-03', '12', '17', '2023-11-23 09:34:00', '2023-11-23 09:34:00');
INSERT INTO `expenses` VALUES ('50', NULL, NULL, '15', '0', '1.5', '4', '2023', 'April - 2023', 'Salary', '55000', '2023-04-03', '12', '17', '2023-11-23 09:34:00', '2023-11-23 09:34:00');
INSERT INTO `expenses` VALUES ('51', NULL, NULL, '14', '0', '1.5', '4', '2023', 'April - 2023', 'Salary', '70000', '2023-04-03', '12', '17', '2023-11-23 09:34:00', '2023-11-23 09:34:00');
INSERT INTO `expenses` VALUES ('52', NULL, NULL, '13', '0', '1.5', '4', '2023', 'April - 2023', 'Salary', '65000', '2023-04-03', '12', '17', '2023-11-23 09:34:00', '2023-11-23 09:34:00');
INSERT INTO `expenses` VALUES ('53', NULL, NULL, '12', '0', '1.5', '4', '2023', 'April - 2023', 'Salary', '55000', '2023-04-03', '12', '17', '2023-11-23 09:34:00', '2023-11-23 09:34:00');
INSERT INTO `expenses` VALUES ('54', NULL, NULL, '19', '0', '1.5', '5', '2023', 'May - 2023', 'Salary', '75000', '2023-05-02', '12', '17', '2023-11-23 09:34:29', '2023-11-23 09:34:29');
INSERT INTO `expenses` VALUES ('55', NULL, NULL, '18', '0', '1.5', '5', '2023', 'May - 2023', 'Salary', '70000', '2023-05-02', '12', '17', '2023-11-23 09:34:29', '2023-11-23 09:34:29');
INSERT INTO `expenses` VALUES ('56', NULL, NULL, '17', '0', '1.5', '5', '2023', 'May - 2023', 'Salary', '65000', '2023-05-02', '12', '17', '2023-11-23 09:34:29', '2023-11-23 09:34:29');
INSERT INTO `expenses` VALUES ('57', NULL, NULL, '16', '0', '1.5', '5', '2023', 'May - 2023', 'Salary', '60000', '2023-05-02', '12', '17', '2023-11-23 09:34:29', '2023-11-23 09:34:29');
INSERT INTO `expenses` VALUES ('58', NULL, NULL, '15', '0', '1.5', '5', '2023', 'May - 2023', 'Salary', '55000', '2023-05-02', '12', '17', '2023-11-23 09:34:29', '2023-11-23 09:34:29');
INSERT INTO `expenses` VALUES ('59', NULL, NULL, '14', '0', '1.5', '5', '2023', 'May - 2023', 'Salary', '70000', '2023-05-02', '12', '17', '2023-11-23 09:34:29', '2023-11-23 09:34:29');
INSERT INTO `expenses` VALUES ('60', NULL, NULL, '13', '0', '1.5', '5', '2023', 'May - 2023', 'Salary', '65000', '2023-05-02', '12', '17', '2023-11-23 09:34:29', '2023-11-23 09:34:29');
INSERT INTO `expenses` VALUES ('61', NULL, NULL, '12', '0', '1.5', '5', '2023', 'May - 2023', 'Salary', '55000', '2023-05-02', '12', '17', '2023-11-23 09:34:29', '2023-11-23 09:34:29');
INSERT INTO `expenses` VALUES ('62', NULL, NULL, '19', '0', '1.5', '6', '2023', 'June - 2023', 'Salary', '75000', '2023-05-02', '12', '17', '2023-11-23 09:34:40', '2023-11-23 09:34:40');
INSERT INTO `expenses` VALUES ('63', NULL, NULL, '18', '0', '1.5', '6', '2023', 'June - 2023', 'Salary', '70000', '2023-05-02', '12', '17', '2023-11-23 09:34:40', '2023-11-23 09:34:40');
INSERT INTO `expenses` VALUES ('64', NULL, NULL, '17', '0', '1.5', '6', '2023', 'June - 2023', 'Salary', '65000', '2023-05-02', '12', '17', '2023-11-23 09:34:40', '2023-11-23 09:34:40');
INSERT INTO `expenses` VALUES ('65', NULL, NULL, '16', '0', '1.5', '6', '2023', 'June - 2023', 'Salary', '60000', '2023-05-02', '12', '17', '2023-11-23 09:34:40', '2023-11-23 09:34:40');
INSERT INTO `expenses` VALUES ('66', NULL, NULL, '15', '0', '1.5', '6', '2023', 'June - 2023', 'Salary', '55000', '2023-05-02', '12', '17', '2023-11-23 09:34:40', '2023-11-23 09:34:40');
INSERT INTO `expenses` VALUES ('67', NULL, NULL, '14', '0', '1.5', '6', '2023', 'June - 2023', 'Salary', '70000', '2023-05-02', '12', '17', '2023-11-23 09:34:40', '2023-11-23 09:34:40');
INSERT INTO `expenses` VALUES ('68', NULL, NULL, '13', '0', '1.5', '6', '2023', 'June - 2023', 'Salary', '65000', '2023-05-02', '12', '17', '2023-11-23 09:34:40', '2023-11-23 09:34:40');
INSERT INTO `expenses` VALUES ('69', NULL, NULL, '12', '0', '1.5', '6', '2023', 'June - 2023', 'Salary', '55000', '2023-05-02', '12', '17', '2023-11-23 09:34:40', '2023-11-23 09:34:40');
INSERT INTO `expenses` VALUES ('70', NULL, NULL, '19', '0', '1.5', '7', '2023', 'July - 2023', 'Salary', '75000', '2023-07-03', '12', '17', '2023-11-23 09:35:11', '2023-11-23 09:35:11');
INSERT INTO `expenses` VALUES ('71', NULL, NULL, '18', '0', '1.5', '7', '2023', 'July - 2023', 'Salary', '70000', '2023-07-03', '12', '17', '2023-11-23 09:35:11', '2023-11-23 09:35:11');
INSERT INTO `expenses` VALUES ('72', NULL, NULL, '17', '0', '1.5', '7', '2023', 'July - 2023', 'Salary', '65000', '2023-07-03', '12', '17', '2023-11-23 09:35:11', '2023-11-23 09:35:11');
INSERT INTO `expenses` VALUES ('73', NULL, NULL, '16', '0', '1.5', '7', '2023', 'July - 2023', 'Salary', '60000', '2023-07-03', '12', '17', '2023-11-23 09:35:11', '2023-11-23 09:35:11');
INSERT INTO `expenses` VALUES ('74', NULL, NULL, '15', '0', '1.5', '7', '2023', 'July - 2023', 'Salary', '55000', '2023-07-03', '12', '17', '2023-11-23 09:35:11', '2023-11-23 09:35:11');
INSERT INTO `expenses` VALUES ('75', NULL, NULL, '14', '0', '1.5', '7', '2023', 'July - 2023', 'Salary', '70000', '2023-07-03', '12', '17', '2023-11-23 09:35:11', '2023-11-23 09:35:11');
INSERT INTO `expenses` VALUES ('76', NULL, NULL, '13', '0', '1.5', '7', '2023', 'July - 2023', 'Salary', '65000', '2023-07-03', '12', '17', '2023-11-23 09:35:11', '2023-11-23 09:35:11');
INSERT INTO `expenses` VALUES ('77', NULL, NULL, '12', '0', '1.5', '7', '2023', 'July - 2023', 'Salary', '55000', '2023-07-03', '12', '17', '2023-11-23 09:35:11', '2023-11-23 09:35:11');
INSERT INTO `expenses` VALUES ('78', NULL, NULL, '19', '0', '1.5', '8', '2023', 'August - 2023', 'Salary', '75000', '2023-08-02', '12', '17', '2023-11-23 09:35:25', '2023-11-23 09:35:25');
INSERT INTO `expenses` VALUES ('79', NULL, NULL, '18', '0', '1.5', '8', '2023', 'August - 2023', 'Salary', '70000', '2023-08-02', '12', '17', '2023-11-23 09:35:25', '2023-11-23 09:35:25');
INSERT INTO `expenses` VALUES ('80', NULL, NULL, '17', '0', '1.5', '8', '2023', 'August - 2023', 'Salary', '65000', '2023-08-02', '12', '17', '2023-11-23 09:35:25', '2023-11-23 09:35:25');
INSERT INTO `expenses` VALUES ('81', NULL, NULL, '16', '0', '1.5', '8', '2023', 'August - 2023', 'Salary', '60000', '2023-08-02', '12', '17', '2023-11-23 09:35:25', '2023-11-23 09:35:25');
INSERT INTO `expenses` VALUES ('82', NULL, NULL, '15', '0', '1.5', '8', '2023', 'August - 2023', 'Salary', '55000', '2023-08-02', '12', '17', '2023-11-23 09:35:25', '2023-11-23 09:35:25');
INSERT INTO `expenses` VALUES ('83', NULL, NULL, '14', '0', '1.5', '8', '2023', 'August - 2023', 'Salary', '70000', '2023-08-02', '12', '17', '2023-11-23 09:35:25', '2023-11-23 09:35:25');
INSERT INTO `expenses` VALUES ('84', NULL, NULL, '13', '0', '1.5', '8', '2023', 'August - 2023', 'Salary', '65000', '2023-08-02', '12', '17', '2023-11-23 09:35:25', '2023-11-23 09:35:25');
INSERT INTO `expenses` VALUES ('85', NULL, NULL, '12', '0', '1.5', '8', '2023', 'August - 2023', 'Salary', '55000', '2023-08-02', '12', '17', '2023-11-23 09:35:25', '2023-11-23 09:35:25');
INSERT INTO `expenses` VALUES ('86', NULL, NULL, '19', '0', '1.5', '9', '2023', 'September - 2023', 'Salary', '75000', '2023-09-02', '12', '17', '2023-11-23 09:35:41', '2023-11-23 09:35:41');
INSERT INTO `expenses` VALUES ('87', NULL, NULL, '18', '0', '1.5', '9', '2023', 'September - 2023', 'Salary', '70000', '2023-09-02', '12', '17', '2023-11-23 09:35:41', '2023-11-23 09:35:41');
INSERT INTO `expenses` VALUES ('88', NULL, NULL, '17', '0', '1.5', '9', '2023', 'September - 2023', 'Salary', '65000', '2023-09-02', '12', '17', '2023-11-23 09:35:41', '2023-11-23 09:35:41');
INSERT INTO `expenses` VALUES ('89', NULL, NULL, '16', '0', '1.5', '9', '2023', 'September - 2023', 'Salary', '60000', '2023-09-02', '12', '17', '2023-11-23 09:35:41', '2023-11-23 09:35:41');
INSERT INTO `expenses` VALUES ('90', NULL, NULL, '15', '0', '1.5', '9', '2023', 'September - 2023', 'Salary', '55000', '2023-09-02', '12', '17', '2023-11-23 09:35:41', '2023-11-23 09:35:41');
INSERT INTO `expenses` VALUES ('91', NULL, NULL, '14', '0', '1.5', '9', '2023', 'September - 2023', 'Salary', '70000', '2023-09-02', '12', '17', '2023-11-23 09:35:41', '2023-11-23 09:35:41');
INSERT INTO `expenses` VALUES ('92', NULL, NULL, '13', '0', '1.5', '9', '2023', 'September - 2023', 'Salary', '65000', '2023-09-02', '12', '17', '2023-11-23 09:35:41', '2023-11-23 09:35:41');
INSERT INTO `expenses` VALUES ('93', NULL, NULL, '12', '0', '1.5', '9', '2023', 'September - 2023', 'Salary', '55000', '2023-09-02', '12', '17', '2023-11-23 09:35:41', '2023-11-23 09:35:41');
INSERT INTO `expenses` VALUES ('94', NULL, NULL, '19', '0', '1.5', '10', '2023', 'October - 2023', 'Salary', '75000', '2023-10-02', '12', '17', '2023-11-23 09:35:59', '2023-11-23 09:35:59');
INSERT INTO `expenses` VALUES ('95', NULL, NULL, '18', '0', '1.5', '10', '2023', 'October - 2023', 'Salary', '70000', '2023-10-02', '12', '17', '2023-11-23 09:35:59', '2023-11-23 09:35:59');
INSERT INTO `expenses` VALUES ('96', NULL, NULL, '17', '0', '1.5', '10', '2023', 'October - 2023', 'Salary', '65000', '2023-10-02', '12', '17', '2023-11-23 09:35:59', '2023-11-23 09:35:59');
INSERT INTO `expenses` VALUES ('97', NULL, NULL, '16', '0', '1.5', '10', '2023', 'October - 2023', 'Salary', '60000', '2023-10-02', '12', '17', '2023-11-23 09:35:59', '2023-11-23 09:35:59');
INSERT INTO `expenses` VALUES ('98', NULL, NULL, '15', '0', '1.5', '10', '2023', 'October - 2023', 'Salary', '55000', '2023-10-02', '12', '17', '2023-11-23 09:35:59', '2023-11-23 09:35:59');
INSERT INTO `expenses` VALUES ('99', NULL, NULL, '14', '0', '1.5', '10', '2023', 'October - 2023', 'Salary', '70000', '2023-10-02', '12', '17', '2023-11-23 09:35:59', '2023-11-23 09:35:59');
INSERT INTO `expenses` VALUES ('100', NULL, NULL, '13', '0', '1.5', '10', '2023', 'October - 2023', 'Salary', '65000', '2023-10-02', '12', '17', '2023-11-23 09:35:59', '2023-11-23 09:35:59');
INSERT INTO `expenses` VALUES ('101', NULL, NULL, '12', '0', '1.5', '10', '2023', 'October - 2023', 'Salary', '55000', '2023-10-02', '12', '17', '2023-11-23 09:35:59', '2023-11-23 09:35:59');
INSERT INTO `expenses` VALUES ('102', NULL, NULL, '19', '0', '1.5', '11', '2023', 'November - 2023', 'Salary', '75000', '2023-11-01', '12', '17', '2023-11-23 09:36:12', '2023-11-23 09:36:12');
INSERT INTO `expenses` VALUES ('103', NULL, NULL, '18', '0', '1.5', '11', '2023', 'November - 2023', 'Salary', '70000', '2023-11-01', '12', '17', '2023-11-23 09:36:12', '2023-11-23 09:36:12');
INSERT INTO `expenses` VALUES ('104', NULL, NULL, '17', '0', '1.5', '11', '2023', 'November - 2023', 'Salary', '65000', '2023-11-01', '12', '17', '2023-11-23 09:36:12', '2023-11-23 09:36:12');
INSERT INTO `expenses` VALUES ('105', NULL, NULL, '16', '0', '1.5', '11', '2023', 'November - 2023', 'Salary', '60000', '2023-11-01', '12', '17', '2023-11-23 09:36:12', '2023-11-23 09:36:12');
INSERT INTO `expenses` VALUES ('106', NULL, NULL, '15', '0', '1.5', '11', '2023', 'November - 2023', 'Salary', '55000', '2023-11-01', '12', '17', '2023-11-23 09:36:12', '2023-11-23 09:36:12');
INSERT INTO `expenses` VALUES ('107', NULL, NULL, '14', '0', '1.5', '11', '2023', 'November - 2023', 'Salary', '70000', '2023-11-01', '12', '17', '2023-11-23 09:36:12', '2023-11-23 09:36:12');
INSERT INTO `expenses` VALUES ('108', NULL, NULL, '13', '0', '1.5', '11', '2023', 'November - 2023', 'Salary', '65000', '2023-11-01', '12', '17', '2023-11-23 09:36:12', '2023-11-23 09:36:12');
INSERT INTO `expenses` VALUES ('109', NULL, NULL, '12', '0', '1.5', '11', '2023', 'November - 2023', 'Salary', '55000', '2023-11-01', '12', '17', '2023-11-23 09:36:12', '2023-11-23 09:36:12');
INSERT INTO `expenses` VALUES ('110', NULL, NULL, '19', '0', '1.5', '12', '2023', 'December - 2023', 'Salary', '75000', '2023-12-02', '12', '17', '2023-11-23 09:36:26', '2023-11-23 09:36:26');
INSERT INTO `expenses` VALUES ('111', NULL, NULL, '18', '0', '1.5', '12', '2023', 'December - 2023', 'Salary', '70000', '2023-12-02', '12', '17', '2023-11-23 09:36:26', '2023-11-23 09:36:26');
INSERT INTO `expenses` VALUES ('112', NULL, NULL, '17', '0', '1.5', '12', '2023', 'December - 2023', 'Salary', '65000', '2023-12-02', '12', '17', '2023-11-23 09:36:26', '2023-11-23 09:36:26');
INSERT INTO `expenses` VALUES ('113', NULL, NULL, '16', '0', '1.5', '12', '2023', 'December - 2023', 'Salary', '60000', '2023-12-02', '12', '17', '2023-11-23 09:36:26', '2023-11-23 09:36:26');
INSERT INTO `expenses` VALUES ('114', NULL, NULL, '15', '0', '1.5', '12', '2023', 'December - 2023', 'Salary', '55000', '2023-12-02', '12', '17', '2023-11-23 09:36:26', '2023-11-23 09:36:26');
INSERT INTO `expenses` VALUES ('115', NULL, NULL, '14', '0', '1.5', '12', '2023', 'December - 2023', 'Salary', '70000', '2023-12-02', '12', '17', '2023-11-23 09:36:26', '2023-11-23 09:36:26');
INSERT INTO `expenses` VALUES ('116', NULL, NULL, '13', '0', '1.5', '12', '2023', 'December - 2023', 'Salary', '65000', '2023-12-02', '12', '17', '2023-11-23 09:36:26', '2023-11-23 09:36:26');
INSERT INTO `expenses` VALUES ('117', NULL, NULL, '12', '0', '1.5', '12', '2023', 'December - 2023', 'Salary', '55000', '2023-12-02', '12', '17', '2023-11-23 09:36:26', '2023-11-23 09:36:26');
INSERT INTO `expenses` VALUES ('119', NULL, NULL, '19', '75000', '1.5', '5', '2024', 'May - 2024', 'Salary', '68500', '2024-05-31', '12', '17', '2024-09-06 12:05:50', '2024-09-06 12:05:50');
INSERT INTO `expenses` VALUES ('120', NULL, NULL, '26', '25000', '1.5', '5', '2024', 'May - 2024', 'Salary', '25000', '2024-05-31', '12', '17', '2024-09-06 12:05:50', '2024-09-06 12:05:50');
INSERT INTO `expenses` VALUES ('121', NULL, NULL, '18', '70000', '1.5', '5', '2024', 'May - 2024', 'Salary', '70000', '2024-05-31', '12', '17', '2024-09-06 12:05:50', '2024-09-06 12:05:50');
INSERT INTO `expenses` VALUES ('122', NULL, NULL, '26', '25000', '1.5', '6', '2024', 'June - 2024', 'Salary', '25000', '2024-06-30', '12', '17', '2024-09-06 12:06:02', '2024-09-06 12:06:02');
INSERT INTO `expenses` VALUES ('123', NULL, NULL, '19', '75000', '1.5', '6', '2024', 'June - 2024', 'Salary', '68500', '2024-06-30', '12', '17', '2024-09-06 12:06:02', '2024-09-06 12:06:02');
INSERT INTO `expenses` VALUES ('124', NULL, NULL, '18', '70000', '1.5', '6', '2024', 'June - 2024', 'Salary', '70000', '2024-06-30', '12', '17', '2024-09-06 12:06:02', '2024-09-06 12:06:02');
INSERT INTO `expenses` VALUES ('125', NULL, NULL, '16', '60000', '1.5', '6', '2024', 'June - 2024', 'Salary', '60000', '2024-06-30', '12', '17', '2024-09-06 12:06:02', '2024-09-06 12:06:02');
INSERT INTO `expenses` VALUES ('126', NULL, NULL, '12', '55000', '1.5', '10', '2024', 'October - 2024', 'Salary', '55000', '2024-10-31', '12', '17', '2024-10-14 19:57:59', '2024-10-14 19:57:59');

CREATE TABLE IF NOT EXISTS `extra_user_datas` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `user_id` bigint(20) unsigned NOT NULL COMMENT 'user_id',
  `form_field_id` bigint(20) unsigned NOT NULL,
  `data` text DEFAULT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `extra_user_datas_user_id_foreign` (`user_id`),
  KEY `extra_user_datas_form_field_id_foreign` (`form_field_id`),
  KEY `extra_user_datas_school_id_foreign` (`school_id`),
  CONSTRAINT `extra_user_datas_form_field_id_foreign` FOREIGN KEY (`form_field_id`) REFERENCES `form_fields` (`id`) ON DELETE CASCADE,
  CONSTRAINT `extra_user_datas_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `extra_user_datas_user_id_foreign` FOREIGN KEY (`user_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=2356 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `extra_user_datas` VALUES ('1', '331', '12', 'Class 1', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2', '331', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('3', '331', '14', 'demo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('4', '331', '15', 'Downtown, Toronto, Onterio, CA', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('5', '331', '16', '8200727077', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('6', '333', '12', 'Class 2', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('7', '333', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('8', '333', '14', 'demo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('9', '333', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, '2023-11-21 06:02:26', NULL);
INSERT INTO `extra_user_datas` VALUES ('10', '333', '16', '8200727077', '12', NULL, '2023-11-21 05:28:30', NULL);
INSERT INTO `extra_user_datas` VALUES ('11', '334', '12', 'Class 2', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('12', '334', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('13', '334', '14', 'demo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('14', '334', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, '2023-11-21 05:29:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('15', '334', '16', '8200727077', '12', NULL, '2023-11-21 05:29:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('16', '335', '12', 'Class 2', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('17', '335', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('18', '335', '14', 'demo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('19', '335', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, '2023-11-21 05:31:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('20', '335', '16', '8200727077', '12', NULL, '2023-11-21 05:31:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('21', '336', '12', 'Class 2', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('22', '336', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('23', '336', '14', 'demo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('24', '336', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, '2023-11-21 05:45:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('25', '336', '16', '8200727077', '12', NULL, '2023-11-21 05:45:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('26', '337', '12', 'Class 2', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('27', '337', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('28', '337', '14', 'demo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('29', '337', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, '2023-11-21 05:46:15', NULL);
INSERT INTO `extra_user_datas` VALUES ('30', '337', '16', '8200727077', '12', NULL, '2023-11-21 05:46:15', NULL);
INSERT INTO `extra_user_datas` VALUES ('46', '341', '12', 'Class 2', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('47', '341', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('48', '341', '14', 'demo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('49', '341', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, '2023-11-21 05:47:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('50', '341', '16', '8200727077', '12', NULL, '2023-11-21 05:47:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('101', '349', '12', 'Nicole', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('102', '349', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('103', '349', '14', 'Cunha', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('104', '349', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('105', '349', '16', '4178583056', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('106', '351', '12', 'Andre', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('107', '351', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('108', '351', '14', 'Melo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('109', '351', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('110', '351', '16', '7045171377', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('111', '353', '12', 'Rebeca', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('112', '353', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('113', '353', '14', 'Ribeiro', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('114', '353', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('115', '353', '16', '5204182405', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('116', '355', '12', 'Sarah', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('117', '355', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('118', '355', '14', 'Alves', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('119', '355', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('120', '355', '16', '3147492781', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('121', '357', '12', 'Antonio', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('122', '357', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('123', '357', '14', 'Cunha', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('124', '357', '15', '1593 Briarwood Road', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('125', '357', '16', '5032027980', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('126', '359', '12', 'Clara', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('127', '359', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('128', '359', '14', 'Cunha', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('129', '359', '15', '1180 Concord Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('130', '359', '16', '2603075096', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('131', '361', '12', 'Bruna', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('132', '361', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('133', '361', '14', 'Sousa', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('134', '361', '15', '2573 Parkway Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('135', '361', '16', '6306764116', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('136', '363', '12', 'Kaue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('137', '363', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('138', '363', '14', 'Oliveira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('139', '363', '15', '3072 Hawks Nest Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('140', '363', '16', '8014761619', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('141', '365', '12', 'Caio', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('142', '365', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('143', '365', '14', 'Silva', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('144', '365', '15', '1417 Karen Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('145', '365', '16', '4178831795', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('146', '367', '12', 'Murilo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('147', '367', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('148', '367', '14', 'Cunha', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('149', '367', '15', '4625 Cessna Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('150', '367', '16', '9036367481', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('151', '369', '12', 'Fernanda', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('152', '369', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('153', '369', '14', 'Cardoso', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('154', '369', '15', '3809 Steele Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('155', '369', '16', '7575774415', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('156', '371', '12', 'Vinicius', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('157', '371', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('158', '371', '14', 'Azevedo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('159', '371', '15', '3099 White River Way', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('160', '371', '16', '4846710133', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('161', '373', '12', 'Rebeca', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('162', '373', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('163', '373', '14', 'Oliveira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('164', '373', '15', '15 Briarwood Road', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('165', '373', '16', '7016524974', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('166', '375', '12', 'Julieta', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('167', '375', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('168', '375', '14', 'Dias', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('169', '375', '15', '3513 Thrash Trail', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('170', '375', '16', '5085312029', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('171', '377', '12', 'Matheus', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('172', '377', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('173', '377', '14', 'Araujo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('174', '377', '15', '2878 Allison Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('175', '377', '16', '6262029477', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('176', '379', '12', 'Nicolash', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('177', '379', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('178', '379', '14', 'Castro', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('179', '379', '15', '1403 Bastin Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('180', '379', '16', '2607053999', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('181', '381', '12', 'Rafael', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('182', '381', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('183', '381', '14', 'Alves', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('184', '381', '15', '306 Hidden Meadow Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('185', '381', '16', '3143746446', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('186', '383', '12', 'Guilherme', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('187', '383', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('188', '383', '14', 'Ferreira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('189', '383', '15', '3472 Kovar Road', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('190', '383', '16', '5164232320', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('191', '385', '12', 'Kauan', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('192', '385', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('193', '385', '14', 'Santos', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('194', '385', '15', '3395 Rainbow Road', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('195', '385', '16', '4345823055', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('196', '387', '12', 'Julian', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('197', '387', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('198', '387', '14', 'Cavalcanti', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('199', '387', '15', '4054 Pearcy Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('200', '387', '16', '3042080094', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('201', '389', '12', 'Caua', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('202', '389', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('203', '389', '14', 'Pereira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('204', '389', '15', '676 Bruce Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('205', '389', '16', '3373045081', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('206', '391', '12', 'Thais', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('207', '391', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('208', '391', '14', 'Ferreira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('209', '391', '15', '3016 Gnatty Creek Road', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('210', '391', '16', '4066814745', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('211', '393', '12', 'Thais', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('212', '393', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('213', '393', '14', 'Pereira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('214', '393', '15', '4337 Queens Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('215', '393', '16', '3105664753', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('216', '395', '12', 'Tomas', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('217', '395', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('218', '395', '14', 'Goncalves', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('219', '395', '15', '1818 Tavern Place', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('220', '395', '16', '8026104060', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('221', '397', '12', 'Andre', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('222', '397', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('223', '397', '14', 'Fernandes', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('224', '397', '15', '3292 Willow Oaks Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('225', '397', '16', '8636091242', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('226', '399', '12', 'Felipe', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('227', '399', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('228', '399', '14', 'Ferreira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('229', '399', '15', '1294 Tibbs Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('230', '399', '16', '9529383180', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('231', '401', '12', 'Gustavo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('232', '401', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('233', '401', '14', 'Barbosa', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('234', '401', '15', '3393 Sumner Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('235', '401', '16', '6064639117', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('236', '403', '12', 'Nicolash', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('237', '403', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('238', '403', '14', 'Lima', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('239', '403', '15', '2446 Selah Way', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('240', '403', '16', '4143587297', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('241', '405', '12', 'Diego', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('242', '405', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('243', '405', '14', 'Cunha', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('244', '405', '15', '3881 Oakdale Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('245', '405', '16', '7655523753', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('246', '407', '12', 'Vitoria', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('247', '407', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('248', '407', '14', 'Azevedo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('249', '407', '15', '4127 Sycamore Fork Road', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('250', '407', '16', '6828418219', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('251', '409', '12', 'Mateus', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('252', '409', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('253', '409', '14', 'Ferreira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('254', '409', '15', '1520 Meadowcrest Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('255', '409', '16', '2195106037', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('256', '411', '12', 'Enzo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('257', '411', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('258', '411', '14', 'Souza', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('259', '411', '15', '4393 Johnny Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('260', '411', '16', '3602604974', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('261', '413', '12', 'Tania', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('262', '413', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('263', '413', '14', 'Santos', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('264', '413', '15', '385 Capitol Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('265', '413', '16', '2025581693', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('266', '415', '12', 'Nicolas', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('267', '415', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('268', '415', '14', 'Ribeiro', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('269', '415', '15', '2649 Sycamore Circle', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('270', '415', '16', '4435480016', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('271', '417', '12', 'Rebeca', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('272', '417', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('273', '417', '14', 'Lima', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('274', '417', '15', '1289 Parrill Court', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('275', '417', '16', '4015592403', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('276', '419', '12', 'Kauan', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('277', '419', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('278', '419', '14', 'Araujo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('279', '419', '15', '965 Chardonnay Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('280', '419', '16', '2024064718', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('281', '421', '12', 'Mateus', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('282', '421', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('283', '421', '14', 'Silva', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('284', '421', '15', '2734 Goldcliff Circle', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('285', '421', '16', '9737494754', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('286', '423', '12', 'Miguel', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('287', '423', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('288', '423', '14', 'Martins', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('289', '423', '15', '1143 Harron Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('290', '423', '16', '9102660503', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('291', '425', '12', 'Thiago', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('292', '425', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('293', '425', '14', 'Goncalves', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('294', '425', '15', '4627 Myra Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('295', '425', '16', '8162295022', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('296', '427', '12', 'Sophia', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('297', '427', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('298', '427', '14', 'Costa', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('299', '427', '15', '244 Rhode Island Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('300', '427', '16', '9177417125', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('301', '429', '12', 'Diogo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('302', '429', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('303', '429', '14', 'Lima', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('304', '429', '15', '2088 Spring Haven Trail', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('305', '429', '16', '6788045554', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('306', '431', '12', 'Laura', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('307', '431', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('308', '431', '14', 'Correia', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('309', '431', '15', '4582 Ray Court', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('310', '431', '16', '9895294996', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('311', '433', '12', 'Davi', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('312', '433', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('313', '433', '14', 'Pereira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('314', '433', '15', '2987 Nutter Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('315', '433', '16', '5635743818', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('316', '435', '12', 'Joao', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('317', '435', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('318', '435', '14', 'Castro', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('319', '435', '15', '4828 Settlers Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('320', '435', '16', '2519315347', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('321', '437', '12', 'Kaua', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('322', '437', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('323', '437', '14', 'Almeida', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('324', '437', '15', '1557 Edington Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('325', '437', '16', '6822925498', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('326', '439', '12', 'Erick', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('327', '439', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('328', '439', '14', 'Pinto', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('329', '439', '15', '3888 Robinson Court', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('330', '439', '16', '3038648510', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('331', '441', '12', 'Fabio', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('332', '441', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('333', '441', '14', 'Ribeiro', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('334', '441', '15', '1434 Summit Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('335', '441', '16', '2484899844', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('336', '443', '12', 'Daniel', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('337', '443', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('338', '443', '14', 'Correia', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('339', '443', '15', '1267 Joyce Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('340', '443', '16', '2709653680', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('341', '445', '12', 'Thiago', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('342', '445', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('343', '445', '14', 'Oliveira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('344', '445', '15', '2036 Sycamore Circle', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('345', '445', '16', '4044010282', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('346', '447', '12', 'Carlos', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('347', '447', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('348', '447', '14', 'Azevedo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('349', '447', '15', '2682 Roy Alley', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('350', '447', '16', '2482987687', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('351', '449', '12', 'Matheus', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('352', '449', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('353', '449', '14', 'Cunha', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('354', '449', '15', '2061 Bartlett Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('355', '449', '16', '2259321328', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('356', '451', '12', 'Samuel', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('357', '451', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('358', '451', '14', 'Gomes', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('359', '451', '15', '1806 Shady Pines Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('360', '451', '16', '9015346120', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('361', '453', '12', 'Jose', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('362', '453', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('363', '453', '14', 'Melo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('364', '453', '15', '2450 College Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('365', '453', '16', '9122675548', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('366', '455', '12', 'Vitor', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('367', '455', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('368', '455', '14', 'Pereira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('369', '455', '15', '581 Tennessee Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('370', '455', '16', '3145445393', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('371', '457', '12', 'Lucas', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('372', '457', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('373', '457', '14', 'Santos', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('374', '457', '15', '4969 Coventry Court', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('375', '457', '16', '5739458203', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('376', '459', '12', 'Nicolash', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('377', '459', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('378', '459', '14', 'Rodrigues', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('379', '459', '15', '2820 Lightning Point Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('380', '459', '16', '8437651527', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('381', '461', '12', 'Matheus', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('382', '461', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('383', '461', '14', 'Castro', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('384', '461', '15', '2551 Austin Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('385', '461', '16', '7063277435', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('386', '463', '12', 'Rafael', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('387', '463', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('388', '463', '14', 'Rodrigues', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('389', '463', '15', '2959 Blane Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('390', '463', '16', '7084632716', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('391', '465', '12', 'Vinicius', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('392', '465', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('393', '465', '14', 'Barbosa', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('394', '465', '15', '3683 Sharon Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('395', '465', '16', '6034859842', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('396', '467', '12', 'Vitor', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('397', '467', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('398', '467', '14', 'Sousa', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('399', '467', '15', '3086 Broadway Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('400', '467', '16', '2016102973', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('401', '333', '12', 'Class 2', '12', '2023-11-21 05:28:30', '2023-11-21 05:28:30', NULL);
INSERT INTO `extra_user_datas` VALUES ('402', '333', '13', NULL, '12', '2023-11-21 05:28:30', '2023-11-21 05:28:30', NULL);
INSERT INTO `extra_user_datas` VALUES ('403', '333', '14', 'demo', '12', '2023-11-21 05:28:30', '2023-11-21 05:28:30', NULL);
INSERT INTO `extra_user_datas` VALUES ('404', '334', '12', 'Class 2', '12', '2023-11-21 05:29:53', '2023-11-21 05:29:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('405', '334', '13', NULL, '12', '2023-11-21 05:29:53', '2023-11-21 05:29:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('406', '334', '14', 'demo', '12', '2023-11-21 05:29:53', '2023-11-21 05:29:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('407', '335', '12', 'Class 2', '12', '2023-11-21 05:31:12', '2023-11-21 05:31:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('408', '335', '13', NULL, '12', '2023-11-21 05:31:12', '2023-11-21 05:31:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('409', '335', '14', 'demo', '12', '2023-11-21 05:31:12', '2023-11-21 05:31:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('410', '336', '12', NULL, '12', '2023-11-21 05:45:52', '2023-11-21 05:45:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('411', '336', '13', NULL, '12', '2023-11-21 05:45:52', '2023-11-21 05:45:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('412', '336', '14', NULL, '12', '2023-11-21 05:45:52', '2023-11-21 05:45:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('413', '337', '12', NULL, '12', '2023-11-21 05:46:15', '2023-11-21 05:46:15', NULL);
INSERT INTO `extra_user_datas` VALUES ('414', '337', '13', NULL, '12', '2023-11-21 05:46:15', '2023-11-21 05:46:15', NULL);
INSERT INTO `extra_user_datas` VALUES ('415', '337', '14', NULL, '12', '2023-11-21 05:46:15', '2023-11-21 05:46:15', NULL);
INSERT INTO `extra_user_datas` VALUES ('425', '341', '12', NULL, '12', '2023-11-21 05:47:50', '2023-11-21 05:47:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('426', '341', '13', NULL, '12', '2023-11-21 05:47:50', '2023-11-21 05:47:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('427', '341', '14', NULL, '12', '2023-11-21 05:47:50', '2023-11-21 05:47:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('428', '333', '12', NULL, '12', '2023-11-21 06:02:26', '2023-11-21 06:02:26', NULL);
INSERT INTO `extra_user_datas` VALUES ('429', '333', '13', 'Hello', '12', '2023-11-21 06:02:26', '2023-11-21 06:02:26', NULL);
INSERT INTO `extra_user_datas` VALUES ('430', '333', '14', NULL, '12', '2023-11-21 06:02:26', '2023-11-21 06:02:26', NULL);
INSERT INTO `extra_user_datas` VALUES ('443', '467', '17', NULL, '12', '2023-11-21 06:44:00', '2023-11-21 06:44:00', NULL);
INSERT INTO `extra_user_datas` VALUES ('444', '467', '18', NULL, '12', '2023-11-21 06:44:00', '2023-11-21 06:44:00', NULL);
INSERT INTO `extra_user_datas` VALUES ('445', '465', '17', NULL, '12', '2023-11-21 06:44:11', '2023-11-21 06:44:11', NULL);
INSERT INTO `extra_user_datas` VALUES ('446', '465', '18', NULL, '12', '2023-11-21 06:44:11', '2023-11-21 06:44:11', NULL);
INSERT INTO `extra_user_datas` VALUES ('447', '463', '17', NULL, '12', '2023-11-21 06:44:20', '2023-11-21 06:56:15', NULL);
INSERT INTO `extra_user_datas` VALUES ('448', '463', '18', NULL, '12', '2023-11-21 06:44:20', '2023-11-21 06:56:15', NULL);
INSERT INTO `extra_user_datas` VALUES ('449', '1062', '17', NULL, '12', '2024-03-11 16:03:57', '2024-09-30 13:56:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('450', '1062', '18', NULL, '12', '2024-03-11 16:03:57', '2024-09-30 13:56:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('451', '1060', '17', NULL, '12', '2024-03-11 16:04:17', '2024-03-11 16:04:17', NULL);
INSERT INTO `extra_user_datas` VALUES ('452', '1060', '18', NULL, '12', '2024-03-11 16:04:17', '2024-03-11 16:04:17', NULL);
INSERT INTO `extra_user_datas` VALUES ('453', '1058', '17', NULL, '12', '2024-03-11 16:04:34', '2024-03-11 16:04:34', NULL);
INSERT INTO `extra_user_datas` VALUES ('454', '1058', '18', NULL, '12', '2024-03-11 16:04:34', '2024-03-11 16:04:34', NULL);
INSERT INTO `extra_user_datas` VALUES ('455', '1056', '17', NULL, '12', '2024-03-11 16:04:50', '2024-03-11 16:04:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('456', '1056', '18', NULL, '12', '2024-03-11 16:04:50', '2024-03-11 16:04:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('457', '1054', '17', NULL, '12', '2024-03-11 16:05:05', '2024-03-11 16:05:05', NULL);
INSERT INTO `extra_user_datas` VALUES ('458', '1054', '18', NULL, '12', '2024-03-11 16:05:05', '2024-03-11 16:05:05', NULL);
INSERT INTO `extra_user_datas` VALUES ('459', '1052', '17', NULL, '12', '2024-03-11 16:05:22', '2024-03-11 16:05:22', NULL);
INSERT INTO `extra_user_datas` VALUES ('460', '1052', '18', NULL, '12', '2024-03-11 16:05:22', '2024-03-11 16:05:22', NULL);
INSERT INTO `extra_user_datas` VALUES ('461', '1050', '17', NULL, '12', '2024-03-11 16:05:45', '2024-03-11 16:05:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('462', '1050', '18', NULL, '12', '2024-03-11 16:05:45', '2024-03-11 16:05:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('463', '1048', '17', NULL, '12', '2024-03-11 16:05:57', '2024-03-11 16:05:57', NULL);
INSERT INTO `extra_user_datas` VALUES ('464', '1048', '18', NULL, '12', '2024-03-11 16:05:57', '2024-03-11 16:05:57', NULL);
INSERT INTO `extra_user_datas` VALUES ('465', '1046', '17', NULL, '12', '2024-03-11 16:06:14', '2024-03-11 16:06:14', NULL);
INSERT INTO `extra_user_datas` VALUES ('466', '1046', '18', NULL, '12', '2024-03-11 16:06:14', '2024-03-11 16:06:14', NULL);
INSERT INTO `extra_user_datas` VALUES ('467', '1044', '17', '1', '12', '2024-03-11 16:06:29', '2024-10-10 15:31:23', NULL);
INSERT INTO `extra_user_datas` VALUES ('468', '1044', '18', '9515951595', '12', '2024-03-11 16:06:29', '2024-10-10 15:31:23', NULL);
INSERT INTO `extra_user_datas` VALUES ('469', '331', '17', NULL, '12', '2024-09-30 13:52:58', '2024-09-30 13:56:39', NULL);
INSERT INTO `extra_user_datas` VALUES ('470', '331', '18', NULL, '12', '2024-09-30 13:52:58', '2024-09-30 13:56:39', NULL);
INSERT INTO `extra_user_datas` VALUES ('471', '1044', '12', 'Kamlesh', '12', '2024-10-10 15:31:07', '2024-10-10 15:31:23', NULL);
INSERT INTO `extra_user_datas` VALUES ('472', '331', '12', 'Class 1', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('473', '331', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('474', '331', '14', 'demo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('475', '331', '15', 'Downtown, Toronto, Onterio, CA', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('476', '331', '16', '8200727077', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('477', '333', '12', 'Class 2', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('478', '333', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('479', '333', '14', 'demo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('480', '333', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, '2023-11-21 06:02:26', NULL);
INSERT INTO `extra_user_datas` VALUES ('481', '333', '16', '8200727077', '12', NULL, '2023-11-21 05:28:30', NULL);
INSERT INTO `extra_user_datas` VALUES ('482', '334', '12', 'Class 2', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('483', '334', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('484', '334', '14', 'demo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('485', '334', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, '2023-11-21 05:29:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('486', '334', '16', '8200727077', '12', NULL, '2023-11-21 05:29:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('487', '335', '12', 'Class 2', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('488', '335', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('489', '335', '14', 'demo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('490', '335', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, '2023-11-21 05:31:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('491', '335', '16', '8200727077', '12', NULL, '2023-11-21 05:31:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('492', '336', '12', 'Class 2', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('493', '336', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('494', '336', '14', 'demo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('495', '336', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, '2023-11-21 05:45:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('496', '336', '16', '8200727077', '12', NULL, '2023-11-21 05:45:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('497', '337', '12', 'Class 2', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('498', '337', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('499', '337', '14', 'demo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('500', '337', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, '2023-11-21 05:46:15', NULL);
INSERT INTO `extra_user_datas` VALUES ('501', '337', '16', '8200727077', '12', NULL, '2023-11-21 05:46:15', NULL);
INSERT INTO `extra_user_datas` VALUES ('517', '341', '12', 'Class 2', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('518', '341', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('519', '341', '14', 'demo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('520', '341', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, '2023-11-21 05:47:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('521', '341', '16', '8200727077', '12', NULL, '2023-11-21 05:47:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('572', '349', '12', 'Nicole', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('573', '349', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('574', '349', '14', 'Cunha', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('575', '349', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('576', '349', '16', '4178583056', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('577', '351', '12', 'Andre', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('578', '351', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('579', '351', '14', 'Melo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('580', '351', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('581', '351', '16', '7045171377', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('582', '353', '12', 'Rebeca', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('583', '353', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('584', '353', '14', 'Ribeiro', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('585', '353', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('586', '353', '16', '5204182405', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('587', '355', '12', 'Sarah', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('588', '355', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('589', '355', '14', 'Alves', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('590', '355', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('591', '355', '16', '3147492781', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('592', '357', '12', 'Antonio', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('593', '357', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('594', '357', '14', 'Cunha', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('595', '357', '15', '1593 Briarwood Road', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('596', '357', '16', '5032027980', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('597', '359', '12', 'Clara', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('598', '359', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('599', '359', '14', 'Cunha', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('600', '359', '15', '1180 Concord Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('601', '359', '16', '2603075096', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('602', '361', '12', 'Bruna', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('603', '361', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('604', '361', '14', 'Sousa', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('605', '361', '15', '2573 Parkway Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('606', '361', '16', '6306764116', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('607', '363', '12', 'Kaue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('608', '363', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('609', '363', '14', 'Oliveira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('610', '363', '15', '3072 Hawks Nest Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('611', '363', '16', '8014761619', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('612', '365', '12', 'Caio', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('613', '365', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('614', '365', '14', 'Silva', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('615', '365', '15', '1417 Karen Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('616', '365', '16', '4178831795', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('617', '367', '12', 'Murilo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('618', '367', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('619', '367', '14', 'Cunha', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('620', '367', '15', '4625 Cessna Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('621', '367', '16', '9036367481', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('622', '369', '12', 'Fernanda', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('623', '369', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('624', '369', '14', 'Cardoso', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('625', '369', '15', '3809 Steele Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('626', '369', '16', '7575774415', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('627', '371', '12', 'Vinicius', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('628', '371', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('629', '371', '14', 'Azevedo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('630', '371', '15', '3099 White River Way', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('631', '371', '16', '4846710133', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('632', '373', '12', 'Rebeca', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('633', '373', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('634', '373', '14', 'Oliveira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('635', '373', '15', '15 Briarwood Road', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('636', '373', '16', '7016524974', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('637', '375', '12', 'Julieta', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('638', '375', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('639', '375', '14', 'Dias', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('640', '375', '15', '3513 Thrash Trail', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('641', '375', '16', '5085312029', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('642', '377', '12', 'Matheus', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('643', '377', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('644', '377', '14', 'Araujo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('645', '377', '15', '2878 Allison Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('646', '377', '16', '6262029477', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('647', '379', '12', 'Nicolash', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('648', '379', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('649', '379', '14', 'Castro', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('650', '379', '15', '1403 Bastin Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('651', '379', '16', '2607053999', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('652', '381', '12', 'Rafael', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('653', '381', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('654', '381', '14', 'Alves', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('655', '381', '15', '306 Hidden Meadow Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('656', '381', '16', '3143746446', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('657', '383', '12', 'Guilherme', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('658', '383', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('659', '383', '14', 'Ferreira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('660', '383', '15', '3472 Kovar Road', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('661', '383', '16', '5164232320', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('662', '385', '12', 'Kauan', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('663', '385', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('664', '385', '14', 'Santos', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('665', '385', '15', '3395 Rainbow Road', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('666', '385', '16', '4345823055', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('667', '387', '12', 'Julian', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('668', '387', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('669', '387', '14', 'Cavalcanti', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('670', '387', '15', '4054 Pearcy Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('671', '387', '16', '3042080094', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('672', '389', '12', 'Caua', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('673', '389', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('674', '389', '14', 'Pereira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('675', '389', '15', '676 Bruce Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('676', '389', '16', '3373045081', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('677', '391', '12', 'Thais', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('678', '391', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('679', '391', '14', 'Ferreira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('680', '391', '15', '3016 Gnatty Creek Road', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('681', '391', '16', '4066814745', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('682', '393', '12', 'Thais', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('683', '393', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('684', '393', '14', 'Pereira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('685', '393', '15', '4337 Queens Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('686', '393', '16', '3105664753', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('687', '395', '12', 'Tomas', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('688', '395', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('689', '395', '14', 'Goncalves', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('690', '395', '15', '1818 Tavern Place', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('691', '395', '16', '8026104060', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('692', '397', '12', 'Andre', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('693', '397', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('694', '397', '14', 'Fernandes', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('695', '397', '15', '3292 Willow Oaks Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('696', '397', '16', '8636091242', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('697', '399', '12', 'Felipe', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('698', '399', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('699', '399', '14', 'Ferreira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('700', '399', '15', '1294 Tibbs Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('701', '399', '16', '9529383180', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('702', '401', '12', 'Gustavo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('703', '401', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('704', '401', '14', 'Barbosa', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('705', '401', '15', '3393 Sumner Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('706', '401', '16', '6064639117', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('707', '403', '12', 'Nicolash', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('708', '403', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('709', '403', '14', 'Lima', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('710', '403', '15', '2446 Selah Way', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('711', '403', '16', '4143587297', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('712', '405', '12', 'Diego', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('713', '405', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('714', '405', '14', 'Cunha', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('715', '405', '15', '3881 Oakdale Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('716', '405', '16', '7655523753', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('717', '407', '12', 'Vitoria', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('718', '407', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('719', '407', '14', 'Azevedo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('720', '407', '15', '4127 Sycamore Fork Road', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('721', '407', '16', '6828418219', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('722', '409', '12', 'Mateus', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('723', '409', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('724', '409', '14', 'Ferreira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('725', '409', '15', '1520 Meadowcrest Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('726', '409', '16', '2195106037', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('727', '411', '12', 'Enzo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('728', '411', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('729', '411', '14', 'Souza', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('730', '411', '15', '4393 Johnny Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('731', '411', '16', '3602604974', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('732', '413', '12', 'Tania', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('733', '413', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('734', '413', '14', 'Santos', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('735', '413', '15', '385 Capitol Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('736', '413', '16', '2025581693', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('737', '415', '12', 'Nicolas', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('738', '415', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('739', '415', '14', 'Ribeiro', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('740', '415', '15', '2649 Sycamore Circle', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('741', '415', '16', '4435480016', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('742', '417', '12', 'Rebeca', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('743', '417', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('744', '417', '14', 'Lima', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('745', '417', '15', '1289 Parrill Court', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('746', '417', '16', '4015592403', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('747', '419', '12', 'Kauan', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('748', '419', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('749', '419', '14', 'Araujo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('750', '419', '15', '965 Chardonnay Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('751', '419', '16', '2024064718', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('752', '421', '12', 'Mateus', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('753', '421', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('754', '421', '14', 'Silva', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('755', '421', '15', '2734 Goldcliff Circle', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('756', '421', '16', '9737494754', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('757', '423', '12', 'Miguel', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('758', '423', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('759', '423', '14', 'Martins', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('760', '423', '15', '1143 Harron Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('761', '423', '16', '9102660503', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('762', '425', '12', 'Thiago', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('763', '425', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('764', '425', '14', 'Goncalves', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('765', '425', '15', '4627 Myra Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('766', '425', '16', '8162295022', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('767', '427', '12', 'Sophia', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('768', '427', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('769', '427', '14', 'Costa', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('770', '427', '15', '244 Rhode Island Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('771', '427', '16', '9177417125', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('772', '429', '12', 'Diogo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('773', '429', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('774', '429', '14', 'Lima', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('775', '429', '15', '2088 Spring Haven Trail', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('776', '429', '16', '6788045554', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('777', '431', '12', 'Laura', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('778', '431', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('779', '431', '14', 'Correia', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('780', '431', '15', '4582 Ray Court', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('781', '431', '16', '9895294996', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('782', '433', '12', 'Davi', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('783', '433', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('784', '433', '14', 'Pereira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('785', '433', '15', '2987 Nutter Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('786', '433', '16', '5635743818', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('787', '435', '12', 'Joao', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('788', '435', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('789', '435', '14', 'Castro', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('790', '435', '15', '4828 Settlers Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('791', '435', '16', '2519315347', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('792', '437', '12', 'Kaua', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('793', '437', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('794', '437', '14', 'Almeida', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('795', '437', '15', '1557 Edington Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('796', '437', '16', '6822925498', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('797', '439', '12', 'Erick', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('798', '439', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('799', '439', '14', 'Pinto', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('800', '439', '15', '3888 Robinson Court', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('801', '439', '16', '3038648510', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('802', '441', '12', 'Fabio', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('803', '441', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('804', '441', '14', 'Ribeiro', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('805', '441', '15', '1434 Summit Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('806', '441', '16', '2484899844', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('807', '443', '12', 'Daniel', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('808', '443', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('809', '443', '14', 'Correia', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('810', '443', '15', '1267 Joyce Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('811', '443', '16', '2709653680', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('812', '445', '12', 'Thiago', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('813', '445', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('814', '445', '14', 'Oliveira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('815', '445', '15', '2036 Sycamore Circle', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('816', '445', '16', '4044010282', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('817', '447', '12', 'Carlos', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('818', '447', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('819', '447', '14', 'Azevedo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('820', '447', '15', '2682 Roy Alley', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('821', '447', '16', '2482987687', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('822', '449', '12', 'Matheus', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('823', '449', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('824', '449', '14', 'Cunha', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('825', '449', '15', '2061 Bartlett Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('826', '449', '16', '2259321328', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('827', '451', '12', 'Samuel', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('828', '451', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('829', '451', '14', 'Gomes', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('830', '451', '15', '1806 Shady Pines Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('831', '451', '16', '9015346120', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('832', '453', '12', 'Jose', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('833', '453', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('834', '453', '14', 'Melo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('835', '453', '15', '2450 College Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('836', '453', '16', '9122675548', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('837', '455', '12', 'Vitor', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('838', '455', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('839', '455', '14', 'Pereira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('840', '455', '15', '581 Tennessee Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('841', '455', '16', '3145445393', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('842', '457', '12', 'Lucas', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('843', '457', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('844', '457', '14', 'Santos', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('845', '457', '15', '4969 Coventry Court', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('846', '457', '16', '5739458203', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('847', '459', '12', 'Nicolash', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('848', '459', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('849', '459', '14', 'Rodrigues', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('850', '459', '15', '2820 Lightning Point Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('851', '459', '16', '8437651527', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('852', '461', '12', 'Matheus', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('853', '461', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('854', '461', '14', 'Castro', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('855', '461', '15', '2551 Austin Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('856', '461', '16', '7063277435', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('857', '463', '12', 'Rafael', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('858', '463', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('859', '463', '14', 'Rodrigues', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('860', '463', '15', '2959 Blane Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('861', '463', '16', '7084632716', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('862', '465', '12', 'Vinicius', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('863', '465', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('864', '465', '14', 'Barbosa', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('865', '465', '15', '3683 Sharon Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('866', '465', '16', '6034859842', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('867', '467', '12', 'Vitor', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('868', '467', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('869', '467', '14', 'Sousa', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('870', '467', '15', '3086 Broadway Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('871', '467', '16', '2016102973', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('872', '333', '12', 'Class 2', '12', '2023-11-21 05:28:30', '2023-11-21 05:28:30', NULL);
INSERT INTO `extra_user_datas` VALUES ('873', '333', '13', NULL, '12', '2023-11-21 05:28:30', '2023-11-21 05:28:30', NULL);
INSERT INTO `extra_user_datas` VALUES ('874', '333', '14', 'demo', '12', '2023-11-21 05:28:30', '2023-11-21 05:28:30', NULL);
INSERT INTO `extra_user_datas` VALUES ('875', '334', '12', 'Class 2', '12', '2023-11-21 05:29:53', '2023-11-21 05:29:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('876', '334', '13', NULL, '12', '2023-11-21 05:29:53', '2023-11-21 05:29:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('877', '334', '14', 'demo', '12', '2023-11-21 05:29:53', '2023-11-21 05:29:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('878', '335', '12', 'Class 2', '12', '2023-11-21 05:31:12', '2023-11-21 05:31:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('879', '335', '13', NULL, '12', '2023-11-21 05:31:12', '2023-11-21 05:31:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('880', '335', '14', 'demo', '12', '2023-11-21 05:31:12', '2023-11-21 05:31:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('881', '336', '12', NULL, '12', '2023-11-21 05:45:52', '2023-11-21 05:45:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('882', '336', '13', NULL, '12', '2023-11-21 05:45:52', '2023-11-21 05:45:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('883', '336', '14', NULL, '12', '2023-11-21 05:45:52', '2023-11-21 05:45:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('884', '337', '12', NULL, '12', '2023-11-21 05:46:15', '2023-11-21 05:46:15', NULL);
INSERT INTO `extra_user_datas` VALUES ('885', '337', '13', NULL, '12', '2023-11-21 05:46:15', '2023-11-21 05:46:15', NULL);
INSERT INTO `extra_user_datas` VALUES ('886', '337', '14', NULL, '12', '2023-11-21 05:46:15', '2023-11-21 05:46:15', NULL);
INSERT INTO `extra_user_datas` VALUES ('896', '341', '12', NULL, '12', '2023-11-21 05:47:50', '2023-11-21 05:47:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('897', '341', '13', NULL, '12', '2023-11-21 05:47:50', '2023-11-21 05:47:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('898', '341', '14', NULL, '12', '2023-11-21 05:47:50', '2023-11-21 05:47:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('899', '333', '12', NULL, '12', '2023-11-21 06:02:26', '2023-11-21 06:02:26', NULL);
INSERT INTO `extra_user_datas` VALUES ('900', '333', '13', 'Hello', '12', '2023-11-21 06:02:26', '2023-11-21 06:02:26', NULL);
INSERT INTO `extra_user_datas` VALUES ('901', '333', '14', NULL, '12', '2023-11-21 06:02:26', '2023-11-21 06:02:26', NULL);
INSERT INTO `extra_user_datas` VALUES ('914', '467', '17', NULL, '12', '2023-11-21 06:44:00', '2023-11-21 06:44:00', NULL);
INSERT INTO `extra_user_datas` VALUES ('915', '467', '18', NULL, '12', '2023-11-21 06:44:00', '2023-11-21 06:44:00', NULL);
INSERT INTO `extra_user_datas` VALUES ('916', '465', '17', NULL, '12', '2023-11-21 06:44:11', '2023-11-21 06:44:11', NULL);
INSERT INTO `extra_user_datas` VALUES ('917', '465', '18', NULL, '12', '2023-11-21 06:44:11', '2023-11-21 06:44:11', NULL);
INSERT INTO `extra_user_datas` VALUES ('918', '463', '17', NULL, '12', '2023-11-21 06:44:20', '2023-11-21 06:56:15', NULL);
INSERT INTO `extra_user_datas` VALUES ('919', '463', '18', NULL, '12', '2023-11-21 06:44:20', '2023-11-21 06:56:15', NULL);
INSERT INTO `extra_user_datas` VALUES ('920', '1062', '17', NULL, '12', '2024-03-11 16:03:57', '2024-09-30 13:56:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('921', '1062', '18', NULL, '12', '2024-03-11 16:03:57', '2024-09-30 13:56:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('922', '1060', '17', NULL, '12', '2024-03-11 16:04:17', '2024-03-11 16:04:17', NULL);
INSERT INTO `extra_user_datas` VALUES ('923', '1060', '18', NULL, '12', '2024-03-11 16:04:17', '2024-03-11 16:04:17', NULL);
INSERT INTO `extra_user_datas` VALUES ('924', '1058', '17', NULL, '12', '2024-03-11 16:04:34', '2024-03-11 16:04:34', NULL);
INSERT INTO `extra_user_datas` VALUES ('925', '1058', '18', NULL, '12', '2024-03-11 16:04:34', '2024-03-11 16:04:34', NULL);
INSERT INTO `extra_user_datas` VALUES ('926', '1056', '17', NULL, '12', '2024-03-11 16:04:50', '2024-03-11 16:04:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('927', '1056', '18', NULL, '12', '2024-03-11 16:04:50', '2024-03-11 16:04:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('928', '1054', '17', NULL, '12', '2024-03-11 16:05:05', '2024-03-11 16:05:05', NULL);
INSERT INTO `extra_user_datas` VALUES ('929', '1054', '18', NULL, '12', '2024-03-11 16:05:05', '2024-03-11 16:05:05', NULL);
INSERT INTO `extra_user_datas` VALUES ('930', '1052', '17', NULL, '12', '2024-03-11 16:05:22', '2024-03-11 16:05:22', NULL);
INSERT INTO `extra_user_datas` VALUES ('931', '1052', '18', NULL, '12', '2024-03-11 16:05:22', '2024-03-11 16:05:22', NULL);
INSERT INTO `extra_user_datas` VALUES ('932', '1050', '17', NULL, '12', '2024-03-11 16:05:45', '2024-03-11 16:05:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('933', '1050', '18', NULL, '12', '2024-03-11 16:05:45', '2024-03-11 16:05:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('934', '1048', '17', NULL, '12', '2024-03-11 16:05:57', '2024-03-11 16:05:57', NULL);
INSERT INTO `extra_user_datas` VALUES ('935', '1048', '18', NULL, '12', '2024-03-11 16:05:57', '2024-03-11 16:05:57', NULL);
INSERT INTO `extra_user_datas` VALUES ('936', '1046', '17', NULL, '12', '2024-03-11 16:06:14', '2024-03-11 16:06:14', NULL);
INSERT INTO `extra_user_datas` VALUES ('937', '1046', '18', NULL, '12', '2024-03-11 16:06:14', '2024-03-11 16:06:14', NULL);
INSERT INTO `extra_user_datas` VALUES ('938', '1044', '17', '1', '12', '2024-03-11 16:06:29', '2024-10-10 15:31:23', NULL);
INSERT INTO `extra_user_datas` VALUES ('939', '1044', '18', '9515951595', '12', '2024-03-11 16:06:29', '2024-10-10 15:31:23', NULL);
INSERT INTO `extra_user_datas` VALUES ('940', '331', '17', NULL, '12', '2024-09-30 13:52:58', '2024-09-30 13:56:39', NULL);
INSERT INTO `extra_user_datas` VALUES ('941', '331', '18', NULL, '12', '2024-09-30 13:52:58', '2024-09-30 13:56:39', NULL);
INSERT INTO `extra_user_datas` VALUES ('942', '1044', '12', 'Kamlesh', '12', '2024-10-10 15:31:07', '2024-10-10 15:31:23', NULL);
INSERT INTO `extra_user_datas` VALUES ('943', '331', '12', 'Class 1', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('944', '331', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('945', '331', '14', 'demo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('946', '331', '15', 'Downtown, Toronto, Onterio, CA', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('947', '331', '16', '8200727077', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('948', '333', '12', 'Class 2', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('949', '333', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('950', '333', '14', 'demo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('951', '333', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, '2023-11-21 06:02:26', NULL);
INSERT INTO `extra_user_datas` VALUES ('952', '333', '16', '8200727077', '12', NULL, '2023-11-21 05:28:30', NULL);
INSERT INTO `extra_user_datas` VALUES ('953', '334', '12', 'Class 2', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('954', '334', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('955', '334', '14', 'demo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('956', '334', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, '2023-11-21 05:29:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('957', '334', '16', '8200727077', '12', NULL, '2023-11-21 05:29:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('958', '335', '12', 'Class 2', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('959', '335', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('960', '335', '14', 'demo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('961', '335', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, '2023-11-21 05:31:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('962', '335', '16', '8200727077', '12', NULL, '2023-11-21 05:31:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('963', '336', '12', 'Class 2', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('964', '336', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('965', '336', '14', 'demo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('966', '336', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, '2023-11-21 05:45:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('967', '336', '16', '8200727077', '12', NULL, '2023-11-21 05:45:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('968', '337', '12', 'Class 2', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('969', '337', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('970', '337', '14', 'demo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('971', '337', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, '2023-11-21 05:46:15', NULL);
INSERT INTO `extra_user_datas` VALUES ('972', '337', '16', '8200727077', '12', NULL, '2023-11-21 05:46:15', NULL);
INSERT INTO `extra_user_datas` VALUES ('988', '341', '12', 'Class 2', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('989', '341', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('990', '341', '14', 'demo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('991', '341', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, '2023-11-21 05:47:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('992', '341', '16', '8200727077', '12', NULL, '2023-11-21 05:47:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('1043', '349', '12', 'Nicole', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1044', '349', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1045', '349', '14', 'Cunha', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1046', '349', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1047', '349', '16', '4178583056', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1048', '351', '12', 'Andre', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1049', '351', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1050', '351', '14', 'Melo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1051', '351', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1052', '351', '16', '7045171377', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1053', '353', '12', 'Rebeca', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1054', '353', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1055', '353', '14', 'Ribeiro', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1056', '353', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1057', '353', '16', '5204182405', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1058', '355', '12', 'Sarah', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1059', '355', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1060', '355', '14', 'Alves', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1061', '355', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1062', '355', '16', '3147492781', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1063', '357', '12', 'Antonio', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1064', '357', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1065', '357', '14', 'Cunha', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1066', '357', '15', '1593 Briarwood Road', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1067', '357', '16', '5032027980', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1068', '359', '12', 'Clara', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1069', '359', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1070', '359', '14', 'Cunha', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1071', '359', '15', '1180 Concord Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1072', '359', '16', '2603075096', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1073', '361', '12', 'Bruna', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1074', '361', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1075', '361', '14', 'Sousa', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1076', '361', '15', '2573 Parkway Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1077', '361', '16', '6306764116', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1078', '363', '12', 'Kaue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1079', '363', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1080', '363', '14', 'Oliveira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1081', '363', '15', '3072 Hawks Nest Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1082', '363', '16', '8014761619', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1083', '365', '12', 'Caio', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1084', '365', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1085', '365', '14', 'Silva', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1086', '365', '15', '1417 Karen Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1087', '365', '16', '4178831795', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1088', '367', '12', 'Murilo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1089', '367', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1090', '367', '14', 'Cunha', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1091', '367', '15', '4625 Cessna Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1092', '367', '16', '9036367481', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1093', '369', '12', 'Fernanda', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1094', '369', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1095', '369', '14', 'Cardoso', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1096', '369', '15', '3809 Steele Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1097', '369', '16', '7575774415', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1098', '371', '12', 'Vinicius', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1099', '371', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1100', '371', '14', 'Azevedo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1101', '371', '15', '3099 White River Way', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1102', '371', '16', '4846710133', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1103', '373', '12', 'Rebeca', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1104', '373', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1105', '373', '14', 'Oliveira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1106', '373', '15', '15 Briarwood Road', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1107', '373', '16', '7016524974', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1108', '375', '12', 'Julieta', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1109', '375', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1110', '375', '14', 'Dias', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1111', '375', '15', '3513 Thrash Trail', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1112', '375', '16', '5085312029', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1113', '377', '12', 'Matheus', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1114', '377', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1115', '377', '14', 'Araujo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1116', '377', '15', '2878 Allison Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1117', '377', '16', '6262029477', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1118', '379', '12', 'Nicolash', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1119', '379', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1120', '379', '14', 'Castro', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1121', '379', '15', '1403 Bastin Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1122', '379', '16', '2607053999', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1123', '381', '12', 'Rafael', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1124', '381', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1125', '381', '14', 'Alves', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1126', '381', '15', '306 Hidden Meadow Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1127', '381', '16', '3143746446', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1128', '383', '12', 'Guilherme', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1129', '383', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1130', '383', '14', 'Ferreira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1131', '383', '15', '3472 Kovar Road', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1132', '383', '16', '5164232320', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1133', '385', '12', 'Kauan', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1134', '385', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1135', '385', '14', 'Santos', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1136', '385', '15', '3395 Rainbow Road', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1137', '385', '16', '4345823055', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1138', '387', '12', 'Julian', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1139', '387', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1140', '387', '14', 'Cavalcanti', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1141', '387', '15', '4054 Pearcy Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1142', '387', '16', '3042080094', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1143', '389', '12', 'Caua', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1144', '389', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1145', '389', '14', 'Pereira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1146', '389', '15', '676 Bruce Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1147', '389', '16', '3373045081', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1148', '391', '12', 'Thais', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1149', '391', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1150', '391', '14', 'Ferreira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1151', '391', '15', '3016 Gnatty Creek Road', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1152', '391', '16', '4066814745', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1153', '393', '12', 'Thais', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1154', '393', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1155', '393', '14', 'Pereira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1156', '393', '15', '4337 Queens Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1157', '393', '16', '3105664753', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1158', '395', '12', 'Tomas', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1159', '395', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1160', '395', '14', 'Goncalves', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1161', '395', '15', '1818 Tavern Place', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1162', '395', '16', '8026104060', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1163', '397', '12', 'Andre', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1164', '397', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1165', '397', '14', 'Fernandes', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1166', '397', '15', '3292 Willow Oaks Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1167', '397', '16', '8636091242', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1168', '399', '12', 'Felipe', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1169', '399', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1170', '399', '14', 'Ferreira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1171', '399', '15', '1294 Tibbs Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1172', '399', '16', '9529383180', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1173', '401', '12', 'Gustavo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1174', '401', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1175', '401', '14', 'Barbosa', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1176', '401', '15', '3393 Sumner Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1177', '401', '16', '6064639117', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1178', '403', '12', 'Nicolash', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1179', '403', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1180', '403', '14', 'Lima', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1181', '403', '15', '2446 Selah Way', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1182', '403', '16', '4143587297', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1183', '405', '12', 'Diego', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1184', '405', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1185', '405', '14', 'Cunha', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1186', '405', '15', '3881 Oakdale Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1187', '405', '16', '7655523753', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1188', '407', '12', 'Vitoria', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1189', '407', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1190', '407', '14', 'Azevedo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1191', '407', '15', '4127 Sycamore Fork Road', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1192', '407', '16', '6828418219', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1193', '409', '12', 'Mateus', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1194', '409', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1195', '409', '14', 'Ferreira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1196', '409', '15', '1520 Meadowcrest Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1197', '409', '16', '2195106037', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1198', '411', '12', 'Enzo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1199', '411', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1200', '411', '14', 'Souza', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1201', '411', '15', '4393 Johnny Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1202', '411', '16', '3602604974', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1203', '413', '12', 'Tania', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1204', '413', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1205', '413', '14', 'Santos', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1206', '413', '15', '385 Capitol Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1207', '413', '16', '2025581693', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1208', '415', '12', 'Nicolas', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1209', '415', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1210', '415', '14', 'Ribeiro', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1211', '415', '15', '2649 Sycamore Circle', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1212', '415', '16', '4435480016', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1213', '417', '12', 'Rebeca', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1214', '417', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1215', '417', '14', 'Lima', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1216', '417', '15', '1289 Parrill Court', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1217', '417', '16', '4015592403', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1218', '419', '12', 'Kauan', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1219', '419', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1220', '419', '14', 'Araujo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1221', '419', '15', '965 Chardonnay Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1222', '419', '16', '2024064718', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1223', '421', '12', 'Mateus', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1224', '421', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1225', '421', '14', 'Silva', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1226', '421', '15', '2734 Goldcliff Circle', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1227', '421', '16', '9737494754', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1228', '423', '12', 'Miguel', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1229', '423', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1230', '423', '14', 'Martins', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1231', '423', '15', '1143 Harron Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1232', '423', '16', '9102660503', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1233', '425', '12', 'Thiago', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1234', '425', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1235', '425', '14', 'Goncalves', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1236', '425', '15', '4627 Myra Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1237', '425', '16', '8162295022', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1238', '427', '12', 'Sophia', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1239', '427', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1240', '427', '14', 'Costa', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1241', '427', '15', '244 Rhode Island Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1242', '427', '16', '9177417125', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1243', '429', '12', 'Diogo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1244', '429', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1245', '429', '14', 'Lima', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1246', '429', '15', '2088 Spring Haven Trail', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1247', '429', '16', '6788045554', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1248', '431', '12', 'Laura', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1249', '431', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1250', '431', '14', 'Correia', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1251', '431', '15', '4582 Ray Court', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1252', '431', '16', '9895294996', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1253', '433', '12', 'Davi', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1254', '433', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1255', '433', '14', 'Pereira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1256', '433', '15', '2987 Nutter Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1257', '433', '16', '5635743818', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1258', '435', '12', 'Joao', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1259', '435', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1260', '435', '14', 'Castro', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1261', '435', '15', '4828 Settlers Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1262', '435', '16', '2519315347', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1263', '437', '12', 'Kaua', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1264', '437', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1265', '437', '14', 'Almeida', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1266', '437', '15', '1557 Edington Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1267', '437', '16', '6822925498', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1268', '439', '12', 'Erick', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1269', '439', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1270', '439', '14', 'Pinto', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1271', '439', '15', '3888 Robinson Court', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1272', '439', '16', '3038648510', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1273', '441', '12', 'Fabio', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1274', '441', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1275', '441', '14', 'Ribeiro', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1276', '441', '15', '1434 Summit Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1277', '441', '16', '2484899844', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1278', '443', '12', 'Daniel', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1279', '443', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1280', '443', '14', 'Correia', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1281', '443', '15', '1267 Joyce Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1282', '443', '16', '2709653680', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1283', '445', '12', 'Thiago', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1284', '445', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1285', '445', '14', 'Oliveira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1286', '445', '15', '2036 Sycamore Circle', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1287', '445', '16', '4044010282', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1288', '447', '12', 'Carlos', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1289', '447', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1290', '447', '14', 'Azevedo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1291', '447', '15', '2682 Roy Alley', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1292', '447', '16', '2482987687', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1293', '449', '12', 'Matheus', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1294', '449', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1295', '449', '14', 'Cunha', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1296', '449', '15', '2061 Bartlett Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1297', '449', '16', '2259321328', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1298', '451', '12', 'Samuel', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1299', '451', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1300', '451', '14', 'Gomes', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1301', '451', '15', '1806 Shady Pines Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1302', '451', '16', '9015346120', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1303', '453', '12', 'Jose', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1304', '453', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1305', '453', '14', 'Melo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1306', '453', '15', '2450 College Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1307', '453', '16', '9122675548', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1308', '455', '12', 'Vitor', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1309', '455', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1310', '455', '14', 'Pereira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1311', '455', '15', '581 Tennessee Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1312', '455', '16', '3145445393', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1313', '457', '12', 'Lucas', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1314', '457', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1315', '457', '14', 'Santos', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1316', '457', '15', '4969 Coventry Court', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1317', '457', '16', '5739458203', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1318', '459', '12', 'Nicolash', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1319', '459', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1320', '459', '14', 'Rodrigues', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1321', '459', '15', '2820 Lightning Point Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1322', '459', '16', '8437651527', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1323', '461', '12', 'Matheus', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1324', '461', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1325', '461', '14', 'Castro', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1326', '461', '15', '2551 Austin Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1327', '461', '16', '7063277435', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1328', '463', '12', 'Rafael', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1329', '463', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1330', '463', '14', 'Rodrigues', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1331', '463', '15', '2959 Blane Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1332', '463', '16', '7084632716', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1333', '465', '12', 'Vinicius', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1334', '465', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1335', '465', '14', 'Barbosa', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1336', '465', '15', '3683 Sharon Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1337', '465', '16', '6034859842', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1338', '467', '12', 'Vitor', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1339', '467', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1340', '467', '14', 'Sousa', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1341', '467', '15', '3086 Broadway Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1342', '467', '16', '2016102973', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1343', '333', '12', 'Class 2', '12', '2023-11-21 05:28:30', '2023-11-21 05:28:30', NULL);
INSERT INTO `extra_user_datas` VALUES ('1344', '333', '13', NULL, '12', '2023-11-21 05:28:30', '2023-11-21 05:28:30', NULL);
INSERT INTO `extra_user_datas` VALUES ('1345', '333', '14', 'demo', '12', '2023-11-21 05:28:30', '2023-11-21 05:28:30', NULL);
INSERT INTO `extra_user_datas` VALUES ('1346', '334', '12', 'Class 2', '12', '2023-11-21 05:29:53', '2023-11-21 05:29:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('1347', '334', '13', NULL, '12', '2023-11-21 05:29:53', '2023-11-21 05:29:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('1348', '334', '14', 'demo', '12', '2023-11-21 05:29:53', '2023-11-21 05:29:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('1349', '335', '12', 'Class 2', '12', '2023-11-21 05:31:12', '2023-11-21 05:31:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('1350', '335', '13', NULL, '12', '2023-11-21 05:31:12', '2023-11-21 05:31:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('1351', '335', '14', 'demo', '12', '2023-11-21 05:31:12', '2023-11-21 05:31:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('1352', '336', '12', NULL, '12', '2023-11-21 05:45:52', '2023-11-21 05:45:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('1353', '336', '13', NULL, '12', '2023-11-21 05:45:52', '2023-11-21 05:45:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('1354', '336', '14', NULL, '12', '2023-11-21 05:45:52', '2023-11-21 05:45:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('1355', '337', '12', NULL, '12', '2023-11-21 05:46:15', '2023-11-21 05:46:15', NULL);
INSERT INTO `extra_user_datas` VALUES ('1356', '337', '13', NULL, '12', '2023-11-21 05:46:15', '2023-11-21 05:46:15', NULL);
INSERT INTO `extra_user_datas` VALUES ('1357', '337', '14', NULL, '12', '2023-11-21 05:46:15', '2023-11-21 05:46:15', NULL);
INSERT INTO `extra_user_datas` VALUES ('1367', '341', '12', NULL, '12', '2023-11-21 05:47:50', '2023-11-21 05:47:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('1368', '341', '13', NULL, '12', '2023-11-21 05:47:50', '2023-11-21 05:47:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('1369', '341', '14', NULL, '12', '2023-11-21 05:47:50', '2023-11-21 05:47:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('1370', '333', '12', NULL, '12', '2023-11-21 06:02:26', '2023-11-21 06:02:26', NULL);
INSERT INTO `extra_user_datas` VALUES ('1371', '333', '13', 'Hello', '12', '2023-11-21 06:02:26', '2023-11-21 06:02:26', NULL);
INSERT INTO `extra_user_datas` VALUES ('1372', '333', '14', NULL, '12', '2023-11-21 06:02:26', '2023-11-21 06:02:26', NULL);
INSERT INTO `extra_user_datas` VALUES ('1385', '467', '17', NULL, '12', '2023-11-21 06:44:00', '2023-11-21 06:44:00', NULL);
INSERT INTO `extra_user_datas` VALUES ('1386', '467', '18', NULL, '12', '2023-11-21 06:44:00', '2023-11-21 06:44:00', NULL);
INSERT INTO `extra_user_datas` VALUES ('1387', '465', '17', NULL, '12', '2023-11-21 06:44:11', '2023-11-21 06:44:11', NULL);
INSERT INTO `extra_user_datas` VALUES ('1388', '465', '18', NULL, '12', '2023-11-21 06:44:11', '2023-11-21 06:44:11', NULL);
INSERT INTO `extra_user_datas` VALUES ('1389', '463', '17', NULL, '12', '2023-11-21 06:44:20', '2023-11-21 06:56:15', NULL);
INSERT INTO `extra_user_datas` VALUES ('1390', '463', '18', NULL, '12', '2023-11-21 06:44:20', '2023-11-21 06:56:15', NULL);
INSERT INTO `extra_user_datas` VALUES ('1391', '1062', '17', NULL, '12', '2024-03-11 16:03:57', '2024-09-30 13:56:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('1392', '1062', '18', NULL, '12', '2024-03-11 16:03:57', '2024-09-30 13:56:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('1393', '1060', '17', NULL, '12', '2024-03-11 16:04:17', '2024-03-11 16:04:17', NULL);
INSERT INTO `extra_user_datas` VALUES ('1394', '1060', '18', NULL, '12', '2024-03-11 16:04:17', '2024-03-11 16:04:17', NULL);
INSERT INTO `extra_user_datas` VALUES ('1395', '1058', '17', NULL, '12', '2024-03-11 16:04:34', '2024-03-11 16:04:34', NULL);
INSERT INTO `extra_user_datas` VALUES ('1396', '1058', '18', NULL, '12', '2024-03-11 16:04:34', '2024-03-11 16:04:34', NULL);
INSERT INTO `extra_user_datas` VALUES ('1397', '1056', '17', NULL, '12', '2024-03-11 16:04:50', '2024-03-11 16:04:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('1398', '1056', '18', NULL, '12', '2024-03-11 16:04:50', '2024-03-11 16:04:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('1399', '1054', '17', NULL, '12', '2024-03-11 16:05:05', '2024-03-11 16:05:05', NULL);
INSERT INTO `extra_user_datas` VALUES ('1400', '1054', '18', NULL, '12', '2024-03-11 16:05:05', '2024-03-11 16:05:05', NULL);
INSERT INTO `extra_user_datas` VALUES ('1401', '1052', '17', NULL, '12', '2024-03-11 16:05:22', '2024-03-11 16:05:22', NULL);
INSERT INTO `extra_user_datas` VALUES ('1402', '1052', '18', NULL, '12', '2024-03-11 16:05:22', '2024-03-11 16:05:22', NULL);
INSERT INTO `extra_user_datas` VALUES ('1403', '1050', '17', NULL, '12', '2024-03-11 16:05:45', '2024-03-11 16:05:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('1404', '1050', '18', NULL, '12', '2024-03-11 16:05:45', '2024-03-11 16:05:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('1405', '1048', '17', NULL, '12', '2024-03-11 16:05:57', '2024-03-11 16:05:57', NULL);
INSERT INTO `extra_user_datas` VALUES ('1406', '1048', '18', NULL, '12', '2024-03-11 16:05:57', '2024-03-11 16:05:57', NULL);
INSERT INTO `extra_user_datas` VALUES ('1407', '1046', '17', NULL, '12', '2024-03-11 16:06:14', '2024-03-11 16:06:14', NULL);
INSERT INTO `extra_user_datas` VALUES ('1408', '1046', '18', NULL, '12', '2024-03-11 16:06:14', '2024-03-11 16:06:14', NULL);
INSERT INTO `extra_user_datas` VALUES ('1409', '1044', '17', '1', '12', '2024-03-11 16:06:29', '2024-10-10 15:31:23', NULL);
INSERT INTO `extra_user_datas` VALUES ('1410', '1044', '18', '9515951595', '12', '2024-03-11 16:06:29', '2024-10-10 15:31:23', NULL);
INSERT INTO `extra_user_datas` VALUES ('1411', '331', '17', NULL, '12', '2024-09-30 13:52:58', '2024-09-30 13:56:39', NULL);
INSERT INTO `extra_user_datas` VALUES ('1412', '331', '18', NULL, '12', '2024-09-30 13:52:58', '2024-09-30 13:56:39', NULL);
INSERT INTO `extra_user_datas` VALUES ('1413', '1044', '12', 'Kamlesh', '12', '2024-10-10 15:31:07', '2024-10-10 15:31:23', NULL);
INSERT INTO `extra_user_datas` VALUES ('1414', '331', '12', 'Class 1', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1415', '331', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1416', '331', '14', 'demo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1417', '331', '15', 'Downtown, Toronto, Onterio, CA', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1418', '331', '16', '8200727077', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1419', '333', '12', 'Class 2', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1420', '333', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1421', '333', '14', 'demo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1422', '333', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, '2023-11-21 06:02:26', NULL);
INSERT INTO `extra_user_datas` VALUES ('1423', '333', '16', '8200727077', '12', NULL, '2023-11-21 05:28:30', NULL);
INSERT INTO `extra_user_datas` VALUES ('1424', '334', '12', 'Class 2', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1425', '334', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1426', '334', '14', 'demo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1427', '334', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, '2023-11-21 05:29:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('1428', '334', '16', '8200727077', '12', NULL, '2023-11-21 05:29:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('1429', '335', '12', 'Class 2', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1430', '335', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1431', '335', '14', 'demo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1432', '335', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, '2023-11-21 05:31:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('1433', '335', '16', '8200727077', '12', NULL, '2023-11-21 05:31:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('1434', '336', '12', 'Class 2', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1435', '336', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1436', '336', '14', 'demo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1437', '336', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, '2023-11-21 05:45:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('1438', '336', '16', '8200727077', '12', NULL, '2023-11-21 05:45:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('1439', '337', '12', 'Class 2', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1440', '337', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1441', '337', '14', 'demo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1442', '337', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, '2023-11-21 05:46:15', NULL);
INSERT INTO `extra_user_datas` VALUES ('1443', '337', '16', '8200727077', '12', NULL, '2023-11-21 05:46:15', NULL);
INSERT INTO `extra_user_datas` VALUES ('1459', '341', '12', 'Class 2', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1460', '341', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1461', '341', '14', 'demo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1462', '341', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, '2023-11-21 05:47:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('1463', '341', '16', '8200727077', '12', NULL, '2023-11-21 05:47:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('1514', '349', '12', 'Nicole', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1515', '349', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1516', '349', '14', 'Cunha', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1517', '349', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1518', '349', '16', '4178583056', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1519', '351', '12', 'Andre', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1520', '351', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1521', '351', '14', 'Melo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1522', '351', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1523', '351', '16', '7045171377', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1524', '353', '12', 'Rebeca', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1525', '353', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1526', '353', '14', 'Ribeiro', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1527', '353', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1528', '353', '16', '5204182405', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1529', '355', '12', 'Sarah', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1530', '355', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1531', '355', '14', 'Alves', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1532', '355', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1533', '355', '16', '3147492781', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1534', '357', '12', 'Antonio', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1535', '357', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1536', '357', '14', 'Cunha', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1537', '357', '15', '1593 Briarwood Road', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1538', '357', '16', '5032027980', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1539', '359', '12', 'Clara', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1540', '359', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1541', '359', '14', 'Cunha', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1542', '359', '15', '1180 Concord Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1543', '359', '16', '2603075096', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1544', '361', '12', 'Bruna', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1545', '361', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1546', '361', '14', 'Sousa', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1547', '361', '15', '2573 Parkway Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1548', '361', '16', '6306764116', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1549', '363', '12', 'Kaue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1550', '363', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1551', '363', '14', 'Oliveira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1552', '363', '15', '3072 Hawks Nest Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1553', '363', '16', '8014761619', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1554', '365', '12', 'Caio', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1555', '365', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1556', '365', '14', 'Silva', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1557', '365', '15', '1417 Karen Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1558', '365', '16', '4178831795', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1559', '367', '12', 'Murilo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1560', '367', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1561', '367', '14', 'Cunha', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1562', '367', '15', '4625 Cessna Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1563', '367', '16', '9036367481', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1564', '369', '12', 'Fernanda', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1565', '369', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1566', '369', '14', 'Cardoso', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1567', '369', '15', '3809 Steele Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1568', '369', '16', '7575774415', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1569', '371', '12', 'Vinicius', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1570', '371', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1571', '371', '14', 'Azevedo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1572', '371', '15', '3099 White River Way', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1573', '371', '16', '4846710133', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1574', '373', '12', 'Rebeca', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1575', '373', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1576', '373', '14', 'Oliveira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1577', '373', '15', '15 Briarwood Road', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1578', '373', '16', '7016524974', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1579', '375', '12', 'Julieta', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1580', '375', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1581', '375', '14', 'Dias', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1582', '375', '15', '3513 Thrash Trail', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1583', '375', '16', '5085312029', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1584', '377', '12', 'Matheus', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1585', '377', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1586', '377', '14', 'Araujo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1587', '377', '15', '2878 Allison Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1588', '377', '16', '6262029477', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1589', '379', '12', 'Nicolash', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1590', '379', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1591', '379', '14', 'Castro', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1592', '379', '15', '1403 Bastin Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1593', '379', '16', '2607053999', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1594', '381', '12', 'Rafael', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1595', '381', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1596', '381', '14', 'Alves', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1597', '381', '15', '306 Hidden Meadow Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1598', '381', '16', '3143746446', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1599', '383', '12', 'Guilherme', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1600', '383', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1601', '383', '14', 'Ferreira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1602', '383', '15', '3472 Kovar Road', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1603', '383', '16', '5164232320', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1604', '385', '12', 'Kauan', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1605', '385', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1606', '385', '14', 'Santos', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1607', '385', '15', '3395 Rainbow Road', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1608', '385', '16', '4345823055', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1609', '387', '12', 'Julian', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1610', '387', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1611', '387', '14', 'Cavalcanti', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1612', '387', '15', '4054 Pearcy Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1613', '387', '16', '3042080094', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1614', '389', '12', 'Caua', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1615', '389', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1616', '389', '14', 'Pereira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1617', '389', '15', '676 Bruce Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1618', '389', '16', '3373045081', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1619', '391', '12', 'Thais', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1620', '391', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1621', '391', '14', 'Ferreira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1622', '391', '15', '3016 Gnatty Creek Road', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1623', '391', '16', '4066814745', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1624', '393', '12', 'Thais', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1625', '393', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1626', '393', '14', 'Pereira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1627', '393', '15', '4337 Queens Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1628', '393', '16', '3105664753', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1629', '395', '12', 'Tomas', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1630', '395', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1631', '395', '14', 'Goncalves', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1632', '395', '15', '1818 Tavern Place', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1633', '395', '16', '8026104060', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1634', '397', '12', 'Andre', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1635', '397', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1636', '397', '14', 'Fernandes', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1637', '397', '15', '3292 Willow Oaks Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1638', '397', '16', '8636091242', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1639', '399', '12', 'Felipe', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1640', '399', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1641', '399', '14', 'Ferreira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1642', '399', '15', '1294 Tibbs Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1643', '399', '16', '9529383180', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1644', '401', '12', 'Gustavo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1645', '401', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1646', '401', '14', 'Barbosa', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1647', '401', '15', '3393 Sumner Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1648', '401', '16', '6064639117', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1649', '403', '12', 'Nicolash', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1650', '403', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1651', '403', '14', 'Lima', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1652', '403', '15', '2446 Selah Way', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1653', '403', '16', '4143587297', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1654', '405', '12', 'Diego', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1655', '405', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1656', '405', '14', 'Cunha', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1657', '405', '15', '3881 Oakdale Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1658', '405', '16', '7655523753', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1659', '407', '12', 'Vitoria', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1660', '407', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1661', '407', '14', 'Azevedo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1662', '407', '15', '4127 Sycamore Fork Road', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1663', '407', '16', '6828418219', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1664', '409', '12', 'Mateus', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1665', '409', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1666', '409', '14', 'Ferreira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1667', '409', '15', '1520 Meadowcrest Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1668', '409', '16', '2195106037', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1669', '411', '12', 'Enzo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1670', '411', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1671', '411', '14', 'Souza', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1672', '411', '15', '4393 Johnny Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1673', '411', '16', '3602604974', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1674', '413', '12', 'Tania', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1675', '413', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1676', '413', '14', 'Santos', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1677', '413', '15', '385 Capitol Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1678', '413', '16', '2025581693', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1679', '415', '12', 'Nicolas', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1680', '415', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1681', '415', '14', 'Ribeiro', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1682', '415', '15', '2649 Sycamore Circle', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1683', '415', '16', '4435480016', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1684', '417', '12', 'Rebeca', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1685', '417', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1686', '417', '14', 'Lima', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1687', '417', '15', '1289 Parrill Court', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1688', '417', '16', '4015592403', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1689', '419', '12', 'Kauan', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1690', '419', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1691', '419', '14', 'Araujo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1692', '419', '15', '965 Chardonnay Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1693', '419', '16', '2024064718', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1694', '421', '12', 'Mateus', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1695', '421', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1696', '421', '14', 'Silva', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1697', '421', '15', '2734 Goldcliff Circle', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1698', '421', '16', '9737494754', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1699', '423', '12', 'Miguel', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1700', '423', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1701', '423', '14', 'Martins', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1702', '423', '15', '1143 Harron Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1703', '423', '16', '9102660503', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1704', '425', '12', 'Thiago', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1705', '425', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1706', '425', '14', 'Goncalves', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1707', '425', '15', '4627 Myra Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1708', '425', '16', '8162295022', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1709', '427', '12', 'Sophia', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1710', '427', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1711', '427', '14', 'Costa', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1712', '427', '15', '244 Rhode Island Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1713', '427', '16', '9177417125', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1714', '429', '12', 'Diogo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1715', '429', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1716', '429', '14', 'Lima', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1717', '429', '15', '2088 Spring Haven Trail', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1718', '429', '16', '6788045554', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1719', '431', '12', 'Laura', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1720', '431', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1721', '431', '14', 'Correia', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1722', '431', '15', '4582 Ray Court', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1723', '431', '16', '9895294996', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1724', '433', '12', 'Davi', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1725', '433', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1726', '433', '14', 'Pereira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1727', '433', '15', '2987 Nutter Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1728', '433', '16', '5635743818', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1729', '435', '12', 'Joao', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1730', '435', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1731', '435', '14', 'Castro', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1732', '435', '15', '4828 Settlers Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1733', '435', '16', '2519315347', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1734', '437', '12', 'Kaua', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1735', '437', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1736', '437', '14', 'Almeida', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1737', '437', '15', '1557 Edington Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1738', '437', '16', '6822925498', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1739', '439', '12', 'Erick', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1740', '439', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1741', '439', '14', 'Pinto', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1742', '439', '15', '3888 Robinson Court', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1743', '439', '16', '3038648510', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1744', '441', '12', 'Fabio', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1745', '441', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1746', '441', '14', 'Ribeiro', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1747', '441', '15', '1434 Summit Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1748', '441', '16', '2484899844', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1749', '443', '12', 'Daniel', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1750', '443', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1751', '443', '14', 'Correia', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1752', '443', '15', '1267 Joyce Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1753', '443', '16', '2709653680', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1754', '445', '12', 'Thiago', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1755', '445', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1756', '445', '14', 'Oliveira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1757', '445', '15', '2036 Sycamore Circle', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1758', '445', '16', '4044010282', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1759', '447', '12', 'Carlos', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1760', '447', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1761', '447', '14', 'Azevedo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1762', '447', '15', '2682 Roy Alley', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1763', '447', '16', '2482987687', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1764', '449', '12', 'Matheus', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1765', '449', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1766', '449', '14', 'Cunha', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1767', '449', '15', '2061 Bartlett Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1768', '449', '16', '2259321328', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1769', '451', '12', 'Samuel', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1770', '451', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1771', '451', '14', 'Gomes', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1772', '451', '15', '1806 Shady Pines Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1773', '451', '16', '9015346120', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1774', '453', '12', 'Jose', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1775', '453', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1776', '453', '14', 'Melo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1777', '453', '15', '2450 College Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1778', '453', '16', '9122675548', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1779', '455', '12', 'Vitor', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1780', '455', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1781', '455', '14', 'Pereira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1782', '455', '15', '581 Tennessee Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1783', '455', '16', '3145445393', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1784', '457', '12', 'Lucas', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1785', '457', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1786', '457', '14', 'Santos', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1787', '457', '15', '4969 Coventry Court', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1788', '457', '16', '5739458203', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1789', '459', '12', 'Nicolash', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1790', '459', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1791', '459', '14', 'Rodrigues', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1792', '459', '15', '2820 Lightning Point Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1793', '459', '16', '8437651527', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1794', '461', '12', 'Matheus', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1795', '461', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1796', '461', '14', 'Castro', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1797', '461', '15', '2551 Austin Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1798', '461', '16', '7063277435', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1799', '463', '12', 'Rafael', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1800', '463', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1801', '463', '14', 'Rodrigues', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1802', '463', '15', '2959 Blane Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1803', '463', '16', '7084632716', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1804', '465', '12', 'Vinicius', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1805', '465', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1806', '465', '14', 'Barbosa', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1807', '465', '15', '3683 Sharon Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1808', '465', '16', '6034859842', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1809', '467', '12', 'Vitor', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1810', '467', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1811', '467', '14', 'Sousa', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1812', '467', '15', '3086 Broadway Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1813', '467', '16', '2016102973', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1814', '333', '12', 'Class 2', '12', '2023-11-21 05:28:30', '2023-11-21 05:28:30', NULL);
INSERT INTO `extra_user_datas` VALUES ('1815', '333', '13', NULL, '12', '2023-11-21 05:28:30', '2023-11-21 05:28:30', NULL);
INSERT INTO `extra_user_datas` VALUES ('1816', '333', '14', 'demo', '12', '2023-11-21 05:28:30', '2023-11-21 05:28:30', NULL);
INSERT INTO `extra_user_datas` VALUES ('1817', '334', '12', 'Class 2', '12', '2023-11-21 05:29:53', '2023-11-21 05:29:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('1818', '334', '13', NULL, '12', '2023-11-21 05:29:53', '2023-11-21 05:29:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('1819', '334', '14', 'demo', '12', '2023-11-21 05:29:53', '2023-11-21 05:29:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('1820', '335', '12', 'Class 2', '12', '2023-11-21 05:31:12', '2023-11-21 05:31:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('1821', '335', '13', NULL, '12', '2023-11-21 05:31:12', '2023-11-21 05:31:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('1822', '335', '14', 'demo', '12', '2023-11-21 05:31:12', '2023-11-21 05:31:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('1823', '336', '12', NULL, '12', '2023-11-21 05:45:52', '2023-11-21 05:45:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('1824', '336', '13', NULL, '12', '2023-11-21 05:45:52', '2023-11-21 05:45:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('1825', '336', '14', NULL, '12', '2023-11-21 05:45:52', '2023-11-21 05:45:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('1826', '337', '12', NULL, '12', '2023-11-21 05:46:15', '2023-11-21 05:46:15', NULL);
INSERT INTO `extra_user_datas` VALUES ('1827', '337', '13', NULL, '12', '2023-11-21 05:46:15', '2023-11-21 05:46:15', NULL);
INSERT INTO `extra_user_datas` VALUES ('1828', '337', '14', NULL, '12', '2023-11-21 05:46:15', '2023-11-21 05:46:15', NULL);
INSERT INTO `extra_user_datas` VALUES ('1838', '341', '12', NULL, '12', '2023-11-21 05:47:50', '2023-11-21 05:47:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('1839', '341', '13', NULL, '12', '2023-11-21 05:47:50', '2023-11-21 05:47:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('1840', '341', '14', NULL, '12', '2023-11-21 05:47:50', '2023-11-21 05:47:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('1841', '333', '12', NULL, '12', '2023-11-21 06:02:26', '2023-11-21 06:02:26', NULL);
INSERT INTO `extra_user_datas` VALUES ('1842', '333', '13', 'Hello', '12', '2023-11-21 06:02:26', '2023-11-21 06:02:26', NULL);
INSERT INTO `extra_user_datas` VALUES ('1843', '333', '14', NULL, '12', '2023-11-21 06:02:26', '2023-11-21 06:02:26', NULL);
INSERT INTO `extra_user_datas` VALUES ('1856', '467', '17', NULL, '12', '2023-11-21 06:44:00', '2023-11-21 06:44:00', NULL);
INSERT INTO `extra_user_datas` VALUES ('1857', '467', '18', NULL, '12', '2023-11-21 06:44:00', '2023-11-21 06:44:00', NULL);
INSERT INTO `extra_user_datas` VALUES ('1858', '465', '17', NULL, '12', '2023-11-21 06:44:11', '2023-11-21 06:44:11', NULL);
INSERT INTO `extra_user_datas` VALUES ('1859', '465', '18', NULL, '12', '2023-11-21 06:44:11', '2023-11-21 06:44:11', NULL);
INSERT INTO `extra_user_datas` VALUES ('1860', '463', '17', NULL, '12', '2023-11-21 06:44:20', '2023-11-21 06:56:15', NULL);
INSERT INTO `extra_user_datas` VALUES ('1861', '463', '18', NULL, '12', '2023-11-21 06:44:20', '2023-11-21 06:56:15', NULL);
INSERT INTO `extra_user_datas` VALUES ('1862', '1062', '17', NULL, '12', '2024-03-11 16:03:57', '2024-09-30 13:56:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('1863', '1062', '18', NULL, '12', '2024-03-11 16:03:57', '2024-09-30 13:56:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('1864', '1060', '17', NULL, '12', '2024-03-11 16:04:17', '2024-03-11 16:04:17', NULL);
INSERT INTO `extra_user_datas` VALUES ('1865', '1060', '18', NULL, '12', '2024-03-11 16:04:17', '2024-03-11 16:04:17', NULL);
INSERT INTO `extra_user_datas` VALUES ('1866', '1058', '17', NULL, '12', '2024-03-11 16:04:34', '2024-03-11 16:04:34', NULL);
INSERT INTO `extra_user_datas` VALUES ('1867', '1058', '18', NULL, '12', '2024-03-11 16:04:34', '2024-03-11 16:04:34', NULL);
INSERT INTO `extra_user_datas` VALUES ('1868', '1056', '17', NULL, '12', '2024-03-11 16:04:50', '2024-03-11 16:04:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('1869', '1056', '18', NULL, '12', '2024-03-11 16:04:50', '2024-03-11 16:04:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('1870', '1054', '17', NULL, '12', '2024-03-11 16:05:05', '2024-03-11 16:05:05', NULL);
INSERT INTO `extra_user_datas` VALUES ('1871', '1054', '18', NULL, '12', '2024-03-11 16:05:05', '2024-03-11 16:05:05', NULL);
INSERT INTO `extra_user_datas` VALUES ('1872', '1052', '17', NULL, '12', '2024-03-11 16:05:22', '2024-03-11 16:05:22', NULL);
INSERT INTO `extra_user_datas` VALUES ('1873', '1052', '18', NULL, '12', '2024-03-11 16:05:22', '2024-03-11 16:05:22', NULL);
INSERT INTO `extra_user_datas` VALUES ('1874', '1050', '17', NULL, '12', '2024-03-11 16:05:45', '2024-03-11 16:05:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('1875', '1050', '18', NULL, '12', '2024-03-11 16:05:45', '2024-03-11 16:05:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('1876', '1048', '17', NULL, '12', '2024-03-11 16:05:57', '2024-03-11 16:05:57', NULL);
INSERT INTO `extra_user_datas` VALUES ('1877', '1048', '18', NULL, '12', '2024-03-11 16:05:57', '2024-03-11 16:05:57', NULL);
INSERT INTO `extra_user_datas` VALUES ('1878', '1046', '17', NULL, '12', '2024-03-11 16:06:14', '2024-03-11 16:06:14', NULL);
INSERT INTO `extra_user_datas` VALUES ('1879', '1046', '18', NULL, '12', '2024-03-11 16:06:14', '2024-03-11 16:06:14', NULL);
INSERT INTO `extra_user_datas` VALUES ('1880', '1044', '17', '1', '12', '2024-03-11 16:06:29', '2024-10-10 15:31:23', NULL);
INSERT INTO `extra_user_datas` VALUES ('1881', '1044', '18', '9515951595', '12', '2024-03-11 16:06:29', '2024-10-10 15:31:23', NULL);
INSERT INTO `extra_user_datas` VALUES ('1882', '331', '17', NULL, '12', '2024-09-30 13:52:58', '2024-09-30 13:56:39', NULL);
INSERT INTO `extra_user_datas` VALUES ('1883', '331', '18', NULL, '12', '2024-09-30 13:52:58', '2024-09-30 13:56:39', NULL);
INSERT INTO `extra_user_datas` VALUES ('1884', '1044', '12', 'Kamlesh', '12', '2024-10-10 15:31:07', '2024-10-10 15:31:23', NULL);
INSERT INTO `extra_user_datas` VALUES ('1885', '331', '12', 'Class 1', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1886', '331', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1887', '331', '14', 'demo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1888', '331', '15', 'Downtown, Toronto, Onterio, CA', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1889', '331', '16', '8200727077', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1890', '333', '12', 'Class 2', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1891', '333', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1892', '333', '14', 'demo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1893', '333', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, '2023-11-21 06:02:26', NULL);
INSERT INTO `extra_user_datas` VALUES ('1894', '333', '16', '8200727077', '12', NULL, '2023-11-21 05:28:30', NULL);
INSERT INTO `extra_user_datas` VALUES ('1895', '334', '12', 'Class 2', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1896', '334', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1897', '334', '14', 'demo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1898', '334', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, '2023-11-21 05:29:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('1899', '334', '16', '8200727077', '12', NULL, '2023-11-21 05:29:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('1900', '335', '12', 'Class 2', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1901', '335', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1902', '335', '14', 'demo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1903', '335', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, '2023-11-21 05:31:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('1904', '335', '16', '8200727077', '12', NULL, '2023-11-21 05:31:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('1905', '336', '12', 'Class 2', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1906', '336', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1907', '336', '14', 'demo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1908', '336', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, '2023-11-21 05:45:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('1909', '336', '16', '8200727077', '12', NULL, '2023-11-21 05:45:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('1910', '337', '12', 'Class 2', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1911', '337', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1912', '337', '14', 'demo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1913', '337', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, '2023-11-21 05:46:15', NULL);
INSERT INTO `extra_user_datas` VALUES ('1914', '337', '16', '8200727077', '12', NULL, '2023-11-21 05:46:15', NULL);
INSERT INTO `extra_user_datas` VALUES ('1930', '341', '12', 'Class 2', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1931', '341', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1932', '341', '14', 'demo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1933', '341', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, '2023-11-21 05:47:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('1934', '341', '16', '8200727077', '12', NULL, '2023-11-21 05:47:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('1985', '349', '12', 'Nicole', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1986', '349', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1987', '349', '14', 'Cunha', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1988', '349', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1989', '349', '16', '4178583056', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1990', '351', '12', 'Andre', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1991', '351', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1992', '351', '14', 'Melo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1993', '351', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1994', '351', '16', '7045171377', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1995', '353', '12', 'Rebeca', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1996', '353', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1997', '353', '14', 'Ribeiro', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1998', '353', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('1999', '353', '16', '5204182405', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2000', '355', '12', 'Sarah', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2001', '355', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2002', '355', '14', 'Alves', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2003', '355', '15', 'Demo Address, Bhuj, Gujarat, India', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2004', '355', '16', '3147492781', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2005', '357', '12', 'Antonio', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2006', '357', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2007', '357', '14', 'Cunha', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2008', '357', '15', '1593 Briarwood Road', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2009', '357', '16', '5032027980', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2010', '359', '12', 'Clara', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2011', '359', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2012', '359', '14', 'Cunha', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2013', '359', '15', '1180 Concord Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2014', '359', '16', '2603075096', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2015', '361', '12', 'Bruna', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2016', '361', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2017', '361', '14', 'Sousa', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2018', '361', '15', '2573 Parkway Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2019', '361', '16', '6306764116', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2020', '363', '12', 'Kaue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2021', '363', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2022', '363', '14', 'Oliveira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2023', '363', '15', '3072 Hawks Nest Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2024', '363', '16', '8014761619', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2025', '365', '12', 'Caio', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2026', '365', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2027', '365', '14', 'Silva', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2028', '365', '15', '1417 Karen Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2029', '365', '16', '4178831795', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2030', '367', '12', 'Murilo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2031', '367', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2032', '367', '14', 'Cunha', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2033', '367', '15', '4625 Cessna Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2034', '367', '16', '9036367481', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2035', '369', '12', 'Fernanda', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2036', '369', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2037', '369', '14', 'Cardoso', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2038', '369', '15', '3809 Steele Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2039', '369', '16', '7575774415', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2040', '371', '12', 'Vinicius', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2041', '371', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2042', '371', '14', 'Azevedo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2043', '371', '15', '3099 White River Way', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2044', '371', '16', '4846710133', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2045', '373', '12', 'Rebeca', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2046', '373', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2047', '373', '14', 'Oliveira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2048', '373', '15', '15 Briarwood Road', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2049', '373', '16', '7016524974', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2050', '375', '12', 'Julieta', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2051', '375', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2052', '375', '14', 'Dias', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2053', '375', '15', '3513 Thrash Trail', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2054', '375', '16', '5085312029', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2055', '377', '12', 'Matheus', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2056', '377', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2057', '377', '14', 'Araujo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2058', '377', '15', '2878 Allison Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2059', '377', '16', '6262029477', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2060', '379', '12', 'Nicolash', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2061', '379', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2062', '379', '14', 'Castro', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2063', '379', '15', '1403 Bastin Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2064', '379', '16', '2607053999', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2065', '381', '12', 'Rafael', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2066', '381', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2067', '381', '14', 'Alves', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2068', '381', '15', '306 Hidden Meadow Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2069', '381', '16', '3143746446', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2070', '383', '12', 'Guilherme', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2071', '383', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2072', '383', '14', 'Ferreira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2073', '383', '15', '3472 Kovar Road', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2074', '383', '16', '5164232320', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2075', '385', '12', 'Kauan', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2076', '385', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2077', '385', '14', 'Santos', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2078', '385', '15', '3395 Rainbow Road', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2079', '385', '16', '4345823055', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2080', '387', '12', 'Julian', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2081', '387', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2082', '387', '14', 'Cavalcanti', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2083', '387', '15', '4054 Pearcy Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2084', '387', '16', '3042080094', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2085', '389', '12', 'Caua', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2086', '389', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2087', '389', '14', 'Pereira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2088', '389', '15', '676 Bruce Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2089', '389', '16', '3373045081', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2090', '391', '12', 'Thais', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2091', '391', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2092', '391', '14', 'Ferreira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2093', '391', '15', '3016 Gnatty Creek Road', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2094', '391', '16', '4066814745', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2095', '393', '12', 'Thais', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2096', '393', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2097', '393', '14', 'Pereira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2098', '393', '15', '4337 Queens Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2099', '393', '16', '3105664753', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2100', '395', '12', 'Tomas', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2101', '395', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2102', '395', '14', 'Goncalves', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2103', '395', '15', '1818 Tavern Place', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2104', '395', '16', '8026104060', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2105', '397', '12', 'Andre', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2106', '397', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2107', '397', '14', 'Fernandes', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2108', '397', '15', '3292 Willow Oaks Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2109', '397', '16', '8636091242', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2110', '399', '12', 'Felipe', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2111', '399', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2112', '399', '14', 'Ferreira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2113', '399', '15', '1294 Tibbs Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2114', '399', '16', '9529383180', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2115', '401', '12', 'Gustavo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2116', '401', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2117', '401', '14', 'Barbosa', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2118', '401', '15', '3393 Sumner Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2119', '401', '16', '6064639117', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2120', '403', '12', 'Nicolash', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2121', '403', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2122', '403', '14', 'Lima', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2123', '403', '15', '2446 Selah Way', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2124', '403', '16', '4143587297', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2125', '405', '12', 'Diego', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2126', '405', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2127', '405', '14', 'Cunha', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2128', '405', '15', '3881 Oakdale Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2129', '405', '16', '7655523753', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2130', '407', '12', 'Vitoria', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2131', '407', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2132', '407', '14', 'Azevedo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2133', '407', '15', '4127 Sycamore Fork Road', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2134', '407', '16', '6828418219', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2135', '409', '12', 'Mateus', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2136', '409', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2137', '409', '14', 'Ferreira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2138', '409', '15', '1520 Meadowcrest Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2139', '409', '16', '2195106037', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2140', '411', '12', 'Enzo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2141', '411', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2142', '411', '14', 'Souza', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2143', '411', '15', '4393 Johnny Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2144', '411', '16', '3602604974', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2145', '413', '12', 'Tania', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2146', '413', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2147', '413', '14', 'Santos', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2148', '413', '15', '385 Capitol Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2149', '413', '16', '2025581693', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2150', '415', '12', 'Nicolas', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2151', '415', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2152', '415', '14', 'Ribeiro', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2153', '415', '15', '2649 Sycamore Circle', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2154', '415', '16', '4435480016', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2155', '417', '12', 'Rebeca', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2156', '417', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2157', '417', '14', 'Lima', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2158', '417', '15', '1289 Parrill Court', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2159', '417', '16', '4015592403', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2160', '419', '12', 'Kauan', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2161', '419', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2162', '419', '14', 'Araujo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2163', '419', '15', '965 Chardonnay Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2164', '419', '16', '2024064718', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2165', '421', '12', 'Mateus', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2166', '421', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2167', '421', '14', 'Silva', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2168', '421', '15', '2734 Goldcliff Circle', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2169', '421', '16', '9737494754', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2170', '423', '12', 'Miguel', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2171', '423', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2172', '423', '14', 'Martins', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2173', '423', '15', '1143 Harron Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2174', '423', '16', '9102660503', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2175', '425', '12', 'Thiago', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2176', '425', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2177', '425', '14', 'Goncalves', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2178', '425', '15', '4627 Myra Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2179', '425', '16', '8162295022', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2180', '427', '12', 'Sophia', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2181', '427', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2182', '427', '14', 'Costa', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2183', '427', '15', '244 Rhode Island Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2184', '427', '16', '9177417125', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2185', '429', '12', 'Diogo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2186', '429', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2187', '429', '14', 'Lima', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2188', '429', '15', '2088 Spring Haven Trail', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2189', '429', '16', '6788045554', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2190', '431', '12', 'Laura', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2191', '431', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2192', '431', '14', 'Correia', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2193', '431', '15', '4582 Ray Court', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2194', '431', '16', '9895294996', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2195', '433', '12', 'Davi', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2196', '433', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2197', '433', '14', 'Pereira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2198', '433', '15', '2987 Nutter Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2199', '433', '16', '5635743818', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2200', '435', '12', 'Joao', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2201', '435', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2202', '435', '14', 'Castro', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2203', '435', '15', '4828 Settlers Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2204', '435', '16', '2519315347', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2205', '437', '12', 'Kaua', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2206', '437', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2207', '437', '14', 'Almeida', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2208', '437', '15', '1557 Edington Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2209', '437', '16', '6822925498', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2210', '439', '12', 'Erick', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2211', '439', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2212', '439', '14', 'Pinto', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2213', '439', '15', '3888 Robinson Court', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2214', '439', '16', '3038648510', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2215', '441', '12', 'Fabio', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2216', '441', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2217', '441', '14', 'Ribeiro', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2218', '441', '15', '1434 Summit Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2219', '441', '16', '2484899844', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2220', '443', '12', 'Daniel', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2221', '443', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2222', '443', '14', 'Correia', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2223', '443', '15', '1267 Joyce Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2224', '443', '16', '2709653680', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2225', '445', '12', 'Thiago', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2226', '445', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2227', '445', '14', 'Oliveira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2228', '445', '15', '2036 Sycamore Circle', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2229', '445', '16', '4044010282', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2230', '447', '12', 'Carlos', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2231', '447', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2232', '447', '14', 'Azevedo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2233', '447', '15', '2682 Roy Alley', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2234', '447', '16', '2482987687', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2235', '449', '12', 'Matheus', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2236', '449', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2237', '449', '14', 'Cunha', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2238', '449', '15', '2061 Bartlett Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2239', '449', '16', '2259321328', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2240', '451', '12', 'Samuel', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2241', '451', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2242', '451', '14', 'Gomes', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2243', '451', '15', '1806 Shady Pines Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2244', '451', '16', '9015346120', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2245', '453', '12', 'Jose', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2246', '453', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2247', '453', '14', 'Melo', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2248', '453', '15', '2450 College Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2249', '453', '16', '9122675548', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2250', '455', '12', 'Vitor', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2251', '455', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2252', '455', '14', 'Pereira', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2253', '455', '15', '581 Tennessee Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2254', '455', '16', '3145445393', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2255', '457', '12', 'Lucas', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2256', '457', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2257', '457', '14', 'Santos', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2258', '457', '15', '4969 Coventry Court', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2259', '457', '16', '5739458203', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2260', '459', '12', 'Nicolash', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2261', '459', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2262', '459', '14', 'Rodrigues', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2263', '459', '15', '2820 Lightning Point Drive', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2264', '459', '16', '8437651527', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2265', '461', '12', 'Matheus', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2266', '461', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2267', '461', '14', 'Castro', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2268', '461', '15', '2551 Austin Avenue', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2269', '461', '16', '7063277435', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2270', '463', '12', 'Rafael', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2271', '463', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2272', '463', '14', 'Rodrigues', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2273', '463', '15', '2959 Blane Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2274', '463', '16', '7084632716', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2275', '465', '12', 'Vinicius', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2276', '465', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2277', '465', '14', 'Barbosa', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2278', '465', '15', '3683 Sharon Lane', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2279', '465', '16', '6034859842', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2280', '467', '12', 'Vitor', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2281', '467', '13', NULL, '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2282', '467', '14', 'Sousa', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2283', '467', '15', '3086 Broadway Street', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2284', '467', '16', '2016102973', '12', NULL, NULL, NULL);
INSERT INTO `extra_user_datas` VALUES ('2285', '333', '12', 'Class 2', '12', '2023-11-21 05:28:30', '2023-11-21 05:28:30', NULL);
INSERT INTO `extra_user_datas` VALUES ('2286', '333', '13', NULL, '12', '2023-11-21 05:28:30', '2023-11-21 05:28:30', NULL);
INSERT INTO `extra_user_datas` VALUES ('2287', '333', '14', 'demo', '12', '2023-11-21 05:28:30', '2023-11-21 05:28:30', NULL);
INSERT INTO `extra_user_datas` VALUES ('2288', '334', '12', 'Class 2', '12', '2023-11-21 05:29:53', '2023-11-21 05:29:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('2289', '334', '13', NULL, '12', '2023-11-21 05:29:53', '2023-11-21 05:29:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('2290', '334', '14', 'demo', '12', '2023-11-21 05:29:53', '2023-11-21 05:29:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('2291', '335', '12', 'Class 2', '12', '2023-11-21 05:31:12', '2023-11-21 05:31:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('2292', '335', '13', NULL, '12', '2023-11-21 05:31:12', '2023-11-21 05:31:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('2293', '335', '14', 'demo', '12', '2023-11-21 05:31:12', '2023-11-21 05:31:12', NULL);
INSERT INTO `extra_user_datas` VALUES ('2294', '336', '12', NULL, '12', '2023-11-21 05:45:52', '2023-11-21 05:45:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('2295', '336', '13', NULL, '12', '2023-11-21 05:45:52', '2023-11-21 05:45:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('2296', '336', '14', NULL, '12', '2023-11-21 05:45:52', '2023-11-21 05:45:52', NULL);
INSERT INTO `extra_user_datas` VALUES ('2297', '337', '12', NULL, '12', '2023-11-21 05:46:15', '2023-11-21 05:46:15', NULL);
INSERT INTO `extra_user_datas` VALUES ('2298', '337', '13', NULL, '12', '2023-11-21 05:46:15', '2023-11-21 05:46:15', NULL);
INSERT INTO `extra_user_datas` VALUES ('2299', '337', '14', NULL, '12', '2023-11-21 05:46:15', '2023-11-21 05:46:15', NULL);
INSERT INTO `extra_user_datas` VALUES ('2309', '341', '12', NULL, '12', '2023-11-21 05:47:50', '2023-11-21 05:47:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('2310', '341', '13', NULL, '12', '2023-11-21 05:47:50', '2023-11-21 05:47:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('2311', '341', '14', NULL, '12', '2023-11-21 05:47:50', '2023-11-21 05:47:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('2312', '333', '12', NULL, '12', '2023-11-21 06:02:26', '2023-11-21 06:02:26', NULL);
INSERT INTO `extra_user_datas` VALUES ('2313', '333', '13', 'Hello', '12', '2023-11-21 06:02:26', '2023-11-21 06:02:26', NULL);
INSERT INTO `extra_user_datas` VALUES ('2314', '333', '14', NULL, '12', '2023-11-21 06:02:26', '2023-11-21 06:02:26', NULL);
INSERT INTO `extra_user_datas` VALUES ('2327', '467', '17', NULL, '12', '2023-11-21 06:44:00', '2023-11-21 06:44:00', NULL);
INSERT INTO `extra_user_datas` VALUES ('2328', '467', '18', NULL, '12', '2023-11-21 06:44:00', '2023-11-21 06:44:00', NULL);
INSERT INTO `extra_user_datas` VALUES ('2329', '465', '17', NULL, '12', '2023-11-21 06:44:11', '2023-11-21 06:44:11', NULL);
INSERT INTO `extra_user_datas` VALUES ('2330', '465', '18', NULL, '12', '2023-11-21 06:44:11', '2023-11-21 06:44:11', NULL);
INSERT INTO `extra_user_datas` VALUES ('2331', '463', '17', NULL, '12', '2023-11-21 06:44:20', '2023-11-21 06:56:15', NULL);
INSERT INTO `extra_user_datas` VALUES ('2332', '463', '18', NULL, '12', '2023-11-21 06:44:20', '2023-11-21 06:56:15', NULL);
INSERT INTO `extra_user_datas` VALUES ('2333', '1062', '17', NULL, '12', '2024-03-11 16:03:57', '2024-09-30 13:56:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('2334', '1062', '18', NULL, '12', '2024-03-11 16:03:57', '2024-09-30 13:56:53', NULL);
INSERT INTO `extra_user_datas` VALUES ('2335', '1060', '17', NULL, '12', '2024-03-11 16:04:17', '2024-03-11 16:04:17', NULL);
INSERT INTO `extra_user_datas` VALUES ('2336', '1060', '18', NULL, '12', '2024-03-11 16:04:17', '2024-03-11 16:04:17', NULL);
INSERT INTO `extra_user_datas` VALUES ('2337', '1058', '17', NULL, '12', '2024-03-11 16:04:34', '2024-03-11 16:04:34', NULL);
INSERT INTO `extra_user_datas` VALUES ('2338', '1058', '18', NULL, '12', '2024-03-11 16:04:34', '2024-03-11 16:04:34', NULL);
INSERT INTO `extra_user_datas` VALUES ('2339', '1056', '17', NULL, '12', '2024-03-11 16:04:50', '2024-03-11 16:04:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('2340', '1056', '18', NULL, '12', '2024-03-11 16:04:50', '2024-03-11 16:04:50', NULL);
INSERT INTO `extra_user_datas` VALUES ('2341', '1054', '17', NULL, '12', '2024-03-11 16:05:05', '2024-03-11 16:05:05', NULL);
INSERT INTO `extra_user_datas` VALUES ('2342', '1054', '18', NULL, '12', '2024-03-11 16:05:05', '2024-03-11 16:05:05', NULL);
INSERT INTO `extra_user_datas` VALUES ('2343', '1052', '17', NULL, '12', '2024-03-11 16:05:22', '2024-03-11 16:05:22', NULL);
INSERT INTO `extra_user_datas` VALUES ('2344', '1052', '18', NULL, '12', '2024-03-11 16:05:22', '2024-03-11 16:05:22', NULL);
INSERT INTO `extra_user_datas` VALUES ('2345', '1050', '17', NULL, '12', '2024-03-11 16:05:45', '2024-03-11 16:05:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('2346', '1050', '18', NULL, '12', '2024-03-11 16:05:45', '2024-03-11 16:05:45', NULL);
INSERT INTO `extra_user_datas` VALUES ('2347', '1048', '17', NULL, '12', '2024-03-11 16:05:57', '2024-03-11 16:05:57', NULL);
INSERT INTO `extra_user_datas` VALUES ('2348', '1048', '18', NULL, '12', '2024-03-11 16:05:57', '2024-03-11 16:05:57', NULL);
INSERT INTO `extra_user_datas` VALUES ('2349', '1046', '17', NULL, '12', '2024-03-11 16:06:14', '2024-03-11 16:06:14', NULL);
INSERT INTO `extra_user_datas` VALUES ('2350', '1046', '18', NULL, '12', '2024-03-11 16:06:14', '2024-03-11 16:06:14', NULL);
INSERT INTO `extra_user_datas` VALUES ('2351', '1044', '17', '1', '12', '2024-03-11 16:06:29', '2024-10-10 15:31:23', NULL);
INSERT INTO `extra_user_datas` VALUES ('2352', '1044', '18', '9515951595', '12', '2024-03-11 16:06:29', '2024-10-10 15:31:23', NULL);
INSERT INTO `extra_user_datas` VALUES ('2353', '331', '17', NULL, '12', '2024-09-30 13:52:58', '2024-09-30 13:56:39', NULL);
INSERT INTO `extra_user_datas` VALUES ('2354', '331', '18', NULL, '12', '2024-09-30 13:52:58', '2024-09-30 13:56:39', NULL);
INSERT INTO `extra_user_datas` VALUES ('2355', '1044', '12', 'Kamlesh', '12', '2024-10-10 15:31:07', '2024-10-10 15:31:23', NULL);

CREATE TABLE IF NOT EXISTS `faqs` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `title` varchar(191) NOT NULL,
  `description` text NOT NULL,
  `school_id` bigint(20) unsigned DEFAULT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `faqs_school_id_foreign` (`school_id`),
  CONSTRAINT `faqs_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=7 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `faqs` VALUES ('2', 'Waht is the the admission requirements?', 'Lorem ipsum dolor sit amet consectetur. Diam diam cras tristique varius. Sit lacus vitae augue nisl. Sed condimentum feugiat id ac ac orci massa consectetur urna.', '12', '2024-07-02 17:59:47', '2024-07-02 17:59:47');
INSERT INTO `faqs` VALUES ('3', 'What financial aid or scholarship options are available to students?', 'Lorem ipsum dolor sit amet consectetur. Diam diam cras tristique varius. Sit lacus vitae augue nisl. Sed condimentum feugiat id ac ac orci massa consectetur urna.', '12', '2024-07-02 18:00:02', '2024-07-02 18:00:02');
INSERT INTO `faqs` VALUES ('4', 'What kind of curriculum does School Name offer?', 'Lorem ipsum dolor sit amet consectetur. Diam diam cras tristique varius. Sit lacus vitae augue nisl. Sed condimentum feugiat id ac ac orci massa consectetur urna.', '12', '2024-07-02 18:00:12', '2024-07-02 18:00:12');
INSERT INTO `faqs` VALUES ('5', 'What extracurricular activities are available?', 'Lorem ipsum dolor sit amet consectetur. Diam diam cras tristique varius. Sit lacus vitae augue nisl. Sed condimentum feugiat id ac ac orci massa consectetur urna.', '12', '2024-07-02 18:00:21', '2024-07-02 18:00:21');
INSERT INTO `faqs` VALUES ('6', 'Does School offer financial aid?', 'Lorem ipsum dolor sit amet consectetur. Diam diam cras tristique varius. Sit lacus vitae augue nisl. Sed condimentum feugiat id ac ac orci massa consectetur urna.', '12', '2024-07-02 18:00:38', '2024-07-02 18:00:38');

CREATE TABLE IF NOT EXISTS `fees` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(191) NOT NULL,
  `due_date` date NOT NULL,
  `due_charges` double(8,2) NOT NULL COMMENT 'in percentage (%)',
  `due_charges_amount` double(8,2) NOT NULL,
  `class_id` bigint(20) unsigned NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `session_year_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `fees_session_year_id_foreign` (`session_year_id`),
  KEY `fees_school_id_foreign` (`school_id`),
  KEY `fees_class_id_foreign` (`class_id`),
  CONSTRAINT `fees_class_id_foreign` FOREIGN KEY (`class_id`) REFERENCES `classes` (`id`) ON DELETE CASCADE,
  CONSTRAINT `fees_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `fees_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=17 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `fees` VALUES ('1', '1 - English', '2024-01-31', '1', '60', '13', '12', '17', '2024-01-25 05:05:00', '2024-03-04 15:49:36', NULL);
INSERT INTO `fees` VALUES ('2', '2 - English', '2024-01-31', '1', '60', '14', '12', '17', '2024-01-25 05:05:00', '2024-03-04 15:49:36', NULL);
INSERT INTO `fees` VALUES ('3', '3 - English', '2024-01-31', '1', '60', '15', '12', '17', '2024-01-25 05:05:00', '2024-03-04 15:49:36', NULL);
INSERT INTO `fees` VALUES ('4', '4 - English', '2024-01-31', '1', '60', '16', '12', '17', '2024-01-25 05:05:00', '2024-03-04 15:49:36', NULL);
INSERT INTO `fees` VALUES ('5', '5 - English', '2024-01-31', '1', '60', '17', '12', '17', '2024-01-25 05:05:00', '2024-03-04 15:49:36', NULL);
INSERT INTO `fees` VALUES ('6', '6 - English', '2024-01-31', '1', '60', '18', '12', '17', '2024-01-25 05:05:00', '2024-03-04 15:49:36', NULL);
INSERT INTO `fees` VALUES ('7', '7 - English', '2024-01-31', '1', '60', '19', '12', '17', '2024-01-25 05:05:00', '2024-03-04 15:49:36', NULL);
INSERT INTO `fees` VALUES ('8', '8 - English', '2024-01-31', '1', '60', '20', '12', '17', '2024-01-25 05:05:00', '2024-03-04 15:49:36', NULL);
INSERT INTO `fees` VALUES ('9', '9 - English', '2024-01-31', '1', '60', '21', '12', '17', '2024-01-25 05:05:00', '2024-03-04 15:49:36', NULL);
INSERT INTO `fees` VALUES ('10', '10 - English', '2024-01-31', '1', '60', '23', '12', '17', '2024-01-25 05:05:00', '2024-03-04 15:49:36', NULL);
INSERT INTO `fees` VALUES ('11', '11 (Commerce)  - English', '2024-01-31', '1', '60', '24', '12', '17', '2024-01-25 05:05:00', '2024-03-04 15:49:36', NULL);
INSERT INTO `fees` VALUES ('12', '11 (Arts)  - English', '2024-01-31', '1', '60', '25', '12', '17', '2024-01-25 05:05:00', '2024-03-04 15:49:36', NULL);
INSERT INTO `fees` VALUES ('13', '11 (Science)  - English', '2024-01-31', '1', '60', '26', '12', '17', '2024-01-25 05:05:01', '2024-03-04 15:49:36', NULL);
INSERT INTO `fees` VALUES ('14', '12 (Commerce)  - English', '2024-01-31', '1', '60', '27', '12', '17', '2024-01-25 05:05:01', '2024-03-04 15:49:36', NULL);
INSERT INTO `fees` VALUES ('15', '12 (Arts)  - English', '2024-01-31', '1', '60', '28', '12', '17', '2024-01-25 05:05:01', '2024-03-04 15:49:36', NULL);
INSERT INTO `fees` VALUES ('16', '12 (Science)  - English', '2024-01-31', '1', '60', '29', '12', '17', '2024-01-25 05:05:01', '2024-03-04 15:49:36', NULL);

CREATE TABLE IF NOT EXISTS `fees_advance` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `compulsory_fee_id` bigint(20) unsigned NOT NULL,
  `student_id` bigint(20) unsigned NOT NULL COMMENT 'user_id',
  `parent_id` bigint(20) unsigned NOT NULL COMMENT 'user_id',
  `amount` double(8,2) NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `fees_advance_compulsory_fee_id_foreign` (`compulsory_fee_id`),
  KEY `fees_advance_student_id_foreign` (`student_id`),
  KEY `fees_advance_parent_id_foreign` (`parent_id`),
  CONSTRAINT `fees_advance_compulsory_fee_id_foreign` FOREIGN KEY (`compulsory_fee_id`) REFERENCES `compulsory_fees` (`id`) ON DELETE CASCADE,
  CONSTRAINT `fees_advance_parent_id_foreign` FOREIGN KEY (`parent_id`) REFERENCES `users` (`id`) ON DELETE CASCADE,
  CONSTRAINT `fees_advance_student_id_foreign` FOREIGN KEY (`student_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `fees_advance` VALUES ('1', '2', '331', '330', '500', '2024-01-24 23:42:31', '2024-01-24 23:42:31');

CREATE TABLE IF NOT EXISTS `fees_class_types` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `class_id` bigint(20) unsigned NOT NULL,
  `fees_id` bigint(20) unsigned NOT NULL,
  `fees_type_id` bigint(20) unsigned NOT NULL,
  `amount` double(64,2) NOT NULL,
  `optional` tinyint(1) NOT NULL COMMENT '0 - No, 1 - Yes',
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `unique_ids` (`class_id`,`fees_type_id`,`school_id`,`fees_id`),
  KEY `fees_class_types_fees_id_foreign` (`fees_id`),
  KEY `fees_class_types_fees_type_id_foreign` (`fees_type_id`),
  KEY `fees_class_types_school_id_foreign` (`school_id`),
  CONSTRAINT `fees_class_types_class_id_foreign` FOREIGN KEY (`class_id`) REFERENCES `classes` (`id`) ON DELETE CASCADE,
  CONSTRAINT `fees_class_types_fees_id_foreign` FOREIGN KEY (`fees_id`) REFERENCES `fees` (`id`) ON DELETE CASCADE,
  CONSTRAINT `fees_class_types_fees_type_id_foreign` FOREIGN KEY (`fees_type_id`) REFERENCES `fees_types` (`id`) ON DELETE CASCADE,
  CONSTRAINT `fees_class_types_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=65 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `fees_class_types` VALUES ('1', '13', '1', '2', '5000', '0', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('2', '13', '1', '1', '1000', '0', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('3', '13', '1', '3', '1000', '1', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('4', '13', '1', '4', '5000', '1', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('5', '14', '2', '2', '5000', '0', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('6', '14', '2', '1', '1000', '0', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('7', '14', '2', '3', '1000', '1', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('8', '14', '2', '4', '5000', '1', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('9', '15', '3', '2', '5000', '0', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('10', '15', '3', '1', '1000', '0', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('11', '15', '3', '3', '1000', '1', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('12', '15', '3', '4', '5000', '1', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('13', '16', '4', '2', '5000', '0', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('14', '16', '4', '1', '1000', '0', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('15', '16', '4', '3', '1000', '1', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('16', '16', '4', '4', '5000', '1', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('17', '17', '5', '2', '5000', '0', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('18', '17', '5', '1', '1000', '0', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('19', '17', '5', '3', '1000', '1', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('20', '17', '5', '4', '5000', '1', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('21', '18', '6', '2', '5000', '0', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('22', '18', '6', '1', '1000', '0', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('23', '18', '6', '3', '1000', '1', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('24', '18', '6', '4', '5000', '1', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('25', '19', '7', '2', '5000', '0', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('26', '19', '7', '1', '1000', '0', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('27', '19', '7', '3', '1000', '1', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('28', '19', '7', '4', '5000', '1', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('29', '20', '8', '2', '5000', '0', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('30', '20', '8', '1', '1000', '0', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('31', '20', '8', '3', '1000', '1', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('32', '20', '8', '4', '5000', '1', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('33', '21', '9', '2', '5000', '0', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('34', '21', '9', '1', '1000', '0', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('35', '21', '9', '3', '1000', '1', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('36', '21', '9', '4', '5000', '1', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('37', '23', '10', '2', '5000', '0', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('38', '23', '10', '1', '1000', '0', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('39', '23', '10', '3', '1000', '1', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('40', '23', '10', '4', '5000', '1', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('41', '24', '11', '2', '5000', '0', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('42', '24', '11', '1', '1000', '0', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('43', '24', '11', '3', '1000', '1', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('44', '24', '11', '4', '5000', '1', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_class_types` VALUES ('45', '25', '12', '2', '5000', '0', '12', '2024-01-25 05:05:01', '2024-01-25 05:05:01');
INSERT INTO `fees_class_types` VALUES ('46', '25', '12', '1', '1000', '0', '12', '2024-01-25 05:05:01', '2024-01-25 05:05:01');
INSERT INTO `fees_class_types` VALUES ('47', '25', '12', '3', '1000', '1', '12', '2024-01-25 05:05:01', '2024-01-25 05:05:01');
INSERT INTO `fees_class_types` VALUES ('48', '25', '12', '4', '5000', '1', '12', '2024-01-25 05:05:01', '2024-01-25 05:05:01');
INSERT INTO `fees_class_types` VALUES ('49', '26', '13', '2', '5000', '0', '12', '2024-01-25 05:05:01', '2024-01-25 05:05:01');
INSERT INTO `fees_class_types` VALUES ('50', '26', '13', '1', '1000', '0', '12', '2024-01-25 05:05:01', '2024-01-25 05:05:01');
INSERT INTO `fees_class_types` VALUES ('51', '26', '13', '3', '1000', '1', '12', '2024-01-25 05:05:01', '2024-01-25 05:05:01');
INSERT INTO `fees_class_types` VALUES ('52', '26', '13', '4', '5000', '1', '12', '2024-01-25 05:05:01', '2024-01-25 05:05:01');
INSERT INTO `fees_class_types` VALUES ('53', '27', '14', '2', '5000', '0', '12', '2024-01-25 05:05:01', '2024-01-25 05:05:01');
INSERT INTO `fees_class_types` VALUES ('54', '27', '14', '1', '1000', '0', '12', '2024-01-25 05:05:01', '2024-01-25 05:05:01');
INSERT INTO `fees_class_types` VALUES ('55', '27', '14', '3', '1000', '1', '12', '2024-01-25 05:05:01', '2024-01-25 05:05:01');
INSERT INTO `fees_class_types` VALUES ('56', '27', '14', '4', '5000', '1', '12', '2024-01-25 05:05:01', '2024-01-25 05:05:01');
INSERT INTO `fees_class_types` VALUES ('57', '28', '15', '2', '5000', '0', '12', '2024-01-25 05:05:01', '2024-01-25 05:05:01');
INSERT INTO `fees_class_types` VALUES ('58', '28', '15', '1', '1000', '0', '12', '2024-01-25 05:05:01', '2024-01-25 05:05:01');
INSERT INTO `fees_class_types` VALUES ('59', '28', '15', '3', '1000', '1', '12', '2024-01-25 05:05:01', '2024-01-25 05:05:01');
INSERT INTO `fees_class_types` VALUES ('60', '28', '15', '4', '5000', '1', '12', '2024-01-25 05:05:01', '2024-01-25 05:05:01');
INSERT INTO `fees_class_types` VALUES ('61', '29', '16', '2', '5000', '0', '12', '2024-01-25 05:05:01', '2024-01-25 05:05:01');
INSERT INTO `fees_class_types` VALUES ('62', '29', '16', '1', '1000', '0', '12', '2024-01-25 05:05:01', '2024-01-25 05:05:01');
INSERT INTO `fees_class_types` VALUES ('63', '29', '16', '3', '1000', '1', '12', '2024-01-25 05:05:01', '2024-01-25 05:05:01');
INSERT INTO `fees_class_types` VALUES ('64', '29', '16', '4', '5000', '1', '12', '2024-01-25 05:05:01', '2024-01-25 05:05:01');

CREATE TABLE IF NOT EXISTS `fees_installments` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(191) NOT NULL,
  `due_date` date NOT NULL,
  `due_charges_type` enum('fixed','percentage') NOT NULL DEFAULT 'percentage',
  `due_charges` int(11) NOT NULL,
  `fees_id` bigint(20) unsigned NOT NULL,
  `session_year_id` bigint(20) unsigned NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `fees_installments_fees_id_foreign` (`fees_id`),
  KEY `fees_installments_session_year_id_foreign` (`session_year_id`),
  KEY `fees_installments_school_id_foreign` (`school_id`),
  CONSTRAINT `fees_installments_fees_id_foreign` FOREIGN KEY (`fees_id`) REFERENCES `fees` (`id`) ON DELETE CASCADE,
  CONSTRAINT `fees_installments_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `fees_installments_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=49 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `fees_installments` VALUES ('1', 'Installment 1', '2024-01-31', 'percentage', '2', '1', '17', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_installments` VALUES ('2', 'Installment 2', '2024-02-29', 'percentage', '2', '1', '17', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_installments` VALUES ('3', 'Installment 3', '2024-03-29', 'percentage', '2', '1', '17', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_installments` VALUES ('4', 'Installment 1', '2024-01-31', 'percentage', '2', '2', '17', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_installments` VALUES ('5', 'Installment 2', '2024-02-29', 'percentage', '2', '2', '17', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_installments` VALUES ('6', 'Installment 3', '2024-03-29', 'percentage', '2', '2', '17', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_installments` VALUES ('7', 'Installment 1', '2024-01-31', 'percentage', '2', '3', '17', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_installments` VALUES ('8', 'Installment 2', '2024-02-29', 'percentage', '2', '3', '17', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_installments` VALUES ('9', 'Installment 3', '2024-03-29', 'percentage', '2', '3', '17', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_installments` VALUES ('10', 'Installment 1', '2024-01-31', 'percentage', '2', '4', '17', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_installments` VALUES ('11', 'Installment 2', '2024-02-29', 'percentage', '2', '4', '17', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_installments` VALUES ('12', 'Installment 3', '2024-03-29', 'percentage', '2', '4', '17', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_installments` VALUES ('13', 'Installment 1', '2024-01-31', 'percentage', '2', '5', '17', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_installments` VALUES ('14', 'Installment 2', '2024-02-29', 'percentage', '2', '5', '17', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_installments` VALUES ('15', 'Installment 3', '2024-03-29', 'percentage', '2', '5', '17', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_installments` VALUES ('16', 'Installment 1', '2024-01-31', 'percentage', '2', '6', '17', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_installments` VALUES ('17', 'Installment 2', '2024-02-29', 'percentage', '2', '6', '17', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_installments` VALUES ('18', 'Installment 3', '2024-03-29', 'percentage', '2', '6', '17', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_installments` VALUES ('19', 'Installment 1', '2024-01-31', 'percentage', '2', '7', '17', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_installments` VALUES ('20', 'Installment 2', '2024-02-29', 'percentage', '2', '7', '17', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_installments` VALUES ('21', 'Installment 3', '2024-03-29', 'percentage', '2', '7', '17', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_installments` VALUES ('22', 'Installment 1', '2024-01-31', 'percentage', '2', '8', '17', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_installments` VALUES ('23', 'Installment 2', '2024-02-29', 'percentage', '2', '8', '17', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_installments` VALUES ('24', 'Installment 3', '2024-03-29', 'percentage', '2', '8', '17', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_installments` VALUES ('25', 'Installment 1', '2024-01-31', 'percentage', '2', '9', '17', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_installments` VALUES ('26', 'Installment 2', '2024-02-29', 'percentage', '2', '9', '17', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_installments` VALUES ('27', 'Installment 3', '2024-03-29', 'percentage', '2', '9', '17', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_installments` VALUES ('28', 'Installment 1', '2024-01-31', 'percentage', '2', '10', '17', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_installments` VALUES ('29', 'Installment 2', '2024-02-29', 'percentage', '2', '10', '17', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_installments` VALUES ('30', 'Installment 3', '2024-03-29', 'percentage', '2', '10', '17', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_installments` VALUES ('31', 'Installment 1', '2024-01-31', 'percentage', '2', '11', '17', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_installments` VALUES ('32', 'Installment 2', '2024-02-29', 'percentage', '2', '11', '17', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_installments` VALUES ('33', 'Installment 3', '2024-03-29', 'percentage', '2', '11', '17', '12', '2024-01-25 05:05:00', '2024-01-25 05:05:00');
INSERT INTO `fees_installments` VALUES ('34', 'Installment 1', '2024-01-31', 'percentage', '2', '12', '17', '12', '2024-01-25 05:05:01', '2024-01-25 05:05:01');
INSERT INTO `fees_installments` VALUES ('35', 'Installment 2', '2024-02-29', 'percentage', '2', '12', '17', '12', '2024-01-25 05:05:01', '2024-01-25 05:05:01');
INSERT INTO `fees_installments` VALUES ('36', 'Installment 3', '2024-03-29', 'percentage', '2', '12', '17', '12', '2024-01-25 05:05:01', '2024-01-25 05:05:01');
INSERT INTO `fees_installments` VALUES ('37', 'Installment 1', '2024-01-31', 'percentage', '2', '13', '17', '12', '2024-01-25 05:05:01', '2024-01-25 05:05:01');
INSERT INTO `fees_installments` VALUES ('38', 'Installment 2', '2024-02-29', 'percentage', '2', '13', '17', '12', '2024-01-25 05:05:01', '2024-01-25 05:05:01');
INSERT INTO `fees_installments` VALUES ('39', 'Installment 3', '2024-03-29', 'percentage', '2', '13', '17', '12', '2024-01-25 05:05:01', '2024-01-25 05:05:01');
INSERT INTO `fees_installments` VALUES ('40', 'Installment 1', '2024-01-31', 'percentage', '2', '14', '17', '12', '2024-01-25 05:05:01', '2024-01-25 05:05:01');
INSERT INTO `fees_installments` VALUES ('41', 'Installment 2', '2024-02-29', 'percentage', '2', '14', '17', '12', '2024-01-25 05:05:01', '2024-01-25 05:05:01');
INSERT INTO `fees_installments` VALUES ('42', 'Installment 3', '2024-03-29', 'percentage', '2', '14', '17', '12', '2024-01-25 05:05:01', '2024-01-25 05:05:01');
INSERT INTO `fees_installments` VALUES ('43', 'Installment 1', '2024-01-31', 'percentage', '2', '15', '17', '12', '2024-01-25 05:05:01', '2024-01-25 05:05:01');
INSERT INTO `fees_installments` VALUES ('44', 'Installment 2', '2024-02-29', 'percentage', '2', '15', '17', '12', '2024-01-25 05:05:01', '2024-01-25 05:05:01');
INSERT INTO `fees_installments` VALUES ('45', 'Installment 3', '2024-03-29', 'percentage', '2', '15', '17', '12', '2024-01-25 05:05:01', '2024-01-25 05:05:01');
INSERT INTO `fees_installments` VALUES ('46', 'Installment 1', '2024-01-31', 'percentage', '2', '16', '17', '12', '2024-01-25 05:05:01', '2024-01-25 05:05:01');
INSERT INTO `fees_installments` VALUES ('47', 'Installment 2', '2024-02-29', 'percentage', '2', '16', '17', '12', '2024-01-25 05:05:01', '2024-01-25 05:05:01');
INSERT INTO `fees_installments` VALUES ('48', 'Installment 3', '2024-03-29', 'percentage', '2', '16', '17', '12', '2024-01-25 05:05:01', '2024-01-25 05:05:01');

CREATE TABLE IF NOT EXISTS `fees_paids` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `fees_id` bigint(20) unsigned NOT NULL,
  `student_id` bigint(20) unsigned NOT NULL COMMENT 'user_id',
  `is_fully_paid` tinyint(1) NOT NULL COMMENT '0 - No, 1 - Yes',
  `is_used_installment` tinyint(1) NOT NULL COMMENT '0 - No, 1 - Yes',
  `amount` double(8,2) NOT NULL,
  `date` date NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `unique_ids` (`student_id`,`fees_id`,`school_id`),
  KEY `fees_paids_school_id_foreign` (`school_id`),
  KEY `fees_paids_fees_id_foreign` (`fees_id`),
  CONSTRAINT `fees_paids_fees_id_foreign` FOREIGN KEY (`fees_id`) REFERENCES `fees` (`id`) ON DELETE CASCADE,
  CONSTRAINT `fees_paids_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `fees_paids_student_id_foreign` FOREIGN KEY (`student_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=12 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `fees_paids` VALUES ('1', '1', '331', '0', '1', '13000', '2024-01-25', '12', '2024-01-25 05:11:56', '2024-01-25 05:12:48', NULL);
INSERT INTO `fees_paids` VALUES ('2', '1', '467', '1', '0', '6000', '2024-05-14', '12', '2024-05-14 12:46:52', '2024-05-14 12:46:52', NULL);
INSERT INTO `fees_paids` VALUES ('3', '1', '465', '1', '0', '6000', '2024-05-14', '12', '2024-05-14 12:47:11', '2024-05-14 12:47:11', NULL);
INSERT INTO `fees_paids` VALUES ('4', '1', '463', '1', '0', '6000', '2024-05-14', '12', '2024-05-14 12:47:35', '2024-05-14 12:47:35', NULL);
INSERT INTO `fees_paids` VALUES ('5', '1', '461', '1', '0', '6000', '2024-05-14', '12', '2024-05-14 12:47:50', '2024-05-14 12:47:50', NULL);
INSERT INTO `fees_paids` VALUES ('6', '1', '459', '0', '1', '2000', '2024-05-14', '12', '2024-05-14 12:48:12', '2024-05-14 12:48:12', NULL);
INSERT INTO `fees_paids` VALUES ('7', '1', '457', '0', '1', '2000', '2024-05-14', '12', '2024-05-14 12:48:39', '2024-05-14 12:48:39', NULL);
INSERT INTO `fees_paids` VALUES ('8', '1', '455', '1', '0', '6000', '2024-05-14', '12', '2024-05-14 12:58:28', '2024-05-14 12:58:28', NULL);
INSERT INTO `fees_paids` VALUES ('9', '1', '453', '1', '0', '6000', '2024-05-14', '12', '2024-05-14 12:58:41', '2024-05-14 12:58:41', NULL);
INSERT INTO `fees_paids` VALUES ('10', '1', '451', '1', '0', '6000', '2024-05-14', '12', '2024-05-14 12:58:53', '2024-05-14 12:58:53', NULL);
INSERT INTO `fees_paids` VALUES ('11', '1', '449', '1', '0', '6000', '2024-05-14', '12', '2024-05-14 12:59:07', '2024-05-14 12:59:07', NULL);

CREATE TABLE IF NOT EXISTS `fees_types` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(191) NOT NULL,
  `description` varchar(191) DEFAULT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `fees_types_school_id_foreign` (`school_id`),
  CONSTRAINT `fees_types_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=5 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `fees_types` VALUES ('1', 'Library Fees', NULL, '12', '2024-01-25 05:03:13', '2024-01-25 05:03:13', NULL);
INSERT INTO `fees_types` VALUES ('2', 'Education Fees', NULL, '12', '2024-01-25 05:03:22', '2024-01-25 05:03:22', NULL);
INSERT INTO `fees_types` VALUES ('3', 'Sports Fees', NULL, '12', '2024-01-25 05:03:28', '2024-01-25 05:03:28', NULL);
INSERT INTO `fees_types` VALUES ('4', 'Gym Fees', NULL, '12', '2024-01-25 05:03:32', '2024-01-25 05:03:32', NULL);

CREATE TABLE IF NOT EXISTS `files` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `modal_type` varchar(191) NOT NULL,
  `modal_id` bigint(20) unsigned NOT NULL,
  `file_name` varchar(1024) DEFAULT NULL,
  `file_thumbnail` varchar(1024) DEFAULT NULL,
  `type` tinytext NOT NULL COMMENT '1 = File Upload, 2 = Youtube Link, 3 = Video Upload, 4 = Other Link',
  `file_url` varchar(1024) NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `files_modal_type_modal_id_index` (`modal_type`,`modal_id`),
  KEY `files_school_id_foreign` (`school_id`),
  CONSTRAINT `files_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=113 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `files` VALUES ('16', 'App\\Models\\AssignmentSubmission', '4', '67792at-min.jpg', NULL, '1', '12/files/655c75b0f28d03.159149031700558256.jpg', '12', '2023-11-21 09:17:36', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('30', 'App\\Models\\Gallery', '1', 'leftBigImg', NULL, '1', '12/files/6683f3a7205322.051827591719923623.png', '12', '2024-07-02 18:03:43', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('31', 'App\\Models\\Gallery', '1', 'charming-girl-chistmas-tree', NULL, '1', '12/files/6684d4df838a59.929993701719981279.jpg', '12', '2024-07-03 10:04:39', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('32', 'App\\Models\\Gallery', '1', 'christmas-childhood-people-concept-smiling-with-santa-claus-background', NULL, '1', '12/files/6684d4df8b4a33.744638821719981279.jpg', '12', '2024-07-03 10:04:39', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('33', 'App\\Models\\Gallery', '1', 'happy-kid-with-christmas-gift-boxes-with-decorated-christmas-tree-room', NULL, '1', '12/files/6684d4df8ed175.092001841719981279.jpg', '12', '2024-07-03 10:04:39', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('34', 'App\\Models\\Gallery', '1', 'santa-claus-giving-gifts-christmas', NULL, '1', '12/files/6684d4df925b15.691461391719981279.jpg', '12', '2024-07-03 10:04:39', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('35', 'App\\Models\\Gallery', '2', '3d-illustration-dining-room-decorated-with-colorful-paper-garlands', NULL, '1', '12/files/6684d5127da167.792467231719981330.jpg', '12', '2024-07-03 10:05:30', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('36', 'App\\Models\\Gallery', '2', 'beautiful-christmas-tree-decorating-concept', NULL, '1', '12/files/6684d512856d87.942997771719981330.jpg', '12', '2024-07-03 10:05:30', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('37', 'App\\Models\\Gallery', '2', 'cute-little-girl-playing-with-colorful-paper-sheets-playroom', NULL, '1', '12/files/6684d512895996.130078911719981330.jpg', '12', '2024-07-03 10:05:30', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('38', 'App\\Models\\Gallery', '2', 'girls-throwing-paper-pieces-each-other', NULL, '1', '12/files/6684d5128cae50.309673211719981330.jpg', '12', '2024-07-03 10:05:30', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('39', 'App\\Models\\Gallery', '4', 'Generative Fill', NULL, '1', '12/files/6684d53e7328b2.279165301719981374.jpg', '12', '2024-07-03 10:06:14', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('40', 'App\\Models\\Gallery', '4', 'Generative Fill 2', NULL, '1', '12/files/6684d53e7c3b46.830400231719981374.jpg', '12', '2024-07-03 10:06:14', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('41', 'App\\Models\\Gallery', '4', 'Generative Fill 3', NULL, '1', '12/files/6684d53e7fd742.071394691719981374.jpg', '12', '2024-07-03 10:06:14', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('42', 'App\\Models\\Gallery', '4', 'Generative Fill 4', NULL, '1', '12/files/6684d53e836249.068492721719981374.jpg', '12', '2024-07-03 10:06:14', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('43', 'App\\Models\\Gallery', '4', 'Generative Fill 5', NULL, '1', '12/files/6684d53e86d0f6.709998891719981374.jpg', '12', '2024-07-03 10:06:14', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('44', 'App\\Models\\Gallery', '5', 'happy-holi', NULL, '1', '12/files/6684d5564beea5.049495781719981398.jpg', '12', '2024-07-03 10:06:38', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('45', 'App\\Models\\Gallery', '5', 'happy-holi-holi-celebration', NULL, '1', '12/files/6684d556539595.846449691719981398.jpg', '12', '2024-07-03 10:06:38', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('46', 'App\\Models\\Gallery', '5', 'kids-playing-holi', NULL, '1', '12/files/6684d556576e01.461405291719981398.jpg', '12', '2024-07-03 10:06:38', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('47', 'App\\Models\\Gallery', '5', 'portrait-friends-celebrating-holi-faces-covered-bright-colors-holi-powders', NULL, '1', '12/files/6684d5565aeab5.712236251719981398.jpg', '12', '2024-07-03 10:06:38', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('48', 'App\\Models\\Gallery', '5', 'portrait-girl-blowing-confetti', NULL, '1', '12/files/6684d5565f8e89.645935371719981398.jpg', '12', '2024-07-03 10:06:38', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('49', 'App\\Models\\Gallery', '5', 'portrait-indian-woman-with-colored-powder-face-celebrating-happy-holi-party', NULL, '1', '12/files/6684d556629b63.140120211719981398.jpg', '12', '2024-07-03 10:06:38', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('50', 'App\\Models\\Gallery', '6', 'i1', NULL, '1', '12/files/6684d570844d63.200503241719981424.jpg', '12', '2024-07-03 10:07:04', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('51', 'App\\Models\\Gallery', '6', 'i2', NULL, '1', '12/files/6684d5708b7704.970934111719981424.jpg', '12', '2024-07-03 10:07:04', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('52', 'App\\Models\\Gallery', '6', 'i3', NULL, '1', '12/files/6684d5708fa0a6.674848611719981424.jpg', '12', '2024-07-03 10:07:04', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('53', 'App\\Models\\Gallery', '6', 'i4', NULL, '1', '12/files/6684d5709333e7.993416541719981424.jpg', '12', '2024-07-03 10:07:04', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('54', 'App\\Models\\Gallery', '7', 'beautiful-young-girl-playing-violin-with-rapt-intensity', NULL, '1', '12/files/6684d58c9ec728.928675431719981452.jpg', '12', '2024-07-03 10:07:32', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('55', 'App\\Models\\Gallery', '7', 'choir-rehearsing-with-fervor-music-teacher-s-guidance', NULL, '1', '12/files/6684d58ca7c939.405427761719981452.jpg', '12', '2024-07-03 10:07:32', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('56', 'App\\Models\\Gallery', '7', 'elementary-school-focus-kids-photo', NULL, '1', '12/files/6684d58cac85b4.121460281719981452.jpg', '12', '2024-07-03 10:07:32', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('57', 'App\\Models\\Gallery', '7', 'female-violinist-playing-violin-nightclub', NULL, '1', '12/files/6684d58cb13783.790293451719981452.jpg', '12', '2024-07-03 10:07:32', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('58', 'App\\Models\\Gallery', '7', 'kids-performing-play-stage-word-theatre-day', NULL, '1', '12/files/6684d58cb588b3.549634411719981452.jpg', '12', '2024-07-03 10:07:32', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('59', 'App\\Models\\Gallery', '7', 'male-singer-stage', NULL, '1', '12/files/6684d58cb985c2.599718281719981452.jpg', '12', '2024-07-03 10:07:32', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('60', 'App\\Models\\Gallery', '7', 'male-singer-stage (1)', NULL, '1', '12/files/6684d58cbcd235.171573891719981452.jpg', '12', '2024-07-03 10:07:32', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('61', 'App\\Models\\Gallery', '7', 'young-kids-performing-play-theatre-stage-celebrate-world-theatre-day', NULL, '1', '12/files/6684d58cc02ad3.798371381719981452.jpg', '12', '2024-07-03 10:07:32', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('62', 'App\\Models\\Gallery', '3', 'amateur-football-concept', NULL, '1', '12/files/6684d5d31664e8.380096221719981523.jpg', '12', '2024-07-03 10:08:43', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('63', 'App\\Models\\Gallery', '3', 'big-trophy-women-s-football-matches', NULL, '1', '12/files/6684d5d31b7a37.221632441719981523.jpg', '12', '2024-07-03 10:08:43', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('64', 'App\\Models\\Gallery', '3', 'girl-covering-her-friend-eyes-holding-badminton', NULL, '1', '12/files/6684d5d31f6df7.479116251719981523.jpg', '12', '2024-07-03 10:08:43', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('65', 'App\\Models\\Gallery', '3', 'medium-shot-women-holding-prize', NULL, '1', '12/files/6684d5d32351b8.925446091719981523.jpg', '12', '2024-07-03 10:08:43', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('66', 'App\\Models\\Gallery', '3', 'physical-education-activity-teacher-orchestrates-energetic-outdoor-exercise-class', NULL, '1', '12/files/6684d5d326fcb2.296333701719981523.jpg', '12', '2024-07-03 10:08:43', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('67', 'App\\Models\\Gallery', '3', 'portrait-cute-girl-playing-badminton', NULL, '1', '12/files/6684d5d32aba07.212505931719981523.jpg', '12', '2024-07-03 10:08:43', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('68', 'App\\Models\\Lesson', '8', 'FIle 1', NULL, '1', '12/files/66951287a9c3f2.406109411721045639.png', '12', '2024-07-15 17:44:00', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('69', 'App\\Models\\Lesson', '9', 'FIle 1', NULL, '1', '12/files/669512b81349f2.781304051721045688.png', '12', '2024-07-15 17:44:48', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('70', 'App\\Models\\Lesson', '10', 'Link 1', '12/files/6695f7edbe3df0.248114461721104365.png', '2', 'https://www.youtube.com/watch?v=p0-2yNVsBDg&pp=ygUQZW5nbGlzaCBsZXNzb24gMQ%3D%3D', '12', '2024-07-16 10:02:46', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('71', 'App\\Models\\Lesson', '10', 'File 1', NULL, '1', '12/files/6695f7ee235002.661351811721104366.jpg', '12', '2024-07-16 10:02:46', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('72', 'App\\Models\\Announcement', '24', 'english.png', NULL, '1', '12/files/6695f8580bd5c6.815022481721104472.png', '12', '2024-07-16 10:04:32', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('73', 'App\\Models\\LessonTopic', '5', 'FIle 1', NULL, '1', '12/files/6695f8a7b5d4f1.037624491721104551.png', '12', '2024-07-16 10:05:52', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('74', 'App\\Models\\LessonTopic', '5', 'File 1', NULL, '1', '12/files/6695f8a817aa72.752848931721104552.jpg', '12', '2024-07-16 10:05:52', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('75', 'App\\Models\\LessonTopic', '5', 'Link 1', '12/files/6695f8a818ea49.765828811721104552.jpg', '2', 'https://www.youtube.com/watch?v=jjB63DDXE4I', '12', '2024-07-16 10:05:52', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('76', 'App\\Models\\Assignment', '14', 'english.png', NULL, '1', '12/files/6695f9cd2b7af5.476977751721104845.png', '12', '2024-07-16 10:10:45', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('77', 'App\\Models\\Assignment', '15', 'maths-book.jpg', NULL, '1', '12/files/669605290f8884.751270971721107753.jpg', '12', '2024-07-16 10:59:13', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('78', 'App\\Models\\Announcement', '25', 'event.png', NULL, '1', '12/files/669605a57cfe14.706034681721107877.png', '12', '2024-07-16 11:01:17', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('79', 'App\\Models\\Announcement', '26', 'english.png', NULL, '1', '12/files/66978f76de5160.892905431721208694.png', '12', '2024-07-17 15:01:35', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('80', 'App\\Models\\Announcement', '27', 'event.png', NULL, '1', '12/files/66978fb6cb5301.771806861721208758.png', '12', '2024-07-17 15:02:38', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('81', 'App\\Models\\Announcement', '28', 'music.png', NULL, '1', '12/files/66978fd64318e1.240539001721208790.png', '12', '2024-07-17 15:03:10', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('82', 'App\\Models\\Assignment', '17', 'english.png', NULL, '1', '12/files/669794b92a9c38.486559291721210041.png', '12', '2024-07-17 15:24:01', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('83', 'App\\Models\\AssignmentSubmission', '6', 'Screenshot_2024-07-17-15-21-36-750_com.wrteam.saas.school.jpg', NULL, '1', '12/files/669794dc325530.975058781721210076.jpg', '12', '2024-07-17 15:24:36', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('84', 'App\\Models\\AssignmentSubmission', '7', 'Screenshot_2024-07-17-15-17-16-671_com.wrteam.saas.school.jpg', NULL, '1', '12/files/669794f0477376.831194561721210096.jpg', '12', '2024-07-17 15:24:56', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('85', 'App\\Models\\Assignment', '18', 'maths-book.jpg', NULL, '1', '12/files/669794fa8b2bd1.722209991721210106.jpg', '12', '2024-07-17 15:25:06', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('86', 'App\\Models\\AssignmentSubmission', '8', 'Screenshot_2024-07-17-15-17-16-671_com.wrteam.saas.school.jpg', NULL, '1', '12/files/6697951952aea9.573248971721210137.jpg', '12', '2024-07-17 15:25:37', '2024-09-30 13:04:19', NULL);
INSERT INTO `files` VALUES ('87', 'App\\Models\\Assignment', '20', 'IMG_7398.jpg', NULL, '1', '12/files/670ef26c096447.642315241729032812.jpg', '12', '2024-10-16 04:23:32', '2024-10-16 04:23:32', NULL);
INSERT INTO `files` VALUES ('88', 'App\\Models\\Assignment', '21', 'IMG_7398.jpg', NULL, '1', '12/files/670ef2b740f471.097687631729032887.jpg', '12', '2024-10-16 04:24:47', '2024-10-16 04:24:47', NULL);
INSERT INTO `files` VALUES ('89', 'App\\Models\\Assignment', '22', 'IMG_7398.jpg', NULL, '1', '12/files/670ef3398710b6.679184981729033017.jpg', '12', '2024-10-16 04:26:57', '2024-10-16 04:26:57', NULL);
INSERT INTO `files` VALUES ('90', 'App\\Models\\AssignmentSubmission', '9', 'IMG_6186-removebg-preview.png', NULL, '1', '12/files/670ef3ea509c86.456117091729033194.png', '12', '2024-10-16 04:29:54', '2024-10-16 04:29:54', NULL);
INSERT INTO `files` VALUES ('91', 'App\\Models\\Lesson', '13', 'test material', NULL, '1', '12/files/670ef9b73a00e0.879998791729034679.png', '12', '2024-10-16 04:54:39', '2024-10-16 04:54:39', NULL);
INSERT INTO `files` VALUES ('92', 'App\\Models\\Announcement', '34', 'IMG_20241022_205016.jpg', NULL, '1', '12/files/67180266963c83.801775901729626726.jpg', '12', '2024-10-23 01:22:07', '2024-10-23 01:22:07', NULL);
INSERT INTO `files` VALUES ('96', 'App\\Models\\LessonTopic', '7', 'test', '12/files/6720c8aaa0b767.829782051730201770.jpeg', '3', '12/files/6720c8ab27ad68.988831891730201771.mp4', '12', '2024-10-29 17:06:11', '2024-10-29 17:06:11', NULL);
INSERT INTO `files` VALUES ('97', 'App\\Models\\LessonTopic', '8', 'heheh', '12/files/672c756b4f60e7.602003751730966891.jpeg', '3', '12/files/672c756ba7d036.376336171730966891.mp4', '12', '2024-11-07 13:38:11', '2024-11-07 13:38:11', NULL);
INSERT INTO `files` VALUES ('98', 'App\\Models\\Lesson', '21', 'ddd', NULL, '1', '12/files/673ee8af40e3e2.462329441732176047.jpg', '12', '2024-11-21 13:30:47', '2024-11-21 13:30:47', NULL);
INSERT INTO `files` VALUES ('99', 'App\\Models\\LessonTopic', '9', 'this today', NULL, '1', '12/files/673ee9676284f2.312642371732176231.jpg', '12', '2024-11-21 13:33:51', '2024-11-21 13:33:51', NULL);
INSERT INTO `files` VALUES ('100', 'App\\Models\\Assignment', '24', 'IMG_7398.jpg.jpg', NULL, '1', '12/files/673ee9dbe765d9.020663831732176347.jpg', '12', '2024-11-21 13:35:48', '2024-11-21 13:35:48', NULL);
INSERT INTO `files` VALUES ('102', 'App\\Models\\Announcement', '43', 'GRAVITY BROCHURE-2.pdf', NULL, '1', '12/files/674a0a3dde5ca6.589942311732905533.pdf', '12', '2024-11-30 00:08:53', '2024-11-30 00:08:53', NULL);
INSERT INTO `files` VALUES ('103', 'App\\Models\\Leave', '27', 'WC-Gang-Monitor-No4-GI-TOC-December-2024.pdf', NULL, '1', 'files/AxFGKA7DuAwEfY3vG0FvKeNu2bToxkTXjSD4I00L.pdf', '12', '2024-12-10 04:55:14', '2024-12-10 04:55:14', NULL);
INSERT INTO `files` VALUES ('104', 'App\\Models\\Leave', '28', 'Claim-myUnisa-myLife-Nov-2017.pdf', NULL, '1', 'files/lBnIDhnn4etUIGhkdC81opE3CCZNYypm1Ej5dIF3.pdf', '12', '2024-12-10 04:56:47', '2024-12-10 04:56:47', NULL);
INSERT INTO `files` VALUES ('106', 'App\\Models\\Assignment', '27', 'IMG-20241216-WA0003.jpg', NULL, '1', '12/files/676057847fefd1.827241361734367108.jpg', '12', '2024-12-16 22:08:28', '2024-12-16 22:08:28', NULL);
INSERT INTO `files` VALUES ('107', 'App\\Models\\AssignmentSubmission', '10', 'CIMA BA1 Exam Practice Kit - Chapter 1.pdf', NULL, '1', '12/files/6761edb6a96209.214106551734471094.pdf', '12', '2024-12-18 03:01:34', '2024-12-18 03:01:34', NULL);
INSERT INTO `files` VALUES ('109', 'App\\Models\\Assignment', '30', 'result.pdf', NULL, '1', '12/files/6763afbdb26b98.663487341734586301.pdf', '12', '2024-12-19 11:01:41', '2024-12-19 11:01:41', NULL);
INSERT INTO `files` VALUES ('110', 'App\\Models\\Assignment', '31', 'IMG-20241212-WA0005.jpg', NULL, '1', '12/files/6766e2fb999083.599593651734796027.jpg', '12', '2024-12-21 21:17:07', '2024-12-21 21:17:07', NULL);
INSERT INTO `files` VALUES ('111', 'App\\Models\\Assignment', '33', 'splash.PNG', NULL, '1', '12/files/6772b7563f5f78.774149631735571286.PNG', '12', '2024-12-30 20:38:06', '2024-12-30 20:38:06', NULL);
INSERT INTO `files` VALUES ('112', 'App\\Models\\AssignmentSubmission', '11', 'splash.PNG', NULL, '1', '12/files/6772b7d7bd8180.638061601735571415.PNG', '12', '2024-12-30 20:40:15', '2024-12-30 20:40:15', NULL);

CREATE TABLE IF NOT EXISTS `form_fields` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(128) NOT NULL,
  `type` varchar(128) NOT NULL COMMENT 'text,number,textarea,dropdown,checkbox,radio,fileupload',
  `is_required` tinyint(1) NOT NULL DEFAULT 0,
  `default_values` text DEFAULT NULL COMMENT 'values of radio,checkbox,dropdown,etc',
  `other` text DEFAULT NULL COMMENT 'extra HTML attributes',
  `school_id` bigint(20) unsigned NOT NULL,
  `user_type` int(11) NOT NULL DEFAULT 1 COMMENT '1 => Student, 2 => Teacher/Staff',
  `rank` int(11) NOT NULL DEFAULT 0,
  `display_on_id` int(11) NOT NULL DEFAULT 0 COMMENT '0 => No, 1 => Yes',
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `form_fields_school_id_foreign` (`school_id`),
  CONSTRAINT `form_fields_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=19 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `form_fields` VALUES ('12', 'Student First Name', 'text', '0', NULL, NULL, '12', '1', '1', '0', '2023-11-16 11:09:47', '2024-10-10 15:33:13', NULL);
INSERT INTO `form_fields` VALUES ('13', 'Student Middle Name', 'text', '0', NULL, NULL, '12', '1', '2', '0', '2023-11-16 11:10:14', '2023-11-21 06:02:37', '2023-11-21 06:02:37');
INSERT INTO `form_fields` VALUES ('14', 'Student Last Name', 'text', '0', NULL, NULL, '12', '1', '3', '0', '2023-11-16 11:10:45', '2023-11-21 06:03:00', '2023-11-21 06:03:00');
INSERT INTO `form_fields` VALUES ('15', 'Full Address', 'textarea', '0', NULL, NULL, '12', '1', '4', '0', '2023-11-16 11:10:57', '2023-11-21 06:02:58', '2023-11-21 06:02:58');
INSERT INTO `form_fields` VALUES ('16', 'Contact Details', 'number', '0', NULL, NULL, '12', '1', '5', '0', '2023-11-16 11:11:13', '2023-11-21 06:01:06', '2023-11-21 06:01:06');
INSERT INTO `form_fields` VALUES ('17', 'Blood group', 'dropdown', '0', '[\"A+\",\"B+\",\"A\",\"B\",\"O\",\"O+\"]', NULL, '12', '1', '1', '1', '2023-11-21 06:04:16', '2024-10-10 15:33:13', NULL);
INSERT INTO `form_fields` VALUES ('18', 'Emergency Contact', 'number', '0', NULL, NULL, '12', '1', '2', '1', '2023-11-21 06:04:49', '2024-10-10 15:33:13', NULL);

CREATE TABLE IF NOT EXISTS `galleries` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `title` varchar(191) NOT NULL,
  `description` varchar(191) DEFAULT NULL,
  `thumbnail` varchar(191) DEFAULT NULL,
  `session_year_id` bigint(20) unsigned NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `galleries_session_year_id_foreign` (`session_year_id`),
  KEY `galleries_school_id_foreign` (`school_id`),
  CONSTRAINT `galleries_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `galleries_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=8 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `galleries` VALUES ('1', 'Festival', NULL, '12/gallery/lQBTldhBuhz5cjuvdepefziSWHWXC9GENebW7RES.png', '17', '12', '2024-03-23 09:51:23', '2024-09-30 13:04:18');
INSERT INTO `galleries` VALUES ('2', 'Class Room Decoration', NULL, '12/gallery/H8NAJ8clQgiNr2QEAIpfpNNE0Hb6HvvTuvzreUyJ.png', '17', '12', '2024-07-02 17:48:39', '2024-09-30 13:04:18');
INSERT INTO `galleries` VALUES ('3', 'Sports Day', NULL, '12/gallery/IWGyJFz1RG7N7sA24q3NpOGSoazIvJW87olP6mma.jpg', '17', '12', '2024-07-02 17:49:17', '2024-09-30 13:04:18');
INSERT INTO `galleries` VALUES ('4', 'Dance Competition', NULL, '12/gallery/w3U2hDiRrBE832brz8bxePBhFwW3H6s9jSIZ8A1A.png', '17', '12', '2024-07-02 17:51:14', '2024-09-30 13:04:18');
INSERT INTO `galleries` VALUES ('5', 'Holi', NULL, '12/gallery/4OweN7kL61DuMf0tUoD0lwal73TUwM0oAEXyGcbI.png', '17', '12', '2024-07-02 17:56:12', '2024-09-30 13:04:18');
INSERT INTO `galleries` VALUES ('6', 'Diwali', NULL, '12/gallery/KS61io2bw58orHI7owH03Y5I2RLOmgjIjcogUcAd.png', '17', '12', '2024-07-02 17:57:01', '2024-09-30 13:04:18');
INSERT INTO `galleries` VALUES ('7', 'Singing Competition', NULL, '12/gallery/1SAl6plySh1Fgegrq8vhhvJIJVyhSmYXi468wAIQ.png', '17', '12', '2024-07-02 17:57:40', '2024-09-30 13:04:18');

CREATE TABLE IF NOT EXISTS `grades` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `starting_range` double(8,2) NOT NULL,
  `ending_range` double(8,2) NOT NULL,
  `grade` tinytext NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `grades_school_id_foreign` (`school_id`),
  CONSTRAINT `grades_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=17 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `grades` VALUES ('8', '0', '34', 'FAIL', '12', '2023-11-21 10:34:01', '2023-11-21 10:34:01');
INSERT INTO `grades` VALUES ('9', '35', '42', 'D2', '12', '2023-11-21 10:34:01', '2023-11-21 10:34:01');
INSERT INTO `grades` VALUES ('10', '43', '50', 'D', '12', '2023-11-21 10:34:01', '2023-11-21 10:34:01');
INSERT INTO `grades` VALUES ('11', '51', '58', 'C2', '12', '2023-11-21 10:34:01', '2023-11-21 10:34:01');
INSERT INTO `grades` VALUES ('12', '59', '66', 'C', '12', '2023-11-21 10:34:01', '2023-11-21 10:34:01');
INSERT INTO `grades` VALUES ('13', '67', '74', 'B2', '12', '2023-11-21 10:34:01', '2023-11-21 10:34:01');
INSERT INTO `grades` VALUES ('14', '75', '82', 'B', '12', '2023-11-21 10:34:01', '2023-11-21 10:34:01');
INSERT INTO `grades` VALUES ('15', '83', '91', 'A2', '12', '2023-11-21 10:34:01', '2023-11-21 10:34:01');
INSERT INTO `grades` VALUES ('16', '92', '100', 'A', '12', '2023-11-21 10:34:01', '2023-11-21 10:34:01');

CREATE TABLE IF NOT EXISTS `holidays` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `date` date NOT NULL,
  `title` varchar(128) NOT NULL,
  `description` varchar(1024) DEFAULT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `holidays_school_id_foreign` (`school_id`),
  CONSTRAINT `holidays_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=25 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `holidays` VALUES ('4', '2023-11-02', 'Diwali', 'Festival of Lights', '12', '2023-11-20 07:09:01', '2023-11-20 07:09:01');
INSERT INTO `holidays` VALUES ('5', '2023-12-25', 'Christmas', 'It is a time for family gatherings, festive decorations, gift-giving, and spreading goodwill.', '12', '2023-11-20 07:10:02', '2023-11-20 07:10:11');
INSERT INTO `holidays` VALUES ('6', '2023-11-25', 'Ganesh Chaturthi', NULL, '12', '2023-11-20 07:10:54', '2023-11-20 07:10:54');
INSERT INTO `holidays` VALUES ('7', '2023-11-23', 'Thanksgiving', 'Thanksgiving is a holiday in the United States, observed with a festive meal, usually featuring turkey, and expressing gratitude for the blessings of the past year.', '12', '2023-11-20 07:11:08', '2023-11-22 09:40:43');
INSERT INTO `holidays` VALUES ('8', '2023-11-02', 'Chinese New Year', NULL, '12', '2023-11-20 07:11:24', '2023-11-20 07:11:24');
INSERT INTO `holidays` VALUES ('9', '2023-10-18', 'Navratri', 'Navratri is a Hindu festival lasting nine nights, dedicated to the worship of the goddess Durga. It involves traditional dance, music, and fasting.', '12', '2023-11-20 07:12:10', '2023-11-22 09:40:21');
INSERT INTO `holidays` VALUES ('10', '2023-09-15', 'Easter', 'Easter is a Christian festival celebrating the resurrection of Jesus Christ. It includes church services, egg hunts, and festive meals.', '12', '2023-11-20 07:12:19', '2023-11-22 09:40:13');
INSERT INTO `holidays` VALUES ('11', '2023-09-18', 'Hanukkah', 'Hanukkah, also known as the Festival of Lights, is a Jewish festival commemorating the miracle of the oil in the temple. It is observed with the lighting of the menorah, traditional foods, and gift-giving.', '12', '2023-11-20 07:12:29', '2023-11-22 09:40:00');
INSERT INTO `holidays` VALUES ('12', '2024-01-26', 'Republic Day', 'Republic Day is a significant national holiday in India celebrated annually on January 26th.', '12', '2024-01-25 05:07:26', '2024-01-25 05:07:26');
INSERT INTO `holidays` VALUES ('13', '2024-03-08', 'Maha Shivratri', 'Maha Shivratri, also known as the Great Night of Shiva, is a Hindu festival celebrated annually in honor of Lord Shiva.', '12', '2024-01-25 05:10:38', '2024-01-25 05:10:38');
INSERT INTO `holidays` VALUES ('14', '2024-03-25', 'Dhuleti', 'Dhuleti, also known as Dhulandi or Holi, is a vibrant and colorful Hindu festival celebrated primarily in India and Nepal.', '12', '2024-01-25 05:11:32', '2024-01-25 05:11:32');
INSERT INTO `holidays` VALUES ('15', '2024-04-17', 'Ram Navami', 'Ram Navami is a Hindu festival that celebrates the birth of Lord Rama, the seventh incarnation of Lord Vishnu.', '12', '2024-01-25 05:12:14', '2024-01-25 05:12:14');
INSERT INTO `holidays` VALUES ('16', '2024-08-15', 'Independence Day', 'Independence Day is a significant national holiday celebrated by many countries around the world to commemorate their independence or liberation from colonial rule.', '12', '2024-01-25 05:15:42', '2024-01-25 05:15:42');
INSERT INTO `holidays` VALUES ('17', '2024-03-29', 'Good Friday', 'Good Friday is a Christian religious holiday commemorating the crucifixion of Jesus Christ and his death at Calvary.', '12', '2024-01-25 05:17:03', '2024-01-25 05:17:03');
INSERT INTO `holidays` VALUES ('18', '2024-08-19', 'Raksha Bandhan', NULL, '12', '2024-05-14 12:44:44', '2024-05-14 12:44:44');
INSERT INTO `holidays` VALUES ('19', '2024-08-26', 'Janmashtami', NULL, '12', '2024-05-14 12:45:02', '2024-05-14 12:45:02');
INSERT INTO `holidays` VALUES ('20', '2024-10-12', 'Vijayadashami', NULL, '12', '2024-05-14 12:45:17', '2024-05-14 12:45:17');
INSERT INTO `holidays` VALUES ('21', '2024-10-30', 'Kali Chaudas', NULL, '12', '2024-05-14 12:45:28', '2024-05-14 12:45:28');
INSERT INTO `holidays` VALUES ('22', '2024-11-01', 'Diwali', NULL, '12', '2024-05-14 12:45:37', '2024-05-14 12:45:37');
INSERT INTO `holidays` VALUES ('23', '2024-11-02', 'New Year', NULL, '12', '2024-05-14 12:45:48', '2024-05-14 12:45:48');
INSERT INTO `holidays` VALUES ('24', '2024-11-03', 'Bhai duj', NULL, '12', '2024-05-14 12:45:55', '2024-05-14 12:45:55');

CREATE TABLE IF NOT EXISTS `leave_details` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `leave_id` bigint(20) unsigned NOT NULL,
  `date` date NOT NULL,
  `type` varchar(191) NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `leave_details_leave_id_foreign` (`leave_id`),
  KEY `leave_details_school_id_foreign` (`school_id`),
  CONSTRAINT `leave_details_leave_id_foreign` FOREIGN KEY (`leave_id`) REFERENCES `leaves` (`id`) ON DELETE CASCADE,
  CONSTRAINT `leave_details_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=308 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `leave_details` VALUES ('1', '1', '2024-01-27', 'Full', '12', '2024-01-25 05:23:02', '2024-01-25 05:23:02');
INSERT INTO `leave_details` VALUES ('13', '3', '2024-02-21', 'First Half', '12', '2024-01-25 05:26:05', '2024-01-25 05:26:05');
INSERT INTO `leave_details` VALUES ('14', '3', '2024-02-22', 'Full', '12', '2024-01-25 05:26:05', '2024-01-25 05:26:05');
INSERT INTO `leave_details` VALUES ('15', '3', '2024-02-23', 'Full', '12', '2024-01-25 05:26:05', '2024-01-25 05:26:05');
INSERT INTO `leave_details` VALUES ('16', '3', '2024-02-24', 'Second Half', '12', '2024-01-25 05:26:05', '2024-01-25 05:26:05');
INSERT INTO `leave_details` VALUES ('17', '4', '2024-05-31', 'Full', '12', '2024-05-14 12:50:16', '2024-05-14 12:50:16');
INSERT INTO `leave_details` VALUES ('18', '4', '2024-06-01', 'Full', '12', '2024-05-14 12:50:16', '2024-05-14 12:50:16');
INSERT INTO `leave_details` VALUES ('19', '4', '2024-06-03', 'First Half', '12', '2024-05-14 12:50:16', '2024-05-14 12:50:16');
INSERT INTO `leave_details` VALUES ('20', '5', '2024-07-30', 'Second Half', '12', '2024-05-14 12:51:39', '2024-05-14 12:51:39');
INSERT INTO `leave_details` VALUES ('21', '5', '2024-07-31', 'Full', '12', '2024-05-14 12:51:39', '2024-05-14 12:51:39');
INSERT INTO `leave_details` VALUES ('22', '5', '2024-08-01', 'Full', '12', '2024-05-14 12:51:39', '2024-05-14 12:51:39');
INSERT INTO `leave_details` VALUES ('23', '5', '2024-08-02', 'Full', '12', '2024-05-14 12:51:39', '2024-05-14 12:51:39');
INSERT INTO `leave_details` VALUES ('24', '6', '2024-09-28', 'Second Half', '12', '2024-05-14 12:53:45', '2024-05-14 12:53:45');
INSERT INTO `leave_details` VALUES ('25', '6', '2024-09-30', 'Full', '12', '2024-05-14 12:53:45', '2024-05-14 12:53:45');
INSERT INTO `leave_details` VALUES ('26', '6', '2024-10-01', 'First Half', '12', '2024-05-14 12:53:45', '2024-05-14 12:53:45');
INSERT INTO `leave_details` VALUES ('27', '7', '2024-11-29', 'Full', '12', '2024-05-14 12:54:34', '2024-05-14 12:54:34');
INSERT INTO `leave_details` VALUES ('28', '7', '2024-11-30', 'Full', '12', '2024-05-14 12:54:34', '2024-05-14 12:54:34');
INSERT INTO `leave_details` VALUES ('29', '7', '2024-12-02', 'Full', '12', '2024-05-14 12:54:34', '2024-05-14 12:54:34');
INSERT INTO `leave_details` VALUES ('33', '10', '2024-09-06', 'Full', '12', '2024-09-06 12:31:01', '2024-09-06 12:31:01');
INSERT INTO `leave_details` VALUES ('34', '11', '2024-09-06', 'Full', '12', '2024-09-06 12:31:58', '2024-09-06 12:31:58');
INSERT INTO `leave_details` VALUES ('35', '12', '2024-09-06', 'Second Half', '12', '2024-09-06 12:33:13', '2024-09-06 12:33:13');
INSERT INTO `leave_details` VALUES ('36', '13', '2024-10-03', 'Second Half', '12', '2024-10-03 10:18:38', '2024-10-03 10:18:38');
INSERT INTO `leave_details` VALUES ('37', '13', '2024-10-04', 'Second Half', '12', '2024-10-03 10:18:38', '2024-10-03 10:18:38');
INSERT INTO `leave_details` VALUES ('38', '13', '2024-10-05', 'Full', '12', '2024-10-03 10:18:38', '2024-10-03 10:18:38');
INSERT INTO `leave_details` VALUES ('39', '13', '2024-10-07', 'First Half', '12', '2024-10-03 10:18:38', '2024-10-03 10:18:38');
INSERT INTO `leave_details` VALUES ('40', '13', '2024-10-08', 'Full', '12', '2024-10-03 10:18:38', '2024-10-03 10:18:38');
INSERT INTO `leave_details` VALUES ('41', '13', '2024-10-09', 'First Half', '12', '2024-10-03 10:18:38', '2024-10-03 10:18:38');
INSERT INTO `leave_details` VALUES ('42', '13', '2024-10-10', 'Second Half', '12', '2024-10-03 10:18:38', '2024-10-03 10:18:38');
INSERT INTO `leave_details` VALUES ('43', '13', '2024-10-11', 'Second Half', '12', '2024-10-03 10:18:38', '2024-10-03 10:18:38');
INSERT INTO `leave_details` VALUES ('44', '14', '2024-10-31', 'Full', '12', '2024-10-04 22:47:25', '2024-10-04 22:47:25');
INSERT INTO `leave_details` VALUES ('45', '14', '2024-11-01', 'First Half', '12', '2024-10-04 22:47:25', '2024-10-04 22:47:25');
INSERT INTO `leave_details` VALUES ('46', '15', '2024-10-07', 'Full', '12', '2024-10-05 16:47:05', '2024-10-05 16:47:05');
INSERT INTO `leave_details` VALUES ('47', '16', '2024-10-10', 'Full', '12', '2024-10-09 05:22:52', '2024-10-09 05:22:52');
INSERT INTO `leave_details` VALUES ('48', '16', '2024-10-11', 'Full', '12', '2024-10-09 05:22:52', '2024-10-09 05:22:52');
INSERT INTO `leave_details` VALUES ('49', '17', '2024-10-19', 'Full', '12', '2024-10-18 11:14:56', '2024-10-18 11:14:56');
INSERT INTO `leave_details` VALUES ('50', '17', '2024-10-21', 'Full', '12', '2024-10-18 11:14:56', '2024-10-18 11:14:56');
INSERT INTO `leave_details` VALUES ('51', '17', '2024-10-22', 'Full', '12', '2024-10-18 11:14:56', '2024-10-18 11:14:56');
INSERT INTO `leave_details` VALUES ('52', '17', '2024-10-23', 'Full', '12', '2024-10-18 11:14:56', '2024-10-18 11:14:56');
INSERT INTO `leave_details` VALUES ('53', '17', '2024-10-24', 'Full', '12', '2024-10-18 11:14:56', '2024-10-18 11:14:56');
INSERT INTO `leave_details` VALUES ('54', '17', '2024-10-25', 'Full', '12', '2024-10-18 11:14:56', '2024-10-18 11:14:56');
INSERT INTO `leave_details` VALUES ('55', '18', '2024-10-31', 'Full', '12', '2024-10-30 13:35:58', '2024-10-30 13:35:58');
INSERT INTO `leave_details` VALUES ('56', '19', '2024-11-07', 'Full', '12', '2024-11-07 13:56:42', '2024-11-07 13:56:42');
INSERT INTO `leave_details` VALUES ('57', '20', '2024-11-07', 'Full', '12', '2024-11-07 14:01:29', '2024-11-07 14:01:29');
INSERT INTO `leave_details` VALUES ('58', '20', '2024-11-08', 'Full', '12', '2024-11-07 14:01:29', '2024-11-07 14:01:29');
INSERT INTO `leave_details` VALUES ('59', '20', '2024-11-09', 'Full', '12', '2024-11-07 14:01:29', '2024-11-07 14:01:29');
INSERT INTO `leave_details` VALUES ('60', '21', '2024-11-07', 'Full', '12', '2024-11-07 14:01:32', '2024-11-07 14:01:32');
INSERT INTO `leave_details` VALUES ('61', '21', '2024-11-08', 'Full', '12', '2024-11-07 14:01:32', '2024-11-07 14:01:32');
INSERT INTO `leave_details` VALUES ('62', '21', '2024-11-09', 'Full', '12', '2024-11-07 14:01:32', '2024-11-07 14:01:32');
INSERT INTO `leave_details` VALUES ('63', '22', '2024-11-22', 'First Half', '12', '2024-11-17 17:51:34', '2024-11-17 17:51:34');
INSERT INTO `leave_details` VALUES ('64', '22', '2024-11-23', 'Full', '12', '2024-11-17 17:51:34', '2024-11-17 17:51:34');
INSERT INTO `leave_details` VALUES ('65', '23', '2024-11-25', 'First Half', '12', '2024-11-24 05:37:24', '2024-11-24 05:37:24');
INSERT INTO `leave_details` VALUES ('66', '23', '2024-11-26', 'Second Half', '12', '2024-11-24 05:37:24', '2024-11-24 05:37:24');
INSERT INTO `leave_details` VALUES ('67', '23', '2024-11-27', 'First Half', '12', '2024-11-24 05:37:24', '2024-11-24 05:37:24');
INSERT INTO `leave_details` VALUES ('68', '23', '2024-11-28', 'Second Half', '12', '2024-11-24 05:37:24', '2024-11-24 05:37:24');
INSERT INTO `leave_details` VALUES ('69', '23', '2024-11-29', 'First Half', '12', '2024-11-24 05:37:24', '2024-11-24 05:37:24');
INSERT INTO `leave_details` VALUES ('70', '23', '2024-11-30', 'Full', '12', '2024-11-24 05:37:24', '2024-11-24 05:37:24');
INSERT INTO `leave_details` VALUES ('71', '24', '2024-11-25', 'Full', '12', '2024-11-25 19:44:10', '2024-11-25 19:44:10');
INSERT INTO `leave_details` VALUES ('72', '24', '2024-11-26', 'Full', '12', '2024-11-25 19:44:10', '2024-11-25 19:44:10');
INSERT INTO `leave_details` VALUES ('73', '25', '2024-11-30', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('74', '25', '2024-12-02', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('75', '25', '2024-12-03', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('76', '25', '2024-12-04', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('77', '25', '2024-12-05', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('78', '25', '2024-12-06', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('79', '25', '2024-12-07', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('80', '25', '2024-12-09', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('81', '25', '2024-12-10', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('82', '25', '2024-12-11', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('83', '25', '2024-12-12', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('84', '25', '2024-12-13', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('85', '25', '2024-12-14', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('86', '25', '2024-12-16', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('87', '25', '2024-12-17', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('88', '25', '2024-12-18', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('89', '25', '2024-12-19', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('90', '25', '2024-12-20', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('91', '25', '2024-12-21', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('92', '25', '2024-12-23', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('93', '25', '2024-12-24', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('94', '25', '2024-12-25', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('95', '25', '2024-12-26', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('96', '25', '2024-12-27', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('97', '25', '2024-12-28', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('98', '25', '2024-12-30', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('99', '25', '2024-12-31', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('100', '25', '2025-01-01', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('101', '25', '2025-01-02', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('102', '25', '2025-01-03', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('103', '25', '2025-01-04', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('104', '25', '2025-01-06', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('105', '25', '2025-01-07', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('106', '25', '2025-01-08', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('107', '25', '2025-01-09', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('108', '25', '2025-01-10', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('109', '25', '2025-01-11', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('110', '25', '2025-01-13', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('111', '25', '2025-01-14', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('112', '25', '2025-01-15', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('113', '25', '2025-01-16', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('114', '25', '2025-01-17', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('115', '25', '2025-01-18', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('116', '25', '2025-01-20', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('117', '25', '2025-01-21', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('118', '25', '2025-01-22', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('119', '25', '2025-01-23', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('120', '25', '2025-01-24', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('121', '25', '2025-01-25', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('122', '25', '2025-01-27', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('123', '25', '2025-01-28', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('124', '25', '2025-01-29', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('125', '25', '2025-01-30', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('126', '25', '2025-01-31', 'Full', '12', '2024-11-30 16:11:29', '2024-11-30 16:11:29');
INSERT INTO `leave_details` VALUES ('127', '26', '2024-11-30', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('128', '26', '2024-12-02', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('129', '26', '2024-12-03', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('130', '26', '2024-12-04', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('131', '26', '2024-12-05', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('132', '26', '2024-12-06', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('133', '26', '2024-12-07', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('134', '26', '2024-12-09', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('135', '26', '2024-12-10', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('136', '26', '2024-12-11', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('137', '26', '2024-12-12', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('138', '26', '2024-12-13', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('139', '26', '2024-12-14', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('140', '26', '2024-12-16', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('141', '26', '2024-12-17', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('142', '26', '2024-12-18', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('143', '26', '2024-12-19', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('144', '26', '2024-12-20', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('145', '26', '2024-12-21', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('146', '26', '2024-12-23', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('147', '26', '2024-12-24', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('148', '26', '2024-12-25', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('149', '26', '2024-12-26', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('150', '26', '2024-12-27', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('151', '26', '2024-12-28', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('152', '26', '2024-12-30', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('153', '26', '2024-12-31', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('154', '26', '2025-01-01', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('155', '26', '2025-01-02', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('156', '26', '2025-01-03', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('157', '26', '2025-01-04', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('158', '26', '2025-01-06', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('159', '26', '2025-01-07', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('160', '26', '2025-01-08', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('161', '26', '2025-01-09', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('162', '26', '2025-01-10', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('163', '26', '2025-01-11', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('164', '26', '2025-01-13', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('165', '26', '2025-01-14', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('166', '26', '2025-01-15', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('167', '26', '2025-01-16', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('168', '26', '2025-01-17', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('169', '26', '2025-01-18', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('170', '26', '2025-01-20', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('171', '26', '2025-01-21', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('172', '26', '2025-01-22', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('173', '26', '2025-01-23', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('174', '26', '2025-01-24', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('175', '26', '2025-01-25', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('176', '26', '2025-01-27', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('177', '26', '2025-01-28', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('178', '26', '2025-01-29', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('179', '26', '2025-01-30', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('180', '26', '2025-01-31', 'Full', '12', '2024-11-30 16:13:22', '2024-11-30 16:13:22');
INSERT INTO `leave_details` VALUES ('181', '27', '2024-12-11', 'Full', '12', '2024-12-10 04:55:14', '2024-12-10 04:55:14');
INSERT INTO `leave_details` VALUES ('182', '28', '2024-12-18', 'Full', '12', '2024-12-10 04:56:47', '2024-12-10 04:56:47');
INSERT INTO `leave_details` VALUES ('183', '28', '2024-12-19', 'Full', '12', '2024-12-10 04:56:47', '2024-12-10 04:56:47');
INSERT INTO `leave_details` VALUES ('184', '29', '2024-12-25', 'Full', '12', '2024-12-24 02:51:16', '2024-12-24 02:51:16');
INSERT INTO `leave_details` VALUES ('185', '29', '2024-12-26', 'Full', '12', '2024-12-24 02:51:16', '2024-12-24 02:51:16');
INSERT INTO `leave_details` VALUES ('186', '29', '2024-12-27', 'Full', '12', '2024-12-24 02:51:16', '2024-12-24 02:51:16');
INSERT INTO `leave_details` VALUES ('187', '29', '2024-12-28', 'Full', '12', '2024-12-24 02:51:16', '2024-12-24 02:51:16');
INSERT INTO `leave_details` VALUES ('188', '29', '2024-12-30', 'Full', '12', '2024-12-24 02:51:16', '2024-12-24 02:51:16');
INSERT INTO `leave_details` VALUES ('189', '29', '2024-12-31', 'Full', '12', '2024-12-24 02:51:16', '2024-12-24 02:51:16');
INSERT INTO `leave_details` VALUES ('190', '30', '2024-12-24', 'Full', '12', '2024-12-24 05:13:06', '2024-12-24 05:13:06');
INSERT INTO `leave_details` VALUES ('191', '30', '2024-12-25', 'Full', '12', '2024-12-24 05:13:06', '2024-12-24 05:13:06');
INSERT INTO `leave_details` VALUES ('192', '30', '2024-12-26', 'Full', '12', '2024-12-24 05:13:06', '2024-12-24 05:13:06');
INSERT INTO `leave_details` VALUES ('193', '30', '2024-12-27', 'Full', '12', '2024-12-24 05:13:06', '2024-12-24 05:13:06');
INSERT INTO `leave_details` VALUES ('194', '30', '2024-12-28', 'Full', '12', '2024-12-24 05:13:06', '2024-12-24 05:13:06');
INSERT INTO `leave_details` VALUES ('195', '31', '2024-12-27', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('196', '31', '2024-12-28', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('197', '31', '2024-12-30', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('198', '31', '2024-12-31', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('199', '31', '2025-01-01', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('200', '31', '2025-01-02', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('201', '31', '2025-01-03', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('202', '31', '2025-01-04', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('203', '31', '2025-01-06', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('204', '31', '2025-01-07', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('205', '31', '2025-01-08', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('206', '31', '2025-01-09', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('207', '31', '2025-01-10', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('208', '31', '2025-01-11', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('209', '31', '2025-01-13', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('210', '31', '2025-01-14', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('211', '31', '2025-01-15', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('212', '31', '2025-01-16', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('213', '31', '2025-01-17', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('214', '31', '2025-01-18', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('215', '31', '2025-01-20', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('216', '31', '2025-01-21', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('217', '31', '2025-01-22', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('218', '31', '2025-01-23', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('219', '31', '2025-01-24', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('220', '31', '2025-01-25', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('221', '31', '2025-01-27', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('222', '31', '2025-01-28', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('223', '31', '2025-01-29', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('224', '31', '2025-01-30', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('225', '31', '2025-01-31', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('226', '31', '2025-02-01', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('227', '31', '2025-02-03', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('228', '31', '2025-02-04', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('229', '31', '2025-02-05', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('230', '31', '2025-02-06', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('231', '31', '2025-02-07', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('232', '31', '2025-02-08', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('233', '31', '2025-02-10', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('234', '31', '2025-02-11', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('235', '31', '2025-02-12', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('236', '31', '2025-02-13', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('237', '31', '2025-02-14', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('238', '31', '2025-02-15', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('239', '31', '2025-02-17', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('240', '31', '2025-02-18', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('241', '31', '2025-02-19', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('242', '31', '2025-02-20', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('243', '31', '2025-02-21', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('244', '31', '2025-02-22', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('245', '31', '2025-02-24', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('246', '31', '2025-02-25', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('247', '31', '2025-02-26', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('248', '31', '2025-02-27', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('249', '31', '2025-02-28', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('250', '31', '2025-03-01', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('251', '31', '2025-03-03', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('252', '31', '2025-03-04', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('253', '31', '2025-03-05', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('254', '31', '2025-03-06', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('255', '31', '2025-03-07', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('256', '31', '2025-03-08', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('257', '31', '2025-03-10', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('258', '31', '2025-03-11', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('259', '31', '2025-03-12', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('260', '31', '2025-03-13', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('261', '31', '2025-03-14', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('262', '31', '2025-03-15', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('263', '31', '2025-03-17', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('264', '31', '2025-03-18', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('265', '31', '2025-03-19', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('266', '31', '2025-03-20', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('267', '31', '2025-03-21', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('268', '31', '2025-03-22', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('269', '31', '2025-03-24', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('270', '31', '2025-03-25', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('271', '31', '2025-03-26', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('272', '31', '2025-03-27', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('273', '31', '2025-03-28', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('274', '31', '2025-03-29', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('275', '31', '2025-03-31', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('276', '31', '2025-04-01', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('277', '31', '2025-04-02', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('278', '31', '2025-04-03', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('279', '31', '2025-04-04', 'Full', '12', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leave_details` VALUES ('280', '32', '2024-12-28', 'Full', '12', '2024-12-28 15:38:14', '2024-12-28 15:38:14');
INSERT INTO `leave_details` VALUES ('281', '32', '2024-12-30', 'Full', '12', '2024-12-28 15:38:14', '2024-12-28 15:38:14');
INSERT INTO `leave_details` VALUES ('282', '32', '2024-12-31', 'Full', '12', '2024-12-28 15:38:14', '2024-12-28 15:38:14');
INSERT INTO `leave_details` VALUES ('283', '33', '2025-01-08', 'Full', '12', '2025-01-07 01:54:55', '2025-01-07 01:54:55');
INSERT INTO `leave_details` VALUES ('284', '33', '2025-01-09', 'Full', '12', '2025-01-07 01:54:55', '2025-01-07 01:54:55');
INSERT INTO `leave_details` VALUES ('285', '34', '2025-01-08', 'Full', '12', '2025-01-08 03:53:14', '2025-01-08 03:53:14');
INSERT INTO `leave_details` VALUES ('286', '34', '2025-01-09', 'Full', '12', '2025-01-08 03:53:14', '2025-01-08 03:53:14');
INSERT INTO `leave_details` VALUES ('287', '35', '2025-01-08', 'Full', '12', '2025-01-08 15:04:28', '2025-01-08 15:04:28');
INSERT INTO `leave_details` VALUES ('288', '35', '2025-01-09', 'Full', '12', '2025-01-08 15:04:28', '2025-01-08 15:04:28');
INSERT INTO `leave_details` VALUES ('289', '35', '2025-01-10', 'Full', '12', '2025-01-08 15:04:28', '2025-01-08 15:04:28');
INSERT INTO `leave_details` VALUES ('290', '35', '2025-01-11', 'Full', '12', '2025-01-08 15:04:28', '2025-01-08 15:04:28');
INSERT INTO `leave_details` VALUES ('291', '35', '2025-01-13', 'Full', '12', '2025-01-08 15:04:28', '2025-01-08 15:04:28');
INSERT INTO `leave_details` VALUES ('292', '35', '2025-01-14', 'Full', '12', '2025-01-08 15:04:28', '2025-01-08 15:04:28');
INSERT INTO `leave_details` VALUES ('293', '35', '2025-01-15', 'Full', '12', '2025-01-08 15:04:28', '2025-01-08 15:04:28');
INSERT INTO `leave_details` VALUES ('294', '35', '2025-01-16', 'Full', '12', '2025-01-08 15:04:28', '2025-01-08 15:04:28');
INSERT INTO `leave_details` VALUES ('295', '35', '2025-01-17', 'Full', '12', '2025-01-08 15:04:28', '2025-01-08 15:04:28');
INSERT INTO `leave_details` VALUES ('296', '35', '2025-01-18', 'Full', '12', '2025-01-08 15:04:28', '2025-01-08 15:04:28');
INSERT INTO `leave_details` VALUES ('297', '35', '2025-01-20', 'Full', '12', '2025-01-08 15:04:28', '2025-01-08 15:04:28');
INSERT INTO `leave_details` VALUES ('298', '35', '2025-01-21', 'Full', '12', '2025-01-08 15:04:28', '2025-01-08 15:04:28');
INSERT INTO `leave_details` VALUES ('299', '35', '2025-01-22', 'Full', '12', '2025-01-08 15:04:28', '2025-01-08 15:04:28');
INSERT INTO `leave_details` VALUES ('300', '35', '2025-01-23', 'Full', '12', '2025-01-08 15:04:28', '2025-01-08 15:04:28');
INSERT INTO `leave_details` VALUES ('301', '35', '2025-01-24', 'Full', '12', '2025-01-08 15:04:28', '2025-01-08 15:04:28');
INSERT INTO `leave_details` VALUES ('302', '35', '2025-01-25', 'Full', '12', '2025-01-08 15:04:28', '2025-01-08 15:04:28');
INSERT INTO `leave_details` VALUES ('303', '35', '2025-01-27', 'Full', '12', '2025-01-08 15:04:28', '2025-01-08 15:04:28');
INSERT INTO `leave_details` VALUES ('304', '35', '2025-01-28', 'Full', '12', '2025-01-08 15:04:28', '2025-01-08 15:04:28');
INSERT INTO `leave_details` VALUES ('305', '35', '2025-01-29', 'Full', '12', '2025-01-08 15:04:28', '2025-01-08 15:04:28');
INSERT INTO `leave_details` VALUES ('306', '35', '2025-01-30', 'Full', '12', '2025-01-08 15:04:28', '2025-01-08 15:04:28');
INSERT INTO `leave_details` VALUES ('307', '35', '2025-01-31', 'Full', '12', '2025-01-08 15:04:28', '2025-01-08 15:04:28');

CREATE TABLE IF NOT EXISTS `leave_masters` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `leaves` double(8,2) NOT NULL COMMENT 'Leaves per month',
  `holiday` varchar(191) NOT NULL,
  `session_year_id` bigint(20) unsigned NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `leave_masters_session_year_id_foreign` (`session_year_id`),
  KEY `leave_masters_school_id_foreign` (`school_id`),
  CONSTRAINT `leave_masters_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `leave_masters_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `leave_masters` VALUES ('1', '1.5', 'Sunday', '17', '12', '2024-01-25 05:18:50', '2024-01-25 05:18:50');

CREATE TABLE IF NOT EXISTS `leaves` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `user_id` bigint(20) unsigned NOT NULL,
  `reason` varchar(191) NOT NULL,
  `from_date` date NOT NULL,
  `to_date` date NOT NULL,
  `status` int(11) NOT NULL DEFAULT 0 COMMENT '0 => Pending, 1 => Approved, 2 => Rejected',
  `school_id` bigint(20) unsigned NOT NULL,
  `leave_master_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `leaves_school_id_foreign` (`school_id`),
  KEY `leaves_leave_master_id_foreign` (`leave_master_id`),
  KEY `leaves_user_id_foreign` (`user_id`),
  CONSTRAINT `leaves_leave_master_id_foreign` FOREIGN KEY (`leave_master_id`) REFERENCES `leave_masters` (`id`) ON DELETE CASCADE,
  CONSTRAINT `leaves_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `leaves_user_id_foreign` FOREIGN KEY (`user_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=36 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `leaves` VALUES ('1', '49', 'Sick Leave', '2024-01-27', '2024-01-27', '1', '12', '1', '2024-01-25 05:23:02', '2024-01-25 05:26:37');
INSERT INTO `leaves` VALUES ('3', '48', 'Sick Leave', '2024-02-21', '2024-02-24', '1', '12', '1', '2024-01-25 05:26:05', '2024-01-25 05:26:33');
INSERT INTO `leaves` VALUES ('4', '49', 'Out of City', '2024-05-31', '2024-06-03', '1', '12', '1', '2024-05-14 12:50:16', '2024-05-14 12:52:15');
INSERT INTO `leaves` VALUES ('5', '48', 'Function', '2024-07-30', '2024-08-02', '1', '12', '1', '2024-05-14 12:51:39', '2024-05-14 12:52:19');
INSERT INTO `leaves` VALUES ('6', '47', 'Trip', '2024-09-28', '2024-10-01', '1', '12', '1', '2024-05-14 12:53:45', '2024-05-14 12:54:53');
INSERT INTO `leaves` VALUES ('7', '47', 'Family function', '2024-11-29', '2024-12-02', '1', '12', '1', '2024-05-14 12:54:34', '2024-05-14 12:54:59');
INSERT INTO `leaves` VALUES ('10', '48', 'Sick Leave', '2024-09-06', '2024-09-06', '1', '12', '1', '2024-09-06 12:31:01', '2024-09-06 12:33:44');
INSERT INTO `leaves` VALUES ('11', '46', 'Trip', '2024-09-06', '2024-09-06', '1', '12', '1', '2024-09-06 12:31:58', '2024-09-06 12:33:40');
INSERT INTO `leaves` VALUES ('12', '45', 'Parent meeting in school.', '2024-09-06', '2024-09-06', '1', '12', '1', '2024-09-06 12:33:13', '2024-09-06 12:33:34');
INSERT INTO `leaves` VALUES ('13', '49', 'Navrati', '2024-10-03', '2024-10-11', '1', '12', '1', '2024-10-03 10:18:38', '2024-10-03 10:23:19');
INSERT INTO `leaves` VALUES ('14', '49', 'sick leave test', '2024-10-31', '2024-11-01', '0', '12', '1', '2024-10-04 22:47:25', '2024-10-04 22:47:25');
INSERT INTO `leaves` VALUES ('15', '49', 'sick', '2024-10-07', '2024-10-07', '2', '12', '1', '2024-10-05 16:47:05', '2024-10-25 13:09:04');
INSERT INTO `leaves` VALUES ('16', '49', 'sock', '2024-10-10', '2024-10-12', '0', '12', '1', '2024-10-09 05:22:52', '2024-10-09 05:22:52');
INSERT INTO `leaves` VALUES ('17', '49', 'uthf', '2024-10-19', '2024-10-25', '0', '12', '1', '2024-10-18 11:14:56', '2024-10-18 11:14:56');
INSERT INTO `leaves` VALUES ('18', '48', 'sndf', '2024-10-30', '2024-10-31', '0', '12', '1', '2024-10-30 13:35:58', '2024-10-30 13:35:58');
INSERT INTO `leaves` VALUES ('19', '48', 'sghyhy', '2024-11-07', '2024-11-07', '0', '12', '1', '2024-11-07 13:56:42', '2024-11-07 13:56:42');
INSERT INTO `leaves` VALUES ('20', '48', 'fever', '2024-11-07', '2024-11-09', '0', '12', '1', '2024-11-07 14:01:29', '2024-11-07 14:01:29');
INSERT INTO `leaves` VALUES ('21', '48', 'fever', '2024-11-07', '2024-11-09', '0', '12', '1', '2024-11-07 14:01:32', '2024-11-07 14:01:32');
INSERT INTO `leaves` VALUES ('22', '48', 'I want to resign', '2024-11-22', '2024-11-23', '1', '12', '1', '2024-11-17 17:51:34', '2024-12-24 03:00:14');
INSERT INTO `leaves` VALUES ('23', '48', 'text', '2024-11-25', '2024-11-30', '0', '12', '1', '2024-11-24 05:37:24', '2024-11-24 05:37:24');
INSERT INTO `leaves` VALUES ('24', '48', 'jsnd', '2024-11-25', '2024-11-26', '0', '12', '1', '2024-11-25 19:44:10', '2024-11-25 19:44:10');
INSERT INTO `leaves` VALUES ('25', '48', 'u', '2024-11-30', '2025-01-09', '1', '12', '1', '2024-11-30 16:11:29', '2024-12-24 03:00:34');
INSERT INTO `leaves` VALUES ('26', '48', 'hjd', '2024-11-30', '2025-01-09', '1', '12', '1', '2024-11-30 16:13:22', '2024-12-24 02:59:31');
INSERT INTO `leaves` VALUES ('27', '49', 'work', '2024-12-11', '2024-12-11', '1', '12', '1', '2024-12-10 04:55:14', '2024-12-24 02:59:20');
INSERT INTO `leaves` VALUES ('28', '49', 'sick', '2024-12-18', '2024-12-19', '1', '12', '1', '2024-12-10 04:56:47', '2024-12-24 02:59:15');
INSERT INTO `leaves` VALUES ('29', '331', 'Going to Goa on christmas Holiday.', '2024-12-25', '2024-12-31', '1', '12', '1', '2024-12-24 02:51:16', '2024-12-24 02:56:25');
INSERT INTO `leaves` VALUES ('30', '42', 'vaca', '2024-12-24', '2024-12-28', '0', '12', '1', '2024-12-24 05:13:06', '2024-12-24 05:13:06');
INSERT INTO `leaves` VALUES ('31', '42', 'Sick', '2024-12-27', '2025-04-04', '0', '12', '1', '2024-12-26 21:19:47', '2024-12-26 21:19:47');
INSERT INTO `leaves` VALUES ('32', '42', 'dvdbd', '2024-12-28', '2024-12-31', '0', '12', '1', '2024-12-28 15:38:14', '2024-12-28 15:38:14');
INSERT INTO `leaves` VALUES ('33', '42', 'Hari Kebangsaan', '2025-01-08', '2025-01-09', '0', '12', '1', '2025-01-07 01:54:55', '2025-01-07 01:54:55');
INSERT INTO `leaves` VALUES ('34', '42', 'تجربه', '2025-01-08', '2025-01-09', '0', '12', '1', '2025-01-08 03:53:14', '2025-01-08 03:53:14');
INSERT INTO `leaves` VALUES ('35', '42', 'Sick', '2025-01-10', '2025-01-09', '0', '12', '1', '2025-01-08 15:04:28', '2025-01-08 15:04:28');

CREATE TABLE IF NOT EXISTS `lesson_commons` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `lesson_id` bigint(20) unsigned NOT NULL,
  `class_section_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `lesson_commons_lesson_id_foreign` (`lesson_id`),
  KEY `lesson_commons_class_section_id_foreign` (`class_section_id`),
  CONSTRAINT `lesson_commons_class_section_id_foreign` FOREIGN KEY (`class_section_id`) REFERENCES `class_sections` (`id`) ON DELETE CASCADE,
  CONSTRAINT `lesson_commons_lesson_id_foreign` FOREIGN KEY (`lesson_id`) REFERENCES `lessons` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=21 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `lesson_commons` VALUES ('1', '4', '28', '2025-01-03 10:50:57', '2025-01-03 10:50:57');
INSERT INTO `lesson_commons` VALUES ('2', '5', '25', '2025-01-03 10:50:57', '2025-01-03 10:50:57');
INSERT INTO `lesson_commons` VALUES ('3', '6', '27', '2025-01-03 10:50:57', '2025-01-03 10:50:57');
INSERT INTO `lesson_commons` VALUES ('4', '8', '55', '2025-01-03 10:50:57', '2025-01-03 10:50:57');
INSERT INTO `lesson_commons` VALUES ('5', '9', '55', '2025-01-03 10:50:57', '2025-01-03 10:50:57');
INSERT INTO `lesson_commons` VALUES ('6', '10', '55', '2025-01-03 10:50:57', '2025-01-03 10:50:57');
INSERT INTO `lesson_commons` VALUES ('7', '11', '55', '2025-01-03 10:50:57', '2025-01-03 10:50:57');
INSERT INTO `lesson_commons` VALUES ('8', '12', '55', '2025-01-03 10:50:57', '2025-01-03 10:50:57');
INSERT INTO `lesson_commons` VALUES ('9', '13', '55', '2025-01-03 10:50:57', '2025-01-03 10:50:57');
INSERT INTO `lesson_commons` VALUES ('10', '14', '21', '2025-01-03 10:50:57', '2025-01-03 10:50:57');
INSERT INTO `lesson_commons` VALUES ('11', '15', '22', '2025-01-03 10:50:57', '2025-01-03 10:50:57');
INSERT INTO `lesson_commons` VALUES ('12', '18', '23', '2025-01-03 10:50:57', '2025-01-03 10:50:57');
INSERT INTO `lesson_commons` VALUES ('13', '19', '21', '2025-01-03 10:50:57', '2025-01-03 10:50:57');
INSERT INTO `lesson_commons` VALUES ('14', '20', '57', '2025-01-03 10:50:57', '2025-01-03 10:50:57');
INSERT INTO `lesson_commons` VALUES ('15', '21', '57', '2025-01-03 10:50:57', '2025-01-03 10:50:57');
INSERT INTO `lesson_commons` VALUES ('16', '24', '21', '2025-01-03 10:50:57', '2025-01-03 10:50:57');
INSERT INTO `lesson_commons` VALUES ('17', '25', '22', '2025-01-03 10:50:57', '2025-01-03 10:50:57');
INSERT INTO `lesson_commons` VALUES ('18', '26', '23', '2025-01-03 10:50:57', '2025-01-03 10:50:57');
INSERT INTO `lesson_commons` VALUES ('19', '28', '55', '2025-01-03 10:50:57', '2025-01-03 10:50:57');
INSERT INTO `lesson_commons` VALUES ('20', '29', '22', '2025-01-08 03:32:09', '2025-01-08 03:32:09');

CREATE TABLE IF NOT EXISTS `lesson_topics` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `lesson_id` bigint(20) unsigned NOT NULL,
  `name` varchar(128) NOT NULL,
  `description` varchar(1024) DEFAULT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `lesson_topics_lesson_id_foreign` (`lesson_id`),
  KEY `lesson_topics_school_id_foreign` (`school_id`),
  CONSTRAINT `lesson_topics_lesson_id_foreign` FOREIGN KEY (`lesson_id`) REFERENCES `lessons` (`id`) ON DELETE CASCADE,
  CONSTRAINT `lesson_topics_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=13 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `lesson_topics` VALUES ('3', '5', 'Hypothesis Development', 'Hypothesis Development is the initial step in the scientific method, where researchers formulate educated guesses or predictions about experiment outcomes based on observations and existing knowledge.', '12', '2024-03-12 12:46:24', '2024-03-12 12:46:24');
INSERT INTO `lesson_topics` VALUES ('4', '4', 'Algebraic Expressions', 'explores the fundamental building blocks of algebra, focusing on the representation of mathematical relationships using symbols and variables. Students learn to simplify expressions, combine like terms, and apply algebraic rules to solve equations.', '12', '2024-03-12 12:48:41', '2024-03-12 12:48:41');
INSERT INTO `lesson_topics` VALUES ('5', '8', 'Topic 1', 'AS', '12', '2024-07-16 10:05:51', '2024-07-16 10:05:51');
INSERT INTO `lesson_topics` VALUES ('6', '12', 'test topic', 'test topic', '12', '2024-10-16 04:55:31', '2024-10-16 04:55:31');
INSERT INTO `lesson_topics` VALUES ('7', '19', 'eng', 'test eng', '12', '2024-10-29 17:06:10', '2024-10-29 17:06:10');
INSERT INTO `lesson_topics` VALUES ('8', '15', 'beijdb', 'hsjdbdj', '12', '2024-11-07 13:38:11', '2024-11-07 13:38:11');
INSERT INTO `lesson_topics` VALUES ('9', '21', 'dha2 img', 'dha2 img text', '12', '2024-11-21 13:33:51', '2024-11-21 13:33:51');
INSERT INTO `lesson_topics` VALUES ('11', '19', 'Advance Diploma In Education', 'Discription', '12', '2024-12-06 13:40:58', '2024-12-06 13:40:58');
INSERT INTO `lesson_topics` VALUES ('12', '25', 'Test topic', 't', '12', '2024-12-26 17:24:46', '2024-12-26 17:24:46');

CREATE TABLE IF NOT EXISTS `lessons` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(512) NOT NULL,
  `description` varchar(1024) DEFAULT NULL,
  `class_section_id` bigint(20) unsigned NOT NULL,
  `class_subject_id` bigint(20) unsigned NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `lessons_school_id_foreign` (`school_id`),
  KEY `lessons_class_section_id_foreign` (`class_section_id`),
  KEY `lessons_class_subject_id_foreign` (`class_subject_id`),
  CONSTRAINT `lessons_class_section_id_foreign` FOREIGN KEY (`class_section_id`) REFERENCES `class_sections` (`id`) ON DELETE CASCADE,
  CONSTRAINT `lessons_class_subject_id_foreign` FOREIGN KEY (`class_subject_id`) REFERENCES `class_subjects` (`id`) ON DELETE CASCADE,
  CONSTRAINT `lessons_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=30 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `lessons` VALUES ('4', 'Introduction to Algebra', '\"Introduction to Algebra\" covers essential concepts, equations, and expressions. It equips students with skills to solve equations and apply algebra to real-world scenarios, setting the stage for deeper mathematical study.', '28', '115', '12', '2024-03-12 12:39:47', '2024-03-12 12:39:47');
INSERT INTO `lessons` VALUES ('5', 'The Scientific Method', 'The Scientific Method\" is a systematic approach used by scientists to investigate phenomena, involving observation, hypothesis formation, experimentation, and analysis. It provides a structured framework for conducting research and gaining insights into the natural world.', '25', '82', '12', '2024-03-12 12:42:04', '2024-03-12 12:42:04');
INSERT INTO `lessons` VALUES ('6', 'Creative Writing: Narrative Techniques', 'explores various storytelling methods, including plot development, character creation, and setting establishment. Students learn to craft compelling narratives through engaging exercises and constructive feedback.', '27', '103', '12', '2024-03-12 12:43:41', '2024-03-12 12:43:41');
INSERT INTO `lessons` VALUES ('8', 'Day 1', 'A', '55', '46', '12', '2024-07-15 17:43:59', '2024-07-15 17:43:59');
INSERT INTO `lessons` VALUES ('9', 'Lesson 1', 'A', '55', '49', '12', '2024-07-15 17:44:47', '2024-07-15 17:44:47');
INSERT INTO `lessons` VALUES ('10', 'Day 2', 'Day 2', '55', '46', '12', '2024-07-16 10:02:45', '2024-07-16 10:02:45');
INSERT INTO `lessons` VALUES ('11', 'اسم الدرس', 'وصف', '55', '50', '12', '2024-10-14 22:57:51', '2024-10-14 22:57:51');
INSERT INTO `lessons` VALUES ('12', 'Day3', 'test day 3', '55', '46', '12', '2024-10-16 04:52:28', '2024-10-16 04:52:28');
INSERT INTO `lessons` VALUES ('13', 'test', 'estate', '55', '47', '12', '2024-10-16 04:54:39', '2024-10-16 04:54:39');
INSERT INTO `lessons` VALUES ('14', 'test med', 'test app', '21', '54', '12', '2024-10-23 01:08:22', '2024-10-23 01:08:22');
INSERT INTO `lessons` VALUES ('15', 'test the app from a tester', 'if liked I\'ll purchase it 🙂', '22', '61', '12', '2024-10-23 01:12:18', '2024-10-23 01:12:18');
INSERT INTO `lessons` VALUES ('18', 'lesson name', 'description', '23', '72', '12', '2024-10-29 02:17:41', '2024-10-29 02:17:41');
INSERT INTO `lessons` VALUES ('19', 'english', 'desc', '21', '54', '12', '2024-10-29 16:57:34', '2024-10-29 16:57:34');
INSERT INTO `lessons` VALUES ('20', 'dha', 'dha txt', '57', '60', '12', '2024-11-21 13:29:25', '2024-11-21 13:29:25');
INSERT INTO `lessons` VALUES ('21', 'dha img', 'gha text img', '57', '60', '12', '2024-11-21 13:30:47', '2024-11-21 13:30:47');
INSERT INTO `lessons` VALUES ('24', 'te', 'tttt', '21', '46', '12', '2024-12-14 13:10:48', '2024-12-14 13:10:48');
INSERT INTO `lessons` VALUES ('25', 'Test', 'tt', '22', '55', '12', '2024-12-26 17:24:04', '2024-12-26 17:24:04');
INSERT INTO `lessons` VALUES ('26', 'س', 'سس', '23', '64', '12', '2024-12-30 23:09:51', '2024-12-30 23:09:51');
INSERT INTO `lessons` VALUES ('28', 'mathematics', 'nil', '55', '46', '12', '2025-01-02 10:14:57', '2025-01-02 10:14:57');
INSERT INTO `lessons` VALUES ('29', 'New', 'new', '22', '55', '12', '2025-01-08 03:32:09', '2025-01-08 03:32:09');

CREATE TABLE IF NOT EXISTS `mediums` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(512) NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `mediums_school_id_foreign` (`school_id`),
  CONSTRAINT `mediums_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=17 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `mediums` VALUES ('10', 'English', '12', NULL, '2023-11-16 10:29:27', '2023-11-16 10:29:27');
INSERT INTO `mediums` VALUES ('11', 'Gujarati', '12', NULL, '2023-11-16 10:29:32', '2023-11-16 10:29:32');

CREATE TABLE IF NOT EXISTS `model_has_permissions` (
  `permission_id` bigint(20) unsigned NOT NULL,
  `model_type` varchar(191) NOT NULL,
  `model_id` bigint(20) unsigned NOT NULL,
  PRIMARY KEY (`permission_id`,`model_id`,`model_type`),
  KEY `model_has_permissions_model_id_model_type_index` (`model_id`,`model_type`),
  CONSTRAINT `model_has_permissions_permission_id_foreign` FOREIGN KEY (`permission_id`) REFERENCES `permissions` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `model_has_permissions` VALUES ('110', 'App\\Models\\User', '6');
INSERT INTO `model_has_permissions` VALUES ('110', 'App\\Models\\User', '11');
INSERT INTO `model_has_permissions` VALUES ('110', 'App\\Models\\User', '22');
INSERT INTO `model_has_permissions` VALUES ('110', 'App\\Models\\User', '36');
INSERT INTO `model_has_permissions` VALUES ('110', 'App\\Models\\User', '37');
INSERT INTO `model_has_permissions` VALUES ('110', 'App\\Models\\User', '42');
INSERT INTO `model_has_permissions` VALUES ('110', 'App\\Models\\User', '43');
INSERT INTO `model_has_permissions` VALUES ('110', 'App\\Models\\User', '44');
INSERT INTO `model_has_permissions` VALUES ('110', 'App\\Models\\User', '45');
INSERT INTO `model_has_permissions` VALUES ('110', 'App\\Models\\User', '46');
INSERT INTO `model_has_permissions` VALUES ('110', 'App\\Models\\User', '47');
INSERT INTO `model_has_permissions` VALUES ('110', 'App\\Models\\User', '48');
INSERT INTO `model_has_permissions` VALUES ('110', 'App\\Models\\User', '49');
INSERT INTO `model_has_permissions` VALUES ('110', 'App\\Models\\User', '1159');
INSERT INTO `model_has_permissions` VALUES ('110', 'App\\Models\\User', '1188');
INSERT INTO `model_has_permissions` VALUES ('111', 'App\\Models\\User', '6');
INSERT INTO `model_has_permissions` VALUES ('111', 'App\\Models\\User', '11');
INSERT INTO `model_has_permissions` VALUES ('111', 'App\\Models\\User', '22');
INSERT INTO `model_has_permissions` VALUES ('111', 'App\\Models\\User', '36');
INSERT INTO `model_has_permissions` VALUES ('111', 'App\\Models\\User', '37');
INSERT INTO `model_has_permissions` VALUES ('111', 'App\\Models\\User', '42');
INSERT INTO `model_has_permissions` VALUES ('111', 'App\\Models\\User', '43');
INSERT INTO `model_has_permissions` VALUES ('111', 'App\\Models\\User', '44');
INSERT INTO `model_has_permissions` VALUES ('111', 'App\\Models\\User', '45');
INSERT INTO `model_has_permissions` VALUES ('111', 'App\\Models\\User', '46');
INSERT INTO `model_has_permissions` VALUES ('111', 'App\\Models\\User', '47');
INSERT INTO `model_has_permissions` VALUES ('111', 'App\\Models\\User', '48');
INSERT INTO `model_has_permissions` VALUES ('111', 'App\\Models\\User', '49');
INSERT INTO `model_has_permissions` VALUES ('111', 'App\\Models\\User', '1159');
INSERT INTO `model_has_permissions` VALUES ('111', 'App\\Models\\User', '1188');
INSERT INTO `model_has_permissions` VALUES ('119', 'App\\Models\\User', '6');
INSERT INTO `model_has_permissions` VALUES ('119', 'App\\Models\\User', '11');
INSERT INTO `model_has_permissions` VALUES ('119', 'App\\Models\\User', '22');
INSERT INTO `model_has_permissions` VALUES ('119', 'App\\Models\\User', '36');
INSERT INTO `model_has_permissions` VALUES ('119', 'App\\Models\\User', '37');
INSERT INTO `model_has_permissions` VALUES ('119', 'App\\Models\\User', '42');
INSERT INTO `model_has_permissions` VALUES ('119', 'App\\Models\\User', '43');
INSERT INTO `model_has_permissions` VALUES ('119', 'App\\Models\\User', '44');
INSERT INTO `model_has_permissions` VALUES ('119', 'App\\Models\\User', '45');
INSERT INTO `model_has_permissions` VALUES ('119', 'App\\Models\\User', '46');
INSERT INTO `model_has_permissions` VALUES ('119', 'App\\Models\\User', '47');
INSERT INTO `model_has_permissions` VALUES ('119', 'App\\Models\\User', '48');
INSERT INTO `model_has_permissions` VALUES ('119', 'App\\Models\\User', '49');
INSERT INTO `model_has_permissions` VALUES ('119', 'App\\Models\\User', '1159');
INSERT INTO `model_has_permissions` VALUES ('119', 'App\\Models\\User', '1188');
INSERT INTO `model_has_permissions` VALUES ('388', 'App\\Models\\User', '1087');
INSERT INTO `model_has_permissions` VALUES ('389', 'App\\Models\\User', '1087');
INSERT INTO `model_has_permissions` VALUES ('390', 'App\\Models\\User', '1087');
INSERT INTO `model_has_permissions` VALUES ('391', 'App\\Models\\User', '1087');

CREATE TABLE IF NOT EXISTS `model_has_roles` (
  `role_id` bigint(20) unsigned NOT NULL,
  `model_type` varchar(191) NOT NULL,
  `model_id` bigint(20) unsigned NOT NULL,
  PRIMARY KEY (`role_id`,`model_id`,`model_type`),
  KEY `model_has_roles_model_id_model_type_index` (`model_id`,`model_type`),
  CONSTRAINT `model_has_roles_role_id_foreign` FOREIGN KEY (`role_id`) REFERENCES `roles` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '2');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '3');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '7');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '10');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '15');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '16');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '17');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '19');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '27');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '28');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '39');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '40');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '41');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '50');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '468');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1063');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1064');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1065');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1066');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1067');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1068');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1069');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1070');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1071');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1072');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1073');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1074');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1075');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1076');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1077');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1078');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1079');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1080');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1081');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1082');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1083');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1084');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1085');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1086');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1088');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1089');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1090');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1091');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1092');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1093');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1094');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1095');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1096');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1097');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1098');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1099');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1100');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1101');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1102');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1103');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1104');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1105');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1106');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1107');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1108');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1109');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1110');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1153');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1154');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1155');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1156');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1157');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1158');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1160');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1161');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1162');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1163');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1164');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1165');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1166');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1167');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1168');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1169');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1170');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1171');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1172');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1174');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1175');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1191');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1192');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1193');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1194');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1195');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1196');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1197');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1198');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1199');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1200');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1201');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1202');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1203');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1204');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1205');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1206');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1207');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1208');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1209');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1210');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1211');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1212');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1213');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1214');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1215');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1216');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1217');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1218');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1219');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1220');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1221');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1222');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1223');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1224');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1225');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1226');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1227');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1228');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1229');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1230');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1231');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1232');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1233');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1234');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1235');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1236');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1237');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1238');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1239');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1240');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1241');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1242');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1243');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1244');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1245');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1246');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1248');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1249');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1250');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1251');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1252');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1253');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1254');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1255');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1256');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1257');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1258');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1259');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1260');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1261');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1262');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1263');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1264');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1265');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1266');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1267');
INSERT INTO `model_has_roles` VALUES ('2', 'App\\Models\\User', '1268');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '330');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '348');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '350');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '352');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '354');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '356');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '358');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '360');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '362');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '364');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '366');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '368');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '370');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '372');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '374');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '376');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '378');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '380');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '382');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '384');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '386');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '388');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '390');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '392');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '394');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '396');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '398');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '400');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '402');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '404');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '406');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '408');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '410');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '412');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '414');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '416');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '418');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '420');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '422');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '424');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '426');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '428');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '430');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '432');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '434');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '436');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '438');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '440');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '442');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '444');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '446');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '448');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '450');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '452');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '454');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '456');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '458');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '460');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '462');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '464');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '466');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '469');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '471');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '473');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '475');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '477');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '479');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '481');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '483');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '485');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '487');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '489');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '491');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '493');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '495');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '497');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '499');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '501');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '503');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '505');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '507');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '509');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '511');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '513');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '515');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '517');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '519');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '521');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '523');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '525');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '527');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '529');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '531');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '533');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '535');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '537');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '539');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '541');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '543');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '545');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '547');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '549');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '551');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '553');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '555');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '557');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '559');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '561');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '563');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '565');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '567');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '569');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '571');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '573');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '575');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '577');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '579');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '581');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '583');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '585');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '587');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '589');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '591');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '593');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '595');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '597');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '599');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '601');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '603');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '605');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '607');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '609');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '611');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '613');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '615');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '617');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '619');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '621');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '623');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '625');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '627');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '629');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '631');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '633');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '635');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '637');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '639');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '641');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '643');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '645');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '647');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '649');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '651');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '653');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '655');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '657');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '659');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '661');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '663');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '665');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '667');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '669');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '671');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '673');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '675');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '677');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '679');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '681');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '683');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '685');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '687');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '689');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '691');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '693');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '695');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '697');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '699');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '701');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '703');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '705');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '707');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '709');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '711');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '713');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '715');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '717');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '719');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '721');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '723');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '725');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '727');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '729');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '731');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '733');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '735');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '737');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '739');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '741');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '743');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '745');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '747');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '749');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '751');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '753');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '755');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '757');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '759');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '761');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '763');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '765');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '767');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '769');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '771');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '773');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '775');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '777');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '779');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '781');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '783');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '785');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '787');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '789');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '791');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '793');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '795');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '797');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '799');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '801');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '803');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '805');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '807');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '809');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '811');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '813');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '815');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '817');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '819');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '821');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '823');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '825');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '827');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '829');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '831');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '833');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '835');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '837');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '839');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '841');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '843');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '845');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '847');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '849');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '851');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '853');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '855');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '857');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '859');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '861');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '863');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '865');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '867');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '869');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '871');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '873');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '875');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '877');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '879');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '881');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '883');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '885');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '887');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '889');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '891');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '893');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '895');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '897');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '899');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '901');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '903');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '905');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '907');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '909');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '911');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '913');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '915');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '917');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '919');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '921');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '923');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '925');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '927');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '929');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '931');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '933');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '935');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '937');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '939');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '941');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '943');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '945');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '947');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '949');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '951');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '953');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '955');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '957');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '959');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '961');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '963');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '965');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '967');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '969');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '971');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '973');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '975');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '977');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '979');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '981');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '983');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '985');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '987');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '989');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '991');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '993');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '995');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '997');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '999');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1001');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1003');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1005');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1007');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1009');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1011');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1013');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1015');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1017');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1019');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1021');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1023');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1025');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1027');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1029');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1031');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1033');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1035');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1037');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1039');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1041');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1043');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1045');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1047');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1049');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1051');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1053');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1055');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1057');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1059');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1061');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1088');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1090');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1092');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1094');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1096');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1098');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1100');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1102');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1104');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1106');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1108');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1110');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1112');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1114');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1116');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1118');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1120');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1122');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1124');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1126');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1128');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1130');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1133');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1136');
INSERT INTO `model_has_roles` VALUES ('41', 'App\\Models\\User', '1138');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '331');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '333');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '334');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '335');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '336');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '337');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '338');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '339');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '340');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '341');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '342');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '343');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '344');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '345');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '346');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '347');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '349');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '351');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '353');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '355');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '357');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '359');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '361');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '363');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '365');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '367');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '371');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '377');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '381');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '387');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '403');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '407');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '409');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '417');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '419');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '421');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '423');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '425');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '427');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '429');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '431');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '433');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '435');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '437');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '439');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '441');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '443');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '445');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '447');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '449');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '451');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '453');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '455');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '457');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '459');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '461');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '463');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '465');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '467');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '470');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '472');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '474');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '476');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '478');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '480');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '482');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '484');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '486');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '488');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '490');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '492');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '494');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '496');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '498');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '500');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '502');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '504');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '506');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '508');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '510');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '512');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '514');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '516');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '518');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '520');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '522');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '524');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '526');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '528');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '530');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '532');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '534');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '536');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '538');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '540');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '542');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '544');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '546');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '548');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '550');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '552');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '554');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '556');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '558');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '560');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '562');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '564');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '566');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '568');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '570');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '572');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '574');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '576');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '578');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '580');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '582');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '584');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '586');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '588');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '590');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '592');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '594');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '596');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '598');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '600');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '602');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '604');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '606');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '608');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '610');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '612');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '614');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '616');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '618');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '620');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '622');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '624');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '626');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '628');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '630');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '632');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '634');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '636');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '638');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '640');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '642');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '644');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '646');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '648');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '650');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '652');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '654');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '656');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '658');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '660');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '662');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '664');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '666');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '668');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '670');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '672');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '674');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '676');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '678');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '680');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '682');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '684');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '686');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '688');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '690');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '692');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '694');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '696');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '698');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '700');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '702');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '704');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '706');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '708');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '710');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '712');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '714');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '716');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '718');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '720');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '722');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '724');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '726');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '728');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '730');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '732');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '734');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '736');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '738');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '740');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '742');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '744');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '746');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '748');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '750');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '752');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '754');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '756');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '758');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '760');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '762');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '764');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '766');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '768');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '770');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '772');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '774');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '776');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '778');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '780');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '782');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '784');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '786');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '788');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '790');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '792');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '794');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '796');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '798');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '800');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '802');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '804');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '806');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '808');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '810');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '812');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '814');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '816');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '818');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '820');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '822');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '824');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '826');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '828');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '830');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '832');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '834');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '836');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '838');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '840');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '842');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '844');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '846');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '848');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '850');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '852');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '854');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '856');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '858');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '860');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '862');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '864');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '866');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '868');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '870');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '872');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '874');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '876');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '878');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '880');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '882');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '884');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '886');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '888');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '890');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '892');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '894');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '896');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '898');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '900');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '902');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '904');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '906');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '908');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '910');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '912');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '914');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '916');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '918');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '920');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '922');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '924');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '926');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '928');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '930');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '932');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '934');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '936');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '938');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '940');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '942');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '944');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '946');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '948');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '950');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '952');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '954');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '956');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '958');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '960');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '962');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '964');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '966');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '968');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '970');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '972');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '974');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '976');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '978');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '980');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '982');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '984');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '986');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '988');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '990');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '992');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '994');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '996');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '998');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1000');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1002');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1004');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1006');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1008');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1010');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1012');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1014');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1016');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1018');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1020');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1022');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1024');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1026');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1028');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1030');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1032');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1034');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1036');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1038');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1040');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1042');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1044');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1046');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1048');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1050');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1052');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1054');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1056');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1058');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1060');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1062');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1089');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1091');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1093');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1095');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1097');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1099');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1101');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1103');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1105');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1107');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1109');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1111');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1113');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1115');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1117');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1119');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1121');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1123');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1125');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1127');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1129');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1131');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1132');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1134');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1135');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1137');
INSERT INTO `model_has_roles` VALUES ('42', 'App\\Models\\User', '1139');
INSERT INTO `model_has_roles` VALUES ('128', 'App\\Models\\User', '1087');

CREATE TABLE IF NOT EXISTS `notifications` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `title` varchar(191) NOT NULL,
  `message` varchar(191) DEFAULT NULL,
  `image` varchar(191) DEFAULT NULL,
  `send_to` varchar(191) NOT NULL,
  `session_year_id` bigint(20) unsigned NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `notifications_session_year_id_foreign` (`session_year_id`),
  KEY `notifications_school_id_foreign` (`school_id`),
  CONSTRAINT `notifications_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `notifications_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=39 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `notifications` VALUES ('1', 'This is a test notification', 'Test', NULL, 'All users', '17', '12', '2024-03-21 17:54:10', '2024-03-21 17:54:10');
INSERT INTO `notifications` VALUES ('2', 'Hello', 'Test', NULL, 'All users', '17', '12', '2024-03-21 17:59:35', '2024-03-21 17:59:35');
INSERT INTO `notifications` VALUES ('3', 'Hello', 'Test', NULL, 'All users', '17', '12', '2024-03-21 17:59:57', '2024-03-21 17:59:57');
INSERT INTO `notifications` VALUES ('4', 'This is a test', 'notification', NULL, 'All users', '17', '12', '2024-03-21 18:00:33', '2024-03-21 18:00:33');
INSERT INTO `notifications` VALUES ('37', 'Test', 'Test msg', NULL, 'Roles', '17', '12', '2024-05-27 12:32:25', '2024-05-27 12:32:25');
INSERT INTO `notifications` VALUES ('38', 'test', 'test', NULL, 'All users', '17', '12', '2024-12-16 02:25:24', '2024-12-16 02:25:24');

CREATE TABLE IF NOT EXISTS `online_exam_commons` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `online_exam_id` bigint(20) unsigned NOT NULL,
  `class_section_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `online_exam_commons_online_exam_id_foreign` (`online_exam_id`),
  KEY `online_exam_commons_class_section_id_foreign` (`class_section_id`),
  CONSTRAINT `online_exam_commons_class_section_id_foreign` FOREIGN KEY (`class_section_id`) REFERENCES `class_sections` (`id`) ON DELETE CASCADE,
  CONSTRAINT `online_exam_commons_online_exam_id_foreign` FOREIGN KEY (`online_exam_id`) REFERENCES `online_exams` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=5 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `online_exam_commons` VALUES ('1', '15', '21', '2025-01-03 10:51:05', '2025-01-03 10:51:05');
INSERT INTO `online_exam_commons` VALUES ('2', '16', '21', '2025-01-03 10:51:05', '2025-01-03 10:51:05');
INSERT INTO `online_exam_commons` VALUES ('3', '17', '21', '2025-01-03 10:51:05', '2025-01-03 10:51:05');
INSERT INTO `online_exam_commons` VALUES ('4', '19', '21', '2025-01-03 10:51:06', '2025-01-03 10:51:06');

CREATE TABLE IF NOT EXISTS `online_exam_question_choices` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `online_exam_id` bigint(20) unsigned NOT NULL,
  `question_id` bigint(20) unsigned NOT NULL,
  `marks` int(11) DEFAULT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `online_exam_question_choices_school_id_foreign` (`school_id`),
  KEY `online_exam_question_choices_online_exam_id_foreign` (`online_exam_id`),
  KEY `online_exam_question_choices_question_id_foreign` (`question_id`),
  CONSTRAINT `online_exam_question_choices_online_exam_id_foreign` FOREIGN KEY (`online_exam_id`) REFERENCES `online_exams` (`id`) ON DELETE CASCADE,
  CONSTRAINT `online_exam_question_choices_question_id_foreign` FOREIGN KEY (`question_id`) REFERENCES `online_exam_questions` (`id`) ON DELETE CASCADE,
  CONSTRAINT `online_exam_question_choices_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=28 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `online_exam_question_choices` VALUES ('21', '15', '19', '10', '12', '2023-11-21 10:14:09', '2023-11-21 10:14:09', NULL);
INSERT INTO `online_exam_question_choices` VALUES ('22', '15', '18', '10', '12', '2023-11-21 10:14:09', '2023-11-21 10:14:09', NULL);
INSERT INTO `online_exam_question_choices` VALUES ('23', '15', '17', '10', '12', '2023-11-21 10:14:09', '2023-11-21 10:14:09', NULL);
INSERT INTO `online_exam_question_choices` VALUES ('24', '16', '20', '50', '12', '2023-11-23 06:41:33', '2023-11-23 06:41:33', NULL);
INSERT INTO `online_exam_question_choices` VALUES ('25', '19', '23', '5', '12', '2024-09-06 12:00:59', '2024-09-06 12:00:59', NULL);
INSERT INTO `online_exam_question_choices` VALUES ('26', '19', '22', '5', '12', '2024-09-06 12:00:59', '2024-09-06 12:00:59', NULL);
INSERT INTO `online_exam_question_choices` VALUES ('27', '19', '21', '5', '12', '2024-09-06 12:00:59', '2024-09-06 12:00:59', NULL);

CREATE TABLE IF NOT EXISTS `online_exam_question_commons` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `online_exam_question_id` bigint(20) unsigned NOT NULL,
  `class_section_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `online_exam_question_commons_online_exam_question_id_foreign` (`online_exam_question_id`),
  KEY `online_exam_question_commons_class_section_id_foreign` (`class_section_id`),
  CONSTRAINT `online_exam_question_commons_class_section_id_foreign` FOREIGN KEY (`class_section_id`) REFERENCES `class_sections` (`id`) ON DELETE CASCADE,
  CONSTRAINT `online_exam_question_commons_online_exam_question_id_foreign` FOREIGN KEY (`online_exam_question_id`) REFERENCES `online_exam_questions` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=8 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `online_exam_question_commons` VALUES ('1', '17', '21', '2025-01-03 10:51:08', '2025-01-03 10:51:08');
INSERT INTO `online_exam_question_commons` VALUES ('2', '18', '21', '2025-01-03 10:51:08', '2025-01-03 10:51:08');
INSERT INTO `online_exam_question_commons` VALUES ('3', '19', '21', '2025-01-03 10:51:08', '2025-01-03 10:51:08');
INSERT INTO `online_exam_question_commons` VALUES ('4', '20', '21', '2025-01-03 10:51:08', '2025-01-03 10:51:08');
INSERT INTO `online_exam_question_commons` VALUES ('5', '21', '21', '2025-01-03 10:51:08', '2025-01-03 10:51:08');
INSERT INTO `online_exam_question_commons` VALUES ('6', '22', '21', '2025-01-03 10:51:08', '2025-01-03 10:51:08');
INSERT INTO `online_exam_question_commons` VALUES ('7', '23', '21', '2025-01-03 10:51:08', '2025-01-03 10:51:08');

CREATE TABLE IF NOT EXISTS `online_exam_question_options` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `question_id` bigint(20) unsigned NOT NULL,
  `option` varchar(1024) NOT NULL,
  `is_answer` tinyint(4) NOT NULL COMMENT '1 - yes, 0 - no',
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `online_exam_question_options_question_id_foreign` (`question_id`),
  KEY `online_exam_question_options_school_id_foreign` (`school_id`),
  CONSTRAINT `online_exam_question_options_question_id_foreign` FOREIGN KEY (`question_id`) REFERENCES `online_exam_questions` (`id`) ON DELETE CASCADE,
  CONSTRAINT `online_exam_question_options_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=66 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `online_exam_question_options` VALUES ('40', '17', '&lt;p&gt;ख&lt;/p&gt;', '0', '12', NULL, NULL, NULL);
INSERT INTO `online_exam_question_options` VALUES ('41', '17', '&lt;p&gt;क&lt;/p&gt;', '1', '12', NULL, NULL, NULL);
INSERT INTO `online_exam_question_options` VALUES ('42', '17', '&lt;p&gt;ग&lt;/p&gt;', '0', '12', NULL, NULL, NULL);
INSERT INTO `online_exam_question_options` VALUES ('43', '17', '&lt;p&gt;च&lt;/p&gt;', '0', '12', NULL, NULL, NULL);
INSERT INTO `online_exam_question_options` VALUES ('44', '18', '&lt;p&gt;🍇&lt;/p&gt;', '0', '12', NULL, NULL, NULL);
INSERT INTO `online_exam_question_options` VALUES ('45', '18', '&lt;p&gt;🍎&lt;/p&gt;', '0', '12', NULL, NULL, NULL);
INSERT INTO `online_exam_question_options` VALUES ('46', '18', '&lt;p&gt;&amp;nbsp;🍊&lt;/p&gt;', '0', '12', NULL, NULL, NULL);
INSERT INTO `online_exam_question_options` VALUES ('47', '18', '&lt;p&gt;🥭&lt;/p&gt;', '1', '12', NULL, NULL, NULL);
INSERT INTO `online_exam_question_options` VALUES ('48', '19', '&lt;p&gt;दो (Two)&lt;/p&gt;', '0', '12', NULL, NULL, NULL);
INSERT INTO `online_exam_question_options` VALUES ('49', '19', '&lt;p&gt;तीन (Three)&lt;/p&gt;', '0', '12', NULL, NULL, NULL);
INSERT INTO `online_exam_question_options` VALUES ('50', '19', '&lt;p&gt;चार (Four)&lt;/p&gt;', '0', '12', NULL, NULL, NULL);
INSERT INTO `online_exam_question_options` VALUES ('51', '19', '&lt;p&gt;पाँच (Five)&lt;/p&gt;', '1', '12', NULL, NULL, NULL);
INSERT INTO `online_exam_question_options` VALUES ('52', '20', '&lt;p&gt;Ballet&lt;/p&gt;', '0', '12', NULL, NULL, NULL);
INSERT INTO `online_exam_question_options` VALUES ('53', '20', '&lt;p&gt;Jazz&lt;/p&gt;', '0', '12', NULL, NULL, NULL);
INSERT INTO `online_exam_question_options` VALUES ('54', '20', '&lt;p&gt;Tap&lt;/p&gt;', '1', '12', NULL, NULL, NULL);
INSERT INTO `online_exam_question_options` VALUES ('55', '20', '&lt;p&gt;Flamenco&lt;/p&gt;', '0', '12', NULL, NULL, NULL);
INSERT INTO `online_exam_question_options` VALUES ('56', '21', '&lt;p&gt;0&lt;/p&gt;', '0', '12', '2024-09-06 11:56:11', '2024-09-06 11:56:11', NULL);
INSERT INTO `online_exam_question_options` VALUES ('57', '21', '&lt;p&gt;2&lt;/p&gt;', '0', '12', '2024-09-06 11:56:11', '2024-09-06 11:56:11', NULL);
INSERT INTO `online_exam_question_options` VALUES ('58', '21', '&lt;p&gt;4&lt;/p&gt;', '1', '12', '2024-09-06 11:56:11', '2024-09-06 11:56:11', NULL);
INSERT INTO `online_exam_question_options` VALUES ('59', '21', '&lt;p&gt;22&lt;/p&gt;', '0', '12', '2024-09-06 11:56:11', '2024-09-06 11:56:11', NULL);
INSERT INTO `online_exam_question_options` VALUES ('60', '22', '&lt;p&gt;True&lt;/p&gt;', '1', '12', '2024-09-06 11:56:53', '2024-09-06 11:56:53', NULL);
INSERT INTO `online_exam_question_options` VALUES ('61', '22', '&lt;p&gt;False&lt;/p&gt;', '0', '12', '2024-09-06 11:56:53', '2024-09-06 11:56:53', NULL);
INSERT INTO `online_exam_question_options` VALUES ('62', '23', '&lt;p&gt;&lt;span class=&quot;math-tex&quot;&gt;\\(\\alpha\\)&lt;/span&gt;&lt;/p&gt;', '1', '12', '2024-09-06 12:00:34', '2024-09-06 12:00:34', NULL);
INSERT INTO `online_exam_question_options` VALUES ('63', '23', '&lt;p&gt;&lt;span class=&quot;math-tex&quot;&gt;\\(\\beta\\)&lt;/span&gt;&lt;/p&gt;', '0', '12', '2024-09-06 12:00:34', '2024-09-06 12:00:34', NULL);
INSERT INTO `online_exam_question_options` VALUES ('64', '23', '&lt;p&gt;&lt;span class=&quot;math-tex&quot;&gt;\\(\\pi\\)&lt;/span&gt;&lt;/p&gt;', '0', '12', '2024-09-06 12:00:34', '2024-09-06 12:00:34', NULL);
INSERT INTO `online_exam_question_options` VALUES ('65', '23', '&lt;p&gt;&lt;span class=&quot;math-tex&quot;&gt;\\(\\Phi\\)&lt;/span&gt;&lt;/p&gt;', '0', '12', '2024-09-06 12:00:34', '2024-09-06 12:00:34', NULL);

CREATE TABLE IF NOT EXISTS `online_exam_questions` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `class_section_id` bigint(20) unsigned NOT NULL,
  `class_subject_id` bigint(20) unsigned NOT NULL,
  `question` varchar(1024) NOT NULL,
  `image_url` varchar(1024) DEFAULT NULL,
  `note` varchar(1024) DEFAULT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `last_edited_by` bigint(20) unsigned NOT NULL COMMENT 'teacher_user_id',
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `online_exam_questions_school_id_foreign` (`school_id`),
  KEY `online_exam_questions_class_section_id_foreign` (`class_section_id`),
  KEY `online_exam_questions_class_subject_id_foreign` (`class_subject_id`),
  KEY `online_exam_questions_last_edited_by_foreign` (`last_edited_by`),
  CONSTRAINT `online_exam_questions_class_section_id_foreign` FOREIGN KEY (`class_section_id`) REFERENCES `class_sections` (`id`) ON DELETE CASCADE,
  CONSTRAINT `online_exam_questions_class_subject_id_foreign` FOREIGN KEY (`class_subject_id`) REFERENCES `class_subjects` (`id`) ON DELETE CASCADE,
  CONSTRAINT `online_exam_questions_last_edited_by_foreign` FOREIGN KEY (`last_edited_by`) REFERENCES `users` (`id`) ON DELETE CASCADE,
  CONSTRAINT `online_exam_questions_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=24 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `online_exam_questions` VALUES ('17', '21', '47', '&lt;p&gt;What is the Hindi letter for the sound &amp;quot;क&amp;quot;?&lt;/p&gt;', NULL, NULL, '12', '45', '2023-11-21 10:10:01', '2023-11-21 10:10:01', NULL);
INSERT INTO `online_exam_questions` VALUES ('18', '21', '47', '&lt;p&gt;&amp;nbsp;&lt;/p&gt;&lt;p&gt;Which picture represents the word &amp;quot;आम&amp;quot;?&lt;/p&gt;&lt;ul&gt;&lt;/ul&gt;', NULL, NULL, '12', '45', '2023-11-21 10:12:36', '2023-11-21 10:12:36', NULL);
INSERT INTO `online_exam_questions` VALUES ('19', '21', '47', '&lt;p&gt;How many fingers are there in Hindi when we say &amp;quot;अंगुली&amp;quot;?&lt;/p&gt;', NULL, NULL, '12', '45', '2023-11-21 10:13:45', '2023-11-21 10:13:45', NULL);
INSERT INTO `online_exam_questions` VALUES ('20', '21', '53', '&lt;p&gt;What is the name of the dance where you clap your hands and stomp your feet in a rhythmic pattern?&lt;/p&gt;', NULL, NULL, '12', '45', '2023-11-23 06:41:21', '2023-11-23 06:41:21', NULL);
INSERT INTO `online_exam_questions` VALUES ('21', '21', '48', '&lt;p&gt;2+2 = ?&lt;/p&gt;', NULL, NULL, '12', '49', '2024-09-06 11:56:11', '2024-09-06 11:56:11', NULL);
INSERT INTO `online_exam_questions` VALUES ('22', '21', '48', '&lt;p&gt;&lt;span class=&quot;math-tex&quot;&gt;\\(x = {-b \\pm \\sqrt{b^2-4ac} \\over 2a}\\)&lt;/span&gt;&lt;/p&gt;', NULL, NULL, '12', '49', '2024-09-06 11:56:53', '2024-09-06 11:56:53', NULL);
INSERT INTO `online_exam_questions` VALUES ('23', '21', '48', '&lt;p&gt;Alpha sign?&lt;/p&gt;', NULL, NULL, '12', '49', '2024-09-06 12:00:34', '2024-09-06 12:00:34', NULL);

CREATE TABLE IF NOT EXISTS `online_exam_student_answers` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `student_id` bigint(20) unsigned NOT NULL COMMENT 'user_id',
  `online_exam_id` bigint(20) unsigned NOT NULL,
  `question_id` bigint(20) unsigned NOT NULL,
  `option_id` bigint(20) unsigned NOT NULL,
  `submitted_date` date NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `online_exam_student_answers_school_id_foreign` (`school_id`),
  KEY `online_exam_student_answers_student_id_foreign` (`student_id`),
  KEY `online_exam_student_answers_online_exam_id_foreign` (`online_exam_id`),
  KEY `online_exam_student_answers_question_id_foreign` (`question_id`),
  KEY `online_exam_student_answers_option_id_foreign` (`option_id`),
  CONSTRAINT `online_exam_student_answers_online_exam_id_foreign` FOREIGN KEY (`online_exam_id`) REFERENCES `online_exams` (`id`) ON DELETE CASCADE,
  CONSTRAINT `online_exam_student_answers_option_id_foreign` FOREIGN KEY (`option_id`) REFERENCES `online_exam_question_options` (`id`) ON DELETE CASCADE,
  CONSTRAINT `online_exam_student_answers_question_id_foreign` FOREIGN KEY (`question_id`) REFERENCES `online_exam_question_choices` (`id`) ON DELETE CASCADE,
  CONSTRAINT `online_exam_student_answers_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `online_exam_student_answers_student_id_foreign` FOREIGN KEY (`student_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `online_exams` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `class_section_id` bigint(20) unsigned NOT NULL,
  `class_subject_id` bigint(20) unsigned NOT NULL,
  `title` varchar(128) NOT NULL,
  `exam_key` bigint(20) NOT NULL,
  `duration` int(11) NOT NULL COMMENT 'in minutes',
  `start_date` datetime NOT NULL,
  `end_date` datetime NOT NULL,
  `session_year_id` bigint(20) unsigned NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `online_exams_school_id_foreign` (`school_id`),
  KEY `online_exams_class_section_id_foreign` (`class_section_id`),
  KEY `online_exams_class_subject_id_foreign` (`class_subject_id`),
  KEY `online_exams_session_year_id_foreign` (`session_year_id`),
  CONSTRAINT `online_exams_class_section_id_foreign` FOREIGN KEY (`class_section_id`) REFERENCES `class_sections` (`id`) ON DELETE CASCADE,
  CONSTRAINT `online_exams_class_subject_id_foreign` FOREIGN KEY (`class_subject_id`) REFERENCES `class_subjects` (`id`) ON DELETE CASCADE,
  CONSTRAINT `online_exams_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `online_exams_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=20 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `online_exams` VALUES ('15', '21', '47', 'Oral Examination (Key : 1122)', '1122', '30', '2024-01-01 10:30:00', '2024-01-01 11:00:00', '17', '12', '2023-11-21 10:01:53', '2023-11-21 10:15:35', NULL);
INSERT INTO `online_exams` VALUES ('16', '21', '53', 'Practical Exam (Key : 3344)', '3344', '30', '2023-12-02 10:30:00', '2023-12-02 11:00:00', '17', '12', '2023-11-21 10:03:42', '2023-11-21 10:15:12', NULL);
INSERT INTO `online_exams` VALUES ('17', '21', '46', 'Number system', '420', '30', '2023-11-24 10:30:00', '2023-11-25 10:30:00', '17', '12', '2023-11-23 06:56:03', '2023-11-23 06:56:03', NULL);
INSERT INTO `online_exams` VALUES ('19', '21', '48', 'Basic Maths', '2515', '30', '2024-09-01 10:00:00', '2024-09-30 17:00:00', '17', '12', '2024-09-06 11:55:32', '2024-09-06 11:55:32', NULL);

CREATE TABLE IF NOT EXISTS `optional_fees` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `student_id` bigint(20) unsigned NOT NULL COMMENT 'user_id',
  `class_id` bigint(20) unsigned NOT NULL,
  `payment_transaction_id` bigint(20) unsigned DEFAULT NULL,
  `fees_class_id` bigint(20) unsigned DEFAULT NULL,
  `mode` enum('Cash','Cheque','Online') NOT NULL,
  `cheque_no` varchar(191) DEFAULT NULL,
  `amount` double(8,2) NOT NULL,
  `fees_paid_id` bigint(20) unsigned DEFAULT NULL,
  `date` date NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `status` enum('Success','Pending','Failed') NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `optional_fees_school_id_foreign` (`school_id`),
  KEY `optional_fees_student_id_foreign` (`student_id`),
  KEY `optional_fees_class_id_foreign` (`class_id`),
  KEY `optional_fees_payment_transaction_id_foreign` (`payment_transaction_id`),
  KEY `optional_fees_fees_paid_id_foreign` (`fees_paid_id`),
  KEY `optional_fees_fees_class_id_foreign` (`fees_class_id`),
  CONSTRAINT `optional_fees_class_id_foreign` FOREIGN KEY (`class_id`) REFERENCES `classes` (`id`) ON DELETE CASCADE,
  CONSTRAINT `optional_fees_fees_class_id_foreign` FOREIGN KEY (`fees_class_id`) REFERENCES `fees_class_types` (`id`) ON DELETE CASCADE,
  CONSTRAINT `optional_fees_fees_paid_id_foreign` FOREIGN KEY (`fees_paid_id`) REFERENCES `fees_paids` (`id`) ON DELETE CASCADE,
  CONSTRAINT `optional_fees_payment_transaction_id_foreign` FOREIGN KEY (`payment_transaction_id`) REFERENCES `payment_transactions` (`id`) ON DELETE CASCADE,
  CONSTRAINT `optional_fees_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `optional_fees_student_id_foreign` FOREIGN KEY (`student_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `optional_fees` VALUES ('1', '331', '13', NULL, '4', 'Cash', NULL, '5000', '1', '2024-01-25', '12', 'Success', '2024-01-25 05:12:48', '2024-01-25 05:12:48', NULL);

CREATE TABLE IF NOT EXISTS `payment_configurations` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `payment_method` varchar(191) NOT NULL,
  `api_key` varchar(191) NOT NULL,
  `secret_key` varchar(191) NOT NULL,
  `webhook_secret_key` varchar(191) NOT NULL,
  `bank_name` varchar(191) DEFAULT NULL,
  `account_name` varchar(191) DEFAULT NULL,
  `account_no` varchar(191) DEFAULT NULL,
  `currency_code` varchar(128) DEFAULT NULL,
  `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '0 - Disabled, 1 - Enabled',
  `school_id` bigint(20) unsigned DEFAULT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `payment_configurations_school_id_foreign` (`school_id`),
  CONSTRAINT `payment_configurations_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=3 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `payment_configurations` VALUES ('2', 'Stripe', 'pk_test_51OXHuyBvoXuMhOgsDDsPnkhDar7xywK5RD07QoxNHgwk0jgV16C7QTp3CcgZRCwWWaPtQYvtc1I116eEC0giEqcT00CXsDq9e1', 'sk_test_51OXHuyBvoXuMhOgstCekbAaafmg3AgTYFemu3jW1v4fw1xC5nrifuloLwsbdTcX6tZaV8xydf1fMxlcMxWV8UQ7a00AuKnL7eF', 'whsec_PoIFDameYGyBmH6B0ZnXhHF9rYSfA813', NULL, NULL, NULL, 'USD', '1', '12', '2024-02-21 10:31:33', '2024-02-21 10:31:33');

CREATE TABLE IF NOT EXISTS `payment_transactions` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `user_id` bigint(20) unsigned NOT NULL,
  `amount` double(64,2) NOT NULL,
  `payment_gateway` varchar(191) NOT NULL,
  `order_id` varchar(191) DEFAULT NULL COMMENT 'order_id / payment_intent_id',
  `payment_id` varchar(191) DEFAULT NULL,
  `payment_signature` varchar(191) DEFAULT NULL,
  `payment_status` enum('failed','succeed','pending') NOT NULL,
  `school_id` bigint(20) unsigned DEFAULT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `payment_transactions_school_id_foreign` (`school_id`),
  KEY `payment_transactions_user_id_foreign` (`user_id`),
  CONSTRAINT `payment_transactions_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `payment_transactions_user_id_foreign` FOREIGN KEY (`user_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=223 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `payment_transactions` VALUES ('1', '330', '6060', 'Stripe', 'pi_3Q5DuvBvoXuMhOgs0QbUQSmF', NULL, NULL, 'pending', '12', '2024-10-02 03:17:36', '2024-10-02 03:17:37');
INSERT INTO `payment_transactions` VALUES ('2', '330', '6060', 'Stripe', 'pi_3Q5VK2BvoXuMhOgs1U5cTuus', NULL, NULL, 'pending', '12', '2024-10-02 21:52:42', '2024-10-02 21:52:43');
INSERT INTO `payment_transactions` VALUES ('3', '330', '6060', 'Stripe', 'pi_3Q5VYDBvoXuMhOgs0bw20PV7', NULL, NULL, 'pending', '12', '2024-10-02 22:07:21', '2024-10-02 22:07:22');
INSERT INTO `payment_transactions` VALUES ('4', '330', '6060', 'Stripe', 'pi_3Q5m3cBvoXuMhOgs1M7vB60R', NULL, NULL, 'pending', '12', '2024-10-03 15:44:51', '2024-10-03 15:44:52');
INSERT INTO `payment_transactions` VALUES ('5', '330', '6060', 'Stripe', 'pi_3Q5m3wBvoXuMhOgs0UHAhG24', NULL, NULL, 'pending', '12', '2024-10-03 15:45:12', '2024-10-03 15:45:12');
INSERT INTO `payment_transactions` VALUES ('6', '330', '1530', 'Stripe', 'pi_3Q5qsyBvoXuMhOgs0lc7WpdG', NULL, NULL, 'pending', '12', '2024-10-03 20:54:12', '2024-10-03 20:54:13');
INSERT INTO `payment_transactions` VALUES ('7', '330', '1530', 'Stripe', 'pi_3Q6TZsBvoXuMhOgs105isvWH', NULL, NULL, 'pending', '12', '2024-10-05 14:13:03', '2024-10-05 14:13:04');
INSERT INTO `payment_transactions` VALUES ('8', '330', '1000', 'Stripe', 'pi_3Q6TalBvoXuMhOgs0J7NvPAm', NULL, NULL, 'pending', '12', '2024-10-05 14:13:59', '2024-10-05 14:13:59');
INSERT INTO `payment_transactions` VALUES ('9', '330', '1530', 'Stripe', 'pi_3Q6UA3BvoXuMhOgs0Z9HxMp2', NULL, NULL, 'pending', '12', '2024-10-05 14:50:26', '2024-10-05 14:50:27');
INSERT INTO `payment_transactions` VALUES ('10', '330', '6120', 'Stripe', 'pi_3Q6gWyBvoXuMhOgs12sVdBZg', NULL, NULL, 'pending', '12', '2024-10-06 04:02:56', '2024-10-06 04:02:57');
INSERT INTO `payment_transactions` VALUES ('11', '330', '1530', 'Stripe', 'pi_3Q6wICBvoXuMhOgs0IJd6O9C', NULL, NULL, 'pending', '12', '2024-10-06 20:52:44', '2024-10-06 20:52:45');
INSERT INTO `payment_transactions` VALUES ('12', '330', '6060', 'Stripe', 'pi_3Q6xwLBvoXuMhOgs1vqv2P4q', NULL, NULL, 'pending', '12', '2024-10-06 22:38:16', '2024-10-06 22:38:17');
INSERT INTO `payment_transactions` VALUES ('13', '330', '1530', 'Stripe', 'pi_3Q7CueBvoXuMhOgs1NejJ6U2', NULL, NULL, 'pending', '12', '2024-10-07 14:37:31', '2024-10-07 14:37:32');
INSERT INTO `payment_transactions` VALUES ('14', '330', '1530', 'Stripe', 'pi_3Q7IyhBvoXuMhOgs1TElp3y1', NULL, NULL, 'pending', '12', '2024-10-07 21:06:06', '2024-10-07 21:06:07');
INSERT INTO `payment_transactions` VALUES ('15', '330', '1000', 'Stripe', 'pi_3Q7OeWBvoXuMhOgs1Q2dNGPu', NULL, NULL, 'pending', '12', '2024-10-08 03:09:39', '2024-10-08 03:09:40');
INSERT INTO `payment_transactions` VALUES ('16', '330', '1530', 'Stripe', 'pi_3Q7OfJBvoXuMhOgs1JPE24lD', NULL, NULL, 'pending', '12', '2024-10-08 03:10:29', '2024-10-08 03:10:29');
INSERT INTO `payment_transactions` VALUES ('17', '330', '1530', 'Stripe', 'pi_3Q7OqABvoXuMhOgs0QQw3GWc', NULL, NULL, 'pending', '12', '2024-10-08 03:21:41', '2024-10-08 03:21:42');
INSERT INTO `payment_transactions` VALUES ('18', '330', '6060', 'Stripe', 'pi_3Q7QJVBvoXuMhOgs1akjcP0O', NULL, NULL, 'succeed', '12', '2024-10-08 04:56:05', '2024-10-08 05:00:08');
INSERT INTO `payment_transactions` VALUES ('19', '330', '1530', 'Stripe', 'pi_3Q7QNSBvoXuMhOgs0bN1KkxQ', NULL, NULL, 'succeed', '12', '2024-10-08 05:00:10', '2024-10-08 05:02:59');
INSERT INTO `payment_transactions` VALUES ('20', '330', '1530', 'Stripe', 'pi_3Q7QOkBvoXuMhOgs1phxrVDz', NULL, NULL, 'pending', '12', '2024-10-08 05:01:30', '2024-10-08 05:01:31');
INSERT INTO `payment_transactions` VALUES ('21', '330', '1530', 'Stripe', 'pi_3Q7QOmBvoXuMhOgs02v80C10', NULL, NULL, 'pending', '12', '2024-10-08 05:01:31', '2024-10-08 05:01:32');
INSERT INTO `payment_transactions` VALUES ('22', '330', '1000', 'Stripe', 'pi_3Q7QQEBvoXuMhOgs1Wb4IVHL', NULL, NULL, 'pending', '12', '2024-10-08 05:03:02', '2024-10-08 05:03:03');
INSERT INTO `payment_transactions` VALUES ('23', '330', '1000', 'Stripe', 'pi_3Q7QVPBvoXuMhOgs0mvDhWyh', NULL, NULL, 'succeed', '12', '2024-10-08 05:08:22', '2024-10-08 19:55:05');
INSERT INTO `payment_transactions` VALUES ('24', '330', '6060', 'Stripe', 'pi_3Q7Qz5BvoXuMhOgs0aXxreEI', NULL, NULL, 'succeed', '12', '2024-10-08 05:39:02', '2024-10-08 19:55:05');
INSERT INTO `payment_transactions` VALUES ('25', '330', '1530', 'Stripe', 'pi_3Q7fDLBvoXuMhOgs1lXHGhxV', NULL, NULL, 'pending', '12', '2024-10-08 20:50:43', '2024-10-08 20:50:43');
INSERT INTO `payment_transactions` VALUES ('26', '330', '1530', 'Stripe', 'pi_3Q7fsJBvoXuMhOgs1zrkbPiS', NULL, NULL, 'pending', '12', '2024-10-08 21:33:02', '2024-10-08 21:33:03');
INSERT INTO `payment_transactions` VALUES ('27', '330', '6060', 'Stripe', 'pi_3Q84uTBvoXuMhOgs1t8ek0O9', NULL, NULL, 'pending', '12', '2024-10-10 00:16:57', '2024-10-10 00:16:57');
INSERT INTO `payment_transactions` VALUES ('28', '330', '1530', 'Stripe', 'pi_3Q8eiQBvoXuMhOgs15yH1bWQ', NULL, NULL, 'pending', '12', '2024-10-11 14:30:53', '2024-10-11 14:30:54');
INSERT INTO `payment_transactions` VALUES ('29', '330', '1530', 'Stripe', 'pi_3Q98FVBvoXuMhOgs1KfMlMzr', NULL, NULL, 'pending', '12', '2024-10-12 22:03:01', '2024-10-12 22:03:01');
INSERT INTO `payment_transactions` VALUES ('30', '330', '6060', 'Stripe', 'pi_3Q99CyBvoXuMhOgs0wkpijjr', NULL, NULL, 'pending', '12', '2024-10-12 23:04:27', '2024-10-12 23:04:28');
INSERT INTO `payment_transactions` VALUES ('31', '330', '1530', 'Stripe', 'pi_3Q9FidBvoXuMhOgs1JvNx2ZQ', NULL, NULL, 'pending', '12', '2024-10-13 06:01:35', '2024-10-13 06:01:36');
INSERT INTO `payment_transactions` VALUES ('32', '330', '6060', 'Stripe', 'pi_3Q9J13BvoXuMhOgs0A8u2GUF', NULL, NULL, 'pending', '12', '2024-10-13 09:32:48', '2024-10-13 09:32:49');
INSERT INTO `payment_transactions` VALUES ('33', '330', '6060', 'Stripe', 'pi_3Q9QN7BvoXuMhOgs1JZEOV3S', NULL, NULL, 'pending', '12', '2024-10-13 17:24:04', '2024-10-13 17:24:05');
INSERT INTO `payment_transactions` VALUES ('34', '330', '6120', 'Stripe', 'pi_3Q9apmBvoXuMhOgs0WpwVg1m', NULL, NULL, 'pending', '12', '2024-10-14 04:34:21', '2024-10-14 04:34:22');
INSERT INTO `payment_transactions` VALUES ('35', '330', '1530', 'Stripe', 'pi_3Q9orSBvoXuMhOgs0nqLkPEU', NULL, NULL, 'pending', '12', '2024-10-14 19:33:02', '2024-10-14 19:33:03');
INSERT INTO `payment_transactions` VALUES ('36', '330', '1530', 'Stripe', 'pi_3Q9rcZBvoXuMhOgs0BjLIIgY', NULL, NULL, 'pending', '12', '2024-10-14 22:29:50', '2024-10-14 22:29:51');
INSERT INTO `payment_transactions` VALUES ('37', '330', '6120', 'Stripe', 'pi_3QA0NeBvoXuMhOgs0sTvqoAI', NULL, NULL, 'pending', '12', '2024-10-15 07:51:01', '2024-10-15 07:51:02');
INSERT INTO `payment_transactions` VALUES ('38', '330', '1530', 'Stripe', 'pi_3QA70PBvoXuMhOgs1WI4YRb4', NULL, NULL, 'pending', '12', '2024-10-15 14:55:28', '2024-10-15 14:55:29');
INSERT INTO `payment_transactions` VALUES ('39', '330', '6000', 'Stripe', 'pi_3QA7tJBvoXuMhOgs00ZUL5Vf', NULL, NULL, 'pending', '12', '2024-10-15 15:52:13', '2024-10-15 15:52:14');
INSERT INTO `payment_transactions` VALUES ('40', '330', '1530', 'Stripe', 'pi_3QA9h3BvoXuMhOgs12VP0sQm', NULL, NULL, 'pending', '12', '2024-10-15 17:47:40', '2024-10-15 17:47:41');
INSERT INTO `payment_transactions` VALUES ('41', '330', '1530', 'Stripe', 'pi_3QADC1BvoXuMhOgs1my2s7Os', NULL, NULL, 'pending', '12', '2024-10-15 21:31:53', '2024-10-15 21:31:54');
INSERT INTO `payment_transactions` VALUES ('42', '330', '1530', 'Stripe', 'pi_3QAIemBvoXuMhOgs1tCq4VRU', NULL, NULL, 'pending', '12', '2024-10-16 03:21:55', '2024-10-16 03:21:56');
INSERT INTO `payment_transactions` VALUES ('43', '330', '1530', 'Stripe', 'pi_3QAIfBBvoXuMhOgs0ZZZrHmV', NULL, NULL, 'pending', '12', '2024-10-16 03:22:21', '2024-10-16 03:22:21');
INSERT INTO `payment_transactions` VALUES ('44', '330', '6060', 'Stripe', 'pi_3QAJenBvoXuMhOgs1kYCIRoq', NULL, NULL, 'pending', '12', '2024-10-16 04:26:01', '2024-10-16 04:26:02');
INSERT INTO `payment_transactions` VALUES ('45', '330', '1000', 'Stripe', 'pi_3QAKFYBvoXuMhOgs1w1K0fst', NULL, NULL, 'pending', '12', '2024-10-16 05:03:59', '2024-10-16 05:04:00');
INSERT INTO `payment_transactions` VALUES ('46', '330', '1530', 'Stripe', 'pi_3QAPCPBvoXuMhOgs1PFMT7KF', NULL, NULL, 'pending', '12', '2024-10-16 10:21:04', '2024-10-16 10:21:06');
INSERT INTO `payment_transactions` VALUES ('47', '330', '6060', 'Stripe', 'pi_3QATXTBvoXuMhOgs0mbbPVX4', NULL, NULL, 'pending', '12', '2024-10-16 14:59:07', '2024-10-16 14:59:08');
INSERT INTO `payment_transactions` VALUES ('48', '330', '1530', 'Stripe', 'pi_3QAV6qBvoXuMhOgs0FmnH8VV', NULL, NULL, 'pending', '12', '2024-10-16 16:39:44', '2024-10-16 16:39:44');
INSERT INTO `payment_transactions` VALUES ('49', '330', '6060', 'Stripe', 'pi_3QAZcLBvoXuMhOgs04oukJYE', NULL, NULL, 'pending', '12', '2024-10-16 21:28:32', '2024-10-16 21:28:33');
INSERT INTO `payment_transactions` VALUES ('50', '330', '1530', 'Stripe', 'pi_3QAxSuBvoXuMhOgs1oJu7TXs', NULL, NULL, 'pending', '12', '2024-10-17 22:56:23', '2024-10-17 22:56:24');
INSERT INTO `payment_transactions` VALUES ('51', '330', '6060', 'Stripe', 'pi_3QAzTDBvoXuMhOgs1ysaTFFQ', NULL, NULL, 'pending', '12', '2024-10-18 01:04:50', '2024-10-18 01:04:51');
INSERT INTO `payment_transactions` VALUES ('52', '330', '6060', 'Stripe', 'pi_3QBRHcBvoXuMhOgs1CcRTIiN', NULL, NULL, 'pending', '12', '2024-10-19 06:46:43', '2024-10-19 06:46:44');
INSERT INTO `payment_transactions` VALUES ('53', '330', '1530', 'Stripe', 'pi_3QBRhiBvoXuMhOgs0CEf9TH9', NULL, NULL, 'pending', '12', '2024-10-19 07:13:41', '2024-10-19 07:13:42');
INSERT INTO `payment_transactions` VALUES ('54', '330', '1530', 'Stripe', 'pi_3QBUIJBvoXuMhOgs1QOZ2f5C', NULL, NULL, 'pending', '12', '2024-10-19 09:59:38', '2024-10-19 09:59:39');
INSERT INTO `payment_transactions` VALUES ('55', '330', '6120', 'Stripe', 'pi_3QCKCyBvoXuMhOgs0REGbbpI', NULL, NULL, 'pending', '12', '2024-10-21 17:25:35', '2024-10-21 17:25:36');
INSERT INTO `payment_transactions` VALUES ('56', '330', '1530', 'Stripe', 'pi_3QCMAbBvoXuMhOgs1QHFxHhh', NULL, NULL, 'pending', '12', '2024-10-21 19:31:17', '2024-10-21 19:31:18');
INSERT INTO `payment_transactions` VALUES ('57', '330', '6060', 'Stripe', 'pi_3QCbvTBvoXuMhOgs0OOp4Fkh', NULL, NULL, 'pending', '12', '2024-10-22 12:20:43', '2024-10-22 12:20:43');
INSERT INTO `payment_transactions` VALUES ('58', '330', '1530', 'Stripe', 'pi_3QCewMBvoXuMhOgs0IE09GmC', NULL, NULL, 'pending', '12', '2024-10-22 15:33:49', '2024-10-22 15:33:50');
INSERT INTO `payment_transactions` VALUES ('59', '330', '6060', 'Stripe', 'pi_3QCoBZBvoXuMhOgs1keuh8mr', NULL, NULL, 'pending', '12', '2024-10-23 01:26:09', '2024-10-23 01:26:10');
INSERT INTO `payment_transactions` VALUES ('60', '330', '1530', 'Stripe', 'pi_3QCpgABvoXuMhOgs1YhsW5AT', NULL, NULL, 'pending', '12', '2024-10-23 03:01:50', '2024-10-23 03:01:51');
INSERT INTO `payment_transactions` VALUES ('61', '330', '1530', 'Stripe', 'pi_3QCqXEBvoXuMhOgs10e4eI5b', NULL, NULL, 'pending', '12', '2024-10-23 03:56:39', '2024-10-23 03:56:40');
INSERT INTO `payment_transactions` VALUES ('62', '330', '1530', 'Stripe', 'pi_3QCqYGBvoXuMhOgs0RCcq2NE', NULL, NULL, 'pending', '12', '2024-10-23 03:57:44', '2024-10-23 03:57:45');
INSERT INTO `payment_transactions` VALUES ('63', '330', '1530', 'Stripe', 'pi_3QCrSSBvoXuMhOgs0O8bS4Gj', NULL, NULL, 'pending', '12', '2024-10-23 04:55:47', '2024-10-23 04:55:48');
INSERT INTO `payment_transactions` VALUES ('64', '330', '1530', 'Stripe', 'pi_3QCylQBvoXuMhOgs0EoKQ7QW', NULL, NULL, 'pending', '12', '2024-10-23 12:43:52', '2024-10-23 12:43:53');
INSERT INTO `payment_transactions` VALUES ('65', '330', '6060', 'Stripe', 'pi_3QD3YOBvoXuMhOgs0l2D8dqb', NULL, NULL, 'pending', '12', '2024-10-23 17:50:43', '2024-10-23 17:50:44');
INSERT INTO `payment_transactions` VALUES ('66', '330', '6120', 'Stripe', 'pi_3QD3aBBvoXuMhOgs0sQBwmjA', NULL, NULL, 'pending', '12', '2024-10-23 17:52:34', '2024-10-23 17:52:35');
INSERT INTO `payment_transactions` VALUES ('67', '330', '6060', 'Stripe', 'pi_3QD4JGBvoXuMhOgs0lW7xdPY', NULL, NULL, 'pending', '12', '2024-10-23 18:39:09', '2024-10-23 18:39:10');
INSERT INTO `payment_transactions` VALUES ('68', '330', '1530', 'Stripe', 'pi_3QD77WBvoXuMhOgs0PEO9gQE', NULL, NULL, 'pending', '12', '2024-10-23 21:39:14', '2024-10-23 21:39:14');
INSERT INTO `payment_transactions` VALUES ('69', '330', '1530', 'Stripe', 'pi_3QD9MRBvoXuMhOgs0vBxqv6X', NULL, NULL, 'pending', '12', '2024-10-24 00:02:46', '2024-10-24 00:02:47');
INSERT INTO `payment_transactions` VALUES ('70', '330', '1530', 'Stripe', 'pi_3QDLYxBvoXuMhOgs14Z5X2Mb', NULL, NULL, 'succeed', '12', '2024-10-24 13:04:31', '2024-10-24 13:08:36');
INSERT INTO `payment_transactions` VALUES ('71', '330', '1530', 'Stripe', 'pi_3QDPVIBvoXuMhOgs1x2XkAOA', NULL, NULL, 'pending', '12', '2024-10-24 17:16:59', '2024-10-24 17:17:00');
INSERT INTO `payment_transactions` VALUES ('72', '330', '1530', 'Stripe', 'pi_3QDYakBvoXuMhOgs0o5X22SA', NULL, NULL, 'pending', '12', '2024-10-25 02:59:13', '2024-10-25 02:59:14');
INSERT INTO `payment_transactions` VALUES ('73', '330', '1000', 'Stripe', 'pi_3QDYbLBvoXuMhOgs0cwqESrV', NULL, NULL, 'pending', '12', '2024-10-25 02:59:50', '2024-10-25 02:59:51');
INSERT INTO `payment_transactions` VALUES ('74', '330', '6120', 'Stripe', 'pi_3QDl6hBvoXuMhOgs05YphYn3', NULL, NULL, 'pending', '12', '2024-10-25 16:21:03', '2024-10-25 16:21:03');
INSERT INTO `payment_transactions` VALUES ('75', '330', '6060', 'Stripe', 'pi_3QE4K2BvoXuMhOgs1b3TGK4R', NULL, NULL, 'pending', '12', '2024-10-26 12:52:05', '2024-10-26 12:52:06');
INSERT INTO `payment_transactions` VALUES ('76', '330', '1530', 'Stripe', 'pi_3QEAi9BvoXuMhOgs1gztzEaz', NULL, NULL, 'pending', '12', '2024-10-26 19:41:24', '2024-10-26 19:41:25');
INSERT INTO `payment_transactions` VALUES ('77', '330', '1530', 'Stripe', 'pi_3QEByUBvoXuMhOgs1Jk1BtnC', NULL, NULL, 'pending', '12', '2024-10-26 21:02:21', '2024-10-26 21:02:22');
INSERT INTO `payment_transactions` VALUES ('78', '330', '1530', 'Stripe', 'pi_3QENKeBvoXuMhOgs18kwAFp7', NULL, NULL, 'pending', '12', '2024-10-27 09:09:59', '2024-10-27 09:10:00');
INSERT INTO `payment_transactions` VALUES ('79', '1061', '6060', 'Stripe', 'pi_3QEYZNBvoXuMhOgs1Va4XvfA', NULL, NULL, 'pending', '12', '2024-10-27 21:09:57', '2024-10-27 21:09:58');
INSERT INTO `payment_transactions` VALUES ('80', '330', '6060', 'Stripe', 'pi_3QEYg9BvoXuMhOgs0cTbIRcw', NULL, NULL, 'pending', '12', '2024-10-27 21:16:56', '2024-10-27 21:16:57');
INSERT INTO `payment_transactions` VALUES ('81', '330', '1530', 'Stripe', 'pi_3QEqKdBvoXuMhOgs1vHc7wKJ', NULL, NULL, 'pending', '12', '2024-10-28 16:07:54', '2024-10-28 16:07:55');
INSERT INTO `payment_transactions` VALUES ('82', '330', '1530', 'Stripe', 'pi_3QF90OBvoXuMhOgs1fwzFmki', NULL, NULL, 'pending', '12', '2024-10-29 12:04:16', '2024-10-29 12:04:17');
INSERT INTO `payment_transactions` VALUES ('83', '330', '1530', 'Stripe', 'pi_3QFDcYBvoXuMhOgs08UsNgaA', NULL, NULL, 'pending', '12', '2024-10-29 16:59:58', '2024-10-29 16:59:59');
INSERT INTO `payment_transactions` VALUES ('84', '330', '1530', 'Stripe', 'pi_3QFysUBvoXuMhOgs06ukrohP', NULL, NULL, 'pending', '12', '2024-10-31 19:27:34', '2024-10-31 19:27:34');
INSERT INTO `payment_transactions` VALUES ('85', '330', '6060', 'Stripe', 'pi_3QG6wSBvoXuMhOgs1Hx0EGi9', NULL, NULL, 'pending', '12', '2024-11-01 04:04:11', '2024-11-01 04:04:12');
INSERT INTO `payment_transactions` VALUES ('86', '330', '1530', 'Stripe', 'pi_3QGJMLBvoXuMhOgs0RsgF6EA', NULL, NULL, 'pending', '12', '2024-11-01 17:19:45', '2024-11-01 17:19:46');
INSERT INTO `payment_transactions` VALUES ('87', '330', '1530', 'Stripe', 'pi_3QGOVqBvoXuMhOgs14fyiJ35', NULL, NULL, 'pending', '12', '2024-11-01 22:49:54', '2024-11-01 22:49:54');
INSERT INTO `payment_transactions` VALUES ('88', '330', '1530', 'Stripe', 'pi_3QGpa7BvoXuMhOgs1zlXpcBG', NULL, NULL, 'pending', '12', '2024-11-03 03:44:07', '2024-11-03 03:44:08');
INSERT INTO `payment_transactions` VALUES ('89', '330', '1530', 'Stripe', 'pi_3QHnJQBvoXuMhOgs03L2WXkI', NULL, NULL, 'succeed', '12', '2024-11-05 19:30:51', '2024-11-06 11:10:04');
INSERT INTO `payment_transactions` VALUES ('90', '330', '1530', 'Stripe', 'pi_3QI8iuBvoXuMhOgs01W1XcJa', NULL, NULL, 'pending', '12', '2024-11-06 18:22:36', '2024-11-06 18:22:37');
INSERT INTO `payment_transactions` VALUES ('91', '330', '1530', 'Stripe', 'pi_3QI8nnBvoXuMhOgs0Co7DlFA', NULL, NULL, 'pending', '12', '2024-11-06 18:27:38', '2024-11-06 18:27:39');
INSERT INTO `payment_transactions` VALUES ('92', '330', '1530', 'Stripe', 'pi_3QIOfUBvoXuMhOgs0FhTrUfO', NULL, NULL, 'pending', '12', '2024-11-07 11:24:07', '2024-11-07 11:24:08');
INSERT INTO `payment_transactions` VALUES ('93', '330', '1530', 'Stripe', 'pi_3QIRNQBvoXuMhOgs0OTE41dL', NULL, NULL, 'pending', '12', '2024-11-07 14:17:40', '2024-11-07 14:17:40');
INSERT INTO `payment_transactions` VALUES ('94', '330', '1530', 'Stripe', 'pi_3QIRNcBvoXuMhOgs0cTNzjFy', NULL, NULL, 'pending', '12', '2024-11-07 14:17:52', '2024-11-07 14:17:52');
INSERT INTO `payment_transactions` VALUES ('95', '330', '1530', 'Stripe', 'pi_3QIl58BvoXuMhOgs1PsBGrS9', NULL, NULL, 'pending', '12', '2024-11-08 11:20:05', '2024-11-08 11:20:06');
INSERT INTO `payment_transactions` VALUES ('96', '330', '1530', 'Stripe', 'pi_3QIpJgBvoXuMhOgs1WNYrl7g', NULL, NULL, 'pending', '12', '2024-11-08 15:51:24', '2024-11-08 15:51:25');
INSERT INTO `payment_transactions` VALUES ('97', '330', '1530', 'Stripe', 'pi_3QJFa2BvoXuMhOgs0OdDvEWq', NULL, NULL, 'pending', '12', '2024-11-09 19:54:02', '2024-11-09 19:54:03');
INSERT INTO `payment_transactions` VALUES ('98', '330', '6060', 'Stripe', 'pi_3QJIEPBvoXuMhOgs0pvUWiKj', NULL, NULL, 'pending', '12', '2024-11-09 22:43:52', '2024-11-09 22:43:53');
INSERT INTO `payment_transactions` VALUES ('99', '330', '1530', 'Stripe', 'pi_3QJcj4BvoXuMhOgs1VrGIdLt', NULL, NULL, 'pending', '12', '2024-11-10 20:36:54', '2024-11-10 20:36:55');
INSERT INTO `payment_transactions` VALUES ('100', '330', '1530', 'Stripe', 'pi_3QKvQ8BvoXuMhOgs0rPF0BeR', NULL, NULL, 'pending', '12', '2024-11-14 10:46:43', '2024-11-14 10:46:44');
INSERT INTO `payment_transactions` VALUES ('101', '330', '1530', 'Stripe', 'pi_3QKwQdBvoXuMhOgs1ZldC7oQ', NULL, NULL, 'pending', '12', '2024-11-14 11:51:19', '2024-11-14 11:51:20');
INSERT INTO `payment_transactions` VALUES ('102', '330', '1530', 'Stripe', 'pi_3QKzY5BvoXuMhOgs1LcB9Hla', NULL, NULL, 'pending', '12', '2024-11-14 15:11:13', '2024-11-14 15:11:13');
INSERT INTO `payment_transactions` VALUES ('103', '330', '6060', 'Stripe', 'pi_3QL3gUBvoXuMhOgs18S9W05J', NULL, NULL, 'pending', '12', '2024-11-14 19:36:10', '2024-11-14 19:36:10');
INSERT INTO `payment_transactions` VALUES ('104', '330', '1530', 'Stripe', 'pi_3QL8RWBvoXuMhOgs0zqocsdI', NULL, NULL, 'pending', '12', '2024-11-15 00:41:02', '2024-11-15 00:41:02');
INSERT INTO `payment_transactions` VALUES ('105', '330', '1530', 'Stripe', 'pi_3QL9UcBvoXuMhOgs1QjVvsgY', NULL, NULL, 'pending', '12', '2024-11-15 01:48:18', '2024-11-15 01:48:18');
INSERT INTO `payment_transactions` VALUES ('106', '330', '6000', 'Stripe', 'pi_3QLGkmBvoXuMhOgs0gwahQX1', NULL, NULL, 'pending', '12', '2024-11-15 09:33:27', '2024-11-15 09:33:28');
INSERT INTO `payment_transactions` VALUES ('107', '330', '1530', 'Stripe', 'pi_3QLJF1BvoXuMhOgs1GY9WxFM', NULL, NULL, 'pending', '12', '2024-11-15 12:12:51', '2024-11-15 12:12:52');
INSERT INTO `payment_transactions` VALUES ('108', '330', '1530', 'Stripe', 'pi_3QLJFJBvoXuMhOgs1G036A0N', NULL, NULL, 'pending', '12', '2024-11-15 12:13:08', '2024-11-15 12:13:09');
INSERT INTO `payment_transactions` VALUES ('109', '330', '6060', 'Stripe', 'pi_3QLPvUBvoXuMhOgs0nmyyUjx', NULL, NULL, 'pending', '12', '2024-11-15 19:21:07', '2024-11-15 19:21:08');
INSERT INTO `payment_transactions` VALUES ('110', '330', '1530', 'Stripe', 'pi_3QM95gBvoXuMhOgs1cAI6SYZ', NULL, NULL, 'pending', '12', '2024-11-17 19:34:39', '2024-11-17 19:34:40');
INSERT INTO `payment_transactions` VALUES ('111', '330', '1000', 'Stripe', 'pi_3QM97tBvoXuMhOgs0IkOFQT9', NULL, NULL, 'pending', '12', '2024-11-17 19:36:56', '2024-11-17 19:36:57');
INSERT INTO `payment_transactions` VALUES ('112', '330', '1530', 'Stripe', 'pi_3QMKLrBvoXuMhOgs0n6mkWLm', NULL, NULL, 'pending', '12', '2024-11-18 07:36:06', '2024-11-18 07:36:07');
INSERT INTO `payment_transactions` VALUES ('113', '330', '1530', 'Stripe', 'pi_3QMlvwBvoXuMhOgs0O5VTVXH', NULL, NULL, 'pending', '12', '2024-11-19 13:03:12', '2024-11-19 13:03:13');
INSERT INTO `payment_transactions` VALUES ('114', '330', '1530', 'Stripe', 'pi_3QN6NrBvoXuMhOgs15hd1iBK', NULL, NULL, 'pending', '12', '2024-11-20 10:53:22', '2024-11-20 10:53:23');
INSERT INTO `payment_transactions` VALUES ('115', '330', '1530', 'Stripe', 'pi_3QNDOYBvoXuMhOgs1elu1BKG', NULL, NULL, 'succeed', '12', '2024-11-20 18:22:33', '2024-11-20 19:41:07');
INSERT INTO `payment_transactions` VALUES ('116', '330', '1530', 'Stripe', 'pi_3QNRDLBvoXuMhOgs16Ek3h3j', NULL, NULL, 'pending', '12', '2024-11-21 09:07:54', '2024-11-21 09:07:55');
INSERT INTO `payment_transactions` VALUES ('117', '330', '1530', 'Stripe', 'pi_3QNSA0BvoXuMhOgs1g3S3NkZ', NULL, NULL, 'pending', '12', '2024-11-21 10:08:31', '2024-11-21 10:08:32');
INSERT INTO `payment_transactions` VALUES ('118', '330', '1530', 'Stripe', 'pi_3QNShnBvoXuMhOgs06sEkp76', NULL, NULL, 'pending', '12', '2024-11-21 10:43:27', '2024-11-21 10:43:28');
INSERT INTO `payment_transactions` VALUES ('119', '330', '1530', 'Stripe', 'pi_3QNcTxBvoXuMhOgs07YIs04b', NULL, NULL, 'pending', '12', '2024-11-21 21:09:48', '2024-11-21 21:09:49');
INSERT INTO `payment_transactions` VALUES ('120', '330', '1530', 'Stripe', 'pi_3QNq9MBvoXuMhOgs1fks0Sj0', NULL, NULL, 'pending', '12', '2024-11-22 11:45:27', '2024-11-22 11:45:28');
INSERT INTO `payment_transactions` VALUES ('121', '330', '1530', 'Stripe', 'pi_3QNuJiBvoXuMhOgs0i61mgeB', NULL, NULL, 'pending', '12', '2024-11-22 16:12:26', '2024-11-22 16:12:26');
INSERT INTO `payment_transactions` VALUES ('122', '330', '1530', 'Stripe', 'pi_3QNybDBvoXuMhOgs13Q7hZ6I', NULL, NULL, 'pending', '12', '2024-11-22 20:46:46', '2024-11-22 20:46:47');
INSERT INTO `payment_transactions` VALUES ('123', '330', '6060', 'Stripe', 'pi_3QOD8DBvoXuMhOgs0NDmdODc', NULL, NULL, 'succeed', '12', '2024-11-23 12:17:49', '2024-11-25 13:44:11');
INSERT INTO `payment_transactions` VALUES ('124', '330', '1530', 'Stripe', 'pi_3QONhxBvoXuMhOgs16OjewJR', NULL, NULL, 'pending', '12', '2024-11-23 23:35:24', '2024-11-23 23:35:25');
INSERT INTO `payment_transactions` VALUES ('125', '330', '1530', 'Stripe', 'pi_3QOTHUBvoXuMhOgs1KDfP9ln', NULL, NULL, 'pending', '12', '2024-11-24 05:32:28', '2024-11-24 05:32:28');
INSERT INTO `payment_transactions` VALUES ('126', '330', '1530', 'Stripe', 'pi_3QOx0WBvoXuMhOgs0vIjTSJ0', NULL, NULL, 'pending', '12', '2024-11-25 13:16:56', '2024-11-25 13:16:57');
INSERT INTO `payment_transactions` VALUES ('127', '330', '6060', 'Stripe', 'pi_3QP5GoBvoXuMhOgs06yFbnN7', NULL, NULL, 'pending', '12', '2024-11-25 22:06:18', '2024-11-25 22:06:18');
INSERT INTO `payment_transactions` VALUES ('128', '330', '1530', 'Stripe', 'pi_3QPOu9BvoXuMhOgs0rcHj3bO', NULL, NULL, 'pending', '12', '2024-11-26 19:04:12', '2024-11-26 19:04:13');
INSERT INTO `payment_transactions` VALUES ('129', '330', '1530', 'Stripe', 'pi_3QPQMMBvoXuMhOgs1eJtah10', NULL, NULL, 'pending', '12', '2024-11-26 20:37:25', '2024-11-26 20:37:26');
INSERT INTO `payment_transactions` VALUES ('130', '330', '1530', 'Stripe', 'pi_3QPTq8BvoXuMhOgs0vXL6a5c', NULL, NULL, 'pending', '12', '2024-11-27 00:20:23', '2024-11-27 00:20:24');
INSERT INTO `payment_transactions` VALUES ('131', '330', '1530', 'Stripe', 'pi_3QPaY1BvoXuMhOgs1v4yXYmA', NULL, NULL, 'pending', '12', '2024-11-27 07:30:09', '2024-11-27 07:30:10');
INSERT INTO `payment_transactions` VALUES ('132', '330', '1530', 'Stripe', 'pi_3QPlEABvoXuMhOgs0Appmg1H', NULL, NULL, 'pending', '12', '2024-11-27 18:54:21', '2024-11-27 18:54:22');
INSERT INTO `payment_transactions` VALUES ('133', '330', '1000', 'Stripe', 'pi_3QPlEuBvoXuMhOgs1LvA8uXa', NULL, NULL, 'pending', '12', '2024-11-27 18:55:07', '2024-11-27 18:55:08');
INSERT INTO `payment_transactions` VALUES ('134', '330', '6060', 'Stripe', 'pi_3QPsAOBvoXuMhOgs144067Ds', NULL, NULL, 'pending', '12', '2024-11-28 02:18:56', '2024-11-28 02:18:57');
INSERT INTO `payment_transactions` VALUES ('135', '330', '6120', 'Stripe', 'pi_3QQ5M1BvoXuMhOgs0TzvMhwQ', NULL, NULL, 'pending', '12', '2024-11-28 16:23:48', '2024-11-28 16:23:49');
INSERT INTO `payment_transactions` VALUES ('136', '330', '1530', 'Stripe', 'pi_3QQOT7BvoXuMhOgs1qnwlrip', NULL, NULL, 'pending', '12', '2024-11-29 12:48:25', '2024-11-29 12:48:25');
INSERT INTO `payment_transactions` VALUES ('137', '330', '1530', 'Stripe', 'pi_3QQm0vBvoXuMhOgs19gslkoe', NULL, NULL, 'pending', '12', '2024-11-30 13:56:53', '2024-11-30 13:56:54');
INSERT INTO `payment_transactions` VALUES ('138', '330', '1530', 'Stripe', 'pi_3QQm1BBvoXuMhOgs1y4u3pea', NULL, NULL, 'pending', '12', '2024-11-30 13:57:09', '2024-11-30 13:57:10');
INSERT INTO `payment_transactions` VALUES ('139', '330', '1530', 'Stripe', 'pi_3QRAoSBvoXuMhOgs1wyjgJc6', NULL, NULL, 'pending', '12', '2024-12-01 16:25:39', '2024-12-01 16:25:40');
INSERT INTO `payment_transactions` VALUES ('140', '330', '1530', 'Stripe', 'pi_3QRkifBvoXuMhOgs1hLq1YUY', NULL, NULL, 'pending', '12', '2024-12-03 06:46:05', '2024-12-03 06:46:05');
INSERT INTO `payment_transactions` VALUES ('141', '330', '6060', 'Stripe', 'pi_3QRnzABvoXuMhOgs0BQyA8Cb', NULL, NULL, 'pending', '12', '2024-12-03 10:15:19', '2024-12-03 10:15:20');
INSERT INTO `payment_transactions` VALUES ('142', '330', '1530', 'Stripe', 'pi_3QRoXyBvoXuMhOgs0rwgxV0j', NULL, NULL, 'pending', '12', '2024-12-03 10:51:18', '2024-12-03 10:51:18');
INSERT INTO `payment_transactions` VALUES ('143', '330', '6060', 'Stripe', 'pi_3QRozWBvoXuMhOgs1ow0HKns', NULL, NULL, 'succeed', '12', '2024-12-03 11:19:46', '2024-12-03 11:21:25');
INSERT INTO `payment_transactions` VALUES ('144', '330', '6120', 'Stripe', 'pi_3QRp1ABvoXuMhOgs0PrkYd37', NULL, NULL, 'succeed', '12', '2024-12-03 11:21:28', '2024-12-03 11:23:03');
INSERT INTO `payment_transactions` VALUES ('145', '330', '1530', 'Stripe', 'pi_3QRp2kBvoXuMhOgs0YdaAbgu', NULL, NULL, 'succeed', '12', '2024-12-03 11:23:06', '2024-12-03 11:24:00');
INSERT INTO `payment_transactions` VALUES ('146', '330', '1530', 'Stripe', 'pi_3QRp3uBvoXuMhOgs0qTTATr0', NULL, NULL, 'succeed', '12', '2024-12-03 11:24:18', '2024-12-03 11:25:29');
INSERT INTO `payment_transactions` VALUES ('147', '330', '1530', 'Stripe', 'pi_3QRp55BvoXuMhOgs0pyHxzvD', NULL, NULL, 'succeed', '12', '2024-12-03 11:25:31', '2024-12-03 11:26:31');
INSERT INTO `payment_transactions` VALUES ('148', '330', '1000', 'Stripe', 'pi_3QRp66BvoXuMhOgs02Q1EySc', NULL, NULL, 'succeed', '12', '2024-12-03 11:26:33', '2024-12-03 23:44:41');
INSERT INTO `payment_transactions` VALUES ('149', '330', '1530', 'Stripe', 'pi_3QRzlVBvoXuMhOgs0wMCfu2d', NULL, NULL, 'pending', '12', '2024-12-03 22:50:00', '2024-12-03 22:50:02');
INSERT INTO `payment_transactions` VALUES ('150', '330', '6120', 'Stripe', 'pi_3QS0edBvoXuMhOgs1A0uqjwT', NULL, NULL, 'pending', '12', '2024-12-03 23:46:58', '2024-12-03 23:46:59');
INSERT INTO `payment_transactions` VALUES ('151', '330', '1530', 'Stripe', 'pi_3QSCVtBvoXuMhOgs0NoritLi', NULL, NULL, 'pending', '12', '2024-12-04 12:26:44', '2024-12-04 12:26:45');
INSERT INTO `payment_transactions` VALUES ('152', '330', '6060', 'Stripe', 'pi_3QSgKXBvoXuMhOgs0bpYg7KL', NULL, NULL, 'pending', '12', '2024-12-05 20:17:00', '2024-12-05 20:17:01');
INSERT INTO `payment_transactions` VALUES ('153', '330', '1530', 'Stripe', 'pi_3QSwYGBvoXuMhOgs1fjg0Ws2', NULL, NULL, 'pending', '12', '2024-12-06 13:36:15', '2024-12-06 13:36:16');
INSERT INTO `payment_transactions` VALUES ('154', '330', '6060', 'Stripe', 'pi_3QSzZOBvoXuMhOgs1pUbpaBs', NULL, NULL, 'pending', '12', '2024-12-06 16:49:37', '2024-12-06 16:49:38');
INSERT INTO `payment_transactions` VALUES ('155', '330', '1000', 'Stripe', 'pi_3QT14dBvoXuMhOgs0IuBQeox', NULL, NULL, 'pending', '12', '2024-12-06 18:25:59', '2024-12-06 18:26:00');
INSERT INTO `payment_transactions` VALUES ('156', '330', '1530', 'Stripe', 'pi_3QTInxBvoXuMhOgs1RtISuhr', NULL, NULL, 'pending', '12', '2024-12-07 13:21:57', '2024-12-07 13:21:58');
INSERT INTO `payment_transactions` VALUES ('157', '330', '1530', 'Stripe', 'pi_3QTJLZBvoXuMhOgs0d5CwFz3', NULL, NULL, 'pending', '12', '2024-12-07 13:56:41', '2024-12-07 13:56:41');
INSERT INTO `payment_transactions` VALUES ('158', '330', '1530', 'Stripe', 'pi_3QTQjABvoXuMhOgs1fc3EHuc', NULL, NULL, 'pending', '12', '2024-12-07 21:49:31', '2024-12-07 21:49:32');
INSERT INTO `payment_transactions` VALUES ('159', '330', '1530', 'Stripe', 'pi_3QU6QFBvoXuMhOgs0Yh1Jdem', NULL, NULL, 'pending', '12', '2024-12-09 18:20:46', '2024-12-09 18:20:47');
INSERT INTO `payment_transactions` VALUES ('160', '330', '6060', 'Stripe', 'pi_3QUFsmBvoXuMhOgs0BuuAVou', NULL, NULL, 'pending', '12', '2024-12-10 04:26:51', '2024-12-10 04:26:52');
INSERT INTO `payment_transactions` VALUES ('161', '330', '6060', 'Stripe', 'pi_3QUGNgBvoXuMhOgs0zYZyeKm', NULL, NULL, 'pending', '12', '2024-12-10 04:58:48', '2024-12-10 04:58:49');
INSERT INTO `payment_transactions` VALUES ('162', '330', '1530', 'Stripe', 'pi_3QUQe0BvoXuMhOgs0hkiqLB2', NULL, NULL, 'pending', '12', '2024-12-10 15:56:20', '2024-12-10 15:56:20');
INSERT INTO `payment_transactions` VALUES ('163', '330', '6060', 'Stripe', 'pi_3QUYqiBvoXuMhOgs15Bn1Opo', NULL, NULL, 'pending', '12', '2024-12-11 00:42:00', '2024-12-11 00:42:00');
INSERT INTO `payment_transactions` VALUES ('164', '330', '1530', 'Stripe', 'pi_3QUk0GBvoXuMhOgs0rxMlr3P', NULL, NULL, 'pending', '12', '2024-12-11 12:36:35', '2024-12-11 12:36:36');
INSERT INTO `payment_transactions` VALUES ('165', '330', '1530', 'Stripe', 'pi_3QUzZRBvoXuMhOgs0a7pkCfg', NULL, NULL, 'pending', '12', '2024-12-12 05:13:56', '2024-12-12 05:13:57');
INSERT INTO `payment_transactions` VALUES ('166', '330', '1530', 'Stripe', 'pi_3QV9elBvoXuMhOgs1tdub0HN', NULL, NULL, 'pending', '12', '2024-12-12 16:00:07', '2024-12-12 16:00:08');
INSERT INTO `payment_transactions` VALUES ('167', '330', '1530', 'Stripe', 'pi_3QVoPeBvoXuMhOgs0pshube8', NULL, NULL, 'pending', '12', '2024-12-14 11:31:12', '2024-12-14 11:31:15');
INSERT INTO `payment_transactions` VALUES ('168', '330', '1530', 'Stripe', 'pi_3QVp4FBvoXuMhOgs0eZzli6I', NULL, NULL, 'pending', '12', '2024-12-14 12:13:10', '2024-12-14 12:13:11');
INSERT INTO `payment_transactions` VALUES ('169', '330', '1530', 'Stripe', 'pi_3QWeuaBvoXuMhOgs0N8U5eNO', NULL, NULL, 'pending', '12', '2024-12-16 19:34:39', '2024-12-16 19:34:40');
INSERT INTO `payment_transactions` VALUES ('170', '330', '1530', 'Stripe', 'pi_3QX0CMBvoXuMhOgs1fa6lyeo', NULL, NULL, 'pending', '12', '2024-12-17 18:18:25', '2024-12-17 18:18:27');
INSERT INTO `payment_transactions` VALUES ('171', '330', '1530', 'Stripe', 'pi_3QX6UbBvoXuMhOgs1FPdTT0a', NULL, NULL, 'pending', '12', '2024-12-18 01:01:41', '2024-12-18 01:01:42');
INSERT INTO `payment_transactions` VALUES ('172', '330', '1530', 'Stripe', 'pi_3QX7mdBvoXuMhOgs0aqJp61r', NULL, NULL, 'pending', '12', '2024-12-18 02:24:22', '2024-12-18 02:24:23');
INSERT INTO `payment_transactions` VALUES ('173', '330', '1530', 'Stripe', 'pi_3QXEy9BvoXuMhOgs1xzROBat', NULL, NULL, 'pending', '12', '2024-12-18 10:04:44', '2024-12-18 10:04:45');
INSERT INTO `payment_transactions` VALUES ('174', '330', '1530', 'Stripe', 'pi_3QXHZ4BvoXuMhOgs0C70e971', NULL, NULL, 'pending', '12', '2024-12-18 12:51:01', '2024-12-18 12:51:02');
INSERT INTO `payment_transactions` VALUES ('175', '330', '6060', 'Stripe', 'pi_3QXIstBvoXuMhOgs0KGuua2n', NULL, NULL, 'pending', '12', '2024-12-18 14:15:35', '2024-12-18 14:15:35');
INSERT INTO `payment_transactions` VALUES ('176', '330', '1530', 'Stripe', 'pi_3QXM9IBvoXuMhOgs0gmYMO1c', NULL, NULL, 'pending', '12', '2024-12-18 17:44:43', '2024-12-18 17:44:44');
INSERT INTO `payment_transactions` VALUES ('177', '330', '6060', 'Stripe', 'pi_3QXMwzBvoXuMhOgs1cge0OJc', NULL, NULL, 'pending', '12', '2024-12-18 18:36:05', '2024-12-18 18:36:06');
INSERT INTO `payment_transactions` VALUES ('178', '330', '1530', 'Stripe', 'pi_3QXe3pBvoXuMhOgs1LbvFGl3', NULL, NULL, 'pending', '12', '2024-12-19 12:52:17', '2024-12-19 12:52:17');
INSERT INTO `payment_transactions` VALUES ('179', '330', '1000', 'Stripe', 'pi_3QY5gABvoXuMhOgs106f6soB', NULL, NULL, 'pending', '12', '2024-12-20 18:21:41', '2024-12-20 18:21:42');
INSERT INTO `payment_transactions` VALUES ('180', '330', '1530', 'Stripe', 'pi_3QY5ytBvoXuMhOgs0euXXS8D', NULL, NULL, 'pending', '12', '2024-12-20 18:41:03', '2024-12-20 18:41:03');
INSERT INTO `payment_transactions` VALUES ('181', '330', '1530', 'Stripe', 'pi_3QYZcQBvoXuMhOgs0wdyr064', NULL, NULL, 'pending', '12', '2024-12-22 02:19:49', '2024-12-22 02:19:50');
INSERT INTO `payment_transactions` VALUES ('182', '330', '1530', 'Stripe', 'pi_3QYj9KBvoXuMhOgs1dyNWArq', NULL, NULL, 'pending', '12', '2024-12-22 12:30:25', '2024-12-22 12:30:26');
INSERT INTO `payment_transactions` VALUES ('183', '330', '1530', 'Stripe', 'pi_3QYoufBvoXuMhOgs1mAsFy6x', NULL, NULL, 'pending', '12', '2024-12-22 18:39:41', '2024-12-22 18:39:42');
INSERT INTO `payment_transactions` VALUES ('184', '330', '1530', 'Stripe', 'pi_3QZKbyBvoXuMhOgs17N5c7SH', NULL, NULL, 'pending', '12', '2024-12-24 04:30:30', '2024-12-24 04:30:31');
INSERT INTO `payment_transactions` VALUES ('185', '330', '1530', 'Stripe', 'pi_3QZjWRBvoXuMhOgs1L32wo31', NULL, NULL, 'pending', '12', '2024-12-25 07:06:26', '2024-12-25 07:06:27');
INSERT INTO `payment_transactions` VALUES ('186', '330', '1530', 'Stripe', 'pi_3QZlMCBvoXuMhOgs1M2KNr8x', NULL, NULL, 'pending', '12', '2024-12-25 09:04:00', '2024-12-25 09:04:01');
INSERT INTO `payment_transactions` VALUES ('187', '330', '5000', 'Stripe', 'pi_3Qa8RHBvoXuMhOgs02EXrfRb', NULL, NULL, 'pending', '12', '2024-12-26 09:42:47', '2024-12-26 09:42:48');
INSERT INTO `payment_transactions` VALUES ('188', '330', '6120', 'Stripe', 'pi_3Qa8SoBvoXuMhOgs0ZS4NwUJ', NULL, NULL, 'pending', '12', '2024-12-26 09:44:21', '2024-12-26 09:44:22');
INSERT INTO `payment_transactions` VALUES ('189', '330', '1000', 'Stripe', 'pi_3QaDXwBvoXuMhOgs0Sh1lbq0', NULL, NULL, 'pending', '12', '2024-12-26 15:10:00', '2024-12-26 15:10:01');
INSERT INTO `payment_transactions` VALUES ('190', '330', '1530', 'Stripe', 'pi_3QacO9BvoXuMhOgs1OjkOBKB', NULL, NULL, 'pending', '12', '2024-12-27 17:41:32', '2024-12-27 17:41:33');
INSERT INTO `payment_transactions` VALUES ('191', '330', '1000', 'Stripe', 'pi_3QahP0BvoXuMhOgs0evzVZgH', NULL, NULL, 'pending', '12', '2024-12-27 23:02:46', '2024-12-27 23:02:46');
INSERT INTO `payment_transactions` VALUES ('192', '330', '1530', 'Stripe', 'pi_3QawWhBvoXuMhOgs0poSDluE', NULL, NULL, 'pending', '12', '2024-12-28 15:11:43', '2024-12-28 15:11:44');
INSERT INTO `payment_transactions` VALUES ('193', '330', '1530', 'Stripe', 'pi_3QawX6BvoXuMhOgs1HI2rT9j', NULL, NULL, 'pending', '12', '2024-12-28 15:12:07', '2024-12-28 15:12:08');
INSERT INTO `payment_transactions` VALUES ('194', '330', '1530', 'Stripe', 'pi_3Qb6WaBvoXuMhOgs0RQvSMkm', NULL, NULL, 'pending', '12', '2024-12-29 01:52:16', '2024-12-29 01:52:16');
INSERT INTO `payment_transactions` VALUES ('195', '330', '1530', 'Stripe', 'pi_3QbNBMBvoXuMhOgs0ZPtLd74', NULL, NULL, 'pending', '12', '2024-12-29 19:39:27', '2024-12-29 19:39:28');
INSERT INTO `payment_transactions` VALUES ('196', '330', '1530', 'Stripe', 'pi_3QbQhKBvoXuMhOgs0J4ikwL6', NULL, NULL, 'pending', '12', '2024-12-29 23:24:42', '2024-12-29 23:24:43');
INSERT INTO `payment_transactions` VALUES ('197', '330', '1000', 'Stripe', 'pi_3QbaXdBvoXuMhOgs05Tbbz9s', NULL, NULL, 'pending', '12', '2024-12-30 09:55:21', '2024-12-30 09:55:22');
INSERT INTO `payment_transactions` VALUES ('198', '330', '1530', 'Stripe', 'pi_3QbahTBvoXuMhOgs1vA0KtQw', NULL, NULL, 'pending', '12', '2024-12-30 10:05:31', '2024-12-30 10:05:32');
INSERT INTO `payment_transactions` VALUES ('199', '330', '6060', 'Stripe', 'pi_3QbaudBvoXuMhOgs1KGBiSfc', NULL, NULL, 'pending', '12', '2024-12-30 10:19:07', '2024-12-30 10:19:07');
INSERT INTO `payment_transactions` VALUES ('200', '330', '6060', 'Stripe', 'pi_3Qbb1VBvoXuMhOgs00Ukt6Zc', NULL, NULL, 'pending', '12', '2024-12-30 10:26:12', '2024-12-30 10:26:13');
INSERT INTO `payment_transactions` VALUES ('201', '330', '6060', 'Stripe', 'pi_3QbjnwBvoXuMhOgs1vxwhYXr', NULL, NULL, 'pending', '12', '2024-12-30 19:48:48', '2024-12-30 19:48:48');
INSERT INTO `payment_transactions` VALUES ('202', '330', '6000', 'Stripe', 'pi_3QbxpyBvoXuMhOgs1PdXkALZ', NULL, NULL, 'pending', '12', '2024-12-31 10:47:49', '2024-12-31 10:47:50');
INSERT INTO `payment_transactions` VALUES ('203', '330', '1530', 'Stripe', 'pi_3QcLBqBvoXuMhOgs0NoB8prv', NULL, NULL, 'pending', '12', '2025-01-01 11:43:57', '2025-01-01 11:43:58');
INSERT INTO `payment_transactions` VALUES ('204', '330', '1530', 'Stripe', 'pi_3QcPgjBvoXuMhOgs0xRIbQRc', NULL, NULL, 'pending', '12', '2025-01-01 16:32:09', '2025-01-01 16:32:09');
INSERT INTO `payment_transactions` VALUES ('205', '330', '1000', 'Stripe', 'pi_3QcVMwBvoXuMhOgs0aFEnntH', NULL, NULL, 'pending', '12', '2025-01-01 22:36:05', '2025-01-01 22:36:06');
INSERT INTO `payment_transactions` VALUES ('206', '330', '6060', 'Stripe', 'pi_3QcY8nBvoXuMhOgs0Ccc6Mmo', NULL, NULL, 'pending', '12', '2025-01-02 01:33:41', '2025-01-02 01:33:42');
INSERT INTO `payment_transactions` VALUES ('207', '330', '1530', 'Stripe', 'pi_3Qco5OBvoXuMhOgs0Bbyp96N', NULL, NULL, 'pending', '12', '2025-01-02 18:35:14', '2025-01-02 18:35:15');
INSERT INTO `payment_transactions` VALUES ('208', '330', '6060', 'Stripe', 'pi_3QcsziBvoXuMhOgs08veDg5L', NULL, NULL, 'pending', '12', '2025-01-02 23:49:41', '2025-01-02 23:49:42');

CREATE TABLE IF NOT EXISTS `payroll_settings` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(191) NOT NULL,
  `amount` double DEFAULT NULL,
  `percentage` double(8,2) DEFAULT NULL,
  `type` varchar(191) NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `payroll_settings_school_id_foreign` (`school_id`),
  CONSTRAINT `payroll_settings_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=6 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `payroll_settings` VALUES ('1', 'Rent', '5000', NULL, 'allowance', '12', '2024-09-06 12:02:10', '2024-09-06 12:02:10', NULL);
INSERT INTO `payroll_settings` VALUES ('2', 'Transportation', '2000', NULL, 'allowance', '12', '2024-09-06 12:02:19', '2024-09-06 12:02:19', NULL);
INSERT INTO `payroll_settings` VALUES ('3', 'PF', NULL, '10', 'deduction', '12', '2024-09-06 12:02:26', '2024-09-06 12:02:26', NULL);
INSERT INTO `payroll_settings` VALUES ('4', 'Tax', NULL, '12', 'deduction', '12', '2024-09-06 12:02:38', '2024-09-06 12:02:38', NULL);
INSERT INTO `payroll_settings` VALUES ('5', 'LIC', NULL, '4', 'allowance', '12', '2024-09-06 12:02:51', '2024-09-06 12:02:51', NULL);

CREATE TABLE IF NOT EXISTS `permissions` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(191) NOT NULL,
  `guard_name` varchar(191) NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `permissions_name_guard_name_unique` (`name`,`guard_name`)
) ENGINE=InnoDB AUTO_INCREMENT=871 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `permissions` VALUES ('1', 'role-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('2', 'role-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('3', 'role-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('4', 'role-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('5', 'medium-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('6', 'medium-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('7', 'medium-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('8', 'medium-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('9', 'section-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('10', 'section-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('11', 'section-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('12', 'section-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('13', 'class-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('14', 'class-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('15', 'class-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('16', 'class-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('17', 'class-section-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('18', 'class-section-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('19', 'class-section-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('20', 'class-section-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('21', 'subject-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('22', 'subject-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('23', 'subject-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('24', 'subject-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('25', 'teacher-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('26', 'teacher-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('27', 'teacher-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('28', 'teacher-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('29', 'guardian-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('30', 'guardian-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('31', 'guardian-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('32', 'guardian-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('33', 'session-year-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('34', 'session-year-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('35', 'session-year-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('36', 'session-year-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('37', 'student-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('38', 'student-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('39', 'student-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('40', 'student-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('41', 'timetable-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('42', 'timetable-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('43', 'timetable-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('44', 'timetable-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('45', 'attendance-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('46', 'attendance-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('47', 'attendance-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('48', 'attendance-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('49', 'holiday-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('50', 'holiday-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('51', 'holiday-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('52', 'holiday-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('53', 'announcement-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('54', 'announcement-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('55', 'announcement-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('56', 'announcement-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('57', 'slider-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('58', 'slider-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('59', 'slider-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('60', 'slider-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('61', 'promote-student-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('62', 'promote-student-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('63', 'promote-student-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('64', 'promote-student-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('65', 'language-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('66', 'language-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('67', 'language-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('68', 'language-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('69', 'lesson-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('70', 'lesson-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('71', 'lesson-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('72', 'lesson-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('73', 'topic-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('74', 'topic-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('75', 'topic-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('76', 'topic-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('77', 'schools-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('78', 'schools-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('79', 'schools-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('80', 'schools-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('81', 'form-fields-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('82', 'form-fields-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('83', 'form-fields-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('84', 'form-fields-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('85', 'grade-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('86', 'grade-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('87', 'grade-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('88', 'grade-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('89', 'package-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('90', 'package-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('91', 'package-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('92', 'package-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('93', 'addons-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('94', 'addons-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('95', 'addons-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('96', 'addons-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('97', 'assignment-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('98', 'assignment-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('99', 'assignment-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('100', 'assignment-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('101', 'assignment-submission', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('102', 'exam-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('103', 'exam-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('104', 'exam-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('105', 'exam-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('106', 'exam-timetable-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('107', 'exam-timetable-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('108', 'exam-timetable-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('109', 'exam-timetable-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('110', 'exam-upload-marks', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('111', 'exam-result', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('112', 'system-setting-manage', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('113', 'fcm-setting-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('114', 'email-setting-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('115', 'privacy-policy', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('116', 'contact-us', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('117', 'about-us', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('118', 'terms-condition', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('119', 'class-teacher', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('120', 'student-reset-password', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('121', 'reset-password-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('122', 'student-change-password', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('123', 'update-admin-profile', 'web', '2023-11-07 12:56:51', '2024-03-30 11:20:22');
INSERT INTO `permissions` VALUES ('124', 'fees-classes', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('125', 'fees-paid', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('126', 'fees-config', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('127', 'school-setting-manage', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('128', 'app-settings', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('129', 'subscription-view', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('130', 'online-exam-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('131', 'online-exam-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('132', 'online-exam-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('133', 'online-exam-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('134', 'online-exam-questions-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('135', 'online-exam-questions-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('136', 'online-exam-questions-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('137', 'online-exam-questions-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('138', 'fees-type-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('139', 'fees-type-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('140', 'fees-type-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('141', 'fees-type-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('142', 'fees-class-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('143', 'fees-class-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('144', 'fees-class-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('145', 'fees-class-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('146', 'staff-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('147', 'staff-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('148', 'staff-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('149', 'staff-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('150', 'expense-category-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('151', 'expense-category-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('152', 'expense-category-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('153', 'expense-category-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('154', 'expense-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('155', 'expense-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('156', 'expense-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('157', 'expense-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('158', 'semester-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('159', 'semester-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('160', 'semester-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('161', 'semester-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('162', 'payroll-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('163', 'payroll-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('164', 'payroll-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('165', 'payroll-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('166', 'stream-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('167', 'stream-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('168', 'stream-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('169', 'stream-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('170', 'shift-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('171', 'shift-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('172', 'shift-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('173', 'shift-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('174', 'faqs-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('175', 'faqs-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('176', 'faqs-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('177', 'faqs-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('178', 'online-exam-result-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('179', 'fcm-setting-manage', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('180', 'fees-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('181', 'fees-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('182', 'fees-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('183', 'fees-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('184', 'transfer-student-list', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('185', 'transfer-student-create', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('186', 'transfer-student-edit', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('187', 'transfer-student-delete', 'web', '2023-11-07 12:56:51', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('192', 'front-site-setting', 'web', '2023-11-30 12:20:17', '2024-02-05 14:35:17');
INSERT INTO `permissions` VALUES ('384', 'guidance-list', 'web', '2024-01-19 11:43:59', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('385', 'guidance-create', 'web', '2024-01-19 11:43:59', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('386', 'guidance-edit', 'web', '2024-01-19 11:43:59', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('387', 'guidance-delete', 'web', '2024-01-19 11:43:59', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('388', 'leave-list', 'web', '2024-01-19 11:43:59', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('389', 'leave-create', 'web', '2024-01-19 11:43:59', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('390', 'leave-edit', 'web', '2024-01-19 11:43:59', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('391', 'leave-delete', 'web', '2024-01-19 11:43:59', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('392', 'approve-leave', 'web', '2024-01-19 11:43:59', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('393', 'payment-settings', 'web', '2024-01-19 11:43:59', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('394', 'subscription-settings', 'web', '2024-01-19 11:43:59', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('395', 'subscription-change-bills', 'web', '2024-01-19 11:43:59', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('396', 'school-terms-condition', 'web', '2024-01-19 11:43:59', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('397', 'gallery-list', 'web', '2024-03-04 15:49:38', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('398', 'gallery-create', 'web', '2024-03-04 15:49:38', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('399', 'gallery-edit', 'web', '2024-03-04 15:49:38', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('400', 'gallery-delete', 'web', '2024-03-04 15:49:38', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('401', 'notification-list', 'web', '2024-03-04 15:49:38', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('402', 'notification-create', 'web', '2024-03-04 15:49:38', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('403', 'notification-edit', 'web', '2024-03-04 15:49:38', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('404', 'notification-delete', 'web', '2024-03-04 15:49:38', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('405', 'student-id-card-settings', 'web', '2024-03-04 15:49:38', '2024-05-27 12:29:16');
INSERT INTO `permissions` VALUES ('406', 'subscription-bill-payment', 'web', '2024-03-04 15:49:38', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('407', 'web-settings', 'web', '2024-03-04 15:49:38', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('623', 'exam-result-edit', 'web', '2024-05-14 10:56:31', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('624', 'id-card-settings', 'web', '2024-06-28 17:15:27', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('625', 'certificate-list', 'web', '2024-06-28 17:15:27', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('626', 'certificate-create', 'web', '2024-06-28 17:15:27', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('627', 'certificate-edit', 'web', '2024-06-28 17:15:27', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('628', 'certificate-delete', 'web', '2024-06-28 17:15:27', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('629', 'payroll-settings-list', 'web', '2024-06-28 17:15:27', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('630', 'payroll-settings-create', 'web', '2024-06-28 17:15:27', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('631', 'payroll-settings-edit', 'web', '2024-06-28 17:15:27', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('632', 'payroll-settings-delete', 'web', '2024-06-28 17:15:27', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('633', 'school-web-settings', 'web', '2024-06-28 17:15:27', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('634', 'class-group-list', 'web', '2024-06-28 17:15:27', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('635', 'class-group-create', 'web', '2024-06-28 17:15:27', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('636', 'class-group-edit', 'web', '2024-06-28 17:15:27', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('637', 'class-group-delete', 'web', '2024-06-28 17:15:27', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('638', 'email-template', 'web', '2024-06-28 17:15:27', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('639', 'database-backup', 'web', '2024-10-10 15:28:43', '2025-01-03 10:51:13');
INSERT INTO `permissions` VALUES ('640', 'view-exam-marks', 'web', '2025-01-03 10:51:13', '2025-01-03 10:51:13');

CREATE TABLE IF NOT EXISTS `promote_students` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `student_id` bigint(20) unsigned NOT NULL COMMENT 'user_id',
  `class_section_id` bigint(20) unsigned NOT NULL,
  `session_year_id` bigint(20) unsigned NOT NULL,
  `result` tinyint(4) NOT NULL DEFAULT 1 COMMENT '1=>Pass,0=>fail',
  `status` tinyint(4) NOT NULL DEFAULT 1 COMMENT '1=>continue,0=>leave',
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `unique_columns` (`student_id`,`class_section_id`,`session_year_id`),
  KEY `promote_students_school_id_foreign` (`school_id`),
  KEY `promote_students_class_section_id_foreign` (`class_section_id`),
  KEY `promote_students_session_year_id_foreign` (`session_year_id`),
  CONSTRAINT `promote_students_class_section_id_foreign` FOREIGN KEY (`class_section_id`) REFERENCES `class_sections` (`id`) ON DELETE CASCADE,
  CONSTRAINT `promote_students_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `promote_students_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE,
  CONSTRAINT `promote_students_student_id_foreign` FOREIGN KEY (`student_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `role_has_permissions` (
  `permission_id` bigint(20) unsigned NOT NULL,
  `role_id` bigint(20) unsigned NOT NULL,
  PRIMARY KEY (`permission_id`,`role_id`),
  KEY `role_has_permissions_role_id_foreign` (`role_id`),
  CONSTRAINT `role_has_permissions_permission_id_foreign` FOREIGN KEY (`permission_id`) REFERENCES `permissions` (`id`) ON DELETE CASCADE,
  CONSTRAINT `role_has_permissions_role_id_foreign` FOREIGN KEY (`role_id`) REFERENCES `roles` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `role_has_permissions` VALUES ('1', '2');
INSERT INTO `role_has_permissions` VALUES ('2', '2');
INSERT INTO `role_has_permissions` VALUES ('3', '2');
INSERT INTO `role_has_permissions` VALUES ('4', '2');
INSERT INTO `role_has_permissions` VALUES ('5', '2');
INSERT INTO `role_has_permissions` VALUES ('6', '2');
INSERT INTO `role_has_permissions` VALUES ('7', '2');
INSERT INTO `role_has_permissions` VALUES ('8', '2');
INSERT INTO `role_has_permissions` VALUES ('9', '2');
INSERT INTO `role_has_permissions` VALUES ('10', '2');
INSERT INTO `role_has_permissions` VALUES ('11', '2');
INSERT INTO `role_has_permissions` VALUES ('12', '2');
INSERT INTO `role_has_permissions` VALUES ('13', '2');
INSERT INTO `role_has_permissions` VALUES ('14', '2');
INSERT INTO `role_has_permissions` VALUES ('15', '2');
INSERT INTO `role_has_permissions` VALUES ('16', '2');
INSERT INTO `role_has_permissions` VALUES ('17', '2');
INSERT INTO `role_has_permissions` VALUES ('18', '2');
INSERT INTO `role_has_permissions` VALUES ('19', '2');
INSERT INTO `role_has_permissions` VALUES ('20', '2');
INSERT INTO `role_has_permissions` VALUES ('21', '2');
INSERT INTO `role_has_permissions` VALUES ('22', '2');
INSERT INTO `role_has_permissions` VALUES ('23', '2');
INSERT INTO `role_has_permissions` VALUES ('24', '2');
INSERT INTO `role_has_permissions` VALUES ('25', '2');
INSERT INTO `role_has_permissions` VALUES ('26', '2');
INSERT INTO `role_has_permissions` VALUES ('27', '2');
INSERT INTO `role_has_permissions` VALUES ('28', '2');
INSERT INTO `role_has_permissions` VALUES ('29', '2');
INSERT INTO `role_has_permissions` VALUES ('30', '2');
INSERT INTO `role_has_permissions` VALUES ('31', '2');
INSERT INTO `role_has_permissions` VALUES ('32', '2');
INSERT INTO `role_has_permissions` VALUES ('33', '2');
INSERT INTO `role_has_permissions` VALUES ('34', '2');
INSERT INTO `role_has_permissions` VALUES ('35', '2');
INSERT INTO `role_has_permissions` VALUES ('36', '2');
INSERT INTO `role_has_permissions` VALUES ('37', '2');
INSERT INTO `role_has_permissions` VALUES ('38', '2');
INSERT INTO `role_has_permissions` VALUES ('39', '2');
INSERT INTO `role_has_permissions` VALUES ('40', '2');
INSERT INTO `role_has_permissions` VALUES ('41', '2');
INSERT INTO `role_has_permissions` VALUES ('42', '2');
INSERT INTO `role_has_permissions` VALUES ('43', '2');
INSERT INTO `role_has_permissions` VALUES ('44', '2');
INSERT INTO `role_has_permissions` VALUES ('45', '2');
INSERT INTO `role_has_permissions` VALUES ('49', '2');
INSERT INTO `role_has_permissions` VALUES ('50', '2');
INSERT INTO `role_has_permissions` VALUES ('51', '2');
INSERT INTO `role_has_permissions` VALUES ('52', '2');
INSERT INTO `role_has_permissions` VALUES ('53', '2');
INSERT INTO `role_has_permissions` VALUES ('54', '2');
INSERT INTO `role_has_permissions` VALUES ('55', '2');
INSERT INTO `role_has_permissions` VALUES ('56', '2');
INSERT INTO `role_has_permissions` VALUES ('57', '2');
INSERT INTO `role_has_permissions` VALUES ('58', '2');
INSERT INTO `role_has_permissions` VALUES ('59', '2');
INSERT INTO `role_has_permissions` VALUES ('60', '2');
INSERT INTO `role_has_permissions` VALUES ('61', '2');
INSERT INTO `role_has_permissions` VALUES ('62', '2');
INSERT INTO `role_has_permissions` VALUES ('63', '2');
INSERT INTO `role_has_permissions` VALUES ('64', '2');
INSERT INTO `role_has_permissions` VALUES ('81', '2');
INSERT INTO `role_has_permissions` VALUES ('82', '2');
INSERT INTO `role_has_permissions` VALUES ('83', '2');
INSERT INTO `role_has_permissions` VALUES ('84', '2');
INSERT INTO `role_has_permissions` VALUES ('85', '2');
INSERT INTO `role_has_permissions` VALUES ('86', '2');
INSERT INTO `role_has_permissions` VALUES ('87', '2');
INSERT INTO `role_has_permissions` VALUES ('88', '2');
INSERT INTO `role_has_permissions` VALUES ('101', '2');
INSERT INTO `role_has_permissions` VALUES ('102', '2');
INSERT INTO `role_has_permissions` VALUES ('103', '2');
INSERT INTO `role_has_permissions` VALUES ('104', '2');
INSERT INTO `role_has_permissions` VALUES ('105', '2');
INSERT INTO `role_has_permissions` VALUES ('106', '2');
INSERT INTO `role_has_permissions` VALUES ('107', '2');
INSERT INTO `role_has_permissions` VALUES ('109', '2');
INSERT INTO `role_has_permissions` VALUES ('111', '2');
INSERT INTO `role_has_permissions` VALUES ('120', '2');
INSERT INTO `role_has_permissions` VALUES ('121', '2');
INSERT INTO `role_has_permissions` VALUES ('122', '2');
INSERT INTO `role_has_permissions` VALUES ('125', '2');
INSERT INTO `role_has_permissions` VALUES ('126', '2');
INSERT INTO `role_has_permissions` VALUES ('127', '2');
INSERT INTO `role_has_permissions` VALUES ('130', '2');
INSERT INTO `role_has_permissions` VALUES ('131', '2');
INSERT INTO `role_has_permissions` VALUES ('132', '2');
INSERT INTO `role_has_permissions` VALUES ('133', '2');
INSERT INTO `role_has_permissions` VALUES ('134', '2');
INSERT INTO `role_has_permissions` VALUES ('135', '2');
INSERT INTO `role_has_permissions` VALUES ('136', '2');
INSERT INTO `role_has_permissions` VALUES ('137', '2');
INSERT INTO `role_has_permissions` VALUES ('138', '2');
INSERT INTO `role_has_permissions` VALUES ('139', '2');
INSERT INTO `role_has_permissions` VALUES ('140', '2');
INSERT INTO `role_has_permissions` VALUES ('141', '2');
INSERT INTO `role_has_permissions` VALUES ('142', '2');
INSERT INTO `role_has_permissions` VALUES ('143', '2');
INSERT INTO `role_has_permissions` VALUES ('144', '2');
INSERT INTO `role_has_permissions` VALUES ('145', '2');
INSERT INTO `role_has_permissions` VALUES ('146', '2');
INSERT INTO `role_has_permissions` VALUES ('147', '2');
INSERT INTO `role_has_permissions` VALUES ('148', '2');
INSERT INTO `role_has_permissions` VALUES ('149', '2');
INSERT INTO `role_has_permissions` VALUES ('150', '2');
INSERT INTO `role_has_permissions` VALUES ('151', '2');
INSERT INTO `role_has_permissions` VALUES ('152', '2');
INSERT INTO `role_has_permissions` VALUES ('153', '2');
INSERT INTO `role_has_permissions` VALUES ('154', '2');
INSERT INTO `role_has_permissions` VALUES ('155', '2');
INSERT INTO `role_has_permissions` VALUES ('156', '2');
INSERT INTO `role_has_permissions` VALUES ('157', '2');
INSERT INTO `role_has_permissions` VALUES ('158', '2');
INSERT INTO `role_has_permissions` VALUES ('159', '2');
INSERT INTO `role_has_permissions` VALUES ('160', '2');
INSERT INTO `role_has_permissions` VALUES ('161', '2');
INSERT INTO `role_has_permissions` VALUES ('162', '2');
INSERT INTO `role_has_permissions` VALUES ('163', '2');
INSERT INTO `role_has_permissions` VALUES ('164', '2');
INSERT INTO `role_has_permissions` VALUES ('165', '2');
INSERT INTO `role_has_permissions` VALUES ('166', '2');
INSERT INTO `role_has_permissions` VALUES ('167', '2');
INSERT INTO `role_has_permissions` VALUES ('168', '2');
INSERT INTO `role_has_permissions` VALUES ('169', '2');
INSERT INTO `role_has_permissions` VALUES ('170', '2');
INSERT INTO `role_has_permissions` VALUES ('171', '2');
INSERT INTO `role_has_permissions` VALUES ('172', '2');
INSERT INTO `role_has_permissions` VALUES ('173', '2');
INSERT INTO `role_has_permissions` VALUES ('174', '2');
INSERT INTO `role_has_permissions` VALUES ('175', '2');
INSERT INTO `role_has_permissions` VALUES ('176', '2');
INSERT INTO `role_has_permissions` VALUES ('177', '2');
INSERT INTO `role_has_permissions` VALUES ('178', '2');
INSERT INTO `role_has_permissions` VALUES ('180', '2');
INSERT INTO `role_has_permissions` VALUES ('181', '2');
INSERT INTO `role_has_permissions` VALUES ('182', '2');
INSERT INTO `role_has_permissions` VALUES ('183', '2');
INSERT INTO `role_has_permissions` VALUES ('184', '2');
INSERT INTO `role_has_permissions` VALUES ('185', '2');
INSERT INTO `role_has_permissions` VALUES ('186', '2');
INSERT INTO `role_has_permissions` VALUES ('187', '2');
INSERT INTO `role_has_permissions` VALUES ('392', '2');
INSERT INTO `role_has_permissions` VALUES ('397', '2');
INSERT INTO `role_has_permissions` VALUES ('398', '2');
INSERT INTO `role_has_permissions` VALUES ('399', '2');
INSERT INTO `role_has_permissions` VALUES ('400', '2');
INSERT INTO `role_has_permissions` VALUES ('401', '2');
INSERT INTO `role_has_permissions` VALUES ('402', '2');
INSERT INTO `role_has_permissions` VALUES ('404', '2');
INSERT INTO `role_has_permissions` VALUES ('623', '2');
INSERT INTO `role_has_permissions` VALUES ('624', '2');
INSERT INTO `role_has_permissions` VALUES ('625', '2');
INSERT INTO `role_has_permissions` VALUES ('626', '2');
INSERT INTO `role_has_permissions` VALUES ('627', '2');
INSERT INTO `role_has_permissions` VALUES ('628', '2');
INSERT INTO `role_has_permissions` VALUES ('629', '2');
INSERT INTO `role_has_permissions` VALUES ('630', '2');
INSERT INTO `role_has_permissions` VALUES ('631', '2');
INSERT INTO `role_has_permissions` VALUES ('632', '2');
INSERT INTO `role_has_permissions` VALUES ('633', '2');
INSERT INTO `role_has_permissions` VALUES ('634', '2');
INSERT INTO `role_has_permissions` VALUES ('635', '2');
INSERT INTO `role_has_permissions` VALUES ('636', '2');
INSERT INTO `role_has_permissions` VALUES ('637', '2');
INSERT INTO `role_has_permissions` VALUES ('638', '2');
INSERT INTO `role_has_permissions` VALUES ('639', '2');
INSERT INTO `role_has_permissions` VALUES ('640', '2');
INSERT INTO `role_has_permissions` VALUES ('17', '43');
INSERT INTO `role_has_permissions` VALUES ('37', '43');
INSERT INTO `role_has_permissions` VALUES ('41', '43');
INSERT INTO `role_has_permissions` VALUES ('45', '43');
INSERT INTO `role_has_permissions` VALUES ('49', '43');
INSERT INTO `role_has_permissions` VALUES ('53', '43');
INSERT INTO `role_has_permissions` VALUES ('54', '43');
INSERT INTO `role_has_permissions` VALUES ('55', '43');
INSERT INTO `role_has_permissions` VALUES ('56', '43');
INSERT INTO `role_has_permissions` VALUES ('69', '43');
INSERT INTO `role_has_permissions` VALUES ('70', '43');
INSERT INTO `role_has_permissions` VALUES ('71', '43');
INSERT INTO `role_has_permissions` VALUES ('72', '43');
INSERT INTO `role_has_permissions` VALUES ('73', '43');
INSERT INTO `role_has_permissions` VALUES ('74', '43');
INSERT INTO `role_has_permissions` VALUES ('75', '43');
INSERT INTO `role_has_permissions` VALUES ('76', '43');
INSERT INTO `role_has_permissions` VALUES ('97', '43');
INSERT INTO `role_has_permissions` VALUES ('98', '43');
INSERT INTO `role_has_permissions` VALUES ('99', '43');
INSERT INTO `role_has_permissions` VALUES ('100', '43');
INSERT INTO `role_has_permissions` VALUES ('101', '43');
INSERT INTO `role_has_permissions` VALUES ('130', '43');
INSERT INTO `role_has_permissions` VALUES ('131', '43');
INSERT INTO `role_has_permissions` VALUES ('132', '43');
INSERT INTO `role_has_permissions` VALUES ('133', '43');
INSERT INTO `role_has_permissions` VALUES ('134', '43');
INSERT INTO `role_has_permissions` VALUES ('135', '43');
INSERT INTO `role_has_permissions` VALUES ('136', '43');
INSERT INTO `role_has_permissions` VALUES ('137', '43');
INSERT INTO `role_has_permissions` VALUES ('178', '43');
INSERT INTO `role_has_permissions` VALUES ('388', '43');
INSERT INTO `role_has_permissions` VALUES ('389', '43');
INSERT INTO `role_has_permissions` VALUES ('390', '43');
INSERT INTO `role_has_permissions` VALUES ('391', '43');
INSERT INTO `role_has_permissions` VALUES ('5', '128');
INSERT INTO `role_has_permissions` VALUES ('6', '128');
INSERT INTO `role_has_permissions` VALUES ('7', '128');
INSERT INTO `role_has_permissions` VALUES ('8', '128');
INSERT INTO `role_has_permissions` VALUES ('9', '128');
INSERT INTO `role_has_permissions` VALUES ('10', '128');
INSERT INTO `role_has_permissions` VALUES ('11', '128');
INSERT INTO `role_has_permissions` VALUES ('12', '128');
INSERT INTO `role_has_permissions` VALUES ('13', '128');
INSERT INTO `role_has_permissions` VALUES ('14', '128');
INSERT INTO `role_has_permissions` VALUES ('15', '128');
INSERT INTO `role_has_permissions` VALUES ('16', '128');
INSERT INTO `role_has_permissions` VALUES ('17', '128');
INSERT INTO `role_has_permissions` VALUES ('18', '128');
INSERT INTO `role_has_permissions` VALUES ('19', '128');
INSERT INTO `role_has_permissions` VALUES ('20', '128');
INSERT INTO `role_has_permissions` VALUES ('21', '128');
INSERT INTO `role_has_permissions` VALUES ('22', '128');
INSERT INTO `role_has_permissions` VALUES ('23', '128');
INSERT INTO `role_has_permissions` VALUES ('24', '128');
INSERT INTO `role_has_permissions` VALUES ('25', '128');
INSERT INTO `role_has_permissions` VALUES ('26', '128');
INSERT INTO `role_has_permissions` VALUES ('27', '128');
INSERT INTO `role_has_permissions` VALUES ('28', '128');
INSERT INTO `role_has_permissions` VALUES ('29', '128');
INSERT INTO `role_has_permissions` VALUES ('30', '128');
INSERT INTO `role_has_permissions` VALUES ('31', '128');
INSERT INTO `role_has_permissions` VALUES ('32', '128');
INSERT INTO `role_has_permissions` VALUES ('37', '128');
INSERT INTO `role_has_permissions` VALUES ('38', '128');
INSERT INTO `role_has_permissions` VALUES ('39', '128');
INSERT INTO `role_has_permissions` VALUES ('40', '128');
INSERT INTO `role_has_permissions` VALUES ('49', '128');
INSERT INTO `role_has_permissions` VALUES ('50', '128');
INSERT INTO `role_has_permissions` VALUES ('51', '128');
INSERT INTO `role_has_permissions` VALUES ('52', '128');
INSERT INTO `role_has_permissions` VALUES ('53', '128');
INSERT INTO `role_has_permissions` VALUES ('54', '128');
INSERT INTO `role_has_permissions` VALUES ('55', '128');
INSERT INTO `role_has_permissions` VALUES ('57', '128');
INSERT INTO `role_has_permissions` VALUES ('58', '128');
INSERT INTO `role_has_permissions` VALUES ('59', '128');
INSERT INTO `role_has_permissions` VALUES ('60', '128');
INSERT INTO `role_has_permissions` VALUES ('85', '128');
INSERT INTO `role_has_permissions` VALUES ('86', '128');
INSERT INTO `role_has_permissions` VALUES ('87', '128');
INSERT INTO `role_has_permissions` VALUES ('88', '128');
INSERT INTO `role_has_permissions` VALUES ('120', '128');
INSERT INTO `role_has_permissions` VALUES ('121', '128');
INSERT INTO `role_has_permissions` VALUES ('154', '128');
INSERT INTO `role_has_permissions` VALUES ('155', '128');
INSERT INTO `role_has_permissions` VALUES ('166', '128');
INSERT INTO `role_has_permissions` VALUES ('167', '128');
INSERT INTO `role_has_permissions` VALUES ('168', '128');
INSERT INTO `role_has_permissions` VALUES ('169', '128');
INSERT INTO `role_has_permissions` VALUES ('170', '128');
INSERT INTO `role_has_permissions` VALUES ('171', '128');
INSERT INTO `role_has_permissions` VALUES ('172', '128');
INSERT INTO `role_has_permissions` VALUES ('173', '128');
INSERT INTO `role_has_permissions` VALUES ('397', '128');
INSERT INTO `role_has_permissions` VALUES ('398', '128');
INSERT INTO `role_has_permissions` VALUES ('399', '128');
INSERT INTO `role_has_permissions` VALUES ('400', '128');
INSERT INTO `role_has_permissions` VALUES ('401', '128');
INSERT INTO `role_has_permissions` VALUES ('402', '128');
INSERT INTO `role_has_permissions` VALUES ('404', '128');

CREATE TABLE IF NOT EXISTS `roles` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(191) NOT NULL,
  `guard_name` varchar(191) NOT NULL,
  `school_id` bigint(20) unsigned DEFAULT NULL,
  `custom_role` tinyint(1) NOT NULL DEFAULT 1,
  `editable` tinyint(1) NOT NULL DEFAULT 1,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `roles_name_guard_name_school_id_unique` (`name`,`guard_name`,`school_id`),
  KEY `roles_school_id_foreign` (`school_id`),
  CONSTRAINT `roles_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=129 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `roles` VALUES ('2', 'School Admin', 'web', '12', '0', '0', NULL, NULL);
INSERT INTO `roles` VALUES ('41', 'Guardian', 'web', '12', '0', '0', '2023-11-16 09:16:37', '2023-11-16 09:16:37');
INSERT INTO `roles` VALUES ('42', 'Student', 'web', '12', '0', '0', '2023-11-16 09:16:37', '2023-11-16 09:16:37');
INSERT INTO `roles` VALUES ('43', 'Teacher', 'web', '12', '0', '1', '2023-11-16 09:16:37', '2023-11-16 09:16:37');
INSERT INTO `roles` VALUES ('128', 'Admin', 'web', '12', '1', '1', '2024-04-02 12:57:27', '2024-04-02 12:57:27');

CREATE TABLE IF NOT EXISTS `school_settings` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(191) NOT NULL,
  `data` text NOT NULL,
  `type` varchar(191) DEFAULT NULL COMMENT 'datatype like string , file etc',
  `school_id` bigint(20) unsigned NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `school_settings_name_school_id_unique` (`name`,`school_id`),
  KEY `school_settings_school_id_foreign` (`school_id`),
  CONSTRAINT `school_settings_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=2617 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `school_settings` VALUES ('1', 'database_name', 'eschool_saas_12_crestwood', 'text', '12');
INSERT INTO `school_settings` VALUES ('175', 'school_name', 'Crestwood Academy', 'string', '12');
INSERT INTO `school_settings` VALUES ('176', 'school_email', 'info@crestwoodacademy.com', 'string', '12');
INSERT INTO `school_settings` VALUES ('177', 'school_phone', '5551234567', 'number', '12');
INSERT INTO `school_settings` VALUES ('178', 'school_tagline', 'Nurturing Excellence, Inspiring Futures', 'string', '12');
INSERT INTO `school_settings` VALUES ('179', 'school_address', '789 Birch Lane
Rivertown, CA 90210
United States', 'string', '12');
INSERT INTO `school_settings` VALUES ('180', 'session_year', '17', 'number', '12');
INSERT INTO `school_settings` VALUES ('181', 'horizontal_logo', '12/school-settings/6684f13c19fb41.027816791719988540.png', 'file', '12');
INSERT INTO `school_settings` VALUES ('182', 'vertical_logo', '12/school-settings/6684f13c2ff446.073594671719988540.svg', 'file', '12');
INSERT INTO `school_settings` VALUES ('183', 'timetable_start_time', '07:00:00', 'time', '12');
INSERT INTO `school_settings` VALUES ('184', 'timetable_end_time', '13:30:00', 'time', '12');
INSERT INTO `school_settings` VALUES ('185', 'timetable_duration', '00:30:00', 'time', '12');
INSERT INTO `school_settings` VALUES ('186', 'auto_renewal_plan', '1', 'integer', '12');
INSERT INTO `school_settings` VALUES ('231', 'favicon', '12/school-settings/6684f13c195d11.910025701719988540.svg', 'file', '12');
INSERT INTO `school_settings` VALUES ('232', 'roll_number_sort_column', 'first_name', 'string', '12');
INSERT INTO `school_settings` VALUES ('233', 'roll_number_sort_order', 'asc', 'string', '12');
INSERT INTO `school_settings` VALUES ('234', 'change_roll_number', '', 'string', '12');
INSERT INTO `school_settings` VALUES ('535', 'currency_code', 'USD', 'string', '12');
INSERT INTO `school_settings` VALUES ('536', 'currency_symbol', '$', 'string', '12');
INSERT INTO `school_settings` VALUES ('603', 'date_format', 'd-m-Y', 'string', '12');
INSERT INTO `school_settings` VALUES ('604', 'time_format', 'h:i A', 'string', '12');
INSERT INTO `school_settings` VALUES ('1189', 'header_color', '#215679', 'string', '12');
INSERT INTO `school_settings` VALUES ('1190', 'footer_color', '#56cc99', 'string', '12');
INSERT INTO `school_settings` VALUES ('1191', 'header_footer_text_color', '#ffffff', 'string', '12');
INSERT INTO `school_settings` VALUES ('1192', 'layout_type', 'vertical', 'string', '12');
INSERT INTO `school_settings` VALUES ('1193', 'profile_image_style', 'round', 'string', '12');
INSERT INTO `school_settings` VALUES ('1194', 'page_width', '85', 'string', '12');
INSERT INTO `school_settings` VALUES ('1195', 'page_height', '160', 'string', '12');
INSERT INTO `school_settings` VALUES ('1196', 'student_id_card_fields', 'student_name,class_section,roll_no,dob,gender,session_year,guardian_name,guardian_contact', 'string', '12');
INSERT INTO `school_settings` VALUES ('1660', 'email-template-parent', '&lt;p&gt;Dear {parent_name},&lt;/p&gt; &lt;p&gt;We are delighted to welcome {child_name} to {school_name}!&lt;/p&gt; &lt;p&gt;As part of our registration process, we have created accounts for both you and your child in our {school_name}. Below are the registration details you will need to access the system, along with links to download our mobile app for your convenience.&lt;/p&gt; &lt;hr&gt; &lt;p&gt;&lt;strong&gt;Student Credential Details:&lt;/strong&gt;&lt;/p&gt; &lt;ul&gt; &lt;li&gt;&lt;strong&gt;Name:&lt;/strong&gt; {child_name}&lt;/li&gt; &lt;li&gt;&lt;strong&gt;Admission No.: &lt;/strong&gt;{admission_no}&lt;/li&gt; &lt;li&gt;&lt;strong&gt;GR No.:&lt;/strong&gt; {grno}&lt;/li&gt; &lt;li&gt;&lt;strong&gt;Password:&lt;/strong&gt; {child_password}&lt;/li&gt; &lt;/ul&gt; &lt;hr&gt; &lt;p&gt;&lt;strong&gt;Parent Credential Details:&lt;/strong&gt;&lt;/p&gt; &lt;ul&gt; &lt;li&gt;&lt;strong&gt;Name:&lt;/strong&gt; {parent_name}&lt;/li&gt; &lt;li&gt;&lt;strong&gt;Email:&lt;/strong&gt; {email}&lt;/li&gt; &lt;li&gt;&lt;strong&gt;Password:&lt;/strong&gt; {password}&lt;/li&gt; &lt;/ul&gt; &lt;hr&gt; &lt;p&gt;&lt;strong&gt;App Download Links:&lt;/strong&gt;&lt;/p&gt; &lt;ul&gt; &lt;li&gt;&lt;strong&gt;Android:&lt;/strong&gt; {android_app}&lt;/li&gt; &lt;li&gt;&lt;strong&gt;iOS:&lt;/strong&gt; {ios_app}&lt;/li&gt; &lt;/ul&gt; &lt;hr&gt; &lt;p&gt;&lt;strong&gt;Steps to Complete the Registration:&lt;/strong&gt;&lt;/p&gt; &lt;ol&gt; &lt;li&gt;Download the school management app using the links above for easier access on your mobile devices.&lt;/li&gt; &lt;li&gt;Enter the email and password for either the student or parent account.&lt;/li&gt; &lt;li&gt;Follow the on-screen instructions to complete the profile setup.&lt;/li&gt; &lt;/ol&gt; &lt;p&gt;&lt;strong&gt;Important:&lt;/strong&gt;&lt;/p&gt; &lt;ul&gt; &lt;li&gt;For security reasons, please ensure that both the student and parent passwords are changed upon first login.&lt;/li&gt; &lt;li&gt;If you encounter any issues during the registration process, please do not hesitate to contact our support team at {support_email} or call {support_contact}.&lt;/li&gt; &lt;/ul&gt; &lt;p&gt;We look forward to an enriching educational experience for {child_name} at {school_name}. Thank you for entrusting us with your child&#039;s education.&lt;/p&gt; &lt;p&gt;Best regards,&lt;/p&gt; &lt;p&gt;{school_name}&lt;br&gt;{support_email}&lt;/p&gt;', 'text', '12');
INSERT INTO `school_settings` VALUES ('1740', 'email-template-staff', '&lt;p&gt;Dear {full_name},&lt;/p&gt; &lt;p&gt;Welcome to {school_name}!&lt;/p&gt; &lt;p&gt;We are excited to have you join our team. Below are your registration details to access the {school_name}:&lt;/p&gt; &lt;hr&gt; &lt;p&gt;&lt;strong&gt;Your Registration Details:&lt;/strong&gt;&lt;/p&gt; &lt;ul&gt; &lt;li&gt;&lt;strong&gt;Registration URL:&lt;/strong&gt; {url}&lt;/li&gt; &lt;li&gt;&lt;strong&gt;Email:&lt;/strong&gt; {email}&lt;/li&gt; &lt;li&gt;&lt;strong&gt;Password:&lt;/strong&gt; {password}&lt;/li&gt; &lt;/ul&gt; &lt;hr&gt; &lt;p&gt;&lt;strong&gt;Steps to Complete Your Registration:&lt;/strong&gt;&lt;/p&gt; &lt;ol&gt; &lt;li&gt;Click on the registration URL provided above.&lt;/li&gt; &lt;li&gt;Enter your email and password.&lt;/li&gt; &lt;li&gt;Follow the on-screen instructions to set up your profile.&lt;/li&gt; &lt;/ol&gt; &lt;p&gt;&lt;strong&gt;Important:&lt;/strong&gt;&lt;/p&gt; &lt;ul&gt; &lt;li&gt;For security reasons, please change your password upon your first login.&lt;/li&gt; &lt;li&gt;If you have any questions or need assistance during the registration process, please contact our support team at {support_email} or call {support_contact}.&lt;/li&gt; &lt;/ul&gt; &lt;p&gt;&lt;strong&gt;App Download Links:&lt;/strong&gt;&lt;/p&gt; &lt;ul&gt; &lt;li&gt;&lt;strong&gt;Android:&lt;/strong&gt; {android_app}&lt;/li&gt; &lt;li&gt;&lt;strong&gt;iOS:&lt;/strong&gt; {ios_app}&lt;/li&gt; &lt;/ul&gt; &lt;p&gt;We look forward to a successful academic year with you on our team. Thank you for your commitment to excellence in education.&lt;/p&gt; &lt;p&gt;Best regards,&lt;/p&gt; &lt;p&gt;{school_name}&lt;br&gt;{support_email}&lt;br&gt;{support_contact}&lt;br&gt;{url}&lt;/p&gt;', 'text', '12');
INSERT INTO `school_settings` VALUES ('1900', 'domain', 'crestwood-academy', 'string', '12');
INSERT INTO `school_settings` VALUES ('1906', 'primary_color', '#22577a', 'string', '12');
INSERT INTO `school_settings` VALUES ('1907', 'secondary_color', '#57cc99', 'string', '12');
INSERT INTO `school_settings` VALUES ('1908', 'primary_background_color', '#f2f5f7', 'string', '12');
INSERT INTO `school_settings` VALUES ('1909', 'text_secondary_color', '#2d2c2fb5', 'string', '12');
INSERT INTO `school_settings` VALUES ('1910', 'primary_hover_color', '#143449', 'string', '12');
INSERT INTO `school_settings` VALUES ('1911', 'about_us_title', 'About Us', 'string', '12');
INSERT INTO `school_settings` VALUES ('1912', 'about_us_heading', 'Personalized Learning for Every Student', 'string', '12');
INSERT INTO `school_settings` VALUES ('1913', 'about_us_description', 'Briefly introduce your school, including its name, location, and level of 
education (elementary, high school, etc.). Highlight your school\'s 
mission statement. This concise statement captures the core purpose 
and philosophy that guides everything you do.

Briefly introduce your school, including its name, location, and level of 
education (elementary, high school, etc.). Highlight your school\'s 
mission statement. This concise statement captures the core purpose 
and philosophy that guides everything you do.', 'string', '12');
INSERT INTO `school_settings` VALUES ('1914', 'about_us_image', '12/school-settings/6683ebbb74e6b4.747441831719921595.png', 'file', '12');
INSERT INTO `school_settings` VALUES ('1915', 'about_us_status', '1', 'string', '12');
INSERT INTO `school_settings` VALUES ('1916', 'education_program_title', 'Educational Programs', 'string', '12');
INSERT INTO `school_settings` VALUES ('1917', 'education_program_heading', 'Educational Programs for every Stage', 'string', '12');
INSERT INTO `school_settings` VALUES ('1918', 'education_program_description', 'Educational programs are tailored to cater to every stage of learning, ensuring comprehensive development from early childhood to adulthood.', 'string', '12');
INSERT INTO `school_settings` VALUES ('1919', 'education_program_status', '1', 'string', '12');
INSERT INTO `school_settings` VALUES ('1920', 'expert_teachers_title', 'Our Expert Teacher', 'string', '12');
INSERT INTO `school_settings` VALUES ('1921', 'expert_teachers_heading', 'More Than Just Teachers, They\'re Mentors', 'string', '12');
INSERT INTO `school_settings` VALUES ('1922', 'expert_teachers_description', 'Educational programs are tailored to cater to every stage of learning, 
ensuring comprehensive development from early childhood to adulthood', 'string', '12');
INSERT INTO `school_settings` VALUES ('1923', 'expert_teachers_status', '1', 'string', '12');
INSERT INTO `school_settings` VALUES ('1924', 'faqs_title', 'Frequently Asked Questions', 'string', '12');
INSERT INTO `school_settings` VALUES ('1925', 'faqs_heading', 'Know More About eSchool', 'string', '12');
INSERT INTO `school_settings` VALUES ('1926', 'faqs_description', 'We\'ve got answers! Explore our comprehensive collection of frequently asked 
questions to find solutions to common queries.', 'string', '12');
INSERT INTO `school_settings` VALUES ('1927', 'faqs_status', '1', 'string', '12');
INSERT INTO `school_settings` VALUES ('1928', 'counter_title', 'CTCA-Contes', 'string', '12');
INSERT INTO `school_settings` VALUES ('1929', 'counter_heading', 'Educational Programs for every Stage', 'string', '12');
INSERT INTO `school_settings` VALUES ('1930', 'counter_description', 'Educational programs are tailored to cater to every stage of learning, 
ensuring comprehensive development from early childhood to adulthood.', 'string', '12');
INSERT INTO `school_settings` VALUES ('1931', 'counter_teacher', '12/school-settings/6683ebbb95b475.629969971719921595.jpg', 'file', '12');
INSERT INTO `school_settings` VALUES ('1932', 'counter_status', '1', 'string', '12');
INSERT INTO `school_settings` VALUES ('1933', 'our_mission_title', 'Who We Are', 'string', '12');
INSERT INTO `school_settings` VALUES ('1934', 'our_mission_heading', 'Discover Our Mission for eSchool', 'string', '12');
INSERT INTO `school_settings` VALUES ('1935', 'our_mission_description', 'Welcome to eSchool, where education meets inspiration, and every
child\'s journey is a story of growth and discovery', 'string', '12');
INSERT INTO `school_settings` VALUES ('1936', 'our_mission_points', 'Educational Institutions,Educational Materials,Online Learning Platform', 'string', '12');
INSERT INTO `school_settings` VALUES ('1937', 'our_mission_status', '1', 'string', '12');
INSERT INTO `school_settings` VALUES ('1938', 'announcement_title', 'Announcement', 'string', '12');
INSERT INTO `school_settings` VALUES ('1939', 'announcement_heading', 'Important Update', 'string', '12');
INSERT INTO `school_settings` VALUES ('1940', 'announcement_description', 'Don\'t miss out on these upcoming events! Check the schedule and marks your calender.', 'string', '12');
INSERT INTO `school_settings` VALUES ('1941', 'announcement_image', '12/school-settings/6683ebbb9a81c6.593235361719921595.png', 'file', '12');
INSERT INTO `school_settings` VALUES ('1942', 'announcement_status', '1', 'string', '12');
INSERT INTO `school_settings` VALUES ('1943', 'gallery_title', 'Our Photo Gallery', 'string', '12');
INSERT INTO `school_settings` VALUES ('1944', 'gallery_heading', 'Tiny Scholars Showcase', 'string', '12');
INSERT INTO `school_settings` VALUES ('1945', 'gallery_description', 'We are group of teachers who really love children\'s and enjoy every moment of teaching.', 'string', '12');
INSERT INTO `school_settings` VALUES ('1946', 'gallery_status', '1', 'string', '12');
INSERT INTO `school_settings` VALUES ('1947', 'contact_us_heading', 'Get In Touch', 'string', '12');
INSERT INTO `school_settings` VALUES ('1948', 'contact_us_description', 'Have Any Query?', 'string', '12');
INSERT INTO `school_settings` VALUES ('1949', 'contact_us_status', '1', 'string', '12');
INSERT INTO `school_settings` VALUES ('1950', 'short_description', 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna.', 'string', '12');
INSERT INTO `school_settings` VALUES ('1951', 'footer_text', '© 2024 © WRTeam. All Rights Reserved', 'string', '12');
INSERT INTO `school_settings` VALUES ('1952', 'facebook', 'https://www.facebook.com/wrteam.in/', 'string', '12');
INSERT INTO `school_settings` VALUES ('1953', 'instagram', 'https://www.instagram.com/wrteam.in/', 'string', '12');
INSERT INTO `school_settings` VALUES ('1954', 'linkedin', 'https://in.linkedin.com/company/wrteam', 'string', '12');
INSERT INTO `school_settings` VALUES ('1955', 'twitter', '0', 'string', '12');
INSERT INTO `school_settings` VALUES ('1956', 'footer_logo', '12/school-settings/6684f1663976d8.778457021719988582.png', 'file', '12');
INSERT INTO `school_settings` VALUES ('2004', 'terms_condition', '&lt;h2&gt;What is Lorem Ipsum?&lt;/h2&gt;
&lt;p&gt;&lt;strong&gt;Lorem Ipsum&lt;/strong&gt;&amp;nbsp;is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry&#039;s standard dummy text ever since the 1500s, when an unknown printer took a galley of type and scrambled it to make a type specimen book. It has survived not only five centuries, but also the leap into electronic typesetting, remaining essentially unchanged. It was popularised in the 1960s with the release of Letraset sheets containing Lorem Ipsum passages, and more recently with desktop publishing software like Aldus PageMaker including versions of Lorem Ipsum.&lt;/p&gt;', 'string', '12');
INSERT INTO `school_settings` VALUES ('2005', 'privacy_policy', '&lt;h2&gt;&lt;strong&gt;Terms and Conditions&lt;/strong&gt;&lt;/h2&gt;
&lt;p&gt;Welcome to eschool!&lt;/p&gt;
&lt;p&gt;These terms and conditions outline the rules and regulations for the use of Wrteam&#039;s Website, located at https://e-school.wrteam.in.&lt;/p&gt;
&lt;p&gt;By accessing this website we assume you accept these terms and conditions. Do not continue to use eschool if you do not agree to take all of the terms and conditions stated on this page.&lt;/p&gt;
&lt;p&gt;The following terminology applies to these Terms and Conditions, Privacy Statement and Disclaimer Notice and all Agreements: &quot;Client&quot;, &quot;You&quot; and &quot;Your&quot; refers to you, the person log on this website and compliant to the Company&amp;rsquo;s terms and conditions. &quot;The Company&quot;, &quot;Ourselves&quot;, &quot;We&quot;, &quot;Our&quot; and &quot;Us&quot;, refers to our Company. &quot;Party&quot;, &quot;Parties&quot;, or &quot;Us&quot;, refers to both the Client and ourselves. All terms refer to the offer, acceptance and consideration of payment necessary to undertake the process of our assistance to the Client in the most appropriate manner for the express purpose of meeting the Client&amp;rsquo;s needs in respect of provision of the Company&amp;rsquo;s stated services, in accordance with and subject to, prevailing law of Netherlands. Any use of the above terminology or other words in the singular, plural, capitalization and/or he/she or they, are taken as interchangeable and therefore as referring to same.&lt;/p&gt;
&lt;h3&gt;&lt;strong&gt;Cookies&lt;/strong&gt;&lt;/h3&gt;
&lt;p&gt;We employ the use of cookies. By accessing eschool, you agreed to use cookies in agreement with the Wrteam&#039;s Privacy Policy.&lt;/p&gt;
&lt;p&gt;Most interactive websites use cookies to let us retrieve the user&amp;rsquo;s details for each visit. Cookies are used by our website to enable the functionality of certain areas to make it easier for people visiting our website. Some of our affiliate/advertising partners may also use cookies.&lt;/p&gt;
&lt;h3&gt;&lt;strong&gt;License&lt;/strong&gt;&lt;/h3&gt;
&lt;p&gt;Unless otherwise stated, Wrteam and/or its licensors own the intellectual property rights for all material on eschool. All intellectual property rights are reserved. You may access this from eschool for your own personal use subjected to restrictions set in these terms and conditions.&lt;/p&gt;
&lt;p&gt;You must not:&lt;/p&gt;
&lt;ul&gt;
&lt;li&gt;Republish material from eschool&lt;/li&gt;
&lt;li&gt;Sell, rent or sub-license material from eschool&lt;/li&gt;
&lt;li&gt;Reproduce, duplicate or copy material from eschool&lt;/li&gt;
&lt;li&gt;Redistribute content from eschool&lt;/li&gt;
&lt;/ul&gt;
&lt;p&gt;This Agreement shall begin on the date hereof. Our Terms and Conditions were created with the help of the &lt;a href=&quot;https://www.termsfeed.com/terms-conditions-generator/&quot;&gt;TermsFeed Free Terms and Conditions Generator&lt;/a&gt;.&lt;/p&gt;
&lt;p&gt;Parts of this website offer an opportunity for users to post and exchange opinions and information in certain areas of the website. Wrteam does not filter, edit, publish or review Comments prior to their presence on the website. Comments do not reflect the views and opinions of Wrteam,its agents and/or affiliates. Comments reflect the views and opinions of the person who post their views and opinions. To the extent permitted by applicable laws, Wrteam shall not be liable for the Comments or for any liability, damages or expenses caused and/or suffered as a result of any use of and/or posting of and/or appearance of the Comments on this website.&lt;/p&gt;
&lt;p&gt;Wrteam reserves the right to monitor all Comments and to remove any Comments which can be considered inappropriate, offensive or causes breach of these Terms and Conditions.&lt;/p&gt;
&lt;p&gt;You warrant and represent that:&lt;/p&gt;
&lt;ul&gt;
&lt;li&gt;You are entitled to post the Comments on our website and have all necessary licenses and consents to do so;&lt;/li&gt;
&lt;li&gt;The Comments do not invade any intellectual property right, including without limitation copyright, patent or trademark of any third party;&lt;/li&gt;
&lt;li&gt;The Comments do not contain any defamatory, libelous, offensive, indecent or otherwise unlawful material which is an invasion of privacy&lt;/li&gt;
&lt;li&gt;The Comments will not be used to solicit or promote business or custom or present commercial activities or unlawful activity.&lt;/li&gt;
&lt;/ul&gt;
&lt;p&gt;You hereby grant Wrteam a non-exclusive license to use, reproduce, edit and authorize others to use, reproduce and edit any of your Comments in any and all forms, formats or media.&lt;/p&gt;
&lt;h3&gt;&lt;strong&gt;Hyperlinking to our Content&lt;/strong&gt;&lt;/h3&gt;
&lt;p&gt;The following organizations may link to our Website without prior written approval:&lt;/p&gt;
&lt;ul&gt;
&lt;li&gt;Government agencies;&lt;/li&gt;
&lt;li&gt;Search engines;&lt;/li&gt;
&lt;li&gt;News organizations;&lt;/li&gt;
&lt;li&gt;Online directory distributors may link to our Website in the same manner as they hyperlink to the Websites of other listed businesses; and&lt;/li&gt;
&lt;li&gt;System wide Accredited Businesses except soliciting non-profit organizations, charity shopping malls, and charity fundraising groups which may not hyperlink to our Web site.&lt;/li&gt;
&lt;/ul&gt;
&lt;p&gt;These organizations may link to our home page, to publications or to other Website information so long as the link: (a) is not in any way deceptive; (b) does not falsely imply sponsorship, endorsement or approval of the linking party and its products and/or services; and (c) fits within the context of the linking party&amp;rsquo;s site.&lt;/p&gt;
&lt;p&gt;We may consider and approve other link requests from the following types of organizations:&lt;/p&gt;
&lt;ul&gt;
&lt;li&gt;commonly-known consumer and/or business information sources;&lt;/li&gt;
&lt;li&gt;dot.com community sites;&lt;/li&gt;
&lt;li&gt;associations or other groups representing charities;&lt;/li&gt;
&lt;li&gt;online directory distributors;&lt;/li&gt;
&lt;li&gt;internet portals;&lt;/li&gt;
&lt;li&gt;accounting, law and consulting firms; and&lt;/li&gt;
&lt;li&gt;educational institutions and trade associations.&lt;/li&gt;
&lt;/ul&gt;
&lt;p&gt;We will approve link requests from these organizations if we decide that: (a) the link would not make us look unfavorably to ourselves or to our accredited businesses; (b) the organization does not have any negative records with us; (c) the benefit to us from the visibility of the hyperlink compensates the absence of Wrteam; and (d) the link is in the context of general resource information.&lt;/p&gt;
&lt;p&gt;These organizations may link to our home page so long as the link: (a) is not in any way deceptive; (b) does not falsely imply sponsorship, endorsement or approval of the linking party and its products or services; and (c) fits within the context of the linking party&amp;rsquo;s site.&lt;/p&gt;
&lt;p&gt;If you are one of the organizations listed in paragraph 2 above and are interested in linking to our website, you must inform us by sending an e-mail to Wrteam. Please include your name, your organization name, contact information as well as the URL of your site, a list of any URLs from which you intend to link to our Website, and a list of the URLs on our site to which you would like to link. Wait 2-3 weeks for a response.&lt;/p&gt;
&lt;p&gt;Approved organizations may hyperlink to our Website as follows:&lt;/p&gt;
&lt;ul&gt;
&lt;li&gt;By use of our corporate name; or&lt;/li&gt;
&lt;li&gt;By use of the uniform resource locator being linked to; or&lt;/li&gt;
&lt;li&gt;By use of any other description of our Website being linked to that makes sense within the context and format of content on the linking party&amp;rsquo;s site.&lt;/li&gt;
&lt;/ul&gt;
&lt;p&gt;No use of Wrteam&#039;s logo or other artwork will be allowed for linking absent a trademark license agreement.&lt;/p&gt;
&lt;h3&gt;&lt;strong&gt;iFrames&lt;/strong&gt;&lt;/h3&gt;
&lt;p&gt;Without prior approval and written permission, you may not create frames around our Webpages that alter in any way the visual presentation or appearance of our Website.&lt;/p&gt;
&lt;h3&gt;&lt;strong&gt;Content Liability&lt;/strong&gt;&lt;/h3&gt;
&lt;p&gt;We shall not be hold responsible for any content that appears on your Website. You agree to protect and defend us against all claims that is rising on your Website. No link(s) should appear on any Website that may be interpreted as libelous, obscene or criminal, or which infringes, otherwise violates, or advocates the infringement or other violation of, any third party rights.&lt;/p&gt;
&lt;h3&gt;&lt;strong&gt;Your Privacy&lt;/strong&gt;&lt;/h3&gt;
&lt;p&gt;Please read Privacy Policy&lt;/p&gt;
&lt;h3&gt;&lt;strong&gt;Reservation of Rights&lt;/strong&gt;&lt;/h3&gt;
&lt;p&gt;We reserve the right to request that you remove all links or any particular link to our Website. You approve to immediately remove all links to our Website upon request. We also reserve the right to amen these terms and conditions and it&amp;rsquo;s linking policy at any time. By continuously linking to our Website, you agree to be bound to and follow these linking terms and conditions.&lt;/p&gt;
&lt;h3&gt;&lt;strong&gt;Removal of links from our website&lt;/strong&gt;&lt;/h3&gt;
&lt;p&gt;If you find any link on our Website that is offensive for any reason, you are free to contact and inform us any moment. We will consider requests to remove links but we are not obligated to or so or to respond to you directly.&lt;/p&gt;
&lt;p&gt;We do not ensure that the information on this website is correct, we do not warrant its completeness or accuracy; nor do we promise to ensure that the website remains available or that the material on the website is kept up to date.&lt;/p&gt;
&lt;h3&gt;&lt;strong&gt;Disclaimer&lt;/strong&gt;&lt;/h3&gt;
&lt;p&gt;To the maximum extent permitted by applicable law, we exclude all representations, warranties and conditions relating to our website and the use of this website. Nothing in this disclaimer will:&lt;/p&gt;
&lt;ul&gt;
&lt;li&gt;limit or exclude our or your liability for death or personal injury;&lt;/li&gt;
&lt;li&gt;limit or exclude our or your liability for fraud or fraudulent misrepresentation;&lt;/li&gt;
&lt;li&gt;limit any of our or your liabilities in any way that is not permitted under applicable law; or&lt;/li&gt;
&lt;li&gt;exclude any of our or your liabilities that may not be excluded under applicable law.&lt;/li&gt;
&lt;/ul&gt;
&lt;p&gt;The limitations and prohibitions of liability set in this Section and elsewhere in this disclaimer: (a) are subject to the preceding paragraph; and (b) govern all liabilities arising under the disclaimer, including liabilities arising in contract, in tort and for breach of statutory duty.&lt;/p&gt;
&lt;p&gt;As long as the website and the information and services on the website are provided free of charge, we will not be liable for any loss or damage of any nature.&lt;/p&gt;', 'string', '12');
INSERT INTO `school_settings` VALUES ('2006', 'google_map_link', 'https://www.google.com/maps/embed?pb=!1m18!1m12!1m3!1d458.2865383121145!2d69.64383512666167!3d23.232447880359715!2m3!1f0!2f0!3f0!3m2!1i1024!2i768!4f13.1!3m3!1m2!1s0x39511e5b00000001%3A0xc42d67c61628af6d!2sWRTeam!5e0!3m2!1sen!2sin!4v1719982026061!5m2!1sen!2sin', 'string', '12');
INSERT INTO `school_settings` VALUES ('2410', 'staff_header_color', '#215679', 'string', '12');
INSERT INTO `school_settings` VALUES ('2411', 'staff_footer_color', '#56cc99', 'string', '12');
INSERT INTO `school_settings` VALUES ('2412', 'staff_header_footer_text_color', '#ffffff', 'string', '12');
INSERT INTO `school_settings` VALUES ('2413', 'staff_layout_type', 'vertical', 'string', '12');
INSERT INTO `school_settings` VALUES ('2414', 'staff_profile_image_style', 'round', 'string', '12');
INSERT INTO `school_settings` VALUES ('2415', 'staff_page_width', '90', 'string', '12');
INSERT INTO `school_settings` VALUES ('2416', 'staff_page_height', '120', 'string', '12');
INSERT INTO `school_settings` VALUES ('2417', 'staff_id_card_fields', 'name,role,contact,email,dob,session_year', 'string', '12');
INSERT INTO `school_settings` VALUES ('2547', 'refund_cancellation', '&lt;h2&gt;What is Lorem Ipsum?&lt;/h2&gt;
&lt;p&gt;&lt;strong&gt;Lorem Ipsum&lt;/strong&gt;&amp;nbsp;is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry&#039;s standard dummy text ever since the 1500s, when an unknown printer took a galley of type and scrambled it to make a type specimen book. It has survived not only five centuries, but also the leap into electronic typesetting, remaining essentially unchanged. It was popularised in the 1960s with the release of Letraset sheets containing Lorem Ipsum passages, and more recently with desktop publishing software like Aldus PageMaker including versions of Lorem Ipsum.&lt;/p&gt;', 'string', '12');
INSERT INTO `school_settings` VALUES ('2548', 'online_registration_title', 'Where Learning Takes Flight', 'string', '12');
INSERT INTO `school_settings` VALUES ('2549', 'online_registration_heading', 'Cultivate Your Curiosity & Explore Endless Possibilities. Admissions Open Now!', 'string', '12');
INSERT INTO `school_settings` VALUES ('2550', 'online_registration_description', 'Our admissions are now open for the 2024-25 school year.  We invite curious and enthusiastic students to join our vibrant learning community.', 'string', '12');
INSERT INTO `school_settings` VALUES ('2551', 'online_registration_image', '12/school-settings/66fb81e95cb749.151711511727758825.svg', 'file', '12');
INSERT INTO `school_settings` VALUES ('2552', 'online_registration_status', '1', 'string', '12');
INSERT INTO `school_settings` VALUES ('2600', 'SCHOOL_RECAPTCHA_SITE_KEY', '6LfqgEYqAAAAAEdANxcZCn6N6bBEAIE-f-EVPawC', 'text', '12');
INSERT INTO `school_settings` VALUES ('2601', 'SCHOOL_RECAPTCHA_SECRET_KEY', '6LfqgEYqAAAAAKMKl2wsv3kGQBW1XIXQEh3cOg-a', 'text', '12');

CREATE TABLE IF NOT EXISTS `schools` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(191) NOT NULL,
  `address` varchar(191) NOT NULL,
  `support_phone` varchar(191) NOT NULL,
  `support_email` varchar(191) NOT NULL,
  `tagline` varchar(191) NOT NULL,
  `logo` varchar(191) NOT NULL,
  `admin_id` bigint(20) unsigned DEFAULT NULL COMMENT 'user_id',
  `status` tinyint(4) NOT NULL DEFAULT 0 COMMENT '0 => Deactivate, 1 => Active',
  `domain` varchar(191) DEFAULT NULL,
  `database_name` varchar(191) DEFAULT NULL,
  `code` varchar(191) DEFAULT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `schools_admin_id_foreign` (`admin_id`),
  CONSTRAINT `schools_admin_id_foreign` FOREIGN KEY (`admin_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=13 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `schools` VALUES ('12', 'Crestwood Academy', '789 Birch Lane
Rivertown, CA 90210
United States', '5551234567', 'info@crestwoodacademy.com', 'Nurturing Excellence, Inspiring Futures', 'https://eschool-saas.wrteam.me/storage/school/jaSPOsD1lnHKqviJWGmXOwJf3oHbujkaMvfK3NO4.svg', '40', '1', 'demo', 'eschool_saas_12_crestwood', 'SCH202412', '2023-11-16 03:46:37', '2024-09-30 13:12:14', NULL);

CREATE TABLE IF NOT EXISTS `sections` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(512) NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `sections_school_id_foreign` (`school_id`),
  CONSTRAINT `sections_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=13 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `sections` VALUES ('10', 'A', '12', '2023-11-16 10:29:51', '2023-11-16 10:29:51', NULL);
INSERT INTO `sections` VALUES ('11', 'B', '12', '2023-11-16 10:29:53', '2023-11-16 10:29:53', NULL);
INSERT INTO `sections` VALUES ('12', 'C', '12', '2023-11-16 10:29:55', '2023-11-16 10:29:55', NULL);

CREATE TABLE IF NOT EXISTS `semesters` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(191) NOT NULL,
  `start_month` tinyint(4) NOT NULL,
  `end_month` tinyint(4) NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `semesters_school_id_foreign` (`school_id`),
  CONSTRAINT `semesters_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=6 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `semesters` VALUES ('4', 'First Semester', '1', '6', '12', '2023-11-16 10:38:53', '2023-11-16 10:38:53', NULL);
INSERT INTO `semesters` VALUES ('5', 'Second Semester', '7', '12', '12', '2023-11-16 10:39:03', '2023-11-16 10:39:03', NULL);

CREATE TABLE IF NOT EXISTS `session_years` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(512) NOT NULL,
  `default` tinyint(4) NOT NULL DEFAULT 0,
  `start_date` date NOT NULL,
  `end_date` date NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `session_years_name_school_id_unique` (`name`,`school_id`),
  KEY `session_years_school_id_foreign` (`school_id`),
  CONSTRAINT `session_years_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=18 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `session_years` VALUES ('17', '2023-24', '1', '2024-05-01', '2025-04-30', '12', '2023-11-16 09:16:38', '2024-05-10 09:21:38', NULL);

CREATE TABLE IF NOT EXISTS `shifts` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(191) NOT NULL,
  `start_time` time NOT NULL,
  `end_time` time NOT NULL,
  `status` int(11) NOT NULL DEFAULT 1,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `shifts_school_id_foreign` (`school_id`),
  CONSTRAINT `shifts_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=7 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `shifts` VALUES ('5', 'Morning Shift', '07:00:00', '13:00:00', '1', '12', '2023-11-16 10:40:32', '2023-11-16 10:41:56', NULL);
INSERT INTO `shifts` VALUES ('6', 'Afternoon Shift', '13:30:00', '18:30:00', '1', '12', '2023-11-16 10:41:47', '2023-11-16 10:41:47', NULL);

CREATE TABLE IF NOT EXISTS `sliders` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `image` varchar(1024) NOT NULL,
  `link` varchar(191) DEFAULT NULL,
  `type` int(11) NOT NULL DEFAULT 1 COMMENT '1 => App, 2 => web, 3 => Both',
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `sliders_school_id_foreign` (`school_id`),
  CONSTRAINT `sliders_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=20 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `sliders` VALUES ('11', '12/sliders/655ee0ae7a9698.385148511700716718.jpg', 'https://1.envato.market/9gqdRe', '1', '12', '2023-11-23 05:18:38', '2024-09-30 13:04:18');
INSERT INTO `sliders` VALUES ('12', '12/sliders/655ee0c012b306.748303811700716736.jpg', 'https://wrteam.in/', '1', '12', '2023-11-23 05:18:56', '2024-09-30 13:04:18');
INSERT INTO `sliders` VALUES ('13', '12/sliders/655ee0d8792112.379809241700716760.jpg', 'https://wrteam.in/cyber-week-sale/', '1', '12', '2023-11-23 05:19:20', '2024-09-30 13:04:18');
INSERT INTO `sliders` VALUES ('14', '12/sliders/655ee1f48a2884.483212281700717044.jpg', 'https://codecanyon.net/user/wrteam', '1', '12', '2023-11-23 05:24:04', '2024-09-30 13:04:18');
INSERT INTO `sliders` VALUES ('15', '12/sliders/655ee1fc0fb589.484579491700717052.jpg', 'https://1.envato.market/rQ4323', '1', '12', '2023-11-23 05:24:12', '2024-09-30 13:04:18');
INSERT INTO `sliders` VALUES ('17', '12/sliders/6683f362626104.103796891719923554.jpg', NULL, '2', '12', '2024-07-02 18:02:34', '2024-09-30 13:04:18');
INSERT INTO `sliders` VALUES ('18', '12/sliders/6683f36a52f5f5.721773571719923562.jpg', NULL, '2', '12', '2024-07-02 18:02:42', '2024-09-30 13:04:18');
INSERT INTO `sliders` VALUES ('19', '12/sliders/6683f376dddfd1.536822741719923574.jpg', NULL, '2', '12', '2024-07-02 18:02:54', '2024-09-30 13:04:18');

CREATE TABLE IF NOT EXISTS `staff_payrolls` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `expense_id` bigint(20) unsigned DEFAULT NULL,
  `payroll_setting_id` bigint(20) unsigned DEFAULT NULL,
  `amount` double DEFAULT NULL,
  `percentage` double(8,2) DEFAULT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `unique_ids` (`expense_id`,`payroll_setting_id`),
  KEY `staff_payrolls_payroll_setting_id_foreign` (`payroll_setting_id`),
  KEY `staff_payrolls_school_id_foreign` (`school_id`),
  CONSTRAINT `staff_payrolls_expense_id_foreign` FOREIGN KEY (`expense_id`) REFERENCES `expenses` (`id`) ON DELETE CASCADE,
  CONSTRAINT `staff_payrolls_payroll_setting_id_foreign` FOREIGN KEY (`payroll_setting_id`) REFERENCES `payroll_settings` (`id`) ON DELETE CASCADE,
  CONSTRAINT `staff_payrolls_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=11 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `staff_payrolls` VALUES ('1', '119', '1', '5000', NULL, '12', '2024-09-06 12:05:50', '2024-09-06 12:05:50');
INSERT INTO `staff_payrolls` VALUES ('2', '119', '2', '2000', NULL, '12', '2024-09-06 12:05:50', '2024-09-06 12:05:50');
INSERT INTO `staff_payrolls` VALUES ('3', '119', '5', NULL, '4', '12', '2024-09-06 12:05:50', '2024-09-06 12:05:50');
INSERT INTO `staff_payrolls` VALUES ('4', '119', '3', NULL, '10', '12', '2024-09-06 12:05:50', '2024-09-06 12:05:50');
INSERT INTO `staff_payrolls` VALUES ('5', '119', '4', NULL, '12', '12', '2024-09-06 12:05:50', '2024-09-06 12:05:50');
INSERT INTO `staff_payrolls` VALUES ('6', '123', '1', '5000', NULL, '12', '2024-09-06 12:06:02', '2024-09-06 12:06:02');
INSERT INTO `staff_payrolls` VALUES ('7', '123', '2', '2000', NULL, '12', '2024-09-06 12:06:02', '2024-09-06 12:06:02');
INSERT INTO `staff_payrolls` VALUES ('8', '123', '5', NULL, '4', '12', '2024-09-06 12:06:02', '2024-09-06 12:06:02');
INSERT INTO `staff_payrolls` VALUES ('9', '123', '3', NULL, '10', '12', '2024-09-06 12:06:02', '2024-09-06 12:06:02');
INSERT INTO `staff_payrolls` VALUES ('10', '123', '4', NULL, '12', '12', '2024-09-06 12:06:02', '2024-09-06 12:06:02');

CREATE TABLE IF NOT EXISTS `staff_salaries` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `staff_id` bigint(20) unsigned DEFAULT NULL,
  `payroll_setting_id` bigint(20) unsigned DEFAULT NULL,
  `amount` double DEFAULT NULL,
  `percentage` double(8,2) DEFAULT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `unique_ids` (`staff_id`,`payroll_setting_id`),
  KEY `staff_salaries_payroll_setting_id_foreign` (`payroll_setting_id`),
  CONSTRAINT `staff_salaries_payroll_setting_id_foreign` FOREIGN KEY (`payroll_setting_id`) REFERENCES `payroll_settings` (`id`) ON DELETE CASCADE,
  CONSTRAINT `staff_salaries_staff_id_foreign` FOREIGN KEY (`staff_id`) REFERENCES `staffs` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=6 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `staff_salaries` VALUES ('1', '19', '1', '5000', NULL, '2024-09-06 06:33:25', '2024-09-06 06:33:25');
INSERT INTO `staff_salaries` VALUES ('2', '19', '2', '2000', NULL, '2024-09-06 06:33:25', '2024-09-06 06:33:25');
INSERT INTO `staff_salaries` VALUES ('3', '19', '5', NULL, '4', '2024-09-06 06:33:25', '2024-09-06 06:33:25');
INSERT INTO `staff_salaries` VALUES ('4', '19', '3', NULL, '10', '2024-09-06 06:33:25', '2024-09-06 06:33:25');
INSERT INTO `staff_salaries` VALUES ('5', '19', '4', NULL, '12', '2024-09-06 06:33:25', '2024-09-06 06:33:25');

CREATE TABLE IF NOT EXISTS `staffs` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `user_id` bigint(20) unsigned NOT NULL,
  `qualification` varchar(512) DEFAULT NULL,
  `salary` double NOT NULL DEFAULT 0,
  `joining_date` date DEFAULT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `staffs_user_id_foreign` (`user_id`),
  CONSTRAINT `staffs_user_id_foreign` FOREIGN KEY (`user_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=27 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `staffs` VALUES ('12', '42', 'Master\'s in Education', '55000', NULL, NULL, NULL);
INSERT INTO `staffs` VALUES ('13', '43', 'PhD in Mathematics Education', '65000', NULL, NULL, NULL);
INSERT INTO `staffs` VALUES ('14', '44', 'Master\'s in Science Education', '70000', NULL, NULL, NULL);
INSERT INTO `staffs` VALUES ('15', '45', 'Bachelor\'s in History', '55000', NULL, NULL, NULL);
INSERT INTO `staffs` VALUES ('16', '46', 'Master\'s in Chemistry', '60000', NULL, NULL, NULL);
INSERT INTO `staffs` VALUES ('17', '47', 'Master\'s in Physics Education', '65000', NULL, NULL, NULL);
INSERT INTO `staffs` VALUES ('18', '48', 'Bachelor\'s in Elementary Education', '70000', NULL, NULL, NULL);
INSERT INTO `staffs` VALUES ('19', '49', 'Bachelor\'s in English', '75000', '1970-01-01', NULL, '2024-10-08 17:03:38');
INSERT INTO `staffs` VALUES ('26', '1087', NULL, '25000', NULL, NULL, NULL);

CREATE TABLE IF NOT EXISTS `streams` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(191) NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `streams_school_id_foreign` (`school_id`),
  CONSTRAINT `streams_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=11 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `streams` VALUES ('8', 'Commerce', '12', '2023-11-16 10:39:29', '2023-11-16 10:39:29', NULL);
INSERT INTO `streams` VALUES ('9', 'Arts', '12', '2023-11-16 10:39:32', '2023-11-16 10:39:32', NULL);
INSERT INTO `streams` VALUES ('10', 'Science', '12', '2023-11-16 10:39:35', '2023-11-16 10:39:35', NULL);

CREATE TABLE IF NOT EXISTS `student_online_exam_statuses` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `student_id` bigint(20) unsigned NOT NULL COMMENT 'user_id',
  `online_exam_id` bigint(20) unsigned NOT NULL,
  `status` tinyint(4) NOT NULL COMMENT '1 - in progress 2 - completed',
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `student_online_exam_statuses_school_id_foreign` (`school_id`),
  KEY `student_online_exam_statuses_student_id_foreign` (`student_id`),
  KEY `student_online_exam_statuses_online_exam_id_foreign` (`online_exam_id`),
  CONSTRAINT `student_online_exam_statuses_online_exam_id_foreign` FOREIGN KEY (`online_exam_id`) REFERENCES `online_exams` (`id`) ON DELETE CASCADE,
  CONSTRAINT `student_online_exam_statuses_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `student_online_exam_statuses_student_id_foreign` FOREIGN KEY (`student_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `student_subjects` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `student_id` bigint(20) unsigned NOT NULL COMMENT 'user_id',
  `class_subject_id` bigint(20) unsigned NOT NULL,
  `class_section_id` bigint(20) unsigned NOT NULL,
  `session_year_id` bigint(20) unsigned NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `student_subjects_school_id_foreign` (`school_id`),
  KEY `student_subjects_student_id_foreign` (`student_id`),
  KEY `student_subjects_class_subject_id_foreign` (`class_subject_id`),
  KEY `student_subjects_class_section_id_foreign` (`class_section_id`),
  KEY `student_subjects_session_year_id_foreign` (`session_year_id`),
  CONSTRAINT `student_subjects_class_section_id_foreign` FOREIGN KEY (`class_section_id`) REFERENCES `class_sections` (`id`) ON DELETE CASCADE,
  CONSTRAINT `student_subjects_class_subject_id_foreign` FOREIGN KEY (`class_subject_id`) REFERENCES `class_subjects` (`id`) ON DELETE CASCADE,
  CONSTRAINT `student_subjects_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `student_subjects_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE,
  CONSTRAINT `student_subjects_student_id_foreign` FOREIGN KEY (`student_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `students` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `user_id` bigint(20) unsigned NOT NULL,
  `class_id` bigint(20) unsigned DEFAULT NULL,
  `class_section_id` bigint(20) unsigned DEFAULT NULL,
  `application_type` varchar(191) DEFAULT 'offline',
  `admission_no` varchar(512) NOT NULL,
  `roll_number` int(11) DEFAULT NULL,
  `admission_date` date NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `application_status` int(11) DEFAULT 1 COMMENT '1- accepted, 0- rejected',
  `guardian_id` bigint(20) unsigned NOT NULL,
  `session_year_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `students_school_id_foreign` (`school_id`),
  KEY `students_user_id_foreign` (`user_id`),
  KEY `students_class_section_id_foreign` (`class_section_id`),
  KEY `students_guardian_id_foreign` (`guardian_id`),
  KEY `students_session_year_id_foreign` (`session_year_id`),
  KEY `students_class_id_foreign` (`class_id`),
  CONSTRAINT `students_class_id_foreign` FOREIGN KEY (`class_id`) REFERENCES `classes` (`id`) ON DELETE CASCADE,
  CONSTRAINT `students_class_section_id_foreign` FOREIGN KEY (`class_section_id`) REFERENCES `class_sections` (`id`) ON DELETE CASCADE,
  CONSTRAINT `students_guardian_id_foreign` FOREIGN KEY (`guardian_id`) REFERENCES `users` (`id`) ON DELETE CASCADE,
  CONSTRAINT `students_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `students_session_year_id_foreign` FOREIGN KEY (`session_year_id`) REFERENCES `session_years` (`id`) ON DELETE CASCADE,
  CONSTRAINT `students_user_id_foreign` FOREIGN KEY (`user_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=537 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `students` VALUES ('136', '331', NULL, '55', 'offline', '2022-23121', '1', '2023-11-20', '12', '1', '330', '17', '2023-11-20 05:10:07', '2023-11-20 05:10:07', NULL);
INSERT INTO `students` VALUES ('138', '333', NULL, '57', 'offline', '2022-2312138', '1', '2023-11-20', '12', '1', '330', '17', '2023-11-20 05:32:09', '2023-11-20 05:32:09', NULL);
INSERT INTO `students` VALUES ('139', '334', NULL, '59', 'offline', '2022-2312139', '1', '2023-11-20', '12', '1', '330', '17', '2023-11-20 05:32:57', '2023-11-20 05:32:57', NULL);
INSERT INTO `students` VALUES ('140', '335', NULL, '24', 'offline', '2022-2312140', '1', '2023-11-20', '12', '1', '330', '17', '2023-11-20 05:33:16', '2023-11-20 05:33:16', NULL);
INSERT INTO `students` VALUES ('141', '336', NULL, '25', 'offline', '2022-2312141', '1', '2023-11-20', '12', '1', '330', '17', '2023-11-20 05:33:29', '2023-11-20 05:33:29', NULL);
INSERT INTO `students` VALUES ('142', '337', NULL, '26', 'offline', '2022-2312142', '1', '2023-11-20', '12', '1', '330', '17', '2023-11-20 05:33:41', '2023-11-20 05:33:41', NULL);
INSERT INTO `students` VALUES ('146', '341', NULL, '31', 'offline', '2022-2312146', '1', '2023-11-20', '12', '1', '330', '17', '2023-11-20 05:34:37', '2023-11-20 05:34:37', NULL);
INSERT INTO `students` VALUES ('153', '349', NULL, '55', 'offline', '2022-2312153', '3', '2023-11-20', '12', '1', '348', '17', '2023-11-20 07:51:07', '2023-11-20 07:51:07', NULL);
INSERT INTO `students` VALUES ('154', '351', NULL, '55', 'offline', '2022-2312154', '4', '2023-11-20', '12', '1', '350', '17', '2023-11-20 07:51:08', '2023-11-20 07:51:08', NULL);
INSERT INTO `students` VALUES ('155', '353', NULL, '55', 'offline', '2022-2312155', '5', '2023-11-20', '12', '1', '352', '17', '2023-11-20 07:51:09', '2023-11-20 07:51:09', NULL);
INSERT INTO `students` VALUES ('156', '355', NULL, '55', 'offline', '2022-2312156', '6', '2023-11-20', '12', '1', '354', '17', '2023-11-20 07:51:09', '2023-11-20 07:51:09', NULL);
INSERT INTO `students` VALUES ('157', '357', NULL, '55', 'offline', '2022-2312157', '7', '2023-11-20', '12', '1', '356', '17', '2023-11-20 07:53:56', '2023-11-20 07:53:56', NULL);
INSERT INTO `students` VALUES ('158', '359', NULL, '55', 'offline', '2022-2312158', '8', '2023-11-20', '12', '1', '358', '17', '2023-11-20 07:53:57', '2023-11-20 07:53:57', NULL);
INSERT INTO `students` VALUES ('159', '361', NULL, '55', 'offline', '2022-2312159', '9', '2023-11-20', '12', '1', '360', '17', '2023-11-20 07:53:57', '2023-11-20 07:53:57', NULL);
INSERT INTO `students` VALUES ('160', '363', NULL, '55', 'offline', '2022-2312160', '10', '2023-11-20', '12', '1', '362', '17', '2023-11-20 07:53:58', '2023-11-20 07:53:58', NULL);
INSERT INTO `students` VALUES ('161', '365', NULL, '55', 'offline', '2022-2312161', '11', '2023-11-20', '12', '1', '364', '17', '2023-11-20 07:53:59', '2023-11-20 07:53:59', NULL);
INSERT INTO `students` VALUES ('162', '367', NULL, '55', 'offline', '2022-2312162', '12', '2023-11-20', '12', '1', '366', '17', '2023-11-20 07:53:59', '2023-11-20 07:53:59', NULL);
INSERT INTO `students` VALUES ('163', '369', NULL, '21', 'offline', '2022-2312163', '13', '2023-11-20', '12', '1', '368', '17', '2023-11-20 07:54:00', '2023-11-20 07:54:00', NULL);
INSERT INTO `students` VALUES ('164', '371', NULL, '21', 'offline', '2022-2312164', '14', '2023-11-20', '12', '1', '370', '17', '2023-11-20 07:54:00', '2023-11-20 07:54:00', NULL);
INSERT INTO `students` VALUES ('165', '373', NULL, '21', 'offline', '2022-2312165', '15', '2023-11-20', '12', '1', '372', '17', '2023-11-20 07:54:01', '2023-11-20 07:54:01', NULL);
INSERT INTO `students` VALUES ('166', '375', NULL, '21', 'offline', '2022-2312166', '16', '2023-11-20', '12', '1', '374', '17', '2023-11-20 07:54:02', '2023-11-20 07:54:02', NULL);
INSERT INTO `students` VALUES ('167', '377', NULL, '21', 'offline', '2022-2312167', '17', '2023-11-20', '12', '1', '376', '17', '2023-11-20 07:54:02', '2023-11-20 07:54:02', NULL);
INSERT INTO `students` VALUES ('168', '379', NULL, '21', 'offline', '2022-2312168', '18', '2023-11-20', '12', '1', '378', '17', '2023-11-20 07:54:03', '2023-11-20 07:54:03', NULL);
INSERT INTO `students` VALUES ('169', '381', NULL, '21', 'offline', '2022-2312169', '19', '2023-11-20', '12', '1', '380', '17', '2023-11-20 07:54:04', '2023-11-20 07:54:04', NULL);
INSERT INTO `students` VALUES ('170', '383', NULL, '21', 'offline', '2022-2312170', '20', '2023-11-20', '12', '1', '382', '17', '2023-11-20 07:54:04', '2023-11-20 07:54:04', NULL);
INSERT INTO `students` VALUES ('171', '385', NULL, '21', 'offline', '2022-2312171', '21', '2023-11-20', '12', '1', '384', '17', '2023-11-20 07:54:05', '2023-11-20 07:54:05', NULL);
INSERT INTO `students` VALUES ('172', '387', NULL, '21', 'offline', '2022-2312172', '22', '2023-11-20', '12', '1', '386', '17', '2023-11-20 07:54:06', '2023-11-20 07:54:06', NULL);
INSERT INTO `students` VALUES ('173', '389', NULL, '21', 'offline', '2022-2312173', '23', '2023-11-20', '12', '1', '388', '17', '2023-11-20 07:54:06', '2023-11-20 07:54:06', NULL);
INSERT INTO `students` VALUES ('174', '391', NULL, '21', 'offline', '2022-2312174', '24', '2023-11-20', '12', '1', '390', '17', '2023-11-20 07:54:07', '2023-11-20 07:54:07', NULL);
INSERT INTO `students` VALUES ('175', '393', NULL, '21', 'offline', '2022-2312175', '25', '2023-11-20', '12', '1', '392', '17', '2023-11-20 07:54:08', '2023-11-20 07:54:08', NULL);
INSERT INTO `students` VALUES ('176', '395', NULL, '21', 'offline', '2022-2312176', '26', '2023-11-20', '12', '1', '394', '17', '2023-11-20 07:54:09', '2023-11-20 07:54:09', NULL);
INSERT INTO `students` VALUES ('177', '397', NULL, '21', 'offline', '2022-2312177', '27', '2023-11-20', '12', '1', '396', '17', '2023-11-20 07:54:09', '2023-11-20 07:54:09', NULL);
INSERT INTO `students` VALUES ('178', '399', NULL, '21', 'offline', '2022-2312178', '28', '2023-11-20', '12', '1', '398', '17', '2023-11-20 07:54:10', '2023-11-20 07:54:10', NULL);
INSERT INTO `students` VALUES ('179', '401', NULL, '21', 'offline', '2022-2312179', '29', '2023-11-20', '12', '1', '400', '17', '2023-11-20 07:54:11', '2023-11-20 07:54:11', NULL);
INSERT INTO `students` VALUES ('180', '403', NULL, '21', 'offline', '2022-2312180', '30', '2023-11-20', '12', '1', '402', '17', '2023-11-20 07:54:11', '2023-11-20 07:54:11', NULL);
INSERT INTO `students` VALUES ('181', '405', NULL, '21', 'offline', '2022-2312181', '31', '2023-11-20', '12', '1', '404', '17', '2023-11-20 07:54:12', '2023-11-20 07:54:12', NULL);
INSERT INTO `students` VALUES ('182', '407', NULL, '21', 'offline', '2022-2312182', '32', '2023-11-20', '12', '1', '406', '17', '2023-11-20 07:54:13', '2023-11-20 07:54:13', NULL);
INSERT INTO `students` VALUES ('183', '409', NULL, '21', 'offline', '2022-2312183', '33', '2023-11-20', '12', '1', '408', '17', '2023-11-20 07:54:13', '2023-11-20 07:54:13', NULL);
INSERT INTO `students` VALUES ('184', '411', NULL, '21', 'offline', '2022-2312184', '34', '2023-11-20', '12', '1', '410', '17', '2023-11-20 07:54:14', '2023-11-20 07:54:14', NULL);
INSERT INTO `students` VALUES ('185', '413', NULL, '21', 'offline', '2022-2312185', '35', '2023-11-20', '12', '1', '412', '17', '2023-11-20 07:54:15', '2023-11-20 07:54:15', NULL);
INSERT INTO `students` VALUES ('186', '415', NULL, '21', 'offline', '2022-2312186', '36', '2023-11-20', '12', '1', '414', '17', '2023-11-20 07:54:15', '2023-11-20 07:54:15', NULL);
INSERT INTO `students` VALUES ('187', '417', NULL, '21', 'offline', '2022-2312187', '37', '2023-11-20', '12', '1', '416', '17', '2023-11-20 07:54:16', '2023-11-20 07:54:16', NULL);
INSERT INTO `students` VALUES ('188', '419', NULL, '21', 'offline', '2022-2312188', '38', '2023-11-20', '12', '1', '418', '17', '2023-11-20 07:54:17', '2023-11-20 07:54:17', NULL);
INSERT INTO `students` VALUES ('189', '421', NULL, '21', 'offline', '2022-2312189', '39', '2023-11-20', '12', '1', '420', '17', '2023-11-20 07:54:17', '2023-11-20 07:54:17', NULL);
INSERT INTO `students` VALUES ('190', '423', NULL, '21', 'offline', '2022-2312190', '40', '2023-11-20', '12', '1', '422', '17', '2023-11-20 07:54:18', '2023-11-20 07:54:18', NULL);
INSERT INTO `students` VALUES ('191', '425', NULL, '21', 'offline', '2022-2312191', '41', '2023-11-20', '12', '1', '424', '17', '2023-11-20 07:54:18', '2023-11-20 07:54:18', NULL);
INSERT INTO `students` VALUES ('192', '427', NULL, '21', 'offline', '2022-2312192', '42', '2023-11-20', '12', '1', '426', '17', '2023-11-20 07:54:19', '2023-11-20 07:54:19', NULL);
INSERT INTO `students` VALUES ('193', '429', NULL, '21', 'offline', '2022-2312193', '43', '2023-11-20', '12', '1', '428', '17', '2023-11-20 07:54:20', '2023-11-20 07:54:20', NULL);
INSERT INTO `students` VALUES ('194', '431', NULL, '21', 'offline', '2022-2312194', '44', '2023-11-20', '12', '1', '430', '17', '2023-11-20 07:54:20', '2023-11-20 07:54:20', NULL);
INSERT INTO `students` VALUES ('195', '433', NULL, '21', 'offline', '2022-2312195', '45', '2023-11-20', '12', '1', '432', '17', '2023-11-20 07:54:21', '2023-11-20 07:54:21', NULL);
INSERT INTO `students` VALUES ('196', '435', NULL, '21', 'offline', '2022-2312196', '46', '2023-11-20', '12', '1', '434', '17', '2023-11-20 07:54:22', '2023-11-20 07:54:22', NULL);
INSERT INTO `students` VALUES ('197', '437', NULL, '21', 'offline', '2022-2312197', '47', '2023-11-20', '12', '1', '436', '17', '2023-11-20 07:54:22', '2023-11-20 07:54:22', NULL);
INSERT INTO `students` VALUES ('198', '439', NULL, '21', 'offline', '2022-2312198', '48', '2023-11-20', '12', '1', '438', '17', '2023-11-20 07:54:23', '2023-11-20 07:54:23', NULL);
INSERT INTO `students` VALUES ('199', '441', NULL, '21', 'offline', '2022-2312199', '49', '2023-11-20', '12', '1', '440', '17', '2023-11-20 07:54:24', '2023-11-20 07:54:24', NULL);
INSERT INTO `students` VALUES ('200', '443', NULL, '21', 'offline', '2022-2312200', '50', '2023-11-20', '12', '1', '442', '17', '2023-11-20 07:54:24', '2023-11-20 07:54:24', NULL);
INSERT INTO `students` VALUES ('201', '445', NULL, '21', 'offline', '2022-2312201', '51', '2023-11-20', '12', '1', '444', '17', '2023-11-20 07:54:25', '2023-11-20 07:54:25', NULL);
INSERT INTO `students` VALUES ('202', '447', NULL, '21', 'offline', '2022-2312202', '52', '2023-11-20', '12', '1', '446', '17', '2023-11-20 07:54:26', '2023-11-20 07:54:26', NULL);
INSERT INTO `students` VALUES ('203', '449', NULL, '21', 'offline', '2022-2312203', '53', '2023-11-20', '12', '1', '448', '17', '2023-11-20 07:54:26', '2023-11-20 07:54:26', NULL);
INSERT INTO `students` VALUES ('204', '451', NULL, '21', 'offline', '2022-2312204', '54', '2023-11-20', '12', '1', '450', '17', '2023-11-20 07:54:27', '2023-11-20 07:54:27', NULL);
INSERT INTO `students` VALUES ('205', '453', NULL, '21', 'offline', '2022-2312205', '55', '2023-11-20', '12', '1', '452', '17', '2023-11-20 07:54:28', '2023-11-20 07:54:28', NULL);
INSERT INTO `students` VALUES ('206', '455', NULL, '21', 'offline', '2022-2312206', '56', '2023-11-20', '12', '1', '454', '17', '2023-11-20 07:54:28', '2023-11-20 07:54:28', NULL);
INSERT INTO `students` VALUES ('207', '457', NULL, '21', 'offline', '2022-2312207', '57', '2023-11-20', '12', '1', '456', '17', '2023-11-20 07:54:29', '2023-11-20 07:54:29', NULL);
INSERT INTO `students` VALUES ('208', '459', NULL, '21', 'offline', '2022-2312208', '58', '2023-11-20', '12', '1', '458', '17', '2023-11-20 07:54:30', '2023-11-20 07:54:30', NULL);
INSERT INTO `students` VALUES ('209', '461', NULL, '21', 'offline', '2022-2312209', '59', '2023-11-20', '12', '1', '460', '17', '2023-11-20 07:54:31', '2023-11-20 07:54:31', NULL);
INSERT INTO `students` VALUES ('210', '463', NULL, '21', 'offline', '2022-2312210', '60', '2023-11-20', '12', '1', '462', '17', '2023-11-20 07:54:31', '2023-11-20 07:54:31', NULL);
INSERT INTO `students` VALUES ('211', '465', NULL, '21', 'offline', '2022-2312211', '61', '2023-11-20', '12', '1', '464', '17', '2023-11-20 07:54:32', '2023-11-20 07:54:32', NULL);
INSERT INTO `students` VALUES ('212', '467', NULL, '21', 'offline', '2022-2312212', '62', '2023-11-20', '12', '1', '466', '17', '2023-11-20 07:54:33', '2023-11-20 07:54:33', NULL);
INSERT INTO `students` VALUES ('213', '470', NULL, '57', 'offline', '2022-2312213', '2', '2023-11-22', '12', '1', '469', '17', '2023-11-22 12:23:03', '2023-11-22 12:23:03', NULL);
INSERT INTO `students` VALUES ('214', '472', NULL, '57', 'offline', '2022-2312214', '3', '2023-11-22', '12', '1', '471', '17', '2023-11-22 12:23:04', '2023-11-22 12:23:04', NULL);
INSERT INTO `students` VALUES ('215', '474', NULL, '57', 'offline', '2022-2312215', '4', '2023-11-22', '12', '1', '473', '17', '2023-11-22 12:23:05', '2023-11-22 12:23:05', NULL);
INSERT INTO `students` VALUES ('216', '476', NULL, '57', 'offline', '2022-2312216', '5', '2023-11-22', '12', '1', '475', '17', '2023-11-22 12:23:05', '2023-11-22 12:23:05', NULL);
INSERT INTO `students` VALUES ('217', '478', NULL, '57', 'offline', '2022-2312217', '6', '2023-11-22', '12', '1', '477', '17', '2023-11-22 12:23:06', '2023-11-22 12:23:06', NULL);
INSERT INTO `students` VALUES ('218', '480', NULL, '57', 'offline', '2022-2312218', '7', '2023-11-22', '12', '1', '479', '17', '2023-11-22 12:23:07', '2023-11-22 12:23:07', NULL);
INSERT INTO `students` VALUES ('219', '482', NULL, '57', 'offline', '2022-2312219', '8', '2023-11-22', '12', '1', '481', '17', '2023-11-22 12:23:07', '2023-11-22 12:23:07', NULL);
INSERT INTO `students` VALUES ('220', '484', NULL, '57', 'offline', '2022-2312220', '9', '2023-11-22', '12', '1', '483', '17', '2023-11-22 12:23:08', '2023-11-22 12:23:08', NULL);
INSERT INTO `students` VALUES ('221', '486', NULL, '57', 'offline', '2022-2312221', '10', '2023-11-22', '12', '1', '485', '17', '2023-11-22 12:23:09', '2023-11-22 12:23:09', NULL);
INSERT INTO `students` VALUES ('222', '488', NULL, '22', 'offline', '2022-2312222', '11', '2023-11-22', '12', '1', '487', '17', '2023-11-22 12:23:09', '2023-11-22 12:23:09', NULL);
INSERT INTO `students` VALUES ('223', '490', NULL, '22', 'offline', '2022-2312223', '12', '2023-11-22', '12', '1', '489', '17', '2023-11-22 12:23:10', '2023-11-22 12:23:10', NULL);
INSERT INTO `students` VALUES ('224', '492', NULL, '22', 'offline', '2022-2312224', '13', '2023-11-22', '12', '1', '491', '17', '2023-11-22 12:23:11', '2023-11-22 12:23:11', NULL);
INSERT INTO `students` VALUES ('225', '494', NULL, '22', 'offline', '2022-2312225', '14', '2023-11-22', '12', '1', '493', '17', '2023-11-22 12:23:11', '2023-11-22 12:23:11', NULL);
INSERT INTO `students` VALUES ('226', '496', NULL, '22', 'offline', '2022-2312226', '15', '2023-11-22', '12', '1', '495', '17', '2023-11-22 12:23:12', '2023-11-22 12:23:12', NULL);
INSERT INTO `students` VALUES ('227', '498', NULL, '22', 'offline', '2022-2312227', '16', '2023-11-22', '12', '1', '497', '17', '2023-11-22 12:23:13', '2023-11-22 12:23:13', NULL);
INSERT INTO `students` VALUES ('228', '500', NULL, '22', 'offline', '2022-2312228', '17', '2023-11-22', '12', '1', '499', '17', '2023-11-22 12:23:13', '2023-11-22 12:23:13', NULL);
INSERT INTO `students` VALUES ('229', '502', NULL, '22', 'offline', '2022-2312229', '18', '2023-11-22', '12', '1', '501', '17', '2023-11-22 12:23:14', '2023-11-22 12:23:14', NULL);
INSERT INTO `students` VALUES ('230', '504', NULL, '22', 'offline', '2022-2312230', '19', '2023-11-22', '12', '1', '503', '17', '2023-11-22 12:23:15', '2023-11-22 12:23:15', NULL);
INSERT INTO `students` VALUES ('231', '506', NULL, '22', 'offline', '2022-2312231', '20', '2023-11-22', '12', '1', '505', '17', '2023-11-22 12:23:15', '2023-11-22 12:23:15', NULL);
INSERT INTO `students` VALUES ('232', '508', NULL, '22', 'offline', '2022-2312232', '21', '2023-11-22', '12', '1', '507', '17', '2023-11-22 12:23:16', '2023-11-22 12:23:16', NULL);
INSERT INTO `students` VALUES ('233', '510', NULL, '22', 'offline', '2022-2312233', '22', '2023-11-22', '12', '1', '509', '17', '2023-11-22 12:23:17', '2023-11-22 12:23:17', NULL);
INSERT INTO `students` VALUES ('234', '512', NULL, '22', 'offline', '2022-2312234', '23', '2023-11-22', '12', '1', '511', '17', '2023-11-22 12:23:17', '2023-11-22 12:23:17', NULL);
INSERT INTO `students` VALUES ('235', '514', NULL, '22', 'offline', '2022-2312235', '24', '2023-11-22', '12', '1', '513', '17', '2023-11-22 12:23:18', '2023-11-22 12:23:18', NULL);
INSERT INTO `students` VALUES ('236', '516', NULL, '22', 'offline', '2022-2312236', '25', '2023-11-22', '12', '1', '515', '17', '2023-11-22 12:23:18', '2023-11-22 12:23:18', NULL);
INSERT INTO `students` VALUES ('237', '518', NULL, '22', 'offline', '2022-2312237', '26', '2023-11-22', '12', '1', '517', '17', '2023-11-22 12:23:19', '2023-11-22 12:23:19', NULL);
INSERT INTO `students` VALUES ('238', '520', NULL, '22', 'offline', '2022-2312238', '27', '2023-11-22', '12', '1', '519', '17', '2023-11-22 12:23:20', '2023-11-22 12:23:20', NULL);
INSERT INTO `students` VALUES ('239', '522', NULL, '22', 'offline', '2022-2312239', '28', '2023-11-22', '12', '1', '521', '17', '2023-11-22 12:23:20', '2023-11-22 12:23:20', NULL);
INSERT INTO `students` VALUES ('240', '524', NULL, '22', 'offline', '2022-2312240', '29', '2023-11-22', '12', '1', '523', '17', '2023-11-22 12:23:21', '2023-11-22 12:23:21', NULL);
INSERT INTO `students` VALUES ('241', '526', NULL, '22', 'offline', '2022-2312241', '30', '2023-11-22', '12', '1', '525', '17', '2023-11-22 12:23:22', '2023-11-22 12:23:22', NULL);
INSERT INTO `students` VALUES ('242', '528', NULL, '59', 'offline', '2022-2312242', '2', '2023-11-22', '12', '1', '527', '17', '2023-11-22 12:36:23', '2023-11-22 12:36:23', NULL);
INSERT INTO `students` VALUES ('243', '530', NULL, '23', 'offline', '2022-2312243', '3', '2023-11-22', '12', '1', '529', '17', '2023-11-22 12:36:23', '2023-11-22 12:36:23', NULL);
INSERT INTO `students` VALUES ('244', '532', NULL, '59', 'offline', '2022-2312244', '4', '2023-11-22', '12', '1', '531', '17', '2023-11-22 12:36:24', '2023-11-22 12:36:24', NULL);
INSERT INTO `students` VALUES ('245', '534', NULL, '59', 'offline', '2022-2312245', '5', '2023-11-22', '12', '1', '533', '17', '2023-11-22 12:36:25', '2023-11-22 12:36:25', NULL);
INSERT INTO `students` VALUES ('246', '536', NULL, '59', 'offline', '2022-2312246', '6', '2023-11-22', '12', '1', '535', '17', '2023-11-22 12:36:26', '2023-11-22 12:36:26', NULL);
INSERT INTO `students` VALUES ('247', '538', NULL, '59', 'offline', '2022-2312247', '7', '2023-11-22', '12', '1', '537', '17', '2023-11-22 12:36:26', '2023-11-22 12:36:26', NULL);
INSERT INTO `students` VALUES ('248', '540', NULL, '59', 'offline', '2022-2312248', '8', '2023-11-22', '12', '1', '539', '17', '2023-11-22 12:36:27', '2023-11-22 12:36:27', NULL);
INSERT INTO `students` VALUES ('249', '542', NULL, '59', 'offline', '2022-2312249', '9', '2023-11-22', '12', '1', '541', '17', '2023-11-22 12:36:27', '2023-11-22 12:36:27', NULL);
INSERT INTO `students` VALUES ('250', '544', NULL, '59', 'offline', '2022-2312250', '10', '2023-11-22', '12', '1', '543', '17', '2023-11-22 12:36:28', '2023-11-22 12:36:28', NULL);
INSERT INTO `students` VALUES ('251', '546', NULL, '59', 'offline', '2022-2312251', '11', '2023-11-22', '12', '1', '545', '17', '2023-11-22 12:36:29', '2023-11-22 12:36:29', NULL);
INSERT INTO `students` VALUES ('252', '548', NULL, '23', 'offline', '2022-2312252', '12', '2023-11-22', '12', '1', '547', '17', '2023-11-22 12:36:30', '2023-11-22 12:36:30', NULL);
INSERT INTO `students` VALUES ('253', '550', NULL, '23', 'offline', '2022-2312253', '13', '2023-11-22', '12', '1', '549', '17', '2023-11-22 12:36:30', '2023-11-22 12:36:30', NULL);
INSERT INTO `students` VALUES ('254', '552', NULL, '23', 'offline', '2022-2312254', '14', '2023-11-22', '12', '1', '551', '17', '2023-11-22 12:36:31', '2023-11-22 12:36:31', NULL);
INSERT INTO `students` VALUES ('255', '554', NULL, '23', 'offline', '2022-2312255', '15', '2023-11-22', '12', '1', '553', '17', '2023-11-22 12:36:31', '2023-11-22 12:36:31', NULL);
INSERT INTO `students` VALUES ('256', '556', NULL, '23', 'offline', '2022-2312256', '16', '2023-11-22', '12', '1', '555', '17', '2023-11-22 12:36:32', '2023-11-22 12:36:32', NULL);
INSERT INTO `students` VALUES ('257', '558', NULL, '23', 'offline', '2022-2312257', '17', '2023-11-22', '12', '1', '557', '17', '2023-11-22 12:36:33', '2023-11-22 12:36:33', NULL);
INSERT INTO `students` VALUES ('258', '560', NULL, '23', 'offline', '2022-2312258', '18', '2023-11-22', '12', '1', '559', '17', '2023-11-22 12:36:33', '2023-11-22 12:36:33', NULL);
INSERT INTO `students` VALUES ('259', '562', NULL, '23', 'offline', '2022-2312259', '19', '2023-11-22', '12', '1', '561', '17', '2023-11-22 12:36:34', '2023-11-22 12:36:34', NULL);
INSERT INTO `students` VALUES ('260', '564', NULL, '23', 'offline', '2022-2312260', '20', '2023-11-22', '12', '1', '563', '17', '2023-11-22 12:36:35', '2023-11-22 12:36:35', NULL);
INSERT INTO `students` VALUES ('261', '566', NULL, '23', 'offline', '2022-2312261', '21', '2023-11-22', '12', '1', '565', '17', '2023-11-22 12:36:35', '2023-11-22 12:36:35', NULL);
INSERT INTO `students` VALUES ('262', '568', NULL, '23', 'offline', '2022-2312262', '22', '2023-11-22', '12', '1', '567', '17', '2023-11-22 12:36:36', '2023-11-22 12:36:36', NULL);
INSERT INTO `students` VALUES ('263', '570', NULL, '23', 'offline', '2022-2312263', '23', '2023-11-22', '12', '1', '569', '17', '2023-11-22 12:36:37', '2023-11-22 12:36:37', NULL);
INSERT INTO `students` VALUES ('264', '572', NULL, '23', 'offline', '2022-2312264', '24', '2023-11-22', '12', '1', '571', '17', '2023-11-22 12:36:37', '2023-11-22 12:36:37', NULL);
INSERT INTO `students` VALUES ('265', '574', NULL, '23', 'offline', '2022-2312265', '25', '2023-11-22', '12', '1', '573', '17', '2023-11-22 12:36:38', '2023-11-22 12:36:38', NULL);
INSERT INTO `students` VALUES ('266', '576', NULL, '23', 'offline', '2022-2312266', '26', '2023-11-22', '12', '1', '575', '17', '2023-11-22 12:36:39', '2023-11-22 12:36:39', NULL);
INSERT INTO `students` VALUES ('267', '578', NULL, '23', 'offline', '2022-2312267', '27', '2023-11-22', '12', '1', '577', '17', '2023-11-22 12:36:39', '2023-11-22 12:36:39', NULL);
INSERT INTO `students` VALUES ('268', '580', NULL, '23', 'offline', '2022-2312268', '28', '2023-11-22', '12', '1', '579', '17', '2023-11-22 12:36:40', '2023-11-22 12:36:40', NULL);
INSERT INTO `students` VALUES ('269', '582', NULL, '23', 'offline', '2022-2312269', '29', '2023-11-22', '12', '1', '581', '17', '2023-11-22 12:36:41', '2023-11-22 12:36:41', NULL);
INSERT INTO `students` VALUES ('270', '584', NULL, '23', 'offline', '2022-2312270', '30', '2023-11-22', '12', '1', '583', '17', '2023-11-22 12:36:41', '2023-11-22 12:36:41', NULL);
INSERT INTO `students` VALUES ('271', '586', NULL, '23', 'offline', '2022-2312271', '31', '2023-11-22', '12', '1', '585', '17', '2023-11-22 12:36:42', '2023-11-22 12:36:42', NULL);
INSERT INTO `students` VALUES ('272', '588', NULL, '23', 'offline', '2022-2312272', '32', '2023-11-22', '12', '1', '587', '17', '2023-11-22 12:36:42', '2023-11-22 12:36:42', NULL);
INSERT INTO `students` VALUES ('273', '590', NULL, '24', 'offline', '2022-2312273', '2', '2023-11-22', '12', '1', '589', '17', '2023-11-22 12:39:20', '2023-11-22 12:39:20', NULL);
INSERT INTO `students` VALUES ('274', '592', NULL, '24', 'offline', '2022-2312274', '3', '2023-11-22', '12', '1', '591', '17', '2023-11-22 12:39:21', '2023-11-22 12:39:21', NULL);
INSERT INTO `students` VALUES ('275', '594', NULL, '24', 'offline', '2022-2312275', '4', '2023-11-22', '12', '1', '593', '17', '2023-11-22 12:39:22', '2023-11-22 12:39:22', NULL);
INSERT INTO `students` VALUES ('276', '596', NULL, '24', 'offline', '2022-2312276', '5', '2023-11-22', '12', '1', '595', '17', '2023-11-22 12:39:22', '2023-11-22 12:39:22', NULL);
INSERT INTO `students` VALUES ('277', '598', NULL, '24', 'offline', '2022-2312277', '6', '2023-11-22', '12', '1', '597', '17', '2023-11-22 12:39:23', '2023-11-22 12:39:23', NULL);
INSERT INTO `students` VALUES ('278', '600', NULL, '24', 'offline', '2022-2312278', '7', '2023-11-22', '12', '1', '599', '17', '2023-11-22 12:39:23', '2023-11-22 12:39:23', NULL);
INSERT INTO `students` VALUES ('279', '602', NULL, '24', 'offline', '2022-2312279', '8', '2023-11-22', '12', '1', '601', '17', '2023-11-22 12:39:24', '2023-11-22 12:39:24', NULL);
INSERT INTO `students` VALUES ('280', '604', NULL, '24', 'offline', '2022-2312280', '9', '2023-11-22', '12', '1', '603', '17', '2023-11-22 12:39:25', '2023-11-22 12:39:25', NULL);
INSERT INTO `students` VALUES ('281', '606', NULL, '24', 'offline', '2022-2312281', '10', '2023-11-22', '12', '1', '605', '17', '2023-11-22 12:39:25', '2023-11-22 12:39:25', NULL);
INSERT INTO `students` VALUES ('282', '608', NULL, '24', 'offline', '2022-2312282', '11', '2023-11-22', '12', '1', '607', '17', '2023-11-22 12:39:26', '2023-11-22 12:39:26', NULL);
INSERT INTO `students` VALUES ('283', '610', NULL, '24', 'offline', '2022-2312283', '12', '2023-11-22', '12', '1', '609', '17', '2023-11-22 12:39:27', '2023-11-22 12:39:27', NULL);
INSERT INTO `students` VALUES ('284', '612', NULL, '24', 'offline', '2022-2312284', '13', '2023-11-22', '12', '1', '611', '17', '2023-11-22 12:39:27', '2023-11-22 12:39:27', NULL);
INSERT INTO `students` VALUES ('285', '614', NULL, '24', 'offline', '2022-2312285', '14', '2023-11-22', '12', '1', '613', '17', '2023-11-22 12:39:28', '2023-11-22 12:39:28', NULL);
INSERT INTO `students` VALUES ('286', '616', NULL, '24', 'offline', '2022-2312286', '15', '2023-11-22', '12', '1', '615', '17', '2023-11-22 12:39:29', '2023-11-22 12:39:29', NULL);
INSERT INTO `students` VALUES ('287', '618', NULL, '24', 'offline', '2022-2312287', '16', '2023-11-22', '12', '1', '617', '17', '2023-11-22 12:39:29', '2023-11-22 12:39:29', NULL);
INSERT INTO `students` VALUES ('288', '620', NULL, '24', 'offline', '2022-2312288', '17', '2023-11-22', '12', '1', '619', '17', '2023-11-22 12:39:30', '2023-11-22 12:39:30', NULL);
INSERT INTO `students` VALUES ('289', '622', NULL, '24', 'offline', '2022-2312289', '18', '2023-11-22', '12', '1', '621', '17', '2023-11-22 12:39:31', '2023-11-22 12:39:31', NULL);
INSERT INTO `students` VALUES ('290', '624', NULL, '24', 'offline', '2022-2312290', '19', '2023-11-22', '12', '1', '623', '17', '2023-11-22 12:39:31', '2023-11-22 12:39:31', NULL);
INSERT INTO `students` VALUES ('291', '626', NULL, '24', 'offline', '2022-2312291', '20', '2023-11-22', '12', '1', '625', '17', '2023-11-22 12:39:32', '2023-11-22 12:39:32', NULL);
INSERT INTO `students` VALUES ('292', '628', NULL, '24', 'offline', '2022-2312292', '21', '2023-11-22', '12', '1', '627', '17', '2023-11-22 12:39:33', '2023-11-22 12:39:33', NULL);
INSERT INTO `students` VALUES ('293', '630', NULL, '24', 'offline', '2022-2312293', '22', '2023-11-22', '12', '1', '629', '17', '2023-11-22 12:39:33', '2023-11-22 12:39:33', NULL);
INSERT INTO `students` VALUES ('294', '632', NULL, '24', 'offline', '2022-2312294', '23', '2023-11-22', '12', '1', '631', '17', '2023-11-22 12:39:34', '2023-11-22 12:39:34', NULL);
INSERT INTO `students` VALUES ('295', '634', NULL, '24', 'offline', '2022-2312295', '24', '2023-11-22', '12', '1', '633', '17', '2023-11-22 12:39:35', '2023-11-22 12:39:35', NULL);
INSERT INTO `students` VALUES ('296', '636', NULL, '24', 'offline', '2022-2312296', '25', '2023-11-22', '12', '1', '635', '17', '2023-11-22 12:39:35', '2023-11-22 12:39:35', NULL);
INSERT INTO `students` VALUES ('297', '638', NULL, '24', 'offline', '2022-2312297', '26', '2023-11-22', '12', '1', '637', '17', '2023-11-22 12:39:36', '2023-11-22 12:39:36', NULL);
INSERT INTO `students` VALUES ('298', '640', NULL, '24', 'offline', '2022-2312298', '27', '2023-11-22', '12', '1', '639', '17', '2023-11-22 12:39:37', '2023-11-22 12:39:37', NULL);
INSERT INTO `students` VALUES ('299', '642', NULL, '24', 'offline', '2022-2312299', '28', '2023-11-22', '12', '1', '641', '17', '2023-11-22 12:39:37', '2023-11-22 12:39:37', NULL);
INSERT INTO `students` VALUES ('300', '644', NULL, '24', 'offline', '2022-2312300', '29', '2023-11-22', '12', '1', '643', '17', '2023-11-22 12:39:38', '2023-11-22 12:39:38', NULL);
INSERT INTO `students` VALUES ('301', '646', NULL, '24', 'offline', '2022-2312301', '30', '2023-11-22', '12', '1', '645', '17', '2023-11-22 12:39:39', '2023-11-22 12:39:39', NULL);
INSERT INTO `students` VALUES ('302', '648', NULL, '24', 'offline', '2022-2312302', '31', '2023-11-22', '12', '1', '647', '17', '2023-11-22 12:39:39', '2023-11-22 12:39:39', NULL);
INSERT INTO `students` VALUES ('303', '650', NULL, '24', 'offline', '2022-2312303', '32', '2023-11-22', '12', '1', '649', '17', '2023-11-22 12:39:40', '2023-11-22 12:39:40', NULL);
INSERT INTO `students` VALUES ('304', '652', NULL, '24', 'offline', '2022-2312304', '33', '2023-11-22', '12', '1', '651', '17', '2023-11-22 12:39:41', '2023-11-22 12:39:41', NULL);
INSERT INTO `students` VALUES ('305', '654', NULL, '24', 'offline', '2022-2312305', '34', '2023-11-22', '12', '1', '653', '17', '2023-11-22 12:39:41', '2023-11-22 12:39:41', NULL);
INSERT INTO `students` VALUES ('306', '656', NULL, '24', 'offline', '2022-2312306', '35', '2023-11-22', '12', '1', '655', '17', '2023-11-22 12:39:42', '2023-11-22 12:39:42', NULL);
INSERT INTO `students` VALUES ('307', '658', NULL, '24', 'offline', '2022-2312307', '36', '2023-11-22', '12', '1', '657', '17', '2023-11-22 12:39:43', '2023-11-22 12:39:43', NULL);
INSERT INTO `students` VALUES ('308', '660', NULL, '24', 'offline', '2022-2312308', '37', '2023-11-22', '12', '1', '659', '17', '2023-11-22 12:39:43', '2023-11-22 12:39:43', NULL);
INSERT INTO `students` VALUES ('309', '662', NULL, '24', 'offline', '2022-2312309', '38', '2023-11-22', '12', '1', '661', '17', '2023-11-22 12:39:44', '2023-11-22 12:39:44', NULL);
INSERT INTO `students` VALUES ('310', '664', NULL, '25', 'offline', '2022-2312310', '2', '2023-11-22', '12', '1', '663', '17', '2023-11-22 12:41:41', '2023-11-22 12:41:41', NULL);
INSERT INTO `students` VALUES ('311', '666', NULL, '25', 'offline', '2022-2312311', '3', '2023-11-22', '12', '1', '665', '17', '2023-11-22 12:41:42', '2023-11-22 12:41:42', NULL);
INSERT INTO `students` VALUES ('312', '668', NULL, '25', 'offline', '2022-2312312', '4', '2023-11-22', '12', '1', '667', '17', '2023-11-22 12:41:43', '2023-11-22 12:41:43', NULL);
INSERT INTO `students` VALUES ('313', '670', NULL, '25', 'offline', '2022-2312313', '5', '2023-11-22', '12', '1', '669', '17', '2023-11-22 12:41:43', '2023-11-22 12:41:43', NULL);
INSERT INTO `students` VALUES ('314', '672', NULL, '25', 'offline', '2022-2312314', '6', '2023-11-22', '12', '1', '671', '17', '2023-11-22 12:41:44', '2023-11-22 12:41:44', NULL);
INSERT INTO `students` VALUES ('315', '674', NULL, '25', 'offline', '2022-2312315', '7', '2023-11-22', '12', '1', '673', '17', '2023-11-22 12:41:45', '2023-11-22 12:41:45', NULL);
INSERT INTO `students` VALUES ('316', '676', NULL, '25', 'offline', '2022-2312316', '8', '2023-11-22', '12', '1', '675', '17', '2023-11-22 12:41:45', '2023-11-22 12:41:45', NULL);
INSERT INTO `students` VALUES ('317', '678', NULL, '25', 'offline', '2022-2312317', '9', '2023-11-22', '12', '1', '677', '17', '2023-11-22 12:41:46', '2023-11-22 12:41:46', NULL);
INSERT INTO `students` VALUES ('318', '680', NULL, '25', 'offline', '2022-2312318', '10', '2023-11-22', '12', '1', '679', '17', '2023-11-22 12:41:47', '2023-11-22 12:41:47', NULL);
INSERT INTO `students` VALUES ('319', '682', NULL, '25', 'offline', '2022-2312319', '11', '2023-11-22', '12', '1', '681', '17', '2023-11-22 12:41:47', '2023-11-22 12:41:47', NULL);
INSERT INTO `students` VALUES ('320', '684', NULL, '25', 'offline', '2022-2312320', '12', '2023-11-22', '12', '1', '683', '17', '2023-11-22 12:41:48', '2023-11-22 12:41:48', NULL);
INSERT INTO `students` VALUES ('321', '686', NULL, '25', 'offline', '2022-2312321', '13', '2023-11-22', '12', '1', '685', '17', '2023-11-22 12:41:49', '2023-11-22 12:41:49', NULL);
INSERT INTO `students` VALUES ('322', '688', NULL, '25', 'offline', '2022-2312322', '14', '2023-11-22', '12', '1', '687', '17', '2023-11-22 12:41:49', '2023-11-22 12:41:49', NULL);
INSERT INTO `students` VALUES ('323', '690', NULL, '25', 'offline', '2022-2312323', '15', '2023-11-22', '12', '1', '689', '17', '2023-11-22 12:41:50', '2023-11-22 12:41:50', NULL);
INSERT INTO `students` VALUES ('324', '692', NULL, '25', 'offline', '2022-2312324', '16', '2023-11-22', '12', '1', '691', '17', '2023-11-22 12:41:51', '2023-11-22 12:41:51', NULL);
INSERT INTO `students` VALUES ('325', '694', NULL, '25', 'offline', '2022-2312325', '17', '2023-11-22', '12', '1', '693', '17', '2023-11-22 12:41:51', '2023-11-22 12:41:51', NULL);
INSERT INTO `students` VALUES ('326', '696', NULL, '25', 'offline', '2022-2312326', '18', '2023-11-22', '12', '1', '695', '17', '2023-11-22 12:41:52', '2023-11-22 12:41:52', NULL);
INSERT INTO `students` VALUES ('327', '698', NULL, '25', 'offline', '2022-2312327', '19', '2023-11-22', '12', '1', '697', '17', '2023-11-22 12:41:52', '2023-11-22 12:41:52', NULL);
INSERT INTO `students` VALUES ('328', '700', NULL, '25', 'offline', '2022-2312328', '20', '2023-11-22', '12', '1', '699', '17', '2023-11-22 12:41:53', '2023-11-22 12:41:53', NULL);
INSERT INTO `students` VALUES ('329', '702', NULL, '25', 'offline', '2022-2312329', '21', '2023-11-22', '12', '1', '701', '17', '2023-11-22 12:41:54', '2023-11-22 12:41:54', NULL);
INSERT INTO `students` VALUES ('330', '704', NULL, '25', 'offline', '2022-2312330', '22', '2023-11-22', '12', '1', '703', '17', '2023-11-22 12:41:54', '2023-11-22 12:41:54', NULL);
INSERT INTO `students` VALUES ('331', '706', NULL, '25', 'offline', '2022-2312331', '23', '2023-11-22', '12', '1', '705', '17', '2023-11-22 12:41:55', '2023-11-22 12:41:55', NULL);
INSERT INTO `students` VALUES ('332', '708', NULL, '25', 'offline', '2022-2312332', '24', '2023-11-22', '12', '1', '707', '17', '2023-11-22 12:41:56', '2023-11-22 12:41:56', NULL);
INSERT INTO `students` VALUES ('333', '710', NULL, '25', 'offline', '2022-2312333', '25', '2023-11-22', '12', '1', '709', '17', '2023-11-22 12:41:57', '2023-11-22 12:41:57', NULL);
INSERT INTO `students` VALUES ('334', '712', NULL, '25', 'offline', '2022-2312334', '26', '2023-11-22', '12', '1', '711', '17', '2023-11-22 12:41:57', '2023-11-22 12:41:57', NULL);
INSERT INTO `students` VALUES ('335', '714', NULL, '25', 'offline', '2022-2312335', '27', '2023-11-22', '12', '1', '713', '17', '2023-11-22 12:41:58', '2023-11-22 12:41:58', NULL);
INSERT INTO `students` VALUES ('336', '716', NULL, '25', 'offline', '2022-2312336', '28', '2023-11-22', '12', '1', '715', '17', '2023-11-22 12:41:59', '2023-11-22 12:41:59', NULL);
INSERT INTO `students` VALUES ('337', '718', NULL, '25', 'offline', '2022-2312337', '29', '2023-11-22', '12', '1', '717', '17', '2023-11-22 12:41:59', '2023-11-22 12:41:59', NULL);
INSERT INTO `students` VALUES ('338', '720', NULL, '25', 'offline', '2022-2312338', '30', '2023-11-22', '12', '1', '719', '17', '2023-11-22 12:42:00', '2023-11-22 12:42:00', NULL);
INSERT INTO `students` VALUES ('339', '722', NULL, '25', 'offline', '2022-2312339', '31', '2023-11-22', '12', '1', '721', '17', '2023-11-22 12:42:01', '2023-11-22 12:42:01', NULL);
INSERT INTO `students` VALUES ('340', '724', NULL, '25', 'offline', '2022-2312340', '32', '2023-11-22', '12', '1', '723', '17', '2023-11-22 12:42:01', '2023-11-22 12:42:01', NULL);
INSERT INTO `students` VALUES ('341', '726', NULL, '25', 'offline', '2022-2312341', '33', '2023-11-22', '12', '1', '725', '17', '2023-11-22 12:42:02', '2023-11-22 12:42:02', NULL);
INSERT INTO `students` VALUES ('342', '728', NULL, '25', 'offline', '2022-2312342', '34', '2023-11-22', '12', '1', '727', '17', '2023-11-22 12:42:03', '2023-11-22 12:42:03', NULL);
INSERT INTO `students` VALUES ('343', '730', NULL, '25', 'offline', '2022-2312343', '35', '2023-11-22', '12', '1', '729', '17', '2023-11-22 12:42:03', '2023-11-22 12:42:03', NULL);
INSERT INTO `students` VALUES ('344', '732', NULL, '25', 'offline', '2022-2312344', '36', '2023-11-22', '12', '1', '731', '17', '2023-11-22 12:42:04', '2023-11-22 12:42:04', NULL);
INSERT INTO `students` VALUES ('345', '734', NULL, '25', 'offline', '2022-2312345', '37', '2023-11-22', '12', '1', '733', '17', '2023-11-22 12:42:05', '2023-11-22 12:42:05', NULL);
INSERT INTO `students` VALUES ('346', '736', NULL, '25', 'offline', '2022-2312346', '38', '2023-11-22', '12', '1', '735', '17', '2023-11-22 12:42:05', '2023-11-22 12:42:05', NULL);
INSERT INTO `students` VALUES ('347', '738', NULL, '25', 'offline', '2022-2312347', '39', '2023-11-22', '12', '1', '737', '17', '2023-11-22 12:42:06', '2023-11-22 12:42:06', NULL);
INSERT INTO `students` VALUES ('348', '740', NULL, '25', 'offline', '2022-2312348', '40', '2023-11-22', '12', '1', '739', '17', '2023-11-22 12:42:07', '2023-11-22 12:42:07', NULL);
INSERT INTO `students` VALUES ('349', '742', NULL, '25', 'offline', '2022-2312349', '41', '2023-11-22', '12', '1', '741', '17', '2023-11-22 12:42:07', '2023-11-22 12:42:07', NULL);
INSERT INTO `students` VALUES ('350', '744', NULL, '26', 'offline', '2022-2312350', '2', '2023-11-22', '12', '1', '743', '17', '2023-11-22 12:51:34', '2023-11-22 12:51:34', NULL);
INSERT INTO `students` VALUES ('351', '746', NULL, '26', 'offline', '2022-2312351', '3', '2023-11-22', '12', '1', '745', '17', '2023-11-22 12:51:35', '2023-11-22 12:51:35', NULL);
INSERT INTO `students` VALUES ('352', '748', NULL, '26', 'offline', '2022-2312352', '4', '2023-11-22', '12', '1', '747', '17', '2023-11-22 12:51:35', '2023-11-22 12:51:35', NULL);
INSERT INTO `students` VALUES ('353', '750', NULL, '26', 'offline', '2022-2312353', '5', '2023-11-22', '12', '1', '749', '17', '2023-11-22 12:51:36', '2023-11-22 12:51:36', NULL);
INSERT INTO `students` VALUES ('354', '752', NULL, '26', 'offline', '2022-2312354', '6', '2023-11-22', '12', '1', '751', '17', '2023-11-22 12:51:37', '2023-11-22 12:51:37', NULL);
INSERT INTO `students` VALUES ('355', '754', NULL, '26', 'offline', '2022-2312355', '7', '2023-11-22', '12', '1', '753', '17', '2023-11-22 12:51:37', '2023-11-22 12:51:37', NULL);
INSERT INTO `students` VALUES ('356', '756', NULL, '26', 'offline', '2022-2312356', '8', '2023-11-22', '12', '1', '755', '17', '2023-11-22 12:51:38', '2023-11-22 12:51:38', NULL);
INSERT INTO `students` VALUES ('357', '758', NULL, '26', 'offline', '2022-2312357', '9', '2023-11-22', '12', '1', '757', '17', '2023-11-22 12:51:39', '2023-11-22 12:51:39', NULL);
INSERT INTO `students` VALUES ('358', '760', NULL, '26', 'offline', '2022-2312358', '10', '2023-11-22', '12', '1', '759', '17', '2023-11-22 12:51:39', '2023-11-22 12:51:39', NULL);
INSERT INTO `students` VALUES ('359', '762', NULL, '26', 'offline', '2022-2312359', '11', '2023-11-22', '12', '1', '761', '17', '2023-11-22 12:51:40', '2023-11-22 12:51:40', NULL);
INSERT INTO `students` VALUES ('360', '764', NULL, '26', 'offline', '2022-2312360', '12', '2023-11-22', '12', '1', '763', '17', '2023-11-22 12:51:41', '2023-11-22 12:51:41', NULL);
INSERT INTO `students` VALUES ('361', '766', NULL, '26', 'offline', '2022-2312361', '13', '2023-11-22', '12', '1', '765', '17', '2023-11-22 12:51:41', '2023-11-22 12:51:41', NULL);
INSERT INTO `students` VALUES ('362', '768', NULL, '26', 'offline', '2022-2312362', '14', '2023-11-22', '12', '1', '767', '17', '2023-11-22 12:51:42', '2023-11-22 12:51:42', NULL);
INSERT INTO `students` VALUES ('363', '770', NULL, '26', 'offline', '2022-2312363', '15', '2023-11-22', '12', '1', '769', '17', '2023-11-22 12:51:43', '2023-11-22 12:51:43', NULL);
INSERT INTO `students` VALUES ('364', '772', NULL, '26', 'offline', '2022-2312364', '16', '2023-11-22', '12', '1', '771', '17', '2023-11-22 12:51:43', '2023-11-22 12:51:43', NULL);
INSERT INTO `students` VALUES ('365', '774', NULL, '26', 'offline', '2022-2312365', '17', '2023-11-22', '12', '1', '773', '17', '2023-11-22 12:51:44', '2023-11-22 12:51:44', NULL);
INSERT INTO `students` VALUES ('366', '776', NULL, '26', 'offline', '2022-2312366', '18', '2023-11-22', '12', '1', '775', '17', '2023-11-22 12:51:45', '2023-11-22 12:51:45', NULL);
INSERT INTO `students` VALUES ('367', '778', NULL, '26', 'offline', '2022-2312367', '19', '2023-11-22', '12', '1', '777', '17', '2023-11-22 12:51:45', '2023-11-22 12:51:45', NULL);
INSERT INTO `students` VALUES ('368', '780', NULL, '26', 'offline', '2022-2312368', '20', '2023-11-22', '12', '1', '779', '17', '2023-11-22 12:51:46', '2023-11-22 12:51:46', NULL);
INSERT INTO `students` VALUES ('369', '782', NULL, '26', 'offline', '2022-2312369', '21', '2023-11-22', '12', '1', '781', '17', '2023-11-22 12:51:46', '2023-11-22 12:51:46', NULL);
INSERT INTO `students` VALUES ('370', '784', NULL, '26', 'offline', '2022-2312370', '22', '2023-11-22', '12', '1', '783', '17', '2023-11-22 12:51:47', '2023-11-22 12:51:47', NULL);
INSERT INTO `students` VALUES ('371', '786', NULL, '26', 'offline', '2022-2312371', '23', '2023-11-22', '12', '1', '785', '17', '2023-11-22 12:51:48', '2023-11-22 12:51:48', NULL);
INSERT INTO `students` VALUES ('372', '788', NULL, '26', 'offline', '2022-2312372', '24', '2023-11-22', '12', '1', '787', '17', '2023-11-22 12:51:48', '2023-11-22 12:51:48', NULL);
INSERT INTO `students` VALUES ('373', '790', NULL, '26', 'offline', '2022-2312373', '25', '2023-11-22', '12', '1', '789', '17', '2023-11-22 12:51:49', '2023-11-22 12:51:49', NULL);
INSERT INTO `students` VALUES ('374', '792', NULL, '26', 'offline', '2022-2312374', '26', '2023-11-22', '12', '1', '791', '17', '2023-11-22 12:51:50', '2023-11-22 12:51:50', NULL);
INSERT INTO `students` VALUES ('375', '794', NULL, '26', 'offline', '2022-2312375', '27', '2023-11-22', '12', '1', '793', '17', '2023-11-22 12:51:50', '2023-11-22 12:51:50', NULL);
INSERT INTO `students` VALUES ('376', '796', NULL, '26', 'offline', '2022-2312376', '28', '2023-11-22', '12', '1', '795', '17', '2023-11-22 12:51:51', '2023-11-22 12:51:51', NULL);
INSERT INTO `students` VALUES ('377', '798', NULL, '26', 'offline', '2022-2312377', '29', '2023-11-22', '12', '1', '797', '17', '2023-11-22 12:51:52', '2023-11-22 12:51:52', NULL);
INSERT INTO `students` VALUES ('378', '800', NULL, '26', 'offline', '2022-2312378', '30', '2023-11-22', '12', '1', '799', '17', '2023-11-22 12:51:52', '2023-11-22 12:51:52', NULL);
INSERT INTO `students` VALUES ('379', '802', NULL, '26', 'offline', '2022-2312379', '31', '2023-11-22', '12', '1', '801', '17', '2023-11-22 12:51:53', '2023-11-22 12:51:53', NULL);
INSERT INTO `students` VALUES ('480', '1004', NULL, '31', 'offline', '2022-2312480', '2', '2023-11-22', '12', '1', '1003', '17', '2023-11-22 12:53:51', '2023-11-22 12:53:51', NULL);
INSERT INTO `students` VALUES ('481', '1006', NULL, '31', 'offline', '2022-2312481', '3', '2023-11-22', '12', '1', '1005', '17', '2023-11-22 12:53:51', '2023-11-22 12:53:51', NULL);
INSERT INTO `students` VALUES ('482', '1008', NULL, '31', 'offline', '2022-2312482', '4', '2023-11-22', '12', '1', '1007', '17', '2023-11-22 12:53:52', '2023-11-22 12:53:52', NULL);
INSERT INTO `students` VALUES ('483', '1010', NULL, '31', 'offline', '2022-2312483', '5', '2023-11-22', '12', '1', '1009', '17', '2023-11-22 12:53:53', '2023-11-22 12:53:53', NULL);
INSERT INTO `students` VALUES ('484', '1012', NULL, '31', 'offline', '2022-2312484', '6', '2023-11-22', '12', '1', '1011', '17', '2023-11-22 12:53:53', '2023-11-22 12:53:53', NULL);
INSERT INTO `students` VALUES ('485', '1014', NULL, '31', 'offline', '2022-2312485', '7', '2023-11-22', '12', '1', '1013', '17', '2023-11-22 12:53:54', '2023-11-22 12:53:54', NULL);
INSERT INTO `students` VALUES ('486', '1016', NULL, '31', 'offline', '2022-2312486', '8', '2023-11-22', '12', '1', '1015', '17', '2023-11-22 12:53:54', '2023-11-22 12:53:54', NULL);
INSERT INTO `students` VALUES ('487', '1018', NULL, '31', 'offline', '2022-2312487', '9', '2023-11-22', '12', '1', '1017', '17', '2023-11-22 12:53:55', '2023-11-22 12:53:55', NULL);
INSERT INTO `students` VALUES ('488', '1020', NULL, '31', 'offline', '2022-2312488', '10', '2023-11-22', '12', '1', '1019', '17', '2023-11-22 12:53:56', '2023-11-22 12:53:56', NULL);
INSERT INTO `students` VALUES ('489', '1022', NULL, '31', 'offline', '2022-2312489', '11', '2023-11-22', '12', '1', '1021', '17', '2023-11-22 12:53:56', '2023-11-22 12:53:56', NULL);
INSERT INTO `students` VALUES ('490', '1024', NULL, '31', 'offline', '2022-2312490', '12', '2023-11-22', '12', '1', '1023', '17', '2023-11-22 12:53:57', '2023-11-22 12:53:57', NULL);
INSERT INTO `students` VALUES ('491', '1026', NULL, '31', 'offline', '2022-2312491', '13', '2023-11-22', '12', '1', '1025', '17', '2023-11-22 12:53:58', '2023-11-22 12:53:58', NULL);
INSERT INTO `students` VALUES ('492', '1028', NULL, '31', 'offline', '2022-2312492', '14', '2023-11-22', '12', '1', '1027', '17', '2023-11-22 12:53:58', '2023-11-22 12:53:58', NULL);
INSERT INTO `students` VALUES ('493', '1030', NULL, '31', 'offline', '2022-2312493', '15', '2023-11-22', '12', '1', '1029', '17', '2023-11-22 12:53:59', '2023-11-22 12:53:59', NULL);
INSERT INTO `students` VALUES ('494', '1032', NULL, '31', 'offline', '2022-2312494', '16', '2023-11-22', '12', '1', '1031', '17', '2023-11-22 12:54:00', '2023-11-22 12:54:00', NULL);
INSERT INTO `students` VALUES ('495', '1034', NULL, '31', 'offline', '2022-2312495', '17', '2023-11-22', '12', '1', '1033', '17', '2023-11-22 12:54:00', '2023-11-22 12:54:00', NULL);
INSERT INTO `students` VALUES ('496', '1036', NULL, '31', 'offline', '2022-2312496', '18', '2023-11-22', '12', '1', '1035', '17', '2023-11-22 12:54:01', '2023-11-22 12:54:01', NULL);
INSERT INTO `students` VALUES ('497', '1038', NULL, '31', 'offline', '2022-2312497', '19', '2023-11-22', '12', '1', '1037', '17', '2023-11-22 12:54:02', '2023-11-22 12:54:02', NULL);
INSERT INTO `students` VALUES ('498', '1040', NULL, '31', 'offline', '2022-2312498', '20', '2023-11-22', '12', '1', '1039', '17', '2023-11-22 12:54:02', '2023-11-22 12:54:02', NULL);
INSERT INTO `students` VALUES ('499', '1042', NULL, '31', 'offline', '2022-2312499', '21', '2023-11-22', '12', '1', '1041', '17', '2023-11-22 12:54:03', '2023-11-22 12:54:03', NULL);
INSERT INTO `students` VALUES ('500', '1044', NULL, '31', 'offline', '2022-2312500', '22', '2023-11-22', '12', '1', '1043', '17', '2023-11-22 12:54:04', '2023-11-22 12:54:04', NULL);
INSERT INTO `students` VALUES ('501', '1046', NULL, '31', 'offline', '2022-2312501', '23', '2023-11-22', '12', '1', '1045', '17', '2023-11-22 12:54:04', '2023-11-22 12:54:04', NULL);
INSERT INTO `students` VALUES ('502', '1048', NULL, '31', 'offline', '2022-2312502', '24', '2023-11-22', '12', '1', '1047', '17', '2023-11-22 12:54:05', '2023-11-22 12:54:05', NULL);
INSERT INTO `students` VALUES ('503', '1050', NULL, '31', 'offline', '2022-2312503', '25', '2023-11-22', '12', '1', '1049', '17', '2023-11-22 12:54:06', '2023-11-22 12:54:06', NULL);
INSERT INTO `students` VALUES ('504', '1052', NULL, '31', 'offline', '2022-2312504', '26', '2023-11-22', '12', '1', '1051', '17', '2023-11-22 12:54:06', '2023-11-22 12:54:06', NULL);
INSERT INTO `students` VALUES ('505', '1054', NULL, '31', 'offline', '2022-2312505', '27', '2023-11-22', '12', '1', '1053', '17', '2023-11-22 12:54:07', '2023-11-22 12:54:07', NULL);
INSERT INTO `students` VALUES ('506', '1056', NULL, '31', 'offline', '2022-2312506', '28', '2023-11-22', '12', '1', '1055', '17', '2023-11-22 12:54:08', '2023-11-22 12:54:08', NULL);
INSERT INTO `students` VALUES ('507', '1058', NULL, '31', 'offline', '2022-2312507', '29', '2023-11-22', '12', '1', '1057', '17', '2023-11-22 12:54:08', '2023-11-22 12:54:08', NULL);
INSERT INTO `students` VALUES ('508', '1060', NULL, '31', 'offline', '2022-2312508', '30', '2023-11-22', '12', '1', '1059', '17', '2023-11-22 12:54:09', '2023-11-22 12:54:09', NULL);
INSERT INTO `students` VALUES ('509', '1062', NULL, '31', 'offline', '2022-2312509', '31', '2023-11-22', '12', '1', '1061', '17', '2023-11-22 12:54:10', '2023-11-22 12:54:10', NULL);
INSERT INTO `students` VALUES ('510', '1089', '13', NULL, 'online', '2023-240120510', NULL, '2024-10-01', '12', '0', '1088', '17', '2024-10-01 11:30:25', '2024-10-01 11:30:25', NULL);
INSERT INTO `students` VALUES ('511', '1091', '18', NULL, 'online', '2023-240120511', NULL, '2024-10-03', '12', '0', '1090', '17', '2024-10-03 03:26:12', '2024-10-03 03:26:12', NULL);
INSERT INTO `students` VALUES ('512', '1093', '13', NULL, 'online', '2023-240120512', NULL, '2024-10-03', '12', '0', '1092', '17', '2024-10-03 21:23:40', '2024-10-03 21:23:40', NULL);
INSERT INTO `students` VALUES ('513', '1095', '29', NULL, 'online', '2023-240120513', NULL, '2024-10-05', '12', '0', '1094', '17', '2024-10-05 23:09:50', '2024-10-05 23:09:50', NULL);
INSERT INTO `students` VALUES ('514', '1097', '29', NULL, 'online', '2023-240120514', NULL, '2024-10-08', '12', '0', '1096', '17', '2024-10-08 15:58:26', '2024-10-08 15:58:26', NULL);
INSERT INTO `students` VALUES ('515', '1099', '29', NULL, 'online', '2023-240120515', NULL, '2024-10-09', '12', '0', '1098', '17', '2024-10-09 22:13:09', '2024-10-09 22:13:09', NULL);
INSERT INTO `students` VALUES ('516', '1101', '13', NULL, 'online', '2023-240120516', NULL, '2024-10-09', '12', '0', '1100', '17', '2024-10-09 23:46:29', '2024-10-09 23:46:29', NULL);
INSERT INTO `students` VALUES ('517', '1103', '18', NULL, 'online', '2023-240120517', NULL, '2024-10-11', '12', '0', '1102', '17', '2024-10-11 13:28:30', '2024-10-11 13:28:30', NULL);
INSERT INTO `students` VALUES ('518', '1105', '14', NULL, 'online', '2023-240120518', NULL, '2024-10-15', '12', '0', '1104', '17', '2024-10-15 03:20:58', '2024-10-15 03:20:58', NULL);
INSERT INTO `students` VALUES ('519', '1107', '23', NULL, 'online', '2023-240120519', NULL, '2024-10-15', '12', '0', '1106', '17', '2024-10-15 11:20:56', '2024-10-15 11:20:56', NULL);
INSERT INTO `students` VALUES ('520', '1109', '27', NULL, 'online', '2023-240120520', NULL, '2024-10-15', '12', '0', '1108', '17', '2024-10-15 11:51:02', '2024-10-15 11:51:02', NULL);
INSERT INTO `students` VALUES ('521', '1111', '13', NULL, 'online', '2023-240120521', NULL, '2024-10-16', '12', '0', '1110', '17', '2024-10-16 12:11:17', '2024-10-16 12:11:17', NULL);
INSERT INTO `students` VALUES ('522', '1113', '24', NULL, 'online', '2023-240120522', NULL, '2024-10-21', '12', '0', '1112', '17', '2024-10-21 09:48:18', '2024-10-21 09:48:18', NULL);
INSERT INTO `students` VALUES ('523', '1115', '21', NULL, 'online', '2023-240120523', NULL, '2024-11-09', '12', '0', '1114', '17', '2024-11-09 11:25:02', '2024-11-09 11:25:02', NULL);
INSERT INTO `students` VALUES ('524', '1117', '13', NULL, 'online', '2023-240120524', NULL, '2024-11-15', '12', '0', '1116', '17', '2024-11-15 11:36:31', '2024-11-15 11:36:31', NULL);
INSERT INTO `students` VALUES ('525', '1119', '23', NULL, 'online', '2023-240120525', NULL, '2024-11-17', '12', '0', '1118', '17', '2024-11-17 16:07:43', '2024-11-17 16:07:43', NULL);
INSERT INTO `students` VALUES ('526', '1121', '16', NULL, 'online', '2023-240120526', NULL, '2024-11-17', '12', '0', '1120', '17', '2024-11-17 18:55:41', '2024-11-17 18:55:41', NULL);
INSERT INTO `students` VALUES ('527', '1123', '13', NULL, 'online', '2023-240120527', NULL, '2024-12-01', '12', '0', '1122', '17', '2024-12-01 20:30:48', '2024-12-01 20:30:48', NULL);
INSERT INTO `students` VALUES ('528', '1125', '16', NULL, 'online', '2023-240120528', NULL, '2024-12-04', '12', '0', '1124', '17', '2024-12-04 20:10:31', '2024-12-04 20:10:31', NULL);
INSERT INTO `students` VALUES ('529', '1127', '26', NULL, 'online', '2023-240120529', NULL, '2024-12-11', '12', '0', '1126', '17', '2024-12-11 00:09:32', '2024-12-11 00:09:32', NULL);
INSERT INTO `students` VALUES ('530', '1129', '19', NULL, 'online', '2023-240120530', NULL, '2024-12-11', '12', '0', '1128', '17', '2024-12-11 12:11:32', '2024-12-11 12:11:32', NULL);
INSERT INTO `students` VALUES ('531', '1131', '23', NULL, 'online', '2023-240120531', NULL, '2024-12-11', '12', '0', '1130', '17', '2024-12-11 19:43:02', '2024-12-11 19:43:02', NULL);
INSERT INTO `students` VALUES ('532', '1132', '23', NULL, 'online', '2023-240120532', NULL, '2024-12-15', '12', '0', '1130', '17', '2024-12-15 02:54:40', '2024-12-15 02:54:40', NULL);
INSERT INTO `students` VALUES ('533', '1134', '25', NULL, 'online', '2023-240120533', NULL, '2024-12-30', '12', '0', '1133', '17', '2024-12-30 21:15:56', '2024-12-30 21:15:56', NULL);
INSERT INTO `students` VALUES ('534', '1135', '13', NULL, 'online', '2023-240120534', NULL, '2024-12-30', '12', '0', '1133', '17', '2024-12-30 21:18:17', '2024-12-30 21:18:17', NULL);
INSERT INTO `students` VALUES ('535', '1137', '27', NULL, 'online', '2023-240120535', NULL, '2025-01-06', '12', '0', '1136', '17', '2025-01-06 23:10:51', '2025-01-06 23:10:51', NULL);
INSERT INTO `students` VALUES ('536', '1139', '24', NULL, 'online', '2023-240120536', NULL, '2025-01-08', '12', '0', '1138', '17', '2025-01-08 03:58:46', '2025-01-08 03:58:46', NULL);

CREATE TABLE IF NOT EXISTS `subject_teachers` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `class_section_id` bigint(20) unsigned NOT NULL,
  `subject_id` bigint(20) unsigned NOT NULL,
  `teacher_id` bigint(20) unsigned NOT NULL COMMENT 'user_id',
  `class_subject_id` bigint(20) unsigned NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `unique_ids` (`class_section_id`,`class_subject_id`,`teacher_id`),
  KEY `subject_teachers_school_id_foreign` (`school_id`),
  KEY `subject_teachers_subject_id_foreign` (`subject_id`),
  KEY `subject_teachers_teacher_id_foreign` (`teacher_id`),
  KEY `subject_teachers_class_subject_id_foreign` (`class_subject_id`),
  CONSTRAINT `subject_teachers_class_section_id_foreign` FOREIGN KEY (`class_section_id`) REFERENCES `class_sections` (`id`) ON DELETE CASCADE,
  CONSTRAINT `subject_teachers_class_subject_id_foreign` FOREIGN KEY (`class_subject_id`) REFERENCES `class_subjects` (`id`) ON DELETE CASCADE,
  CONSTRAINT `subject_teachers_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `subject_teachers_subject_id_foreign` FOREIGN KEY (`subject_id`) REFERENCES `subjects` (`id`) ON DELETE CASCADE,
  CONSTRAINT `subject_teachers_teacher_id_foreign` FOREIGN KEY (`teacher_id`) REFERENCES `users` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=251 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `subject_teachers` VALUES ('74', '21', '19', '42', '46', '12', '2023-11-20 07:36:28', '2024-07-10 11:23:14', NULL);
INSERT INTO `subject_teachers` VALUES ('75', '21', '20', '43', '48', '12', '2023-11-20 07:36:28', '2024-07-10 11:23:14', NULL);
INSERT INTO `subject_teachers` VALUES ('76', '21', '23', '44', '51', '12', '2023-11-20 07:36:28', '2024-07-10 11:23:14', NULL);
INSERT INTO `subject_teachers` VALUES ('77', '21', '25', '45', '47', '12', '2023-11-20 07:36:28', '2024-07-10 11:23:14', NULL);
INSERT INTO `subject_teachers` VALUES ('78', '21', '26', '46', '49', '12', '2023-11-20 07:36:28', '2024-07-10 11:23:14', NULL);
INSERT INTO `subject_teachers` VALUES ('79', '21', '27', '46', '50', '12', '2023-11-20 07:36:28', '2024-07-10 11:23:14', NULL);
INSERT INTO `subject_teachers` VALUES ('80', '21', '28', '47', '52', '12', '2023-11-20 07:36:28', '2024-07-10 11:23:14', NULL);
INSERT INTO `subject_teachers` VALUES ('81', '21', '29', '45', '53', '12', '2023-11-20 07:36:28', '2024-07-10 11:23:14', NULL);
INSERT INTO `subject_teachers` VALUES ('95', '25', '19', '49', '82', '12', '2023-11-24 06:10:25', '2023-11-24 06:55:11', NULL);
INSERT INTO `subject_teachers` VALUES ('96', '26', '19', '49', '91', '12', '2023-11-24 06:10:30', '2024-07-17 15:07:23', NULL);
INSERT INTO `subject_teachers` VALUES ('97', '27', '19', '49', '103', '12', '2023-11-24 06:10:36', '2023-11-24 06:56:57', NULL);
INSERT INTO `subject_teachers` VALUES ('98', '28', '19', '49', '115', '12', '2023-11-24 06:10:41', '2023-11-24 06:57:04', NULL);
INSERT INTO `subject_teachers` VALUES ('99', '29', '19', '49', '127', '12', '2023-11-24 06:10:46', '2023-11-24 06:10:46', NULL);
INSERT INTO `subject_teachers` VALUES ('100', '31', '19', '49', '143', '12', '2023-11-24 06:10:53', '2023-11-24 06:12:14', NULL);
INSERT INTO `subject_teachers` VALUES ('102', '22', '20', '43', '57', '12', '2023-11-24 06:34:21', '2023-11-24 06:54:38', NULL);
INSERT INTO `subject_teachers` VALUES ('104', '24', '19', '42', '73', '12', '2023-11-24 06:37:40', '2023-11-24 06:55:08', NULL);
INSERT INTO `subject_teachers` VALUES ('105', '22', '19', '42', '55', '12', '2023-11-24 06:38:05', '2023-11-24 06:54:38', NULL);
INSERT INTO `subject_teachers` VALUES ('117', '23', '19', '42', '64', '12', '2023-11-24 06:42:10', '2023-11-24 06:54:03', NULL);
INSERT INTO `subject_teachers` VALUES ('118', '22', '23', '44', '60', '12', '2023-11-24 06:45:31', '2023-11-24 06:54:38', NULL);
INSERT INTO `subject_teachers` VALUES ('119', '22', '25', '45', '56', '12', '2023-11-24 06:45:31', '2023-11-24 06:54:38', NULL);
INSERT INTO `subject_teachers` VALUES ('120', '22', '26', '46', '58', '12', '2023-11-24 06:45:31', '2023-11-24 06:54:38', NULL);
INSERT INTO `subject_teachers` VALUES ('121', '22', '27', '46', '59', '12', '2023-11-24 06:45:31', '2023-11-24 06:54:38', NULL);
INSERT INTO `subject_teachers` VALUES ('122', '22', '28', '48', '61', '12', '2023-11-24 06:45:31', '2023-11-24 06:54:38', NULL);
INSERT INTO `subject_teachers` VALUES ('123', '22', '29', '49', '62', '12', '2023-11-24 06:45:31', '2023-11-24 06:54:38', NULL);
INSERT INTO `subject_teachers` VALUES ('148', '23', '20', '43', '66', '12', '2023-11-24 06:54:03', '2023-11-24 06:54:03', NULL);
INSERT INTO `subject_teachers` VALUES ('149', '23', '23', '44', '69', '12', '2023-11-24 06:54:03', '2023-11-24 06:54:03', NULL);
INSERT INTO `subject_teachers` VALUES ('150', '23', '25', '45', '65', '12', '2023-11-24 06:54:03', '2023-11-24 06:54:03', NULL);
INSERT INTO `subject_teachers` VALUES ('151', '23', '26', '46', '67', '12', '2023-11-24 06:54:03', '2023-11-24 06:54:03', NULL);
INSERT INTO `subject_teachers` VALUES ('152', '23', '27', '46', '68', '12', '2023-11-24 06:54:03', '2023-11-24 06:54:03', NULL);
INSERT INTO `subject_teachers` VALUES ('153', '23', '28', '47', '70', '12', '2023-11-24 06:54:03', '2023-11-24 06:54:03', NULL);
INSERT INTO `subject_teachers` VALUES ('154', '23', '29', '45', '71', '12', '2023-11-24 06:54:03', '2023-11-24 06:54:03', NULL);
INSERT INTO `subject_teachers` VALUES ('155', '23', '30', '48', '72', '12', '2023-11-24 06:54:03', '2023-11-24 06:54:03', NULL);
INSERT INTO `subject_teachers` VALUES ('157', '21', '30', '48', '54', '12', '2023-11-24 06:54:20', '2024-07-10 11:23:14', NULL);
INSERT INTO `subject_teachers` VALUES ('166', '22', '30', '48', '63', '12', '2023-11-24 06:54:38', '2023-11-24 06:54:38', NULL);
INSERT INTO `subject_teachers` VALUES ('175', '24', '30', '48', '81', '12', '2023-11-24 06:55:08', '2023-11-24 06:55:08', NULL);
INSERT INTO `subject_teachers` VALUES ('177', '25', '30', '48', '90', '12', '2023-11-24 06:55:11', '2023-11-24 06:55:11', NULL);
INSERT INTO `subject_teachers` VALUES ('179', '26', '30', '48', '100', '12', '2023-11-24 06:55:18', '2024-07-17 15:07:23', NULL);
INSERT INTO `subject_teachers` VALUES ('181', '27', '30', '48', '114', '12', '2023-11-24 06:56:57', '2023-11-24 06:56:57', NULL);
INSERT INTO `subject_teachers` VALUES ('183', '28', '30', '48', '126', '12', '2023-11-24 06:57:04', '2023-11-24 06:57:04', NULL);
INSERT INTO `subject_teachers` VALUES ('184', '55', '19', '42', '46', '12', '2024-01-25 06:26:13', '2024-07-16 10:00:22', NULL);
INSERT INTO `subject_teachers` VALUES ('185', '55', '20', '43', '48', '12', '2024-01-25 06:26:13', '2024-07-16 10:00:22', NULL);
INSERT INTO `subject_teachers` VALUES ('186', '55', '23', '44', '51', '12', '2024-01-25 06:26:13', '2024-07-16 10:00:22', NULL);
INSERT INTO `subject_teachers` VALUES ('187', '55', '25', '43', '47', '12', '2024-01-25 06:26:13', '2024-07-16 10:00:22', NULL);
INSERT INTO `subject_teachers` VALUES ('188', '55', '26', '49', '49', '12', '2024-01-25 06:26:13', '2024-07-16 10:00:22', NULL);
INSERT INTO `subject_teachers` VALUES ('189', '55', '27', '47', '50', '12', '2024-01-25 06:26:13', '2024-07-16 10:00:22', NULL);
INSERT INTO `subject_teachers` VALUES ('190', '55', '28', '43', '52', '12', '2024-01-25 06:26:13', '2024-07-16 10:00:22', NULL);
INSERT INTO `subject_teachers` VALUES ('191', '55', '29', '46', '53', '12', '2024-01-25 06:26:13', '2024-07-16 10:00:22', NULL);
INSERT INTO `subject_teachers` VALUES ('192', '55', '30', '45', '54', '12', '2024-01-25 06:26:13', '2024-07-16 10:00:22', NULL);
INSERT INTO `subject_teachers` VALUES ('193', '60', '19', '43', '64', '12', '2024-03-11 18:17:52', '2024-03-11 18:18:03', NULL);
INSERT INTO `subject_teachers` VALUES ('194', '60', '20', '42', '66', '12', '2024-03-11 18:17:52', '2024-03-11 18:18:03', NULL);
INSERT INTO `subject_teachers` VALUES ('195', '60', '23', '45', '69', '12', '2024-03-11 18:17:52', '2024-03-11 18:18:03', NULL);
INSERT INTO `subject_teachers` VALUES ('196', '60', '25', '44', '65', '12', '2024-03-11 18:17:52', '2024-03-11 18:18:03', NULL);
INSERT INTO `subject_teachers` VALUES ('201', '59', '19', '43', '64', '12', '2024-03-11 18:18:15', '2024-03-11 18:18:15', NULL);
INSERT INTO `subject_teachers` VALUES ('202', '58', '19', '43', '55', '12', '2024-03-11 18:18:41', '2024-03-11 18:18:41', NULL);
INSERT INTO `subject_teachers` VALUES ('203', '58', '20', '48', '57', '12', '2024-03-11 18:18:41', '2024-03-11 18:18:41', NULL);
INSERT INTO `subject_teachers` VALUES ('204', '58', '23', '47', '60', '12', '2024-03-11 18:18:41', '2024-03-11 18:18:41', NULL);
INSERT INTO `subject_teachers` VALUES ('205', '58', '25', '42', '56', '12', '2024-03-11 18:18:41', '2024-03-11 18:18:41', NULL);
INSERT INTO `subject_teachers` VALUES ('206', '57', '19', '45', '55', '12', '2024-03-11 18:19:14', '2024-03-11 18:19:14', NULL);
INSERT INTO `subject_teachers` VALUES ('207', '57', '20', '43', '57', '12', '2024-03-11 18:19:14', '2024-03-11 18:19:14', NULL);
INSERT INTO `subject_teachers` VALUES ('208', '57', '23', '48', '60', '12', '2024-03-11 18:19:14', '2024-03-11 18:19:14', NULL);
INSERT INTO `subject_teachers` VALUES ('209', '57', '25', '49', '56', '12', '2024-03-11 18:19:14', '2024-03-11 18:19:14', NULL);
INSERT INTO `subject_teachers` VALUES ('210', '56', '19', '47', '46', '12', '2024-03-11 18:19:34', '2024-03-11 18:19:34', NULL);
INSERT INTO `subject_teachers` VALUES ('211', '56', '20', '46', '48', '12', '2024-03-11 18:19:34', '2024-03-11 18:19:34', NULL);
INSERT INTO `subject_teachers` VALUES ('212', '56', '23', '44', '51', '12', '2024-03-11 18:19:34', '2024-03-11 18:19:34', NULL);
INSERT INTO `subject_teachers` VALUES ('213', '56', '25', '49', '47', '12', '2024-03-11 18:19:34', '2024-03-11 18:19:34', NULL);
INSERT INTO `subject_teachers` VALUES ('214', '56', '26', '45', '49', '12', '2024-03-11 18:19:34', '2024-03-11 18:19:34', NULL);
INSERT INTO `subject_teachers` VALUES ('220', '21', '19', '49', '46', '12', '2024-07-10 11:23:14', '2024-07-10 11:23:14', NULL);
INSERT INTO `subject_teachers` VALUES ('221', '21', '20', '49', '48', '12', '2024-07-10 11:23:14', '2024-07-10 11:23:14', NULL);
INSERT INTO `subject_teachers` VALUES ('231', '55', '19', '49', '46', '12', '2024-07-16 10:00:22', '2024-07-16 10:00:22', NULL);
INSERT INTO `subject_teachers` VALUES ('232', '55', '20', '49', '48', '12', '2024-07-16 10:00:22', '2024-07-16 10:00:22', NULL);
INSERT INTO `subject_teachers` VALUES ('233', '55', '23', '49', '51', '12', '2024-07-16 10:00:22', '2024-07-16 10:00:22', NULL);
INSERT INTO `subject_teachers` VALUES ('234', '55', '25', '49', '47', '12', '2024-07-16 10:00:22', '2024-07-16 10:00:22', NULL);
INSERT INTO `subject_teachers` VALUES ('235', '55', '27', '49', '50', '12', '2024-07-16 10:00:22', '2024-07-16 10:00:22', NULL);
INSERT INTO `subject_teachers` VALUES ('236', '55', '28', '49', '52', '12', '2024-07-16 10:00:22', '2024-07-16 10:00:22', NULL);
INSERT INTO `subject_teachers` VALUES ('237', '55', '29', '49', '53', '12', '2024-07-16 10:00:22', '2024-07-16 10:00:22', NULL);
INSERT INTO `subject_teachers` VALUES ('238', '55', '30', '49', '54', '12', '2024-07-16 10:00:22', '2024-07-16 10:00:22', NULL);
INSERT INTO `subject_teachers` VALUES ('248', '26', '20', '49', '92', '12', '2024-07-17 15:07:23', '2024-07-17 15:07:23', NULL);
INSERT INTO `subject_teachers` VALUES ('249', '26', '32', '47', '94', '12', '2024-07-17 15:07:23', '2024-07-17 15:07:23', NULL);
INSERT INTO `subject_teachers` VALUES ('250', '26', '33', '47', '95', '12', '2024-07-17 15:07:23', '2024-07-17 15:07:23', NULL);

CREATE TABLE IF NOT EXISTS `subjects` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(512) NOT NULL,
  `code` varchar(64) DEFAULT NULL,
  `bg_color` varchar(32) NOT NULL,
  `image` varchar(512) NOT NULL,
  `medium_id` bigint(20) unsigned NOT NULL,
  `type` varchar(64) NOT NULL COMMENT 'Theory / Practical',
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `subjects_school_id_foreign` (`school_id`),
  KEY `subjects_medium_id_foreign` (`medium_id`),
  CONSTRAINT `subjects_medium_id_foreign` FOREIGN KEY (`medium_id`) REFERENCES `mediums` (`id`) ON DELETE CASCADE,
  CONSTRAINT `subjects_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=90 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `subjects` VALUES ('19', 'English', 'EN-23', '#f6e09e', '12/subject/655ae6027a3ef4.758814641700455938.png', '10', 'Theory', '12', '2023-11-16 10:34:57', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('20', 'Mathematics', 'MA-23', '#95e8ba', '12/subject/655713fc896629.532085471700205564.jpg', '10', 'Theory', '12', '2023-11-16 10:35:41', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('21', 'Science', 'SC-23', '#52adff', '12/subject/655ae63c7f69b0.170824781700455996.png', '10', 'Theory', '12', '2023-11-16 10:36:15', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('22', 'Social Studies', 'SO-23', '#ff7070', '12/subject/655ae65756fce4.369533961700456023.png', '10', 'Theory', '12', '2023-11-16 10:37:12', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('23', 'Physical Education', 'PH-23', '#d8adf8', '12/subject/655713e28e0767.659690711700205538.jpg', '10', 'Practical', '12', '2023-11-16 10:37:47', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('24', 'Art', 'AR-23', '#6be156', '12/subject/655ae6c50900e0.975556431700456133.png', '10', 'Theory', '12', '2023-11-16 10:38:08', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('25', 'Hindi', 'HI-23', '#9ed9dc', '12/subject/655ae7bfe5a858.680138211700456383.png', '10', 'Theory', '12', '2023-11-18 04:22:43', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('26', 'Environmental Studies (EVS)', 'ES', '#e684aa', '12/subject/655ae781c2f5a0.501167521700456321.png', '10', 'Theory', '12', '2023-11-18 04:23:29', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('27', 'Art and Craft', 'AC', '#a7a1f2', '12/subject/655ae6ae24b819.750319321700456110.png', '10', 'Theory', '12', '2023-11-18 04:23:51', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('28', 'Music', 'MU', '#a3f0dc', '12/subject/655c3789a9ba56.037414401700542345.png', '10', 'Practical', '12', '2023-11-18 04:24:41', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('29', 'Dance', 'DA', '#e5dbac', '12/subject/655ae730c6e737.217418941700456240.png', '10', 'Practical', '12', '2023-11-18 04:24:59', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('30', 'General Knowledge', 'GK', '#d0abd9', '12/subject/655ae7a28ad3e3.355688021700456354.png', '10', 'Theory', '12', '2023-11-18 04:25:30', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('31', 'Sanskrit', 'SN', '#c253ff', '12/subject/655ae813e273b8.870946851700456467.png', '10', 'Theory', '12', '2023-11-18 04:34:26', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('32', 'Social Science', 'SS', '#6b53ff', '12/subject/655ae83562eb44.071404541700456501.png', '10', 'Theory', '12', '2023-11-18 04:35:36', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('33', 'Computer Science', 'CS', '#5387ff', '12/subject/655ae723f37275.836156041700456227.png', '10', 'Theory', '12', '2023-11-18 04:35:56', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('34', 'Information and Communication Technology (ICT)', 'ICT', '#53e1ff', '12/subject/655ae7d64ecae5.716225631700456406.png', '10', 'Theory', '12', '2023-11-18 04:45:27', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('35', 'Foundation of Information Technology (FIT)', 'FIT', '#53ffe9', '12/subject/655ae86e7424d1.926107681700456558.png', '10', 'Theory', '12', '2023-11-18 04:45:47', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('36', 'Economics', 'EC', '#53ffba', '12/subject/655ae7570f6d98.600220441700456279.png', '10', 'Theory', '12', '2023-11-18 04:46:12', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('37', 'Business Studies', 'BS', '#53ff79', '12/subject/655ae702d35e20.692626111700456194.png', '10', 'Theory', '12', '2023-11-18 04:46:29', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('38', 'Accountancy', 'ACC', '#61ff53', '12/subject/655ae67da72360.816938731700456061.png', '10', 'Theory', '12', '2023-11-18 04:47:22', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('39', 'Fine Arts', 'FA', '#91ff53', '12/subject/655ae6d17ab611.241229351700456145.png', '10', 'Practical', '12', '2023-11-18 04:47:58', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('40', 'Drama', 'DR', '#c6ff53', '12/subject/655ae7413a7089.988331461700456257.png', '10', 'Theory', '12', '2023-11-18 04:48:14', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('41', 'Physics', 'PH', '#ff8654', '12/subject/655ae7dfee83a2.406470051700456415.png', '10', 'Theory', '12', '2023-11-18 04:55:42', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('42', 'Chemistry', 'CH', '#ffce54', '12/subject/655ae7180f62a5.146679911700456216.png', '10', 'Theory', '12', '2023-11-18 04:55:59', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('43', 'Biology', 'BI', '#fff754', '12/subject/655ae6ee786482.247499971700456174.png', '10', 'Theory', '12', '2023-11-18 04:56:15', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('44', 'Informatics Practices', 'IP', '#d2ff54', '12/subject/655ae8bc9c9a62.913129711700456636.png', '10', 'Practical', '12', '2023-11-18 04:56:51', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('45', 'History', 'HI', '#80ff54', '12/subject/655ae7cad84bf8.730326901700456394.png', '10', 'Theory', '12', '2023-11-18 04:58:24', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('46', 'Geography', 'GE', '#54ff80', '12/subject/655ae7b2d32713.416502961700456370.png', '10', 'Theory', '12', '2023-11-18 04:58:39', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('47', 'Political Science', 'PS', '#54ffaf', '12/subject/655ae8002287a7.950598311700456448.png', '10', 'Theory', '12', '2023-11-18 05:00:26', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('48', 'Psychology', 'PSY', '#718cf0', '12/subject/655ae8c6d93550.310643801700456646.png', '10', 'Theory', '12', '2023-11-18 10:16:11', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('49', 'Sociology', 'SO', '#6b84e0', '12/subject/655ae8d0e08879.977801361700456656.png', '10', 'Theory', '12', '2023-11-18 10:16:30', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('50', 'Fine Arts', 'FA', '#6bcfe0', '12/subject/655ae6e05eaa86.074959871700456160.png', '10', 'Theory', '12', '2023-11-18 10:16:52', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('51', 'Advanced Accountancy', 'AA', '#ea9191', '12/subject/655ae67786f134.771573781700456055.png', '10', 'Theory', '12', '2023-11-18 10:34:57', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('52', 'Advanced Business Studies', 'ABS', '#dd7a7a', '12/subject/655ae6fb651675.891891961700456187.png', '10', 'Theory', '12', '2023-11-18 10:35:12', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('53', 'Advanced Nursing Practice', 'ANP', '#e68383', '12/subject/655ae8e54427d7.179020331700456677.png', '10', 'Practical', '12', '2023-11-18 10:35:31', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('54', 'Advanced Programming', 'AP', '#d26969', '12/subject/655ae8f1eea975.695702951700456689.png', '10', 'Theory', '12', '2023-11-18 10:35:48', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('55', 'Anatomy', 'ANT', '#da7070', '12/subject/655ae8fb598815.022053301700456699.png', '10', 'Theory', '12', '2023-11-18 10:36:06', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('56', 'Artificial Intelligence', 'AI', '#e95959', '12/subject/655893ae511b88.482362431700303790.jpg', '10', 'Theory', '12', '2023-11-18 10:36:30', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('57', 'Biochemistry', 'BIO', '#d93b3b', '12/subject/655893bfebf0a2.844254541700303807.jpg', '10', 'Theory', '12', '2023-11-18 10:36:48', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('58', 'Biostatistics', 'BOS', '#d93bd9', '12/subject/655893da74f465.962795571700303834.jpg', '10', 'Theory', '12', '2023-11-18 10:37:14', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('59', 'Constitutional Law', 'CL', '#7d2edd', '12/subject/655893eeb5edf3.636197171700303854.jpg', '10', 'Theory', '12', '2023-11-18 10:37:34', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('60', 'Contract Law', 'CLAW', '#2e3fdd', '12/subject/65589404430bc1.477578681700303876.jpg', '10', 'Theory', '12', '2023-11-18 10:37:56', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('61', 'Corporate Finance', 'CFIN', '#2eb1dd', '12/subject/65589414c115a3.375308321700303892.jpg', '10', 'Theory', '12', '2023-11-18 10:38:12', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('62', 'Corporate Law', 'CoLaw', '#2edda3', '12/subject/655894286f9d06.310184851700303912.jpg', '10', 'Theory', '12', '2023-11-18 10:38:32', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('63', 'Criminal Law', 'CrLaw', '#2edd73', '12/subject/6558943c083e04.354247511700303932.jpg', '10', 'Theory', '12', '2023-11-18 10:38:52', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('64', 'Database Management', 'DM', '#43dd2e', '12/subject/6558944d1366c3.729534051700303949.jpg', '10', 'Theory', '12', '2023-11-18 10:39:09', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('65', 'Economics of Global Trade and Finance', 'EGTF', '#a9dd2e', '12/subject/655ae76330e149.315562811700456291.png', '10', 'Theory', '12', '2023-11-18 10:39:34', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('66', 'English Literature', 'ELT', '#ddbd2e', '12/subject/655ae77324a3d0.865927991700456307.png', '10', 'Theory', '12', '2023-11-18 10:39:56', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('67', 'Environmental Health', 'EH', '#dd932e', '12/subject/6558948ec81503.682494551700304014.jpg', '10', 'Theory', '12', '2023-11-18 10:40:14', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('68', 'Environmental Science', 'EnvS', '#dd5d2e', '12/subject/655ae856462db7.536305031700456534.png', '10', 'Theory', '12', '2023-11-18 10:40:47', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('69', 'Epidemiology', 'EP', '#dd392e', '12/subject/655894cbb80d86.306797121700304075.jpg', '10', 'Theory', '12', '2023-11-18 10:41:15', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('70', 'Family Law', 'FLaw', '#df2257', '12/subject/655894e5c465f2.222202401700304101.jpg', '10', 'Theory', '12', '2023-11-18 10:41:41', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('71', 'Finance', 'FIN', '#df2277', '12/subject/6558950c397958.409773401700304140.jpg', '10', 'Theory', '12', '2023-11-18 10:42:20', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('72', 'Financial Management', 'FM', '#df229e', '12/subject/655895221a2721.281003501700304162.jpg', '10', 'Theory', '12', '2023-11-18 10:42:42', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('73', 'Health Policy and Advocacy', 'HPA', '#df22c5', '12/subject/6558953aaadc09.864133571700304186.jpg', '10', 'Theory', '12', '2023-11-18 10:43:06', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('74', 'Health Policy and Management', 'HPM', '#bf22df', '12/subject/6558954d39dde2.080197681700304205.jpg', '10', 'Theory', '12', '2023-11-18 10:43:25', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('75', 'Human Resource Management', 'HRM', '#7e22df', '12/subject/65589564158eb7.736804941700304228.jpg', '11', 'Theory', '12', '2023-11-18 10:43:48', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('76', 'Human Resource Management in Social Work', 'HRMSW', '#5022df', '12/subject/65589587630c99.449327551700304263.jpg', '10', 'Theory', '12', '2023-11-18 10:44:23', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('77', 'International Law', 'ILaw', '#222edf', '12/subject/6558959a262376.512871591700304282.jpg', '10', 'Theory', '12', '2023-11-18 10:44:42', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('78', 'Management', 'Man', '#225bdf', '12/subject/655895aed7db23.844178641700304302.jpg', '10', 'Theory', '12', '2023-11-18 10:45:02', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('79', 'Marketing', 'Mar', '#22afdf', '12/subject/655895c0ce9db0.133653241700304320.jpg', '10', 'Theory', '12', '2023-11-18 10:45:20', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('80', 'Marketing Management', 'MarM', '#22dfdb', '12/subject/655895d2833cb3.670177481700304338.jpg', '10', 'Theory', '12', '2023-11-18 10:45:38', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('81', 'Medical and Psychiatric Social Work', 'MPSW', '#22dfba', '12/subject/655895e6e5aea5.000063861700304358.jpg', '10', 'Theory', '12', '2023-11-18 10:45:59', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('82', 'Network Security', 'NS', '#22df86', '12/subject/655897045fc6c3.110256301700304644.jpg', '10', 'Theory', '12', '2023-11-18 10:50:44', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('83', 'Nursing Research', 'NR', '#22df39', '12/subject/6558971b6cb6e6.279255231700304667.jpg', '10', 'Theory', '12', '2023-11-18 10:51:07', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('84', 'Operations Management', 'OM', '#52df22', '12/subject/6558972a243ad9.020773881700304682.jpg', '10', 'Theory', '12', '2023-11-18 10:51:22', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('85', 'Pathology', 'PA', '#a0df22', '12/subject/6558973bc0f818.249292671700304699.jpg', '10', 'Theory', '12', '2023-11-18 10:51:39', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('86', 'Pharmacology', 'PHA', '#dfd622', '12/subject/65589862835839.281978691700304994.jpg', '10', 'Theory', '12', '2023-11-18 10:56:34', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('87', 'Physiology', 'PHY', '#d6b990', '12/subject/65589874b59280.211299871700305012.jpg', '10', 'Theory', '12', '2023-11-18 10:56:52', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('88', 'Social Welfare Administration', 'SWA', '#ebab94', '12/subject/65589a79691738.080680311700305529.jpg', '10', 'Theory', '12', '2023-11-18 11:05:29', '2024-09-30 13:04:18', NULL);
INSERT INTO `subjects` VALUES ('89', 'Strategic Management', 'SM', '#bcd6ac', '12/subject/65589c3350d4e2.830144531700305971.jpg', '10', 'Theory', '12', '2023-11-18 11:12:51', '2024-09-30 13:04:18', NULL);

CREATE TABLE IF NOT EXISTS `subscription_bills` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `subscription_id` bigint(20) unsigned NOT NULL,
  `description` varchar(191) DEFAULT NULL,
  `amount` double(64,4) NOT NULL,
  `total_student` bigint(20) NOT NULL,
  `total_staff` bigint(20) NOT NULL,
  `payment_transaction_id` bigint(20) unsigned DEFAULT NULL,
  `due_date` date NOT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `subscription_bill` (`subscription_id`,`school_id`),
  KEY `subscription_bills_school_id_foreign` (`school_id`),
  KEY `subscription_bills_payment_transaction_id_foreign` (`payment_transaction_id`),
  CONSTRAINT `subscription_bills_payment_transaction_id_foreign` FOREIGN KEY (`payment_transaction_id`) REFERENCES `payment_transactions` (`id`) ON DELETE CASCADE,
  CONSTRAINT `subscription_bills_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `subscription_bills_subscription_id_foreign` FOREIGN KEY (`subscription_id`) REFERENCES `subscriptions` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `subscription_features` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `subscription_id` bigint(20) unsigned NOT NULL,
  `feature_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `unique` (`subscription_id`,`feature_id`),
  KEY `subscription_features_feature_id_foreign` (`feature_id`),
  CONSTRAINT `subscription_features_feature_id_foreign` FOREIGN KEY (`feature_id`) REFERENCES `features` (`id`) ON DELETE CASCADE,
  CONSTRAINT `subscription_features_subscription_id_foreign` FOREIGN KEY (`subscription_id`) REFERENCES `subscriptions` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `subscriptions` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `school_id` bigint(20) unsigned NOT NULL,
  `package_id` bigint(20) unsigned NOT NULL,
  `name` varchar(191) NOT NULL,
  `student_charge` double(8,4) NOT NULL,
  `staff_charge` double(8,4) NOT NULL,
  `start_date` date NOT NULL,
  `end_date` date NOT NULL,
  `package_type` int(11) NOT NULL DEFAULT 1 COMMENT '0 => Prepaid, 1 => Postpaid',
  `no_of_students` int(11) NOT NULL DEFAULT 0,
  `no_of_staffs` int(11) NOT NULL DEFAULT 0,
  `charges` double(64,4) NOT NULL DEFAULT 0.0000,
  `billing_cycle` int(11) NOT NULL DEFAULT 0,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `subscriptions_school_id_foreign` (`school_id`),
  KEY `subscriptions_package_id_foreign` (`package_id`),
  CONSTRAINT `subscriptions_package_id_foreign` FOREIGN KEY (`package_id`) REFERENCES `packages` (`id`) ON DELETE CASCADE,
  CONSTRAINT `subscriptions_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;


CREATE TABLE IF NOT EXISTS `timetables` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `subject_teacher_id` bigint(20) unsigned DEFAULT NULL,
  `class_section_id` bigint(20) unsigned NOT NULL,
  `subject_id` bigint(20) unsigned DEFAULT NULL,
  `start_time` time NOT NULL,
  `end_time` time NOT NULL,
  `note` varchar(1024) DEFAULT NULL,
  `day` enum('Monday','Tuesday','Wednesday','Thursday','Friday','Saturday','Sunday') NOT NULL,
  `type` enum('Lecture','Break') NOT NULL,
  `semester_id` bigint(20) unsigned DEFAULT NULL,
  `school_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `timetables_subject_teacher_id_foreign` (`subject_teacher_id`),
  KEY `timetables_school_id_foreign` (`school_id`),
  KEY `timetables_class_section_id_foreign` (`class_section_id`),
  KEY `timetables_subject_id_foreign` (`subject_id`),
  KEY `timetables_semester_id_foreign` (`semester_id`),
  CONSTRAINT `timetables_class_section_id_foreign` FOREIGN KEY (`class_section_id`) REFERENCES `class_sections` (`id`) ON DELETE CASCADE,
  CONSTRAINT `timetables_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE,
  CONSTRAINT `timetables_semester_id_foreign` FOREIGN KEY (`semester_id`) REFERENCES `semesters` (`id`) ON DELETE CASCADE,
  CONSTRAINT `timetables_subject_id_foreign` FOREIGN KEY (`subject_id`) REFERENCES `subjects` (`id`) ON DELETE CASCADE,
  CONSTRAINT `timetables_subject_teacher_id_foreign` FOREIGN KEY (`subject_teacher_id`) REFERENCES `subject_teachers` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=434 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `timetables` VALUES ('216', '74', '21', '19', '07:00:00', '07:30:00', NULL, 'Monday', 'Lecture', NULL, '12', '2023-11-20 06:58:54', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('217', '75', '21', '20', '07:30:00', '08:00:00', NULL, 'Monday', 'Lecture', NULL, '12', '2023-11-20 06:58:57', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('218', '76', '21', '23', '08:00:00', '08:30:00', NULL, 'Monday', 'Lecture', NULL, '12', '2023-11-20 06:58:59', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('219', '78', '21', '26', '08:30:00', '09:00:00', NULL, 'Monday', 'Lecture', NULL, '12', '2023-11-20 06:59:03', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('220', NULL, '21', NULL, '09:00:00', '09:30:00', 'Break', 'Monday', 'Break', NULL, '12', '2023-11-20 06:59:04', '2023-11-20 06:59:04');
INSERT INTO `timetables` VALUES ('222', '81', '21', '29', '10:00:00', '10:30:00', NULL, 'Monday', 'Lecture', NULL, '12', '2023-11-20 06:59:10', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('223', '79', '21', '27', '10:30:00', '11:00:00', NULL, 'Monday', 'Lecture', NULL, '12', '2023-11-20 06:59:12', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('224', '77', '21', '25', '11:00:00', '11:30:00', NULL, 'Monday', 'Lecture', NULL, '12', '2023-11-20 06:59:17', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('225', '74', '21', '19', '07:00:00', '07:30:00', NULL, 'Tuesday', 'Lecture', NULL, '12', '2023-11-20 07:01:13', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('226', '75', '21', '20', '07:30:00', '08:00:00', NULL, 'Tuesday', 'Lecture', NULL, '12', '2023-11-20 07:01:14', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('227', '78', '21', '26', '08:00:00', '08:30:00', NULL, 'Tuesday', 'Lecture', NULL, '12', '2023-11-20 07:01:16', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('228', '80', '21', '28', '08:30:00', '09:00:00', NULL, 'Tuesday', 'Lecture', NULL, '12', '2023-11-20 07:01:18', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('229', NULL, '21', NULL, '09:00:00', '09:30:00', 'Break', 'Tuesday', 'Break', NULL, '12', '2023-11-20 07:01:19', '2023-11-20 07:01:19');
INSERT INTO `timetables` VALUES ('231', '81', '21', '29', '10:00:00', '10:30:00', NULL, 'Tuesday', 'Lecture', NULL, '12', '2023-11-20 07:01:22', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('232', '79', '21', '27', '10:30:00', '11:00:00', NULL, 'Tuesday', 'Lecture', NULL, '12', '2023-11-20 07:01:23', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('233', '75', '21', '20', '11:00:00', '11:30:00', NULL, 'Tuesday', 'Lecture', NULL, '12', '2023-11-20 07:01:25', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('234', NULL, '21', NULL, '09:00:00', '09:30:00', 'Break', 'Wednesday', 'Break', NULL, '12', '2023-11-20 07:01:27', '2023-11-20 07:01:27');
INSERT INTO `timetables` VALUES ('235', '74', '21', '19', '07:00:00', '07:30:00', NULL, 'Wednesday', 'Lecture', NULL, '12', '2023-11-20 07:01:29', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('236', '76', '21', '23', '07:30:00', '08:00:00', NULL, 'Wednesday', 'Lecture', NULL, '12', '2023-11-20 07:01:31', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('237', '78', '21', '26', '08:00:00', '08:30:00', NULL, 'Wednesday', 'Lecture', NULL, '12', '2023-11-20 07:01:32', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('238', '75', '21', '20', '08:30:00', '09:00:00', NULL, 'Wednesday', 'Lecture', NULL, '12', '2023-11-20 07:01:34', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('239', '79', '21', '27', '09:30:00', '10:00:00', NULL, 'Wednesday', 'Lecture', NULL, '12', '2023-11-20 07:01:37', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('241', '78', '21', '26', '10:30:00', '11:00:00', NULL, 'Wednesday', 'Lecture', NULL, '12', '2023-11-20 07:01:41', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('242', '81', '21', '29', '11:00:00', '11:30:00', NULL, 'Wednesday', 'Lecture', NULL, '12', '2023-11-20 07:01:45', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('243', '74', '21', '19', '07:00:00', '07:30:00', NULL, 'Thursday', 'Lecture', NULL, '12', '2023-11-20 07:02:16', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('244', '75', '21', '20', '07:30:00', '08:00:00', NULL, 'Thursday', 'Lecture', NULL, '12', '2023-11-20 07:02:18', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('245', '76', '21', '23', '08:00:00', '08:30:00', NULL, 'Thursday', 'Lecture', NULL, '12', '2023-11-20 07:02:19', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('246', '77', '21', '25', '08:30:00', '09:00:00', NULL, 'Thursday', 'Lecture', NULL, '12', '2023-11-20 07:02:21', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('247', NULL, '21', NULL, '09:00:00', '09:30:00', 'Break', 'Thursday', 'Break', NULL, '12', '2023-11-20 07:02:23', '2023-11-20 07:02:23');
INSERT INTO `timetables` VALUES ('248', '78', '21', '26', '09:30:00', '10:00:00', NULL, 'Thursday', 'Lecture', NULL, '12', '2023-11-20 07:02:25', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('249', '79', '21', '27', '10:00:00', '10:30:00', NULL, 'Thursday', 'Lecture', NULL, '12', '2023-11-20 07:02:27', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('250', '80', '21', '28', '10:30:00', '11:00:00', NULL, 'Thursday', 'Lecture', NULL, '12', '2023-11-20 07:02:29', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('252', '74', '21', '19', '07:00:00', '07:30:00', NULL, 'Friday', 'Lecture', NULL, '12', '2023-11-20 07:02:32', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('253', '75', '21', '20', '07:30:00', '08:00:00', NULL, 'Friday', 'Lecture', NULL, '12', '2023-11-20 07:02:34', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('254', '76', '21', '23', '08:00:00', '08:30:00', NULL, 'Friday', 'Lecture', NULL, '12', '2023-11-20 07:02:37', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('255', NULL, '21', NULL, '08:30:00', '09:00:00', 'Break', 'Friday', 'Break', NULL, '12', '2023-11-20 07:02:39', '2023-11-20 07:02:39');
INSERT INTO `timetables` VALUES ('256', '77', '21', '25', '09:00:00', '09:30:00', NULL, 'Friday', 'Lecture', NULL, '12', '2023-11-20 07:02:41', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('257', '79', '21', '27', '09:30:00', '10:00:00', NULL, 'Friday', 'Lecture', NULL, '12', '2023-11-20 07:02:47', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('259', '74', '21', '19', '07:00:00', '07:30:00', NULL, 'Saturday', 'Lecture', NULL, '12', '2023-11-20 07:02:51', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('260', '75', '21', '20', '07:30:00', '08:00:00', NULL, 'Saturday', 'Lecture', NULL, '12', '2023-11-20 07:02:53', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('261', '76', '21', '23', '08:00:00', '08:30:00', NULL, 'Saturday', 'Lecture', NULL, '12', '2023-11-20 07:02:55', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('262', '77', '21', '25', '08:30:00', '09:00:00', NULL, 'Saturday', 'Lecture', NULL, '12', '2023-11-20 07:02:56', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('263', NULL, '21', NULL, '09:00:00', '09:30:00', 'Break', 'Saturday', 'Break', NULL, '12', '2023-11-20 07:03:00', '2023-11-20 07:03:00');
INSERT INTO `timetables` VALUES ('264', '78', '21', '26', '09:30:00', '10:00:00', NULL, 'Saturday', 'Lecture', NULL, '12', '2023-11-20 07:03:02', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('265', '79', '21', '27', '10:00:00', '10:30:00', NULL, 'Saturday', 'Lecture', NULL, '12', '2023-11-20 07:03:04', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('266', '81', '21', '29', '10:30:00', '11:00:00', NULL, 'Saturday', 'Lecture', NULL, '12', '2023-11-20 07:03:15', '2023-11-20 07:36:28');
INSERT INTO `timetables` VALUES ('286', '95', '25', '19', '09:30:00', '10:00:00', NULL, 'Monday', 'Lecture', NULL, '12', '2023-11-24 06:14:33', '2023-11-24 06:14:33');
INSERT INTO `timetables` VALUES ('287', '95', '25', '19', '09:30:00', '10:00:00', NULL, 'Tuesday', 'Lecture', NULL, '12', '2023-11-24 06:14:35', '2023-11-24 06:14:36');
INSERT INTO `timetables` VALUES ('288', '95', '25', '19', '09:30:00', '10:00:00', NULL, 'Wednesday', 'Lecture', NULL, '12', '2023-11-24 06:14:38', '2023-11-24 06:14:38');
INSERT INTO `timetables` VALUES ('289', '95', '25', '19', '09:30:00', '10:00:00', NULL, 'Thursday', 'Lecture', NULL, '12', '2023-11-24 06:14:40', '2023-11-24 06:14:40');
INSERT INTO `timetables` VALUES ('290', '95', '25', '19', '09:00:00', '09:30:00', NULL, 'Friday', 'Lecture', NULL, '12', '2023-11-24 06:14:42', '2023-11-24 06:14:42');
INSERT INTO `timetables` VALUES ('291', '95', '25', '19', '09:30:00', '10:00:00', NULL, 'Saturday', 'Lecture', NULL, '12', '2023-11-24 06:14:44', '2023-11-24 06:14:44');
INSERT INTO `timetables` VALUES ('292', '96', '26', '19', '10:00:00', '10:30:00', NULL, 'Monday', 'Lecture', NULL, '12', '2023-11-24 06:15:19', '2023-11-24 06:15:19');
INSERT INTO `timetables` VALUES ('293', '96', '26', '19', '10:00:00', '10:30:00', NULL, 'Tuesday', 'Lecture', NULL, '12', '2023-11-24 06:15:21', '2023-11-24 06:15:21');
INSERT INTO `timetables` VALUES ('294', '96', '26', '19', '10:00:00', '10:30:00', NULL, 'Wednesday', 'Lecture', NULL, '12', '2023-11-24 06:15:22', '2023-11-24 06:15:22');
INSERT INTO `timetables` VALUES ('295', '96', '26', '19', '10:00:00', '10:30:00', NULL, 'Thursday', 'Lecture', NULL, '12', '2023-11-24 06:15:25', '2023-11-24 06:15:25');
INSERT INTO `timetables` VALUES ('296', '96', '26', '19', '09:30:00', '10:00:00', NULL, 'Friday', 'Lecture', NULL, '12', '2023-11-24 06:15:28', '2023-11-24 06:15:28');
INSERT INTO `timetables` VALUES ('297', '96', '26', '19', '10:00:00', '10:30:00', NULL, 'Saturday', 'Lecture', NULL, '12', '2023-11-24 06:15:30', '2023-11-24 06:15:30');
INSERT INTO `timetables` VALUES ('298', '97', '27', '19', '10:30:00', '11:00:00', NULL, 'Monday', 'Lecture', NULL, '12', '2023-11-24 06:15:37', '2023-11-24 06:15:37');
INSERT INTO `timetables` VALUES ('299', '97', '27', '19', '10:30:00', '11:00:00', NULL, 'Tuesday', 'Lecture', NULL, '12', '2023-11-24 06:15:39', '2023-11-24 06:15:39');
INSERT INTO `timetables` VALUES ('300', '97', '27', '19', '10:30:00', '11:00:00', NULL, 'Wednesday', 'Lecture', NULL, '12', '2023-11-24 06:15:41', '2023-11-24 06:15:41');
INSERT INTO `timetables` VALUES ('301', '97', '27', '19', '10:30:00', '11:00:00', NULL, 'Thursday', 'Lecture', NULL, '12', '2023-11-24 06:15:44', '2023-11-24 06:15:44');
INSERT INTO `timetables` VALUES ('302', '97', '27', '19', '10:00:00', '10:30:00', NULL, 'Friday', 'Lecture', NULL, '12', '2023-11-24 06:15:46', '2023-11-24 06:15:46');
INSERT INTO `timetables` VALUES ('303', '97', '27', '19', '10:30:00', '11:00:00', NULL, 'Saturday', 'Lecture', NULL, '12', '2023-11-24 06:15:48', '2023-11-24 06:15:48');
INSERT INTO `timetables` VALUES ('304', '98', '28', '19', '08:30:00', '09:00:00', NULL, 'Monday', 'Lecture', NULL, '12', '2023-11-24 06:15:55', '2023-11-24 06:19:53');
INSERT INTO `timetables` VALUES ('305', '98', '28', '19', '08:30:00', '09:00:00', NULL, 'Wednesday', 'Lecture', NULL, '12', '2023-11-24 06:15:57', '2023-11-24 06:19:55');
INSERT INTO `timetables` VALUES ('306', '98', '28', '19', '08:00:00', '08:30:00', NULL, 'Friday', 'Lecture', NULL, '12', '2023-11-24 06:16:00', '2023-11-24 06:19:57');
INSERT INTO `timetables` VALUES ('307', '98', '28', '19', '08:30:00', '09:00:00', NULL, 'Saturday', 'Lecture', NULL, '12', '2023-11-24 06:16:02', '2023-11-24 06:19:59');
INSERT INTO `timetables` VALUES ('308', '99', '29', '19', '11:00:00', '11:30:00', NULL, 'Tuesday', 'Lecture', NULL, '12', '2023-11-24 06:16:10', '2023-11-24 06:16:10');
INSERT INTO `timetables` VALUES ('309', '99', '29', '19', '11:00:00', '11:30:00', NULL, 'Thursday', 'Lecture', NULL, '12', '2023-11-24 06:16:12', '2023-11-24 06:16:12');
INSERT INTO `timetables` VALUES ('310', '99', '29', '19', '11:00:00', '11:30:00', NULL, 'Saturday', 'Lecture', NULL, '12', '2023-11-24 06:16:15', '2023-11-24 06:16:15');
INSERT INTO `timetables` VALUES ('311', '100', '31', '19', '11:00:00', '11:30:00', NULL, 'Monday', 'Lecture', NULL, '12', '2023-11-24 06:16:22', '2023-11-24 06:16:24');
INSERT INTO `timetables` VALUES ('314', '102', '22', '20', '07:30:00', '08:00:00', NULL, 'Monday', 'Lecture', NULL, '12', '2023-11-24 06:22:27', '2023-11-24 06:34:21');
INSERT INTO `timetables` VALUES ('315', '102', '22', '20', '07:30:00', '08:00:00', NULL, 'Wednesday', 'Lecture', NULL, '12', '2023-11-24 06:22:28', '2023-11-24 06:34:21');
INSERT INTO `timetables` VALUES ('316', '102', '22', '20', '07:30:00', '08:00:00', NULL, 'Saturday', 'Lecture', NULL, '12', '2023-11-24 06:22:32', '2023-11-24 06:34:21');
INSERT INTO `timetables` VALUES ('317', '102', '22', '20', '07:30:00', '08:00:00', NULL, 'Friday', 'Lecture', NULL, '12', '2023-11-24 06:22:38', '2023-11-24 06:40:13');
INSERT INTO `timetables` VALUES ('318', '76', '22', '23', '08:30:00', '09:00:00', NULL, 'Monday', 'Lecture', NULL, '12', '2023-11-24 06:23:49', '2023-11-24 06:38:11');
INSERT INTO `timetables` VALUES ('319', NULL, '22', NULL, '09:00:00', '09:30:00', 'Break', 'Monday', 'Break', NULL, '12', '2023-11-24 06:23:52', '2023-11-24 06:23:52');
INSERT INTO `timetables` VALUES ('320', '78', '22', '26', '11:00:00', '11:30:00', NULL, 'Monday', 'Lecture', NULL, '12', '2023-11-24 06:23:55', '2023-11-24 06:38:11');
INSERT INTO `timetables` VALUES ('321', '80', '22', '28', '11:30:00', '12:30:00', NULL, 'Monday', 'Lecture', NULL, '12', '2023-11-24 06:23:57', '2023-11-24 06:38:11');
INSERT INTO `timetables` VALUES ('324', '77', '22', '25', '10:00:00', '11:00:00', NULL, 'Monday', 'Lecture', NULL, '12', '2023-11-24 06:24:28', '2023-11-24 06:38:11');
INSERT INTO `timetables` VALUES ('325', '79', '22', '27', '09:30:00', '10:00:00', NULL, 'Monday', 'Lecture', NULL, '12', '2023-11-24 06:24:39', '2023-11-24 06:38:11');
INSERT INTO `timetables` VALUES ('327', '102', '31', '20', '09:00:00', '09:30:00', NULL, 'Tuesday', 'Lecture', NULL, '12', '2023-11-24 06:27:11', '2023-11-24 06:34:21');
INSERT INTO `timetables` VALUES ('329', '102', '31', '20', '09:00:00', '09:30:00', NULL, 'Thursday', 'Lecture', NULL, '12', '2023-11-24 06:27:16', '2023-11-24 06:34:21');
INSERT INTO `timetables` VALUES ('331', '102', '31', '20', '09:00:00', '09:30:00', NULL, 'Saturday', 'Lecture', NULL, '12', '2023-11-24 06:27:20', '2023-11-24 06:34:21');
INSERT INTO `timetables` VALUES ('332', NULL, '31', '21', '09:00:00', '10:00:00', NULL, 'Monday', 'Lecture', NULL, '12', '2023-11-24 06:27:27', '2023-11-24 06:27:35');
INSERT INTO `timetables` VALUES ('333', NULL, '31', '34', '10:30:00', '11:00:00', NULL, 'Monday', 'Lecture', NULL, '12', '2023-11-24 06:27:45', '2023-11-24 06:27:48');
INSERT INTO `timetables` VALUES ('334', NULL, '31', NULL, '10:00:00', '10:30:00', 'Break', 'Monday', 'Break', NULL, '12', '2023-11-24 06:27:50', '2023-11-24 06:27:50');
INSERT INTO `timetables` VALUES ('335', '77', '31', '25', '07:00:00', '08:00:00', NULL, 'Monday', 'Lecture', NULL, '12', '2023-11-24 06:27:56', '2023-11-24 06:38:11');
INSERT INTO `timetables` VALUES ('336', NULL, '31', '36', '08:00:00', '09:00:00', NULL, 'Tuesday', 'Lecture', NULL, '12', '2023-11-24 06:28:04', '2023-11-24 06:28:06');
INSERT INTO `timetables` VALUES ('337', '77', '31', '25', '07:00:00', '08:00:00', NULL, 'Tuesday', 'Lecture', NULL, '12', '2023-11-24 06:28:30', '2023-11-24 06:38:11');
INSERT INTO `timetables` VALUES ('338', '102', '23', '20', '09:00:00', '09:30:00', NULL, 'Monday', 'Lecture', NULL, '12', '2023-11-24 06:30:01', '2023-11-24 06:34:21');
INSERT INTO `timetables` VALUES ('339', '102', '23', '20', '09:00:00', '09:30:00', NULL, 'Wednesday', 'Lecture', NULL, '12', '2023-11-24 06:30:03', '2023-11-24 06:34:21');
INSERT INTO `timetables` VALUES ('340', '102', '23', '20', '09:00:00', '09:30:00', NULL, 'Friday', 'Lecture', NULL, '12', '2023-11-24 06:30:05', '2023-11-24 06:34:21');
INSERT INTO `timetables` VALUES ('341', '102', '24', '20', '10:30:00', '11:00:00', NULL, 'Monday', 'Lecture', NULL, '12', '2023-11-24 06:30:36', '2023-11-24 06:34:21');
INSERT INTO `timetables` VALUES ('342', '102', '24', '20', '10:30:00', '11:00:00', NULL, 'Wednesday', 'Lecture', NULL, '12', '2023-11-24 06:30:41', '2023-11-24 06:34:21');
INSERT INTO `timetables` VALUES ('343', '102', '24', '20', '10:30:00', '11:00:00', NULL, 'Friday', 'Lecture', NULL, '12', '2023-11-24 06:30:43', '2023-11-24 06:34:21');
INSERT INTO `timetables` VALUES ('344', '102', '25', '20', '10:00:00', '10:30:00', NULL, 'Tuesday', 'Lecture', NULL, '12', '2023-11-24 06:30:51', '2023-11-24 06:34:21');
INSERT INTO `timetables` VALUES ('345', '102', '25', '20', '10:00:00', '10:30:00', NULL, 'Thursday', 'Lecture', NULL, '12', '2023-11-24 06:30:53', '2023-11-24 06:34:21');
INSERT INTO `timetables` VALUES ('346', '102', '25', '20', '10:00:00', '10:30:00', NULL, 'Saturday', 'Lecture', NULL, '12', '2023-11-24 06:30:55', '2023-11-24 06:34:21');
INSERT INTO `timetables` VALUES ('347', '102', '26', '20', '09:30:00', '10:00:00', NULL, 'Monday', 'Lecture', NULL, '12', '2023-11-24 06:31:00', '2023-11-24 06:34:21');
INSERT INTO `timetables` VALUES ('348', '102', '26', '20', '09:30:00', '10:00:00', NULL, 'Wednesday', 'Lecture', NULL, '12', '2023-11-24 06:31:02', '2023-11-24 06:34:21');
INSERT INTO `timetables` VALUES ('349', '102', '26', '20', '09:00:00', '09:30:00', NULL, 'Friday', 'Lecture', NULL, '12', '2023-11-24 06:31:04', '2023-11-24 06:34:21');
INSERT INTO `timetables` VALUES ('350', '102', '27', '20', '10:00:00', '10:30:00', NULL, 'Tuesday', 'Lecture', NULL, '12', '2023-11-24 06:31:07', '2023-11-24 06:34:21');
INSERT INTO `timetables` VALUES ('351', '102', '27', '20', '10:00:00', '10:30:00', NULL, 'Thursday', 'Lecture', NULL, '12', '2023-11-24 06:31:10', '2023-11-24 06:34:21');
INSERT INTO `timetables` VALUES ('352', '102', '27', '20', '10:00:00', '10:30:00', NULL, 'Saturday', 'Lecture', NULL, '12', '2023-11-24 06:31:16', '2023-11-24 06:34:21');
INSERT INTO `timetables` VALUES ('353', '102', '28', '20', '11:00:00', '11:30:00', NULL, 'Monday', 'Lecture', NULL, '12', '2023-11-24 06:31:25', '2023-11-24 06:34:21');
INSERT INTO `timetables` VALUES ('354', '102', '28', '20', '11:00:00', '11:30:00', NULL, 'Wednesday', 'Lecture', NULL, '12', '2023-11-24 06:31:27', '2023-11-24 06:34:21');
INSERT INTO `timetables` VALUES ('355', '102', '28', '20', '10:30:00', '11:00:00', NULL, 'Friday', 'Lecture', NULL, '12', '2023-11-24 06:31:30', '2023-11-24 06:34:21');
INSERT INTO `timetables` VALUES ('356', '102', '29', '20', '10:30:00', '11:00:00', NULL, 'Tuesday', 'Lecture', NULL, '12', '2023-11-24 06:31:37', '2023-11-24 06:34:21');
INSERT INTO `timetables` VALUES ('357', '102', '29', '20', '10:30:00', '11:00:00', NULL, 'Thursday', 'Lecture', NULL, '12', '2023-11-24 06:31:39', '2023-11-24 06:34:21');
INSERT INTO `timetables` VALUES ('358', '102', '29', '20', '10:30:00', '11:00:00', NULL, 'Saturday', 'Lecture', NULL, '12', '2023-11-24 06:31:42', '2023-11-24 06:34:21');
INSERT INTO `timetables` VALUES ('360', '105', '22', '19', '07:30:00', '08:00:00', NULL, 'Tuesday', 'Lecture', NULL, '12', '2023-11-24 06:40:04', '2023-11-24 06:41:09');
INSERT INTO `timetables` VALUES ('362', '105', '22', '19', '07:30:00', '08:00:00', NULL, 'Thursday', 'Lecture', NULL, '12', '2023-11-24 06:40:07', '2023-11-24 06:41:13');
INSERT INTO `timetables` VALUES ('364', '105', '22', '19', '08:00:00', '08:30:00', NULL, 'Friday', 'Lecture', NULL, '12', '2023-11-24 06:40:15', '2023-11-24 06:41:19');
INSERT INTO `timetables` VALUES ('365', '117', '23', '19', '08:00:00', '08:30:00', NULL, 'Monday', 'Lecture', NULL, '12', '2023-11-24 06:40:43', '2023-11-24 06:42:10');
INSERT INTO `timetables` VALUES ('366', '117', '23', '19', '08:00:00', '08:30:00', NULL, 'Wednesday', 'Lecture', NULL, '12', '2023-11-24 06:40:45', '2023-11-24 06:42:10');
INSERT INTO `timetables` VALUES ('367', '117', '23', '19', '08:00:00', '08:30:00', NULL, 'Friday', 'Lecture', NULL, '12', '2023-11-24 06:40:49', '2023-11-24 06:42:10');
INSERT INTO `timetables` VALUES ('368', '117', '23', '19', '08:30:00', '09:00:00', NULL, 'Saturday', 'Lecture', NULL, '12', '2023-11-24 06:40:52', '2023-11-24 06:42:10');
INSERT INTO `timetables` VALUES ('369', '149', '23', '23', '07:00:00', '07:30:00', NULL, 'Monday', 'Lecture', NULL, '12', '2023-11-24 06:58:43', '2023-11-24 06:58:43');
INSERT INTO `timetables` VALUES ('370', '149', '23', '23', '07:00:00', '07:30:00', NULL, 'Tuesday', 'Lecture', NULL, '12', '2023-11-24 06:58:46', '2023-11-24 06:58:46');
INSERT INTO `timetables` VALUES ('371', '149', '23', '23', '07:00:00', '07:30:00', NULL, 'Wednesday', 'Lecture', NULL, '12', '2023-11-24 06:58:50', '2023-11-24 06:58:50');
INSERT INTO `timetables` VALUES ('372', '149', '23', '23', '07:00:00', '07:30:00', NULL, 'Thursday', 'Lecture', NULL, '12', '2023-11-24 06:58:51', '2023-11-24 06:58:51');
INSERT INTO `timetables` VALUES ('373', '149', '23', '23', '07:00:00', '07:30:00', NULL, 'Friday', 'Lecture', NULL, '12', '2023-11-24 06:58:54', '2023-11-24 06:58:54');
INSERT INTO `timetables` VALUES ('374', '149', '23', '23', '07:00:00', '07:30:00', NULL, 'Saturday', 'Lecture', NULL, '12', '2023-11-24 06:58:56', '2023-11-24 06:58:56');
INSERT INTO `timetables` VALUES ('375', '77', '24', '25', '07:00:00', '07:30:00', NULL, 'Monday', 'Lecture', NULL, '12', '2023-11-24 06:59:31', '2023-11-25 05:13:56');
INSERT INTO `timetables` VALUES ('376', '77', '24', '25', '07:00:00', '07:30:00', NULL, 'Tuesday', 'Lecture', NULL, '12', '2023-11-24 06:59:33', '2023-11-25 05:13:56');
INSERT INTO `timetables` VALUES ('377', '77', '24', '25', '07:00:00', '07:30:00', NULL, 'Wednesday', 'Lecture', NULL, '12', '2023-11-24 06:59:35', '2023-11-25 05:13:56');
INSERT INTO `timetables` VALUES ('378', '77', '24', '25', '07:00:00', '07:30:00', NULL, 'Thursday', 'Lecture', NULL, '12', '2023-11-24 06:59:37', '2023-11-25 05:13:56');
INSERT INTO `timetables` VALUES ('379', '77', '24', '25', '07:00:00', '07:30:00', NULL, 'Friday', 'Lecture', NULL, '12', '2023-11-24 06:59:38', '2023-11-25 05:13:56');
INSERT INTO `timetables` VALUES ('380', '77', '24', '25', '07:00:00', '07:30:00', NULL, 'Saturday', 'Lecture', NULL, '12', '2023-11-24 06:59:40', '2023-11-25 05:13:56');
INSERT INTO `timetables` VALUES ('396', '184', '55', '19', '07:00:00', '07:30:00', NULL, 'Monday', 'Lecture', NULL, '12', '2024-01-25 06:23:16', '2024-01-25 06:26:13');
INSERT INTO `timetables` VALUES ('397', '184', '55', '19', '07:00:00', '07:30:00', NULL, 'Tuesday', 'Lecture', NULL, '12', '2024-01-25 06:23:17', '2024-01-25 06:26:13');
INSERT INTO `timetables` VALUES ('398', '184', '55', '19', '07:00:00', '07:30:00', NULL, 'Wednesday', 'Lecture', NULL, '12', '2024-01-25 06:23:18', '2024-01-25 06:26:13');
INSERT INTO `timetables` VALUES ('399', '184', '55', '19', '07:00:00', '07:30:00', NULL, 'Thursday', 'Lecture', NULL, '12', '2024-01-25 06:23:19', '2024-01-25 06:26:13');
INSERT INTO `timetables` VALUES ('400', '184', '55', '19', '07:00:00', '08:00:00', NULL, 'Friday', 'Lecture', NULL, '12', '2024-01-25 06:23:20', '2024-01-25 06:26:13');
INSERT INTO `timetables` VALUES ('401', '184', '55', '19', '07:00:00', '08:00:00', NULL, 'Saturday', 'Lecture', NULL, '12', '2024-01-25 06:23:21', '2024-01-25 06:26:13');
INSERT INTO `timetables` VALUES ('402', '185', '55', '20', '07:30:00', '08:30:00', NULL, 'Monday', 'Lecture', NULL, '12', '2024-01-25 06:23:22', '2024-01-25 06:26:13');
INSERT INTO `timetables` VALUES ('403', '185', '55', '20', '07:30:00', '08:30:00', NULL, 'Tuesday', 'Lecture', NULL, '12', '2024-01-25 06:23:27', '2024-01-25 06:26:13');
INSERT INTO `timetables` VALUES ('404', '185', '55', '20', '07:30:00', '08:00:00', NULL, 'Wednesday', 'Lecture', NULL, '12', '2024-01-25 06:23:36', '2024-01-25 06:26:13');
INSERT INTO `timetables` VALUES ('405', '185', '55', '20', '07:30:00', '08:00:00', NULL, 'Thursday', 'Lecture', NULL, '12', '2024-01-25 06:23:38', '2024-01-25 06:26:13');
INSERT INTO `timetables` VALUES ('406', '187', '55', '25', '08:00:00', '08:30:00', NULL, 'Wednesday', 'Lecture', NULL, '12', '2024-01-25 06:23:39', '2024-01-25 06:26:13');
INSERT INTO `timetables` VALUES ('407', '187', '55', '25', '08:00:00', '08:30:00', NULL, 'Thursday', 'Lecture', NULL, '12', '2024-01-25 06:23:40', '2024-01-25 06:26:13');
INSERT INTO `timetables` VALUES ('408', '187', '55', '25', '08:00:00', '08:30:00', NULL, 'Friday', 'Lecture', NULL, '12', '2024-01-25 06:23:42', '2024-01-25 06:26:13');
INSERT INTO `timetables` VALUES ('409', '187', '55', '25', '08:00:00', '08:30:00', NULL, 'Saturday', 'Lecture', NULL, '12', '2024-01-25 06:23:43', '2024-01-25 06:26:13');
INSERT INTO `timetables` VALUES ('410', '188', '55', '26', '08:30:00', '09:00:00', NULL, 'Monday', 'Lecture', NULL, '12', '2024-01-25 06:23:49', '2024-01-25 06:26:13');
INSERT INTO `timetables` VALUES ('411', '188', '55', '26', '08:30:00', '09:00:00', NULL, 'Tuesday', 'Lecture', NULL, '12', '2024-01-25 06:23:51', '2024-01-25 06:26:13');
INSERT INTO `timetables` VALUES ('412', '188', '55', '26', '08:30:00', '09:00:00', NULL, 'Wednesday', 'Lecture', NULL, '12', '2024-01-25 06:23:52', '2024-01-25 06:26:13');
INSERT INTO `timetables` VALUES ('413', '188', '55', '26', '08:30:00', '09:00:00', NULL, 'Thursday', 'Lecture', NULL, '12', '2024-01-25 06:23:54', '2024-01-25 06:26:13');
INSERT INTO `timetables` VALUES ('414', '188', '55', '26', '08:30:00', '09:00:00', NULL, 'Friday', 'Lecture', NULL, '12', '2024-01-25 06:23:56', '2024-01-25 06:26:13');
INSERT INTO `timetables` VALUES ('415', '188', '55', '26', '08:30:00', '09:00:00', NULL, 'Saturday', 'Lecture', NULL, '12', '2024-01-25 06:23:59', '2024-01-25 06:26:13');
INSERT INTO `timetables` VALUES ('416', NULL, '55', NULL, '09:30:00', '10:00:00', 'Break', 'Monday', 'Break', NULL, '12', '2024-01-25 06:24:00', '2024-01-25 06:24:05');
INSERT INTO `timetables` VALUES ('417', NULL, '55', NULL, '09:30:00', '10:00:00', 'Break', 'Tuesday', 'Break', NULL, '12', '2024-01-25 06:24:06', '2024-01-25 06:24:06');
INSERT INTO `timetables` VALUES ('418', NULL, '55', NULL, '09:30:00', '10:00:00', 'Break', 'Wednesday', 'Break', NULL, '12', '2024-01-25 06:24:07', '2024-01-25 06:24:07');
INSERT INTO `timetables` VALUES ('419', NULL, '55', NULL, '09:30:00', '10:00:00', 'Break', 'Thursday', 'Break', NULL, '12', '2024-01-25 06:24:09', '2024-01-25 06:24:09');
INSERT INTO `timetables` VALUES ('420', NULL, '55', NULL, '09:30:00', '10:00:00', 'Break', 'Friday', 'Break', NULL, '12', '2024-01-25 06:24:10', '2024-01-25 06:24:10');
INSERT INTO `timetables` VALUES ('421', NULL, '55', NULL, '09:30:00', '10:00:00', 'Break', 'Saturday', 'Break', NULL, '12', '2024-01-25 06:24:11', '2024-01-25 06:24:11');
INSERT INTO `timetables` VALUES ('422', '191', '55', '29', '09:00:00', '09:30:00', NULL, 'Monday', 'Lecture', NULL, '12', '2024-01-25 06:24:14', '2024-01-25 06:26:13');
INSERT INTO `timetables` VALUES ('423', '191', '55', '29', '09:00:00', '09:30:00', NULL, 'Tuesday', 'Lecture', NULL, '12', '2024-01-25 06:24:17', '2024-01-25 06:26:13');
INSERT INTO `timetables` VALUES ('424', '192', '55', '30', '09:00:00', '09:30:00', NULL, 'Wednesday', 'Lecture', NULL, '12', '2024-01-25 06:24:18', '2024-01-25 06:26:13');
INSERT INTO `timetables` VALUES ('425', '192', '55', '30', '09:00:00', '09:30:00', NULL, 'Thursday', 'Lecture', NULL, '12', '2024-01-25 06:24:20', '2024-01-25 06:26:13');
INSERT INTO `timetables` VALUES ('426', '190', '55', '28', '09:00:00', '09:30:00', NULL, 'Friday', 'Lecture', NULL, '12', '2024-01-25 06:24:24', '2024-01-25 06:26:13');
INSERT INTO `timetables` VALUES ('427', '190', '55', '28', '09:00:00', '09:30:00', NULL, 'Saturday', 'Lecture', NULL, '12', '2024-01-25 06:24:25', '2024-01-25 06:26:13');
INSERT INTO `timetables` VALUES ('428', '186', '55', '23', '10:00:00', '11:00:00', NULL, 'Monday', 'Lecture', NULL, '12', '2024-01-25 06:24:54', '2024-01-25 06:26:13');
INSERT INTO `timetables` VALUES ('429', '186', '55', '23', '10:00:00', '11:00:00', NULL, 'Tuesday', 'Lecture', NULL, '12', '2024-01-25 06:24:57', '2024-01-25 06:26:13');
INSERT INTO `timetables` VALUES ('430', '186', '55', '23', '10:00:00', '11:00:00', NULL, 'Wednesday', 'Lecture', NULL, '12', '2024-01-25 06:25:00', '2024-01-25 06:26:13');
INSERT INTO `timetables` VALUES ('431', '186', '55', '23', '10:00:00', '11:00:00', NULL, 'Thursday', 'Lecture', NULL, '12', '2024-01-25 06:25:02', '2024-01-25 06:26:13');
INSERT INTO `timetables` VALUES ('432', '186', '55', '23', '10:00:00', '11:00:00', NULL, 'Friday', 'Lecture', NULL, '12', '2024-01-25 06:25:05', '2024-01-25 06:26:13');
INSERT INTO `timetables` VALUES ('433', '186', '55', '23', '10:00:00', '11:00:00', NULL, 'Saturday', 'Lecture', NULL, '12', '2024-01-25 06:25:09', '2024-01-25 06:26:13');

CREATE TABLE IF NOT EXISTS `topic_commons` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `lesson_topics_id` bigint(20) unsigned NOT NULL,
  `class_section_id` bigint(20) unsigned NOT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `topic_commons_lesson_topics_id_foreign` (`lesson_topics_id`),
  KEY `topic_commons_class_section_id_foreign` (`class_section_id`),
  CONSTRAINT `topic_commons_class_section_id_foreign` FOREIGN KEY (`class_section_id`) REFERENCES `class_sections` (`id`) ON DELETE CASCADE,
  CONSTRAINT `topic_commons_lesson_topics_id_foreign` FOREIGN KEY (`lesson_topics_id`) REFERENCES `lesson_topics` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=10 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `topic_commons` VALUES ('1', '3', '28', '2025-01-03 10:51:01', '2025-01-03 10:51:01');
INSERT INTO `topic_commons` VALUES ('2', '3', '25', '2025-01-03 10:51:01', '2025-01-03 10:51:01');
INSERT INTO `topic_commons` VALUES ('3', '3', '55', '2025-01-03 10:51:01', '2025-01-03 10:51:01');
INSERT INTO `topic_commons` VALUES ('4', '3', '55', '2025-01-03 10:51:01', '2025-01-03 10:51:01');
INSERT INTO `topic_commons` VALUES ('5', '3', '22', '2025-01-03 10:51:01', '2025-01-03 10:51:01');
INSERT INTO `topic_commons` VALUES ('6', '3', '21', '2025-01-03 10:51:01', '2025-01-03 10:51:01');
INSERT INTO `topic_commons` VALUES ('7', '3', '21', '2025-01-03 10:51:01', '2025-01-03 10:51:01');
INSERT INTO `topic_commons` VALUES ('8', '3', '57', '2025-01-03 10:51:01', '2025-01-03 10:51:01');
INSERT INTO `topic_commons` VALUES ('9', '3', '22', '2025-01-03 10:51:01', '2025-01-03 10:51:01');

CREATE TABLE IF NOT EXISTS `users` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `first_name` varchar(128) NOT NULL,
  `last_name` varchar(128) NOT NULL,
  `mobile` varchar(191) DEFAULT NULL,
  `email` varchar(191) NOT NULL,
  `password` varchar(191) NOT NULL,
  `gender` varchar(16) DEFAULT NULL,
  `image` varchar(512) DEFAULT NULL,
  `dob` date DEFAULT NULL,
  `current_address` varchar(191) DEFAULT NULL,
  `permanent_address` varchar(191) DEFAULT NULL,
  `occupation` varchar(128) DEFAULT NULL,
  `status` tinyint(4) NOT NULL DEFAULT 1,
  `reset_request` tinyint(4) NOT NULL DEFAULT 0,
  `fcm_id` varchar(1024) DEFAULT NULL,
  `school_id` bigint(20) unsigned DEFAULT NULL,
  `language` varchar(191) NOT NULL DEFAULT 'en',
  `remember_token` varchar(100) DEFAULT NULL,
  `email_verified_at` timestamp NULL DEFAULT NULL,
  `two_factor_enabled` tinyint(4) NOT NULL DEFAULT 1,
  `two_factor_secret` varchar(191) DEFAULT NULL,
  `two_factor_expires_at` varchar(191) DEFAULT NULL,
  `created_at` timestamp NULL DEFAULT NULL,
  `updated_at` timestamp NULL DEFAULT NULL,
  `deleted_at` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `users_email_unique` (`email`),
  KEY `users_school_id_foreign` (`school_id`),
  CONSTRAINT `users_school_id_foreign` FOREIGN KEY (`school_id`) REFERENCES `schools` (`id`) ON DELETE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=1140 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;

INSERT INTO `users` VALUES ('40', 'Alex', 'Johnson', '5551111111', 'school1@gmail.com', '$2y$10$QWS0CpTw4G/2EP6H7a1VLermT/fA7Nr/omyVF8y5PKsY66c/oJ3ki', NULL, '', NULL, NULL, NULL, NULL, '1', '0', '', '12', 'en', NULL, '2024-09-30 13:04:20', '0', NULL, NULL, '2023-11-16 09:16:37', '2025-01-09 11:23:04', NULL);
INSERT INTO `users` VALUES ('42', 'Gift', 'Felisberto', '0111111111', 'teacher@gmail.com', '$2y$10$A7UHSPl3.3ffJjUbwNeQqera4AWjB83/KLeN0dOwXAp2TeM8OelCe', 'male', '12/user/677177000a7c76.666862291735489280.jpg', '1985-01-15', '456 Pine Street, Crestwood City', '456 Pine Street, Crestwood City', NULL, '1', '0', 'f8sOklE0QQmTjqAF5bxlH1:APA91bGDF1F54gcP2q9e1ViBLfRjOHsnwX40YVd5SBidjIsXcfBKForobl6ny-0B5tOjiy0KsI5H43f6fG0R-Pfs1dsb7Rur9DzikoKM41-NowRWPoGWfkw', '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-16 09:52:37', '2025-01-09 15:14:47', NULL);
INSERT INTO `users` VALUES ('43', 'Brian', 'Miller', '5553334444', 'brian.miller@elementary.org', '$2y$10$vPrb3HM1Vv6C8GYS50qdqu8wSYjRcV3iWHRnylkW1v0taOl0Qt.cq', 'male', '12/user/6555e6aa06e7d7.083113701700128426.jpg', '1988-06-05', '789 Oak Avenue, Groveville', '789 Oak Avenue, Groveville', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-16 09:53:46', '2024-09-30 13:04:17', NULL);
INSERT INTO `users` VALUES ('44', 'Jessica', 'White', '5555556666', 'jessica.white@elementary.org', '$2y$10$ABtdKcKx7BpwNsRswJJeTO5MSwDRv3p6UMZNJ.Yf6c4LZbPkoSsni', 'male', '12/user/6555e710a1e0e1.895718731700128528.jpg', '1977-11-12', '222 Evergreen Street, Prepville', '222 Evergreen Street, Prepville', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-16 09:55:28', '2024-09-30 13:04:17', NULL);
INSERT INTO `users` VALUES ('45', 'Kevin', 'Harris', '5557778888', 'kevin.harris@elementary.org', '$2y$10$mVNl3SQxua2qhNoDHQIu1epMUHkMXP7smIOQa55C1A5Gs7QU3lDMC', 'male', '12/user/6555e72cb62760.642574311700128556.jpg', '1982-09-08', '333 Riverside Drive, Riverdale.', '333 Riverside Drive, Riverdale.', NULL, '1', '0', 'eWuXxEncSqi62QGG7jgBcf:APA91bFfeWdqdMvgnUUxz5STu_vZkQJDN7e3Q1VEOQrlqpL1XiSswzfn7djvCiDNtF4uOEf6ieYTjNtYf11o7j2hOfMAciI-9AIynwRLy6oaZLGpR7eAIYZXd_AmDubMqjaNTQzYaALt', '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-16 09:55:56', '2024-10-11 21:32:45', NULL);
INSERT INTO `users` VALUES ('46', 'Amanda', 'Robinson', '5559990000', 'amanda.robinson@elementary.org', '$2y$10$w5Iq6w1urN/zKLF2b9amn.o2tPsW/0piO21qs304EiN4szYh5AJtK', 'male', '12/user/6555e752eb1ca1.803302601700128594.jpg', '1984-04-03', '444 Summit Road, Viewtown', '444 Summit Road, Viewtown', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-16 09:56:35', '2024-09-30 13:04:17', NULL);
INSERT INTO `users` VALUES ('47', 'Christopher', 'Lee', '5550001111', 'christopher.lee@elementary.org', '$2y$10$jsvRlZJPXJqtEUiofKj0w.vo8l.GF2ZUuBinPS5WBiENpM396zMaG', 'male', '12/user/6555e77a128334.171147361700128634.jpg', '1979-02-22', '555 Oak Lane, Woodsville', '555 Oak Lane, Woodsville', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-16 09:57:01', '2024-09-30 13:04:17', NULL);
INSERT INTO `users` VALUES ('48', 'محمد ارشد', 'عزیز', '+923035707617', 'arshadaziz57070@gmail.com', '$2y$10$k3VZMA/ZMFRVDTVowJF2..TdATHJFHMCI8qP3WUzsda6/hevcVz7C', 'male', '12/user/673bf3ea426494.830966171731982314.jpg', '1992-07-07', 'خطیب ہاؤس گلی نمبر 35 D-17/2 اسلام آباد', 'خطیب ہاؤس گلی نمبر 35 D-17/2 اسلام آباد', NULL, '1', '0', '', '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-16 09:57:44', '2024-12-08 19:37:42', NULL);
INSERT INTO `users` VALUES ('49', 'Percy', 'NDEMBET', '+242065618900', 'sledgepercy222@gmail.com', '$2y$10$w5ruAaXV8fUNV38GkhsVQuEdVhnBXKNXUv2nvqMJjSaIN9aM8epom', 'male', '12/user/6703c0ca4dd162.371316381728299210.jpg', '1998-02-01', 'mpape bwari area council Abuja, Nigeria', 'mpape bwari area council Abuja Nigeria', NULL, '1', '0', '', '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-16 09:59:43', '2024-10-29 00:00:53', NULL);
INSERT INTO `users` VALUES ('51', 'Alice', 'Smith', '123456789', 'Alice@gmail.com', '$2y$10$NrFMKXU.J7FOU/fVyDlZh.Nh0w1MzvfeVoLJtTEiaUHxhWPyIZv42', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-16 12:38:09', '2023-11-16 12:38:09', NULL);
INSERT INTO `users` VALUES ('113', 'Doe', 'Jane', '8200727077', 'johndoe@gmail.com', '$2y$10$7gkIELNcN6MpOCEW0dbywOw7p5lbY6boRyGKDor/IushJx7MQHhfi', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 10:41:44', '2023-11-17 10:41:44', NULL);
INSERT INTO `users` VALUES ('115', 'Smith', 'Michael', '8200727077', 'janesmith@gmail.com', '$2y$10$tNsDI7REf90wB4itlhWyieHqDRdQheKD8pzfbaiGqF4.KC90OFaa6', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 10:41:45', '2023-11-17 10:41:45', NULL);
INSERT INTO `users` VALUES ('117', 'Johnson', 'Emily', '8200727077', 'michaeljohnson@gmail.com', '$2y$10$FFLk8ydwY7Acmy/SUoFJ5uFMVEHshmmedhyrANkH9FDmRDv1RggnS', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 10:41:45', '2023-11-17 10:41:45', NULL);
INSERT INTO `users` VALUES ('119', 'Davis', 'David', '8200727077', 'emilydavis@gmail.com', '$2y$10$AImCUBG1L9tSa1SvfCb2UeyxMVeXgAHwnAwN6fuk8y.RLl25ifeom', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 10:41:46', '2023-11-17 10:41:46', NULL);
INSERT INTO `users` VALUES ('152', 'Martinez', 'Sarah', '8200727077', 'davidmartinez@gmail.com', '$2y$10$hGuzqQfqUNKXcKghyvFw9.2HbSg0cG7GHSpI8rFjJwebRLjKxBvya', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:24:05', '2023-11-17 12:24:05', NULL);
INSERT INTO `users` VALUES ('154', 'Brown', 'James', '8200727077', 'sarahbrown@gmail.com', '$2y$10$jrOzz/w6VOCO6LOGrW/1k.Xglt0.FTsNl1QSZ6BQ.kodm2ywVv.OS', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:24:05', '2023-11-17 12:24:05', NULL);
INSERT INTO `users` VALUES ('156', 'Taylor', 'Linda', '8200727077', 'jamestaylor@gmail.com', '$2y$10$mOlZOl0I5zewYYQVbflC5eONt.cfXhVUSr8xjw/.g0wdORjrVCxlC', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:24:06', '2023-11-17 12:24:06', NULL);
INSERT INTO `users` VALUES ('158', 'Williams', 'Robert', '8200727077', 'lindawilliams@gmail.com', '$2y$10$5ghGPguc/Y5cqXWP/HD9keJ8DGehhXbH6.xpjmIi2Bt960DiuvuMO', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:24:07', '2023-11-17 12:24:07', NULL);
INSERT INTO `users` VALUES ('160', 'Miller', 'Patricia', '8200727077', 'robertmiller@gmail.com', '$2y$10$Tw45yb6e/I8relZCMD8gC.8PMuqUHIeZ4rn.mZGtxjoCNTeUl.oku', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:24:07', '2023-11-17 12:24:07', NULL);
INSERT INTO `users` VALUES ('162', 'Anderson', 'Daniel', '8200727077', 'patriciaanderson@gmail.com', '$2y$10$OkEw1EJMl/z8WJJcSbme4OQ30cJJ.RyLt8vdRhoe.xj7tT02o0y3W', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:24:08', '2023-11-17 12:24:08', NULL);
INSERT INTO `users` VALUES ('164', 'Thomas', 'Jennifer', '8200727077', 'danielthomas@gmail.com', '$2y$10$l15A5f6NJA8QruLIYhnI3uMlgLP8EvmMYvZwf5h6HkY/5VK6753Hm', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:24:09', '2023-11-17 12:24:09', NULL);
INSERT INTO `users` VALUES ('166', 'Jackson', 'Paul', '8200727077', 'jenniferjackson@gmail.com', '$2y$10$nr5KpYU4xdpq9VU0mduxwONFl8nK5zzQzCx9SL0qQ.knL3tfcrKJa', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:24:09', '2023-11-17 12:24:09', NULL);
INSERT INTO `users` VALUES ('168', 'White', 'Maria', '8200727077', 'paulwhite@gmail.com', '$2y$10$2hA8D5PQvJ78Edt6QUweceXshmMjQztrnf06QJwNRCifqMhBnA8Q.', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:24:10', '2023-11-17 12:24:10', NULL);
INSERT INTO `users` VALUES ('170', 'Harris', 'Mark', '8200727077', 'mariaharris@gmail.com', '$2y$10$m4BDghwpMLgpvml3v9ZNYO6yRzEpSI//NzGOF0onrAdsGYDgK8L/6', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:28:48', '2023-11-17 12:28:48', NULL);
INSERT INTO `users` VALUES ('172', 'Martin', 'Susan', '8200727077', 'markmartin@gmail.com', '$2y$10$0/et1alNJCSqRlMS7WBEAeJtEkAO5lw9ZPmUITlLWVXdEMtu6lPi2', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:28:48', '2023-11-17 12:28:48', NULL);
INSERT INTO `users` VALUES ('174', 'Thompson', 'Kevin', '8200727077', 'susanthompson@gmail.com', '$2y$10$TfbXdz9xa45fxoS1a9DsXOxr/jAMbFb14pRLytcD/BuPIB8ZyYV7u', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:28:49', '2023-11-17 12:28:49', NULL);
INSERT INTO `users` VALUES ('176', 'Garcia', 'Karen', '8200727077', 'kevingarcia@gmail.com', '$2y$10$6tmDLE9i.w80q0qC47uiEexwfBk9Hw/Jzc/0Suk8j/uBOWklyoIWO', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:28:50', '2023-11-17 12:28:50', NULL);
INSERT INTO `users` VALUES ('178', 'Martinez', 'Brian', '8200727077', 'karenmartinez@gmail.com', '$2y$10$if5l4iunnTEWlqrnfcKgNOS78ltOZkemn0UfhVf9kh85c30TXVWOa', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:28:50', '2023-11-17 12:28:50', NULL);
INSERT INTO `users` VALUES ('180', 'Robinson', 'Nancy', '8200727077', 'brianrobinson@gmail.com', '$2y$10$S1L4QkSgEdCU/9VNbd456.6gghEvyxv5YJ/D1VstMhhgaLycDXfk.', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:28:51', '2023-11-17 12:28:51', NULL);
INSERT INTO `users` VALUES ('182', 'Clark', 'Jason', '8200727077', 'nancyclark@gmail.com', '$2y$10$w4GbRRFI1MKL1.Ts41htCuz8rMM1qyKK/0JkfhtwQFJb8lML5ts8e', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:28:52', '2023-11-17 12:28:52', NULL);
INSERT INTO `users` VALUES ('184', 'Rodriguez', 'Barbara', '8200727077', 'jasonrodriguez@gmail.com', '$2y$10$Kq585/wwhTf2wBD4omA0pOpb/aw2YNVmJJ3GImPmVDdZDnnHBLkpi', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:28:52', '2023-11-17 12:28:52', NULL);
INSERT INTO `users` VALUES ('186', 'Lewis', 'Justin', '8200727077', 'barbaralewis@gmail.com', '$2y$10$kdiinJ7oMEDqeu5DPlTNaOyAsDubQ1.A.05XXSoBFraUvsNaGXtkO', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:28:53', '2023-11-17 12:28:53', NULL);
INSERT INTO `users` VALUES ('188', 'Lee', 'Elizabeth', '8200727077', 'justinlee@gmail.com', '$2y$10$dhATrnFZ4KHkLKhqvrDYAenX3UxWXdsjuiBAcy/C/acw4dQPlsveC', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:28:53', '2023-11-17 12:28:53', NULL);
INSERT INTO `users` VALUES ('190', 'Walker', 'Ryan', '8200727077', 'elizabethwalker@gmail.com', '$2y$10$4uts7mKz.6GN4gU9pqPtoOMevbFIC4NoITGp6sWL5Jj/xNqjfi6Z.', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:28:54', '2023-11-17 12:28:54', NULL);
INSERT INTO `users` VALUES ('192', 'Hall', 'Jessica', '8200727077', 'ryanhall@gmail.com', '$2y$10$phbTm6d6Y8mJfJItgo2.D.nmQNJvhbuOq5/9xEQmSZPLdWPzzHjLO', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:28:55', '2023-11-17 12:28:55', NULL);
INSERT INTO `users` VALUES ('194', 'Allen', 'Eric', '8200727077', 'jessicaallen@gmail.com', '$2y$10$EZt294nF9awQuomXkMfC/OejMWpstjn9.r39Fg2ZnX7KCjkZY5XEC', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:28:55', '2023-11-17 12:28:55', NULL);
INSERT INTO `users` VALUES ('196', 'Young', 'Stephanie', '8200727077', 'ericyoung@gmail.com', '$2y$10$j0xGsaiPgs6HpQ1DE96YGu/ga3OzzjDFxsbLHtXb70uQQ/Mloj6YG', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:28:56', '2023-11-17 12:28:56', NULL);
INSERT INTO `users` VALUES ('198', 'King', 'Adam', '8200727077', 'stephanieking@gmail.com', '$2y$10$InY4JYezTaS1CkbV7FiZxe9OrFoRfiCPyS42jvCA/bcqfjbZHuAvO', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:28:57', '2023-11-17 12:28:57', NULL);
INSERT INTO `users` VALUES ('200', 'Wright', 'Megan', '8200727077', 'adamwright@gmail.com', '$2y$10$h5JemVYQBzMAIJuEHCoR6uqR6plIgq0o8pYd/T3skNAWTEw2Vr9pG', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:28:57', '2023-11-17 12:28:57', NULL);
INSERT INTO `users` VALUES ('202', 'Scott', 'Jeffrey', '8200727077', 'meganscott@gmail.com', '$2y$10$3B7lMjUbuARG8h4dBLaOa.GZSWutYBSe82uJPBxl7wIPXx2bfOZ3a', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:28:58', '2023-11-17 12:28:58', NULL);
INSERT INTO `users` VALUES ('204', 'Green', 'Christine', '8200727077', 'jeffreygreen@gmail.com', '$2y$10$BwTju5x4MBQb5QOdTsFGWeDS0JC95DD1sbk3uLGIwj5yM0jGrbaGu', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:28:59', '2023-11-17 12:28:59', NULL);
INSERT INTO `users` VALUES ('206', 'Adams', 'Gregory', '8200727077', 'christineadams@gmail.com', '$2y$10$Uhv/8j8J3qwynfxH1Ee/d.RGlhwojqkP6DO//H2h3DdcAyB9r1XTq', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:28:59', '2023-11-17 12:28:59', NULL);
INSERT INTO `users` VALUES ('208', 'Baker', 'Kimberly', '8200727077', 'gregorybaker@gmail.com', '$2y$10$vGYDKetB/Mm39e7NTOT.Uu7uMoV0S3Ong866Wpo7rqDmUss2tfhqa', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:00', '2023-11-17 12:29:00', NULL);
INSERT INTO `users` VALUES ('210', 'Nelson', 'Joshua', '8200727077', 'kimberlynelson@gmail.com', '$2y$10$GiB/l088BZCoEkm.G8vGpOC7/pNzEx0H.6UDnJSXZFd57wZZzsZxi', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:01', '2023-11-17 12:29:01', NULL);
INSERT INTO `users` VALUES ('212', 'Hill', 'Dorothy', '8200727077', 'joshuahill@gmail.com', '$2y$10$jIojsurUusTgHXNJsLCZe.A8lC/pM9Xju5tZ85XKl5rKmNH32GTB.', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:01', '2023-11-17 12:29:01', NULL);
INSERT INTO `users` VALUES ('214', 'Carter', 'Andrew', '8200727077', 'dorothycarter@gmail.com', '$2y$10$FsXDXurMtxNuQAalUNwQ9eUVNlPCdGeFiY2Kw.szC5NF0uCUQUewS', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:02', '2023-11-17 12:29:02', NULL);
INSERT INTO `users` VALUES ('216', 'Mitchell', 'Shirley', '8200727077', 'andrewmitchell@gmail.com', '$2y$10$Lw9Z8cs6XUffluZrspLSA.MFH21curXJ6XnzLRcM52wBzF1b9FBnG', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:02', '2023-11-17 12:29:02', NULL);
INSERT INTO `users` VALUES ('218', 'Roberts', 'Raymond', '8200727077', 'shirleyroberts@gmail.com', '$2y$10$wnfu.mukjmBqvhUtD/dBmeSO37CaHzvJ52JRJtnT4tK985Zk4oxPi', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:03', '2023-11-17 12:29:03', NULL);
INSERT INTO `users` VALUES ('220', 'Phillips', 'Angela', '8200727077', 'raymondphillips@gmail.com', '$2y$10$gGZCRXVF58uyXOtVYUL43eUxfD4cZkkWxwwByMARuQhbq/7E6DoYi', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:04', '2023-11-17 12:29:04', NULL);
INSERT INTO `users` VALUES ('222', 'Campbell', 'Gary', '8200727077', 'angelacampbell@gmail.com', '$2y$10$U67B71nkhe7feqGCslvKveo857A4BSxcA7qjrqDn61wQm0U6utcEq', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:04', '2023-11-17 12:29:04', NULL);
INSERT INTO `users` VALUES ('224', 'Edwards', 'Brenda', '8200727077', 'garyedwards@gmail.com', '$2y$10$W8QdXmU6XAskjjqsKe190O4/e7T8x7cWzm1GxWOW7h6TuYnRl62a.', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:05', '2023-11-17 12:29:05', NULL);
INSERT INTO `users` VALUES ('226', 'Turner', 'Timothy', '8200727077', 'brendaturner@gmail.com', '$2y$10$zsmyOG55N6.0QZOceJQAquDA0BpcRkyzPtH8WwwdHPgiDCk6HqVuK', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:06', '2023-11-17 12:29:06', NULL);
INSERT INTO `users` VALUES ('228', 'Moore', 'Pamela', '8200727077', 'timothymoore@gmail.com', '$2y$10$06pS6rrCM3Av/bXdTXlfjeVnKd9eO.CmNCnFHFRLcKc14t.YFsKoK', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:06', '2023-11-17 12:29:06', NULL);
INSERT INTO `users` VALUES ('230', 'Torres', 'Jerry', '8200727077', 'pamelatorres@gmail.com', '$2y$10$EoMMpyKiSO1WdAYF6Uyc7.SYVIoptGcihAAgIknYgQ4QBvbnLsV8u', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:07', '2023-11-17 12:29:07', NULL);
INSERT INTO `users` VALUES ('232', 'Collins', 'Katherine', '8200727077', 'jerrycollins@gmail.com', '$2y$10$q.wymfw/STKPrP/T25/YUeQj1ghldKjQJc2R.H57yDOQZDnGliwi2', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:08', '2023-11-17 12:29:08', NULL);
INSERT INTO `users` VALUES ('234', 'Stewart', 'Dennis', '8200727077', 'katherinestewart@gmail.com', '$2y$10$iRBmDHRYQOiTKZNIkplDLutaQrEJhi4IR/mJa.IDCizTvg1DWPubO', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:08', '2023-11-17 12:29:08', NULL);
INSERT INTO `users` VALUES ('236', 'Morris', 'Gloria', '8200727077', 'dennismorris@gmail.com', '$2y$10$qFOP/0rEGDX2PIF0zg6zSuy.ZQTSAVGiv1NHufvkQliqKLMQH9biG', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:09', '2023-11-17 12:29:09', NULL);
INSERT INTO `users` VALUES ('238', 'Sanchez', 'Walter', '8200727077', 'gloriasanchez@gmail.com', '$2y$10$38Oq6p7ZIY2SmYmtXjZYNe6lEZQwrbEXyoixu0xpPaBd8e61qDxXO', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:09', '2023-11-17 12:29:09', NULL);
INSERT INTO `users` VALUES ('240', 'Rogers', 'Joan', '8200727077', 'walterrogers@gmail.com', '$2y$10$ax57ZTMRKPn/IoHl7pAZHu4vB9aQoo6KpYXi0Xdvq0iPAi1X6z58m', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:10', '2023-11-17 12:29:10', NULL);
INSERT INTO `users` VALUES ('242', 'Reed', 'Harold', '8200727077', 'joanreed@gmail.com', '$2y$10$XUd6gT.MqJtM4jWcMHBnqewAdifa9u1n2La5yn2jIWfxfB/BKb5FW', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:11', '2023-11-17 12:29:11', NULL);
INSERT INTO `users` VALUES ('244', 'Cook', 'Carol', '8200727077', 'haroldcook@gmail.com', '$2y$10$u4xw8jL5EeP3QOr1td3N3uf4W/hsuRBQlclGD2eFd0oi5JRDxA5lu', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:11', '2023-11-17 12:29:11', NULL);
INSERT INTO `users` VALUES ('246', 'Morgan', 'Joe', '8200727077', 'carolmorgan@gmail.com', '$2y$10$3evLBZQNo35rBTFuk0t6wOJFUqb8NqykNioyJz7n/QIDPbQ8uEBWq', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:12', '2023-11-17 12:29:12', NULL);
INSERT INTO `users` VALUES ('248', 'Bell', 'Sara', '8200727077', 'joebell@gmail.com', '$2y$10$gyFQ6Gv00yWZsWA5ffe8POwzvbKVcceknarSwxV50WdpEfKc3o75u', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:13', '2023-11-17 12:29:13', NULL);
INSERT INTO `users` VALUES ('250', 'Murphy', 'Benjamin', '8200727077', 'saramurphy@gmail.com', '$2y$10$V/WWFlKAzrULd1BtsJ7XYubtm1zDajtqdFEK6dzGX5F74b1cy1NIi', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:13', '2023-11-17 12:29:13', NULL);
INSERT INTO `users` VALUES ('252', 'Bailey', 'Mildred', '8200727077', 'benjaminbailey@gmail.com', '$2y$10$Z.Yi6dK0e13P.vXpb7jzzO3GrLUEWVAn1..JAxtthLJOS41YwRXW.', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:14', '2023-11-17 12:29:14', NULL);
INSERT INTO `users` VALUES ('254', 'Rivera', 'Randy', '8200727077', 'mildredrivera@gmail.com', '$2y$10$xOZwNEFEvyc2.MgzlvP9k.UOOSIirGsdLBANBVL1RwDBUHoqAmBmi', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:15', '2023-11-17 12:29:15', NULL);
INSERT INTO `users` VALUES ('256', 'Cooper', 'Catherine', '8200727077', 'randycooper@gmail.com', '$2y$10$LkUZhCfDQCHQUedIPsS7zuDVuxY4z2gAP1ik83uUK51Aqq1lxTGDG', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:15', '2023-11-17 12:29:15', NULL);
INSERT INTO `users` VALUES ('258', 'Richardson', 'Bruce', '8200727077', 'catherinerichardson@gmail.com', '$2y$10$bAHSinxU0PDc407XEJKv5O05W8Xjtn6tVJDZJM/9hx1FRWBBkWRJG', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:16', '2023-11-17 12:29:16', NULL);
INSERT INTO `users` VALUES ('260', 'Cox', 'Ann', '8200727077', 'brucecox@gmail.com', '$2y$10$VgrvuWDgVZfDEVaNBNn51OStmv5GKPxMVteM9a2caYOjuhD0p2csm', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:17', '2023-11-17 12:29:17', NULL);
INSERT INTO `users` VALUES ('262', 'Howard', 'Steve', '8200727077', 'annhoward@gmail.com', '$2y$10$rmYgjiWkJ5bS5Wd4MZ1Ip.2nr3eYB1TP48ocKKJyUDtyqk.l0JvWu', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:17', '2023-11-17 12:29:17', NULL);
INSERT INTO `users` VALUES ('264', 'Long', 'Denise', '8200727077', 'stevelong@gmail.com', '$2y$10$LzYASxfEk4Pz9osjc8veB.v0URUXbCfd3zRUdPUKP7sBwGhqrOXS.', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:18', '2023-11-17 12:29:18', NULL);
INSERT INTO `users` VALUES ('266', 'Coleman', 'Raymond', '8200727077', 'denisecoleman@gmail.com', '$2y$10$yojbcg7b9tM5LHAb3gzJd.xcfWXq3dxe62OxR4LsbcXNvJPabJLim', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:18', '2023-11-17 12:29:18', NULL);
INSERT INTO `users` VALUES ('268', 'Patterson', 'Teresa', '8200727077', 'raymondpatterson@gmail.com', '$2y$10$M.QCKv3sshXpjyk8U8GHT.gXrDIQ0fLSplhsfW8oiKeluIVRWS0O6', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:19', '2023-11-17 12:29:19', NULL);
INSERT INTO `users` VALUES ('270', 'Simmons', 'Fred', '8200727077', 'teresasimmons@gmail.com', '$2y$10$/4weo56WgKODdTJ4t0kcP.Wux5NhFmH.yq2E0L5RtQpF5mCv/4P9i', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:20', '2023-11-17 12:29:20', NULL);
INSERT INTO `users` VALUES ('272', 'Perry', 'Tammy', '8200727077', 'fredperry@gmail.com', '$2y$10$iUe99DMTpn3iafDWo94U8.WizoD8.WwtHfvqq/cp0KSmQfGHvF9qO', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:20', '2023-11-17 12:29:20', NULL);
INSERT INTO `users` VALUES ('274', 'Bryant', 'Wayne', '8200727077', 'tammybryant@gmail.com', '$2y$10$Wm6EN0QAs7zNhRJNsupgpOMDbT9Bi4KI2F7E7b/SGwH/e1/KTSTgq', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:21', '2023-11-17 12:29:21', NULL);
INSERT INTO `users` VALUES ('276', 'Alexander', 'Dorothy', '8200727077', 'waynealexander@gmail.com', '$2y$10$UpAl6ZelhGGJ005wbWsV4eaKQNazkGG7dTGFbO5/y3KTS1QmNo1M6', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:22', '2023-11-17 12:29:22', NULL);
INSERT INTO `users` VALUES ('278', 'Francis', 'Eugene', '8200727077', 'dorothyfrancis@gmail.com', '$2y$10$YNXqxBKB.2x9/IuhdLCefuuY/zT5jFD/7lodn8ZrBLrE12K5rzzBu', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:22', '2023-11-17 12:29:22', NULL);
INSERT INTO `users` VALUES ('280', 'Russell', 'Gloria', '8200727077', 'eugenerussell@gmail.com', '$2y$10$YnBV4WTP2BETx71YRD2QNe3f87XKFioZYsDpSvz0AdowIzFIcfpYm', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:23', '2023-11-17 12:29:23', NULL);
INSERT INTO `users` VALUES ('282', 'Armstrong', 'Vincent', '8200727077', 'gloriaarmstrong@gmail.com', '$2y$10$ia7bTamuFnTA/0qFSf23M.lLs4IVa0m/KL/HeQcf/CgeiHj.kyo9S', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:24', '2023-11-17 12:29:24', NULL);
INSERT INTO `users` VALUES ('284', 'Weaver', 'Lillian', '8200727077', 'vincentweaver@gmail.com', '$2y$10$fGumUiDu1qE/zgVYo9So/.JRippudkPOQb099lJHRIlnqaPoo80AW', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:24', '2023-11-17 12:29:24', NULL);
INSERT INTO `users` VALUES ('286', 'Washington', 'Zachary', '8200727077', 'lillianwashington@gmail.com', '$2y$10$zxHouCk9fzdFfM3VZZzuc.sqdU8T4NOLqxMuyXSCz6m.3JYaIzi2u', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:25', '2023-11-17 12:29:25', NULL);
INSERT INTO `users` VALUES ('288', 'Freeman', 'Judith', '8200727077', 'zacharyfreeman@gmail.com', '$2y$10$j8S8xpZzpYvVrMGnD.vWbOsqxekW3Wiu5E23XJClJwYaxW/vTdYSu', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:25', '2023-11-17 12:29:25', NULL);
INSERT INTO `users` VALUES ('290', 'Butler', 'Leroy', '8200727077', 'judithbutler@gmail.com', '$2y$10$PhaCJcBt/eDaZ3TfRXqHFuVCUtYVsnKEtZ8YRxvmABJBjZJ6fIizC', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:26', '2023-11-17 12:29:26', NULL);
INSERT INTO `users` VALUES ('292', 'Wallace', 'Marilyn', '8200727077', 'leroywallace@gmail.com', '$2y$10$/e6A5PjvxA5AXPxCuXArW.5.KJxp1Ot6OUK5Bi5QysufyVpN8fJMO', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:27', '2023-11-17 12:29:27', NULL);
INSERT INTO `users` VALUES ('294', 'Stanley', 'Clifford', '8200727077', 'marilynstanley@gmail.com', '$2y$10$zYasGsWLCFlVR6I.fHnjLuu2kHVtEOKojVG6YjNKC1cLE5hZwU8cy', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:27', '2023-11-17 12:29:27', NULL);
INSERT INTO `users` VALUES ('296', 'Jenkins', 'Carolyn', '8200727077', 'cliffordjenkins@gmail.com', '$2y$10$bHFscWFYNpWl2youi.JbeurwlDWLyU8Z18iR1djAFTT/7pB/amRz.', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:28', '2023-11-17 12:29:28', NULL);
INSERT INTO `users` VALUES ('298', 'Warren', 'Calvin', '8200727077', 'carolynwarren@gmail.com', '$2y$10$1lTulttTSRkWKt4/QMfQpuGeeJ3H4CyTW5BuF5ITRaBKDyZvqmPbq', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:29', '2023-11-17 12:29:29', NULL);
INSERT INTO `users` VALUES ('300', 'Dunn', 'Catherine', '8200727077', 'calvindunn@gmail.com', '$2y$10$K6q9wcJ7AeP.LcvJF0lT8.FqnhSFLf10./JimafyFD/a18/ZU4Kbm', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:29', '2023-11-17 12:29:29', NULL);
INSERT INTO `users` VALUES ('302', 'Hoffman', 'Neil', '8200727077', 'catherinehoffman@gmail.com', '$2y$10$.i1do1P0OxZuJZ25.jgiG.pnFWoqT9/s9Uf9lZiP7/OWm6veEF4pi', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:30', '2023-11-17 12:29:30', NULL);
INSERT INTO `users` VALUES ('304', 'Spencer', 'Jeanne', '8200727077', 'neilspencer@gmail.com', '$2y$10$12RhUGUdDhcu4Tr..PsC..UaDORg4XnMrURrPjAGPBE.sWSoiN2we', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:31', '2023-11-17 12:29:31', NULL);
INSERT INTO `users` VALUES ('306', 'Fisher', 'Chester', '8200727077', 'jeannefisher@gmail.com', '$2y$10$zZWh4Ds3wcbclMS/NDEMUOjb7MKa89bjBgJAvm1Dt3kdL62dAd5gi', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:31', '2023-11-17 12:29:31', NULL);
INSERT INTO `users` VALUES ('308', 'Wagner', 'Frances', '8200727077', 'chesterwagner@gmail.com', '$2y$10$vKEHfmtezNE/JYq3c1Xn2uW35tKpAnraf7AfCfjyVsmod7rk5olhe', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:32', '2023-11-17 12:29:32', NULL);
INSERT INTO `users` VALUES ('310', 'Pierce', 'Herman', '8200727077', 'francespierce@gmail.com', '$2y$10$AxQjoDUiV8mCuS3Iu6RXE./uRfkRUSmAtVi7vqhx021UfWfmNsMOe', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:33', '2023-11-17 12:29:33', NULL);
INSERT INTO `users` VALUES ('312', 'Burke', 'Bonnie', '8200727077', 'hermanburke@gmail.com', '$2y$10$qfvooPxHEKn8n4yAe3VNSeUWMgLrbK/PKkUCOVdRS.vBBgbaUmje2', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:33', '2023-11-17 12:29:33', NULL);
INSERT INTO `users` VALUES ('314', 'Lane', 'Vernon', '8200727077', 'bonnielane@gmail.com', '$2y$10$M8UvyHZz9DoZADlcFpKFJug5HopO6llIMXT3/c/cGj66dSF2COqKu', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:34', '2023-11-17 12:29:34', NULL);
INSERT INTO `users` VALUES ('316', 'Olson', 'Rhonda', '8200727077', 'vernonolson@gmail.com', '$2y$10$sIL09CR.5ty51jcMkipK1OtS3mnLY.ErG37hAfYgJ1zVyA1RORFrO', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:34', '2023-11-17 12:29:34', NULL);
INSERT INTO `users` VALUES ('318', 'Snyder', 'Gordon', '8200727077', 'rhondasnyder@gmail.com', '$2y$10$o/CfwUe9nADW/lStS8PphOIvNzENU14i4kZp1gjsVhUAz6RbP7dXi', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:35', '2023-11-17 12:29:35', NULL);
INSERT INTO `users` VALUES ('320', 'Hart', 'Marjorie', '8200727077', 'gordonhart@gmail.com', '$2y$10$LucE6oHR5RX.jBXqnv1OuuXhm69G.pzaIwgGFiHIfYSu8pZFRgFxy', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-17 12:29:36', '2023-11-17 12:29:36', NULL);
INSERT INTO `users` VALUES ('330', 'Guardian', 'Demo', '8200727077', 'guardian@gmail.com', '$2y$10$OdctHTJsJ0hRicjMAHhgTePVGYJQVuv9er6lGadnd3cxVzEI/tGPi', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', '', '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 05:10:07', '2025-01-08 02:20:05', NULL);
INSERT INTO `users` VALUES ('331', 'Class 1', 'demo', '8200727077', '2022-23121', '$2y$10$XrGXf4DHn0KiLuNyVL.eruwLuayMSF36uUtRptyeuFBo5NXpl2pba', 'male', '12/user/655aea2fc543a9.910758891700457007.jpg', '2018-11-19', 'Downtown, Toronto, Onterio, CA', 'Downtown, Toronto, Onterio, CA', NULL, '1', '1', 'dTRW4NrsSqOPE1rLxxWMnu:APA91bGJzVVzYhn9XVYGkq1rsG49rAXlzn2_8gYpTRVblhPnRT1ckoBSCIdGi3tz4u1SIhKGZGgyoK95mcMgF6DSYfeZlM9Kr9B0S810vrjpvTMWkotcpw0', '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 05:10:07', '2025-01-06 17:33:18', NULL);
INSERT INTO `users` VALUES ('333', 'Class 2', 'demo', '8200727077', 'class2demo@gmail.com', '$2y$10$JVEdf28.UUXjtMyCp6tgs.U41LZfY6Gs9NrYvg2vWRGTi4uK5SJwa', 'male', '12/user/655c3ffe6e9417.877815681700544510.jpg', '2023-11-20', '1593 Briarwood Road', '1593 Briarwood Road', NULL, '1', '0', 'fwq243FlQOe_BnEhlJux2n:APA91bEAI4eA2x6uuxtFG-xcW5MDEwidAO9-imMKVEypbeY30PAz9dCLqGvFsMO7rWOOJQs1uKiBC3qqUtxy0zbPxXkqTJC293-lCFS0C3yaLWNWy7rWiN3bp_fWRtkziBaAaPSP9zJt', '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 05:32:09', '2024-09-30 13:04:17', NULL);
INSERT INTO `users` VALUES ('334', 'Class 3', 'demo', '8200727077', 'class3demo@gmail.com', '$2y$10$JVEdf28.UUXjtMyCp6tgs.U41LZfY6Gs9NrYvg2vWRGTi4uK5SJwa', 'male', '12/user/655c405135dc64.949807971700544593.jpg', '2023-11-20', '1180 Concord Street', '1180 Concord Street', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 05:32:57', '2024-09-30 13:04:17', NULL);
INSERT INTO `users` VALUES ('335', 'Class 4', 'demo', '8200727077', 'class4demo@gmail.com', '$2y$10$JVEdf28.UUXjtMyCp6tgs.U41LZfY6Gs9NrYvg2vWRGTi4uK5SJwa', 'male', '12/user/655c40a0d69c33.317745221700544672.jpg', '2023-11-20', '2573 Parkway Drive', '2573 Parkway Drive', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 05:33:16', '2024-09-30 13:04:17', NULL);
INSERT INTO `users` VALUES ('336', 'Class 5', 'demo', '8200727077', 'class5demo@gmail.com', '$2y$10$JVEdf28.UUXjtMyCp6tgs.U41LZfY6Gs9NrYvg2vWRGTi4uK5SJwa', 'male', '12/user/655c44100e1254.778237511700545552.jpg', '2023-11-20', '4625 Cessna Drive', '4625 Cessna Drive', NULL, '1', '0', 'fK-v8Rtw8EY8pjxIJpOtpS:APA91bGlYLOO70NSElWhZbltk-RFmM0x1zCFRD6yKZUlnjskLWNiHRAUV5DwRx8Zvws_IJkSBxJ-bIQ0M2VB4OF7U25VTSkixyEObhKyzRpmDxkt7dkKbOMUlvo8NEITVnylFYcbAjIb', '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 05:33:29', '2024-09-30 13:04:17', NULL);
INSERT INTO `users` VALUES ('337', 'Class 6', 'demo', '8200727077', 'class6demo@gmail.com', '$2y$10$JVEdf28.UUXjtMyCp6tgs.U41LZfY6Gs9NrYvg2vWRGTi4uK5SJwa', 'male', '12/user/655c44276ea5c4.996369381700545575.jpg', '2023-11-20', '3809 Steele Street', '3809 Steele Street', NULL, '1', '0', 'ckjNmXu9QqypYIo-NqzEFj:APA91bHd0PDJhOnlS7dmHP5jZPTCtY4u_zy0hS4p0oi95zEstar7pqOMrA562eNhx2Zli2etN28rdXEoyXMm-u7C_Ag9SuzqvhH0iGapU9dGOloF9FVgwL-hBDjJRZNla1gitYTaZPVG', '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 05:33:41', '2024-09-30 13:04:17', NULL);
INSERT INTO `users` VALUES ('341', 'Class 10', 'demo', '8200727077', 'class10demo@gmail.com', '$2y$10$JVEdf28.UUXjtMyCp6tgs.U41LZfY6Gs9NrYvg2vWRGTi4uK5SJwa', 'male', '12/user/655c44861c7293.426983791700545670.jpg', '2023-11-20', '3016 Gnatty Creek Road', '3016 Gnatty Creek Road', NULL, '1', '0', 'c9oX5ZNHQoKOffqbnYBw8-:APA91bHcfo-C1aXEV6GT6b2Bpm3kzRGQFask7UkYrGL0cbfpujNBomC6x1Ki1kXMP1XL4MD--AI4ymhnXD6dSFj3J5bb3uEhgs91JZZYQZoCaCdEN7XzZbHcyUHZasRknXT12SH7O7gf', '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 05:34:37', '2024-09-30 13:04:17', NULL);
INSERT INTO `users` VALUES ('348', 'Cunha', 'Nicole', '4178583056', 'NicoleGomesCunha@superrito.com', '$2y$10$upTcs5QU9YqLs3ldTE/YxO7Wlw5ewD6fCrjY43DTpNnvC.aDH/BkO', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:51:07', '2023-11-20 07:51:07', NULL);
INSERT INTO `users` VALUES ('349', 'Nicole', 'Cunha', '8200727077', '2022-2312153', '$2y$10$5eNCUMMsyTqoZggkjV8Q8uByblYcR41oWXW0mp2LPefnLlXVTmd22', 'male', NULL, '2023-11-20', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:51:07', '2023-11-20 07:55:03', NULL);
INSERT INTO `users` VALUES ('350', 'Melo', 'Andre', '7045171377', 'AndreSousaMelo@teleworm.us', '$2y$10$NPhs4FjBdYiZl/7b1bv0WuW8W0lOcy0HD2ywROpmNi2oz5UCEBa3C', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:51:08', '2023-11-20 07:51:08', NULL);
INSERT INTO `users` VALUES ('351', 'Andre', 'Melo', '8200727077', '2022-2312154', '$2y$10$HmzQMRiHS1VQDVCIjtWmBuvsvGiiO10zHH1aA7umqqoSUf3ucZU.q', 'male', NULL, '2023-11-20', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:51:08', '2023-11-20 07:55:03', NULL);
INSERT INTO `users` VALUES ('352', 'Ribeiro', 'Rebeca', '5204182405', 'RebecaSouzaRibeiro@gustr.com', '$2y$10$CfjKXfWYXrWS/2EVfKkTZurRWXx6.RxcJFnB/AA81brQYeoyeXM8u', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:51:08', '2023-11-20 07:51:08', NULL);
INSERT INTO `users` VALUES ('353', 'Rebeca', 'Ribeiro', '8200727077', '2022-2312155', '$2y$10$O9Ia9nVGGxxAde9q5Qqm1.zxPuZFKMlSMY5uEUtnwiktOIPNAmV4e', 'male', NULL, '2023-11-20', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:51:09', '2023-11-20 07:55:03', NULL);
INSERT INTO `users` VALUES ('354', 'Alves', 'Sarah', '3147492781', 'SarahCarvalhoAlves@cuvox.de', '$2y$10$nnjmnXnzFFYQ0XXhr8EZneuMmtwjdM1OwlDU.bQyVCnxAPXSNJwJe', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:51:09', '2023-11-20 07:51:09', NULL);
INSERT INTO `users` VALUES ('355', 'Sarah', 'Alves', '8200727077', '2022-2312156', '$2y$10$./JrvA0IpbzYY3vIDAtdruR8zdHp6VucGLqBm13zXMi10R5DYLJEG', 'male', NULL, '2023-11-20', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:51:09', '2023-11-20 07:55:03', NULL);
INSERT INTO `users` VALUES ('356', 'Cunha', 'Antônio', '5032027980', 'AntonioGomesCunha@cuvox.de', '$2y$10$3vMVCMJvL2hOR22ZXcKqwekvRTT5c2CVMGKWRl58CGwIOzsgB.FXe', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:53:56', '2023-11-20 07:53:56', NULL);
INSERT INTO `users` VALUES ('357', 'Antonio', 'Cunha', '5032027980', '2022-2312157', '$2y$10$9M9tK4OZBYpfCAAzfWdrcOJjFIBx08hUmFt3vP5T7PKMmHeTsK41W', 'male', NULL, '2023-11-20', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:53:56', '2023-11-20 07:55:03', NULL);
INSERT INTO `users` VALUES ('358', 'Cunha', 'Clara', '2603075096', 'ClaraCastroCunha@fleckens.hu', '$2y$10$HYk2mNU14UOS7aC76iU3pOGSQ45BR.mhN3Qo3tvwl6I54dd0pO0rO', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:53:56', '2023-11-20 07:53:56', NULL);
INSERT INTO `users` VALUES ('359', 'Clara', 'Cunha', '2603075096', '2022-2312158', '$2y$10$ZCcOVHf/j/DIflyzyMgsTekVnhgoGtK8e.ilG63pxAtzxsHisJP3a', 'male', NULL, '2023-11-20', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:53:57', '2023-11-20 07:55:03', NULL);
INSERT INTO `users` VALUES ('360', 'Sousa', 'Bruna', '6306764116', 'BrunaLimaSousa@armyspy.com', '$2y$10$lBk9tg/mA5UXrrMgD0rMU.yP/gA..VHcb.pma9WktrTqvYVI0k1U.', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:53:57', '2023-11-20 07:53:57', NULL);
INSERT INTO `users` VALUES ('361', 'Bruna', 'Sousa', '6306764116', '2022-2312159', '$2y$10$xW3PMosrO.wnYG2RY5ud7.lRclLoQZoH0ojOUTAqmG90y9ztFdT6G', 'male', NULL, '2023-11-20', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:53:57', '2023-11-20 07:55:03', NULL);
INSERT INTO `users` VALUES ('362', 'Oliveira', 'Kauê', '8014761619', 'KaueMartinsOliveira@fleckens.hu', '$2y$10$dbKcWLtONqA0vdXvjrdSRe5VXuLf1h1nwHCu7aFpka/pJqLKjWTD6', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:53:58', '2023-11-20 07:53:58', NULL);
INSERT INTO `users` VALUES ('363', 'Kaue', 'Oliveira', '8014761619', '2022-2312160', '$2y$10$q6z4koSb2bU2V4pT/ST1J.Ah4PHwhLgb6MSsVl36RBI1s56a3Zw5W', 'male', NULL, '2023-11-20', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:53:58', '2023-11-20 07:55:03', NULL);
INSERT INTO `users` VALUES ('364', 'Silva', 'Caio', '4178831795', 'CaioCorreiaSilva@fleckens.hu', '$2y$10$EcuRMxVqi8APPBAHG1VsO.kuD2TFn2vn05ueqySaAMMANTc1vvlwO', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:53:58', '2023-11-20 07:53:58', NULL);
INSERT INTO `users` VALUES ('365', 'Caio', 'Silva', '4178831795', '2022-2312161', '$2y$10$NCSxXMkCyw85UHZKRVeVVuLDHG1PpYXAiHn8e0xOuptJrJF3DYaHq', 'male', NULL, '2023-11-20', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:53:59', '2023-11-20 07:55:03', NULL);
INSERT INTO `users` VALUES ('366', 'Cunha', 'Murilo', '9036367481', 'MuriloCostaCunha@armyspy.com', '$2y$10$b2N35qUviyqHWzPy409creG1.Yxdu6mNBqQPhqOmGVcm.FT1uZHk.', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:53:59', '2023-11-20 07:53:59', NULL);
INSERT INTO `users` VALUES ('367', 'Murilo', 'Cunha', '9036367481', '2022-2312162', '$2y$10$qnurktdKdzQlvv0mYhhJyeQJ/uhhjqFebsUjiAis5V.YQDQuW4kQS', 'male', NULL, '2023-11-20', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:53:59', '2023-11-20 07:55:03', NULL);
INSERT INTO `users` VALUES ('368', 'Cardoso', 'Fernanda', '7575774415', 'FernandaCostaCardoso@rhyta.com', '$2y$10$IvsWLgkEn0EZH2sku.gNYe9rKTCMrR2iMtZmQQnuh4y0WzV6Oe9RW', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:53:59', '2023-11-20 07:53:59', NULL);
INSERT INTO `users` VALUES ('369', 'Fernanda', 'Cardoso', '7575774415', '2022-2312163', '$2y$10$aCtWeUyl8oto5utxJCZF2.V7OG9WPDOYlky6PrKWsQqlfLm16keHi', 'male', NULL, '2023-11-20', NULL, NULL, NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:00', '2024-05-14 12:57:01', '2024-05-14 12:57:01');
INSERT INTO `users` VALUES ('370', 'Azevedo', 'Vinicius', '4846710133', 'ViniciusFernandesAzevedo@jourrapide.com', '$2y$10$/dzCfj59OMTSnBuCk59GI.WHjVZJm9UO1sv2aVg4Nsi4caz3lloLC', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:00', '2023-11-20 07:54:00', NULL);
INSERT INTO `users` VALUES ('371', 'Vinicius', 'Azevedo', '4846710133', '2022-2312164', '$2y$10$6q0MxMsPFezUJiuf5sGw5.nDvBg.qsASj9.cS7gJiJfSv92E72VoO', 'male', '12/user/cd184Up3gE8l4WsVHTBnO1QHAKCvT1Kv4njos7jI.jpg', '2023-11-20', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:00', '2024-09-30 13:04:17', NULL);
INSERT INTO `users` VALUES ('372', 'Oliveira', 'Rebeca', '7016524974', 'RebecaRochaOliveira@einrot.com', '$2y$10$q2y6UOQWZHOLIYO2f4K0HeW4Q/bszs/OPxc6rcSgtta48eiumzu.S', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:01', '2023-11-20 07:54:01', NULL);
INSERT INTO `users` VALUES ('373', 'Rebeca', 'Oliveira', '7016524974', '2022-2312165', '$2y$10$76COk8imWXqJPWahNJe0cejx539zbko0lAz97LBzlTdwVGYeOIbTa', 'male', NULL, '2023-11-20', NULL, NULL, NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:01', '2024-05-14 12:57:01', '2024-05-14 12:57:01');
INSERT INTO `users` VALUES ('374', 'Dias', 'Julieta', '5085312029', 'JulietaMartinsDias@superrito.com', '$2y$10$ZfRbTI2TVcX94tNaz/UrGetwMeHgK4tUixmODI80/WtWtyoifNm8i', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:01', '2023-11-20 07:54:01', NULL);
INSERT INTO `users` VALUES ('375', 'Julieta', 'Dias', '5085312029', '2022-2312166', '$2y$10$LAoRifcOc3o9qSdBTwzYGuVOEW33Gy7..cNz2ecFjOIUt1YTPmjh.', 'male', NULL, '2023-11-20', NULL, NULL, NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:02', '2024-05-14 12:57:01', '2024-05-14 12:57:01');
INSERT INTO `users` VALUES ('376', 'Araujo', 'Matheus', '6262029477', 'MatheusRibeiroAraujo@fleckens.hu', '$2y$10$t2vVbmhMbLibXDpUWygTzexr/EEsnqpjfEAO5ozHAyNyGmEz.FnhK', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:02', '2023-11-20 07:54:02', NULL);
INSERT INTO `users` VALUES ('377', 'Matheus', 'Araujo', '6262029477', '2022-2312167', '$2y$10$xp.DGG9V1ANW9ID7NS0ZIuw04Y1jGWrQ3bAifUIO1s6DDSAm8RVge', 'male', '12/user/wT1m2a2LbrIDdJR41HyjbnBxiwoOjAmbyptkEHhU.jpg', '2023-11-20', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:02', '2024-09-30 13:04:17', NULL);
INSERT INTO `users` VALUES ('378', 'Castro', 'Nicolash', '2607053999', 'NicolashAraujoCastro@superrito.com', '$2y$10$5n0vsYEllqx2PUSoZc3NrO1w9/l6gO.ehtxO9IL/idcPy3mGE3CxS', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:03', '2023-11-20 07:54:03', NULL);
INSERT INTO `users` VALUES ('379', 'Nicolash', 'Castro', '2607053999', '2022-2312168', '$2y$10$TJ0ZsKFTfAR2UrPmjrp8eeeTqSnzR1BIVvD6bPi8/t7UYEAW1czwu', 'male', NULL, '2023-11-20', NULL, NULL, NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:03', '2024-05-14 12:57:01', '2024-05-14 12:57:01');
INSERT INTO `users` VALUES ('380', 'Alves', 'Rafael', '3143746446', 'RafaelCardosoAlves@superrito.com', '$2y$10$r1Zlvzjq7CTOwGe.5a/RvOpDD0DO/9v1nTpZIoAy2uc.2xkInlhHG', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:03', '2023-11-20 07:54:03', NULL);
INSERT INTO `users` VALUES ('381', 'Rafael', 'Alves', '3143746446', '2022-2312169', '$2y$10$5PRn.0EEwpZrMj/lu2t0iO4aTL9wy9usnG/7QSa2WmJOqqSEgCwdC', 'male', '12/user/VeSAKBPLFsGLesJvCEvlTCdXLqigTWxUSYpQ0pCP.jpg', '2023-11-20', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:04', '2024-09-30 13:04:17', NULL);
INSERT INTO `users` VALUES ('382', 'Ferreira', 'Guilherme', '5164232320', 'GuilhermeAlmeidaFerreira@armyspy.com', '$2y$10$8bLuccCZ8xDpPHWDaeyPyOrx2hbKcdnWDcNVK67hX1V.wdsI0QG12', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:04', '2023-11-20 07:54:04', NULL);
INSERT INTO `users` VALUES ('383', 'Guilherme', 'Ferreira', '5164232320', '2022-2312170', '$2y$10$IEj3s7bCst8bCvCXIpD80.qw9mNGHrnZ6E8nXlVC2pFe.i1pK6D5G', 'male', NULL, '2023-11-20', NULL, NULL, NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:04', '2024-05-14 12:57:27', '2024-05-14 12:57:27');
INSERT INTO `users` VALUES ('384', 'Santos', 'Kauan', '4345823055', 'KauanRibeiroSantos@rhyta.com', '$2y$10$sipUoKUfJjb5.P2H0nSwZeGGwwexv5T0EY7j.i2b0EezrrYWqzXQ2', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:05', '2023-11-20 07:54:05', NULL);
INSERT INTO `users` VALUES ('385', 'Kauan', 'Santos', '4345823055', '2022-2312171', '$2y$10$01UBXZovV9D7etd1XFeuEeuNP.p32FvNrxIw4cWVHhRLhEcRhhoIq', 'male', NULL, '2023-11-20', NULL, NULL, NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:05', '2024-05-14 12:57:01', '2024-05-14 12:57:01');
INSERT INTO `users` VALUES ('386', 'Cavalcanti', 'Julian', '3042080094', 'JulianRochaCavalcanti@jourrapide.com', '$2y$10$lSBQ7VuBS6mAWNM0ODfQeum9EFgRB2O4tO1ekvxMee4qyW0J8BCqy', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:05', '2023-11-20 07:54:05', NULL);
INSERT INTO `users` VALUES ('387', 'Julian', 'Cavalcanti', '3042080094', '2022-2312172', '$2y$10$dcUuoqj9gZ2mR9f3pzblpO4Y6gwmHqnpzB3Sxyf2usDK3cqEFJDeS', 'male', '12/user/OFnuNUjIZm4lza3UQa02zLKZeggHQZeXC91IsjjJ.jpg', '2023-11-20', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:06', '2024-09-30 13:04:17', NULL);
INSERT INTO `users` VALUES ('388', 'Pereira', 'Caua', '3373045081', 'CauaRibeiroPereira@gustr.com', '$2y$10$cFWLYiHpJhrlNduBZAcT4.tM87ADOz5jU/NMhKkCN1AP.xK3bUu2C', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:06', '2023-11-20 07:54:06', NULL);
INSERT INTO `users` VALUES ('389', 'Caua', 'Pereira', '3373045081', '2022-2312173', '$2y$10$RxDCO5DoHt97LXsS5F/uvOna.Y2rpAzcXtsmDz2PRJ1CxlU3Pz5/q', 'male', NULL, '2023-11-20', NULL, NULL, NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:06', '2024-05-14 12:57:27', '2024-05-14 12:57:27');
INSERT INTO `users` VALUES ('390', 'Ferreira', 'Thais', '4066814745', 'ThaisAraujoFerreira@rhyta.com', '$2y$10$oysN4TxuD8Hc7hY5HCu3e.Lfm/ACx1P4aQfYp/whjcDn3p/smTRdS', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:07', '2023-11-20 07:54:07', NULL);
INSERT INTO `users` VALUES ('391', 'Thais', 'Ferreira', '4066814745', '2022-2312174', '$2y$10$CFlPsebYuiPo8JkzuIGWWOL1IeYOoFPunr7i/saVKXsqfh4VF7Z5O', 'male', NULL, '2023-11-20', NULL, NULL, NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:07', '2024-05-14 12:57:27', '2024-05-14 12:57:27');
INSERT INTO `users` VALUES ('392', 'Pereira', 'Mateus', '3105664753', 'MateusAlvesPereira@einrot.com', '$2y$10$q4hGiel7TZsJMna9fDmJfuYy.M/pvJ8oXOS/I88LoHycsWB4PbsN.', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:08', '2023-11-20 07:54:08', NULL);
INSERT INTO `users` VALUES ('393', 'Thais', 'Pereira', '3105664753', '2022-2312175', '$2y$10$qYn0d9bPJteA7fPa8kZzOu6YBbyVARhEYZ7kuF2jj1922XF854pJm', 'male', NULL, '2023-11-20', NULL, NULL, NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:08', '2024-05-14 12:57:27', '2024-05-14 12:57:27');
INSERT INTO `users` VALUES ('394', 'Goncalves', 'Tomas', '8026104060', 'TomasBarrosGoncalves@cuvox.de', '$2y$10$ukbXfj.REfwZcif1IBKQ2eOlYNWgSpSLJoTbye790qgiINT7AQTqu', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:08', '2023-11-20 07:54:08', NULL);
INSERT INTO `users` VALUES ('395', 'Tomas', 'Goncalves', '8026104060', '2022-2312176', '$2y$10$088l1byZUM.bKRhM3S1QD.cEmwWKH4unlIJwkn7mBdHoqcqv4Se2.', 'male', NULL, '2023-11-20', NULL, NULL, NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:09', '2024-05-14 12:57:27', '2024-05-14 12:57:27');
INSERT INTO `users` VALUES ('396', 'Fernandes', 'Andre', '8636091242', 'AndreAlvesFernandes@gustr.com', '$2y$10$E5YUummXxP2ynruIUBPB8uFSyIuQ4sc8tA2knV/POpMT4faZz4PNq', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:09', '2023-11-20 07:54:09', NULL);
INSERT INTO `users` VALUES ('397', 'Andre', 'Fernandes', '8636091242', '2022-2312177', '$2y$10$DK6/sKwv/RkE3ez3AeIqDuvx/vwTThsnRuULoUCepH.EKnUKu2fxy', 'male', NULL, '2023-11-20', NULL, NULL, NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:09', '2024-05-14 12:57:27', '2024-05-14 12:57:27');
INSERT INTO `users` VALUES ('398', 'Ferreira', 'Felipe', '9529383180', 'FelipeCastroFerreira@cuvox.de', '$2y$10$3rJv7S0A1QNMJma5Rt.Syu1mGcXKcZkdTMyIWJ0ksvlJdgaMKX176', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:10', '2023-11-20 07:54:10', NULL);
INSERT INTO `users` VALUES ('399', 'Felipe', 'Ferreira', '9529383180', '2022-2312178', '$2y$10$aMvR1UDO5RpK/n7k4ElCI.9mMXkvJ0l3qf4VwxKkSezg.3UzhotZu', 'male', NULL, '2023-11-20', NULL, NULL, NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:10', '2024-05-14 12:57:27', '2024-05-14 12:57:27');
INSERT INTO `users` VALUES ('400', 'Barbosa', 'Gustavo', '6064639117', 'GustavoMeloBarbosa@jourrapide.com', '$2y$10$fPK9gOeV58vQVETVMn.pzuuKQhqbHLXdSNAA5Y2uOOH/hPKA.PZqG', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:10', '2023-11-20 07:54:10', NULL);
INSERT INTO `users` VALUES ('401', 'Gustavo', 'Barbosa', '6064639117', '2022-2312179', '$2y$10$.iTGC7muekqqgqKHf43tf.esHbaEYOnmvPXC2yh924OimrseF1Tj.', 'male', NULL, '2023-11-20', NULL, NULL, NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:11', '2024-05-14 12:57:27', '2024-05-14 12:57:27');
INSERT INTO `users` VALUES ('402', 'Lima', 'Nicolash', '4143587297', 'NicolashBarrosLima@rhyta.com', '$2y$10$XdWBC/bzQMEQrGX1Z7eEM.5uj/IHbWZ0kGp8VhV.YA5LNzwPPu.Ha', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:11', '2023-11-20 07:54:11', NULL);
INSERT INTO `users` VALUES ('403', 'Nicolash', 'Lima', '4143587297', '2022-2312180', '$2y$10$3xPSSxQgN4JzoJ.2ueNH4.4tzrSE0cSDz7JgzSMglKrcKyikA9USC', 'male', '12/user/DBTclKK5VNeE5w2Sf7eJEnZAMEf5U5MqI5aTRVjO.jpg', '2023-11-20', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:11', '2024-09-30 13:04:17', NULL);
INSERT INTO `users` VALUES ('404', 'Cunha', 'Diego', '7655523753', 'DiegoPintoCunha@dayrep.com', '$2y$10$kZ.XIOLsYJUTKrUD0hdx0.0xCbXYuBvrIz5V4ZDK2LDXQ.2fYGeGm', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:12', '2024-09-30 13:11:58', NULL);
INSERT INTO `users` VALUES ('405', 'Diego', 'Cunha', '7655523753', '2022-2312181', '$2y$10$hsr.7SMIv2LrZjiDmP.u5.E3X0IUXMrZS3jenRcoeEmoZIKfJ2apS', 'male', NULL, '2023-11-20', 'Room 4667781 Mayer CrossingKuasha', 'Room 4667781 Mayer CrossingKuasha', NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:12', '2024-05-14 12:57:27', '2024-05-14 12:57:27');
INSERT INTO `users` VALUES ('406', 'Azevedo', 'Vitoria', '6828418219', 'VitoriaMeloAzevedo@fleckens.hu', '$2y$10$ZOZ/C3UWKNpHCmSRlwHaMOrr81MWiOXy5xavhbIldYrqlPdkWQIC2', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:12', '2024-09-30 13:11:58', NULL);
INSERT INTO `users` VALUES ('407', 'Vitoria', 'Azevedo', '6828418219', '2022-2312182', '$2y$10$lyG/kkuzmuDu38JQL5uCCeSgRWg04CGojjm.Q8mSSXIdOOYUS0MPK', 'male', NULL, '2023-11-20', '8th Floor40043 Drewry CrossingHuayllo', '8th Floor40043 Drewry CrossingHuayllo', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:13', '2023-11-21 06:56:02', NULL);
INSERT INTO `users` VALUES ('408', 'Ferreira', 'Mateus', '2195106037', 'MateusGomesFerreira@dayrep.com', '$2y$10$YClwnWt/iQrfCJ17mfq05OfyrI3m2P71oGOUJWOSyi7nlJ0u4kP.K', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:13', '2024-09-30 13:11:58', NULL);
INSERT INTO `users` VALUES ('409', 'Mateus', 'Ferreira', '2195106037', '2022-2312183', '$2y$10$L/2s0CopctLu.39i0jUUX.zgdJh8jjIRq1BgteGJ/dq0gdjTJYbLu', 'male', NULL, '2023-11-20', 'Suite 6383936 Delaware WayMyrzakent', 'Suite 6383936 Delaware WayMyrzakent', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:13', '2023-11-21 06:55:39', NULL);
INSERT INTO `users` VALUES ('410', 'Souza', 'Enzo', '3602604974', 'EnzoAraujoSouza@einrot.com', '$2y$10$Kjm7iDBBRae/QCgWjvs6qemV.M0NNEi2fjKR7ywhub6FvSHJ/EWGC', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:14', '2024-09-30 13:11:58', NULL);
INSERT INTO `users` VALUES ('411', 'Enzo', 'Souza', '3602604974', '2022-2312184', '$2y$10$z6iNcpduMlWfdXdB06pR6.ueJJPprgc53uDccfLShetriyjcmy7u.', 'male', NULL, '2023-11-20', 'Suite 6383936 Delaware WayMyrzakent', 'Suite 6383936 Delaware WayMyrzakent', NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:14', '2024-05-14 12:57:27', '2024-05-14 12:57:27');
INSERT INTO `users` VALUES ('412', 'Santos', 'Tania', '2025581693', 'TaniaCunhaSantos@rhyta.com', '$2y$10$XP0gPoKEpT7xfvLPO1pf0OtFWLC7cD.aWJkOz2vvJWs9B5MqYbJtm', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:14', '2024-09-30 13:11:58', NULL);
INSERT INTO `users` VALUES ('413', 'Tania', 'Santos', '2025581693', '2022-2312185', '$2y$10$sJrjaqu/1ur3WPivCpfkrebViNK6iLH/ZwIQJA8qrYiWarwK2TVeu', 'male', NULL, '2023-11-20', 'Suite 6383936 Delaware WayMyrzakent', 'Suite 6383936 Delaware WayMyrzakent', NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:15', '2024-05-14 12:57:27', '2024-05-14 12:57:27');
INSERT INTO `users` VALUES ('414', 'Ribeiro', 'Nicolas', '4435480016', 'NicolasFerreiraRibeiro@rhyta.com', '$2y$10$4gDnuMmIMYdOBW0WcfmLcO3Fq2TpD1zpLGj8yi8czhyEGaJhv7/2S', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:15', '2023-11-20 07:54:15', NULL);
INSERT INTO `users` VALUES ('415', 'Nicolas', 'Ribeiro', '4435480016', '2022-2312186', '$2y$10$d4h1txSb8y1HnQmC2ZZQCOk5nqxHm2CRA.slp6zXHSsP0oSvrD9F6', 'male', NULL, '2023-11-20', NULL, NULL, NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:15', '2024-05-14 12:57:27', '2024-05-14 12:57:27');
INSERT INTO `users` VALUES ('416', 'Lima', 'Rebeca', '4015592403', 'RebecaCardosoLima@teleworm.us', '$2y$10$HLXt9spzrUZyoP7ggWUB1OG/FOISR0Vsp7lb/7y64GnLMR/CAiLPi', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:16', '2024-09-30 13:11:58', NULL);
INSERT INTO `users` VALUES ('417', 'Rebeca', 'Lima', '4015592403', '2022-2312187', '$2y$10$am1QEQT6ZRU7E4I3s23ql.xz.eMxFidxWKgoOU1P978PTvfiHLfs.', 'female', NULL, '2023-11-20', 'Apt 16064 Arizona WayRekovac', 'Apt 16064 Arizona WayRekovac', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:16', '2023-11-21 06:55:14', NULL);
INSERT INTO `users` VALUES ('418', 'Araujo', 'Kauan', '2024064718', 'KauanFerreiraAraujo@armyspy.com', '$2y$10$Qc/WJfJr10PCCzdb9osTe.OGe97qZzj/ef5FpCkgRpw/CrFi3EgVS', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:16', '2023-11-20 07:54:16', NULL);
INSERT INTO `users` VALUES ('419', 'Kauan', 'Araujo', '2024064718', '2022-2312188', '$2y$10$VyD8MB2atXzBhXv7x3qjIOClrUxbyuOkGi8d7aZBTwooG7kef.Fry', 'female', NULL, '2023-11-20', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:17', '2023-11-20 07:55:03', NULL);
INSERT INTO `users` VALUES ('420', 'Silva', 'Mateus', '9737494754', 'MateusCarvalhoSilva@armyspy.com', '$2y$10$Wd.YMxiqWhRF88ryT7LAfeEh03Qgn090KgZyS4B61mdOJPFOVCleq', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:17', '2023-11-20 07:54:17', NULL);
INSERT INTO `users` VALUES ('421', 'Mateus', 'Silva', '9737494754', '2022-2312189', '$2y$10$dvhg2V4mkqTv6xAHRdukUOXOgf8asKGwms63SVRN9yFyRqjErM4ya', 'female', NULL, '2023-11-20', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:17', '2023-11-20 07:55:03', NULL);
INSERT INTO `users` VALUES ('422', 'Martins', 'Miguel', '9102660503', 'MiguelPereiraMartins@dayrep.com', '$2y$10$DMM1tnUCE4bPTK1Bvrupq.9g7lpHH0jsYQEViPtqXxilcoKcUScIK', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:18', '2024-09-30 13:11:58', NULL);
INSERT INTO `users` VALUES ('423', 'Miguel', 'Martins', '9102660503', '2022-2312190', '$2y$10$aB8zJ211Dg9q5NfwpqRQtODb1he4ue40nB6b47ClWF3e8n26HI9dW', 'female', NULL, '2023-11-20', 'Room 1365727 Graceland CrossingXiaohekou', 'Room 1365727 Graceland CrossingXiaohekou', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:18', '2023-11-21 06:55:02', NULL);
INSERT INTO `users` VALUES ('424', 'Goncalves', 'Thiago', '8162295022', 'ThiagoCunhaGoncalves@teleworm.us', '$2y$10$XxyTcPBe1fxrAdYzN2uwq.f1z1hLPyaSlZ3WXBvYzufTGhNaocIF6', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:18', '2024-09-30 13:11:58', NULL);
INSERT INTO `users` VALUES ('425', 'Thiago', 'Goncalves', '8162295022', '2022-2312191', '$2y$10$oMvoRqTOoZENqwSrIeRL0uRnvB18XINVmD8OR.8nnfEe24OE5BsKO', 'female', NULL, '2023-11-20', 'Apt 1914 Lawn HillStorvreta', 'Apt 1914 Lawn HillStorvreta', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:18', '2023-11-21 06:54:50', NULL);
INSERT INTO `users` VALUES ('426', 'Costa', 'Sophia', '9177417125', 'SophiaCavalcantiCosta@einrot.com', '$2y$10$O5xzqsQDpK5M4lZJnJ0hjuGbkSS1RrpgEDv1qd5ydB1vlpMdrD4je', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:19', '2024-09-30 13:11:58', NULL);
INSERT INTO `users` VALUES ('427', 'Sophia', 'Costa', '9177417125', '2022-2312192', '$2y$10$e5z2rm06RxJqHuTZ3b.hI.4QciF.oXYgWJdtDTu7RHiuiXl2Z3DQi', 'female', NULL, '2023-11-20', 'Suite 631 Laurel CrossingFlorencio Sánchez', 'Suite 631 Laurel CrossingFlorencio Sánchez', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:19', '2023-11-21 06:54:38', NULL);
INSERT INTO `users` VALUES ('428', 'Lima', 'Diogo', '6788045554', 'DiogoCunhaLima@armyspy.com', '$2y$10$2VtJKEKr0B8zTXfKy9d9CuEarAj5axxJw9PKtOMcgywnU6hVK1N9a', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:19', '2024-09-30 13:11:58', NULL);
INSERT INTO `users` VALUES ('429', 'Diogo', 'Lima', '6788045554', '2022-2312193', '$2y$10$F2s32QmFOI0ptKnmfoyWfeXpeY4jyh91/bdvzggDaoSbjHAKC7ohS', 'female', NULL, '2023-11-20', 'Apt 51731098 Westend PointHaokou', 'Apt 51731098 Westend PointHaokou', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:20', '2023-11-21 06:54:18', NULL);
INSERT INTO `users` VALUES ('430', 'Correia', 'Laura', '9895294996', 'LauraLimaCorreia@rhyta.com', '$2y$10$JthwOKc6z/CbbuaWLQG40eRjSSzlVXq8boFjKk6NUSBSK2yMDyrLm', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:20', '2024-09-30 13:11:58', NULL);
INSERT INTO `users` VALUES ('431', 'Laura', 'Correia', '9895294996', '2022-2312194', '$2y$10$PN2vVsbWDS.Upj155PotsuLBnQ1rRf7v3utqil231kxgtTLhC4rTS', 'female', NULL, '2023-11-20', 'Apt 2400226 Rieder DriveTetovo', 'Apt 2400226 Rieder DriveTetovo', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:20', '2023-11-21 06:54:03', NULL);
INSERT INTO `users` VALUES ('432', 'Pereira', 'Davi', '5635743818', 'DaviPintoPereira@dayrep.com', '$2y$10$7fLffGMZ8idu3alz7t2rpemoDiK4RWLUqftL4waDoeFKLOVXAjFV2', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:21', '2024-09-30 13:11:58', NULL);
INSERT INTO `users` VALUES ('433', 'Davi', 'Pereira', '5635743818', '2022-2312195', '$2y$10$zErjf25PHmGf76hicdrxQuGphb7fydZL.JOOn8DH0cswij9bpbbZ2', 'female', NULL, '2023-11-20', '17th Floor64 Linden CircleBintang', '17th Floor64 Linden CircleBintang', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:21', '2023-11-21 06:53:30', NULL);
INSERT INTO `users` VALUES ('434', 'Castro', 'Joao', '2519315347', 'JoaoMartinsCastro@gustr.com', '$2y$10$/j/FGekOkI1xA/TfQ8O3Lu5o9WnNyZ9Yc.V1viLMHI6adJMTNXLjS', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:21', '2024-09-30 13:11:58', NULL);
INSERT INTO `users` VALUES ('435', 'Joao', 'Castro', '2519315347', '2022-2312196', '$2y$10$Pow1IkOSCjtRIHmolV4xTOpO26O2KGdY16XxL2pLu5mtIga.4ppqK', 'female', NULL, '2023-11-20', '18th Floor943 Eastwood AvenueMirny', '18th Floor943 Eastwood AvenueMirny', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:22', '2023-11-21 06:53:19', NULL);
INSERT INTO `users` VALUES ('436', 'Almeida', 'Kaua', '6822925498', 'KauaSilvaAlmeida@dayrep.com', '$2y$10$RPMVGHGED4hTycoi/tc9JeW6R7RFGwGEW1/Y0p9uAAer04b8P0OpO', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:22', '2024-09-30 13:11:58', NULL);
INSERT INTO `users` VALUES ('437', 'Kaua', 'Almeida', '6822925498', '2022-2312197', '$2y$10$UfBSo/hihktStbLHfDY7yOJFsFgDdBuiUNeJf3Y/mEBaootLiw14W', 'female', NULL, '2023-11-20', 'Apt 14542690 Mockingbird TerraceLa Libertad', 'Apt 14542690 Mockingbird TerraceLa Libertad', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:22', '2023-11-21 06:53:07', NULL);
INSERT INTO `users` VALUES ('438', 'Pinto', 'Erick', '3038648510', 'ErickBarbosaPinto@rhyta.com', '$2y$10$xCBvZQZmvt9HCaR9DLivC.NCRGFDj6UCNIap1R5sMOzKHRtD.IJXG', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:23', '2024-09-30 13:11:58', NULL);
INSERT INTO `users` VALUES ('439', 'Erick', 'Pinto', '3038648510', '2022-2312198', '$2y$10$jovOUpkWclPZ0yZ4ZB.c.u.XK22L2aIQPXwXQJCxfi7xzZ8ppiITW', 'female', NULL, '2023-11-20', 'Apt 108105 Ridgeway DriveLumbang', 'Apt 108105 Ridgeway DriveLumbang', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:23', '2023-11-21 06:52:57', NULL);
INSERT INTO `users` VALUES ('440', 'Ribeiro', 'Fabio', '2484899844', 'FabioSantosRibeiro@fleckens.hu', '$2y$10$wmAWZGLq3hxjk87msnQSRuwwHrVKXCpRNYJM9t83VeiPlywKbeAce', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:23', '2024-09-30 13:11:58', NULL);
INSERT INTO `users` VALUES ('441', 'Fabio', 'Ribeiro', '2484899844', '2022-2312199', '$2y$10$6lS0PzbfXNCfxb2qMl3BuudBwQT09PEWHAoY4UrqjY6I3F5ENR3um', 'female', NULL, '2023-11-20', '10th Floor4017 Eliot DriveLameiras', '10th Floor4017 Eliot DriveLameiras', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:24', '2023-11-21 06:52:41', NULL);
INSERT INTO `users` VALUES ('442', 'Correia', 'Daniel', '2709653680', 'DanielPereiraCorreia@cuvox.de', '$2y$10$mMaLNmNLBETyzsKjukTaDOHThLDHDnThHkO1E/Yq7hSoj4cTVLu4u', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:24', '2024-09-30 13:11:58', NULL);
INSERT INTO `users` VALUES ('443', 'Daniel', 'Correia', '2709653680', '2022-2312200', '$2y$10$Ih0dh6bUIdy3rXfjzj5stuHQTuiQZ.iKJHFOfQFOIZU3XEI/Xp03S', 'female', NULL, '2023-11-20', 'PO Box 794314 Sachs PointSkärholme', 'PO Box 794314 Sachs PointSkärholme', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:24', '2023-11-21 06:52:26', NULL);
INSERT INTO `users` VALUES ('444', 'Oliveira', 'Thiago', '4044010282', 'ThiagoCarvalhoOliveira@gustr.com', '$2y$10$hKu8K5InL4SGewTyqMv.COxejrTVeVQW3c7qzavn4IciX8R1HIzr2', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:25', '2024-09-30 13:11:58', NULL);
INSERT INTO `users` VALUES ('445', 'Thiago', 'Oliveira', '4044010282', '2022-2312201', '$2y$10$mM.qN85TZuoQxO.QdSu0f.IO9XinnH5bIHE/JzlHou3KGbEro/rp6', 'female', NULL, '2023-11-20', 'PO Box 230635417 Maryland PassBonpland', 'PO Box 230635417 Maryland PassBonpland', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:25', '2023-11-21 06:52:14', NULL);
INSERT INTO `users` VALUES ('446', 'Azevedo', 'Carlos', '2482987687', 'CarlosCastroAzevedo@cuvox.de', '$2y$10$I7MgefawUmEVe3l/Z9KVG.TvGStQ/Qcgm6RLQYLPuaVD5OLhntRFO', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:25', '2024-09-30 13:11:58', NULL);
INSERT INTO `users` VALUES ('447', 'Carlos', 'Azevedo', '2482987687', '2022-2312202', '$2y$10$GKutm.Ey5VtIhfw0jYJtWeE6342XSwOKMr.ftC7Bb00lwchqsTVWC', 'female', NULL, '2023-11-20', 'PO Box 777907 Del Sol Point', 'PO Box 777907 Del Sol Point', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:26', '2023-11-21 06:51:08', NULL);
INSERT INTO `users` VALUES ('448', 'Cunha', 'Matheus', '2259321328', 'MatheusAlmeidaCunha@superrito.com', '$2y$10$/jbMmY9rjan.PWWd639VPu7onWf.YO9pce/3oO2NL4ESC6MFKu/MG', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:26', '2024-09-30 13:11:58', NULL);
INSERT INTO `users` VALUES ('449', 'Matheus', 'Cunha', '2259321328', '2022-2312203', '$2y$10$d5hOeflVz8QVYB6zMWhDaOSmi57SjRUFhEMcN84bcrSduC6XMwGPq', 'female', NULL, '2023-11-20', '5 Declaration Lane', '5 Declaration Lane', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:26', '2023-11-21 06:45:43', NULL);
INSERT INTO `users` VALUES ('450', 'Gomes', 'Samuel', '9015346120', 'SamuelPintoGomes@einrot.com', '$2y$10$EULU74HqO5p4dSuKlKoDMucm11zsp/p/.U2RSyuNT.oz3DgmQXopW', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:27', '2024-09-30 13:11:58', NULL);
INSERT INTO `users` VALUES ('451', 'Samuel', 'Gomes', '9015346120', '2022-2312204', '$2y$10$nA8OzRWkSrYYw/aToTBLQOVLUG880qde/ehYXjYFAC46dLnFuHxdu', 'female', NULL, '2023-11-20', '0071 Center Point', '0071 Center Point', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:27', '2023-11-21 06:45:31', NULL);
INSERT INTO `users` VALUES ('452', 'Melo', 'Jose', '9122675548', 'JoseCostaMelo@jourrapide.com', '$2y$10$EQI4ydBvntsvLuZFlBKxKuyuXZAzsJfaUOjDiORW4I4H3I5zeKnKi', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:27', '2024-09-30 13:11:58', NULL);
INSERT INTO `users` VALUES ('453', 'Jose', 'Melo', '9122675548', '2022-2312205', '$2y$10$XmNPx6S40dVoLeSBLWOLGu/xNG.XsMH2af1JXbKb5xtK2l8YlnvXW', 'female', NULL, '2023-11-20', '9 Menomonie Drive', '9 Menomonie Drive', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:28', '2023-11-21 06:45:19', NULL);
INSERT INTO `users` VALUES ('454', 'Pereira', 'Vitor', '3145445393', 'VitorBarbosaPereira@teleworm.us', '$2y$10$s5yhjPxIc1rV4HhSnR30HOKUhlK7XCkSHgO/m.HsxghOYHfS3maeq', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:28', '2023-11-20 07:54:28', NULL);
INSERT INTO `users` VALUES ('455', 'Vitor', 'Pereira', '3145445393', '2022-2312206', '$2y$10$cwI/WlGLdidn3kkrKzvQWOTOSLblsthlo7MbRkvd5uAQDgXQ.7LK.', 'female', NULL, '2023-11-20', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:28', '2023-11-20 07:55:03', NULL);
INSERT INTO `users` VALUES ('456', 'Santos', 'Lucas', '5739458203', 'LucasOliveiraSantos@dayrep.com', '$2y$10$QpaIoRmmF4HBu8GG4RWzAeV0L5X1yodIz2fzcUpC4rPSqsnf0GLw6', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:29', '2024-09-30 13:11:58', NULL);
INSERT INTO `users` VALUES ('457', 'Lucas', 'Santos', '5739458203', '2022-2312207', '$2y$10$7RqHEwuDFO2efefdUVYEVectGbyAfur26qkW7k3LhwLTRFwBT15py', 'female', NULL, '2023-11-20', 'Ap #335-9012 Pretium St.', 'Ap #335-9012 Pretium St.', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:29', '2023-11-21 06:45:01', NULL);
INSERT INTO `users` VALUES ('458', 'Rodrigues', 'Nicolash', '8437651527', 'NicolashSantosRodrigues@fleckens.hu', '$2y$10$HvaApMao6v10MMOtjz1gjezgOmyNkFldD1Kzq3xPOLavNhxJ5m4/.', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:29', '2024-09-30 13:11:59', NULL);
INSERT INTO `users` VALUES ('459', 'Nicolash', 'Rodrigues', '8437651527', '2022-2312208', '$2y$10$fhD3Inj14hNV1h/cYhAkDugnT46nWa7xv9mqxLkrM2jMKAdiZZTN.', 'female', NULL, '2023-11-20', 'Ap #740-5313 Rutrum Rd.', 'Ap #740-5313 Rutrum Rd.', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:30', '2023-11-21 06:44:46', NULL);
INSERT INTO `users` VALUES ('460', 'Castro', 'Matheus', '7063277435', 'MatheusPintoCastro@dayrep.com', '$2y$10$ctQe6rFL41lVF/jhR5Z4Ze0YhN3iD99ilfdeJb7aa.xzenqXraRfS', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:30', '2024-09-30 13:11:59', NULL);
INSERT INTO `users` VALUES ('461', 'Matheus', 'Castro', '7063277435', '2022-2312209', '$2y$10$WPzYD7RO6sTnOzAhfnuKpOmLcQoopuD3SMO0.hhcSbxSmqB7QxyvO', 'female', '12/user/eQlwBg4RAji1crzmVXrwszIBpwtHzlFcUmRTR5l5.jpg', '2023-11-20', 'P.O. Box 332, 9554 Sed Rd.', 'P.O. Box 332, 9554 Sed Rd.', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:31', '2024-09-30 13:04:17', NULL);
INSERT INTO `users` VALUES ('462', 'Rodrigues', 'Rafael', '7084632716', 'RafaelBarrosRodrigues@fleckens.hu', '$2y$10$P.y59jxORjH.OMEBFRM2d.7Jlvyal12OWROReIAKJbW42gYMe3m5.', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:31', '2024-09-30 13:11:59', NULL);
INSERT INTO `users` VALUES ('463', 'Rafael', 'Rodrigues', '7084632716', '2022-2312210', '$2y$10$AvSYHOdAn49R7eooQVM.SO/dgVEzs6/IN.7.lx9L0/VHy.zZKLrLC', 'female', NULL, '2023-11-20', '612-4911 Placerat. Avenue', '612-4911 Placerat. Avenue', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:31', '2023-11-21 06:44:20', NULL);
INSERT INTO `users` VALUES ('464', 'Barbosa', 'Vinicius', '6034859842', 'ViniciusAlmeidaBarbosa@cuvox.de', '$2y$10$aSNAhtTl6/bncRJHSx.o1uDQMFFZnKV88.v8zexu7oEX7yX69d6qe', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:32', '2024-09-30 13:11:59', NULL);
INSERT INTO `users` VALUES ('465', 'Vinicius', 'Barbosa', '6034859842', '2022-2312211', '$2y$10$Jn.4zl9BMcHN0fl5YQyRwee5T4wNmRMGbQTXtyZ58IRuftdgInVda', 'female', NULL, '2023-11-20', '7560 Feugiat Rd.', '7560 Feugiat Rd.', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:32', '2023-11-21 06:44:11', NULL);
INSERT INTO `users` VALUES ('466', 'Sousa', 'Vitor', '2016102973', 'VitorSantosSousa@jourrapide.com', '$2y$10$Lc1XAVqlWe/D6LvRuo/3eeXhL4x.XI3cckRlkXdLEs6By02QspErq', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:33', '2024-09-30 13:11:59', NULL);
INSERT INTO `users` VALUES ('467', 'Vitor', 'Sousa', '2016102973', '2022-2312212', '$2y$10$CxwysmVuAnrCSz9aSjXge.OTglZhnlDEjePT7UqVp.ZsoCgu/6xXK', 'male', NULL, '2023-11-20', '75 Kensington Alley', '34 Lakewood Alley', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-20 07:54:33', '2023-11-21 06:44:00', NULL);
INSERT INTO `users` VALUES ('469', 'Ulysses', 'Gerace', '8200727077', 'UlyssesAGerace@teleworm.us', '$2y$10$9UzwjrBbPLJ1YylbbvgP5u6GKyQ4vmEavo97d7xanNpDUi.bn4PUi', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:03', '2023-11-22 12:23:03', NULL);
INSERT INTO `users` VALUES ('470', 'Eduardo', 'Correia', '8200727077', '2022-2312213', '$2y$10$tqxgSpBmpIGIQp2Kge1bqOHOO6OWyhDj150MrY31NPU1agsbzY41a', 'male', NULL, '2010-09-10', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:03', '2023-11-22 12:23:51', NULL);
INSERT INTO `users` VALUES ('471', 'Micheal', 'Sigala', '8200727077', 'MichealJSigala@superrito.com', '$2y$10$vHRdnS9pTu0wgXqga9ugfudPqPUWH3iUjgzCGEzFIB7x2siWMoDy6', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:04', '2023-11-22 12:23:04', NULL);
INSERT INTO `users` VALUES ('472', 'Sarah', 'Melo', '8200727077', '2022-2312214', '$2y$10$3.Oaa.NGaRBBaO2Mcie.vet73S3OtCWcEeUUQvd1eR7aQrkqe45ma', 'female', NULL, '2011-07-06', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:04', '2023-11-22 12:23:51', NULL);
INSERT INTO `users` VALUES ('473', 'James', 'Harris', '8200727077', 'JamesSHarris@jourrapide.com', '$2y$10$3nRtReOzN2k8S3YRVll8O.d/gIgyx2Gm97FxRZtaao7s5wR5ssgC.', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:04', '2023-11-22 12:23:04', NULL);
INSERT INTO `users` VALUES ('474', 'Nicolas', 'Silva', '8200727077', '2022-2312215', '$2y$10$dSzIHDCBC7zyGBE2WQ4yw.6bN8AwOVIgnStxSMb.Rr2qBnZH/JsY6', 'male', NULL, '2013-05-23', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:05', '2023-11-22 12:23:51', NULL);
INSERT INTO `users` VALUES ('475', 'Anna', 'Greenawalt', '8200727077', 'AnnaMGreenawalt@armyspy.com', '$2y$10$RT2VS75isf7gvPgPFQihSe1YmkJY6iG7HBsJDkPmMsB1YplzmPuv2', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:05', '2023-11-22 12:23:05', NULL);
INSERT INTO `users` VALUES ('476', 'Larissa', 'Castro', '8200727077', '2022-2312216', '$2y$10$N69v1QISzbQF2/U03/wKSe8R8xV8fWEi5GF2AwPoirSvFAVLgzjl2', 'female', NULL, '2013-05-05', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:05', '2023-11-22 12:23:51', NULL);
INSERT INTO `users` VALUES ('477', 'Rodney', 'Jones', '8200727077', 'RodneyCJones@armyspy.com', '$2y$10$msAEhl6jpeME5P4FtuJANe7Ovsj1N8LVFyyll3NOznUzLLnT8Qox2', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:06', '2023-11-22 12:23:06', NULL);
INSERT INTO `users` VALUES ('478', 'Fábio', 'Alves', '8200727077', '2022-2312217', '$2y$10$vbBQxeJATqYEcNEhuLGG0uT/oJ1enyF2UZFi87bh28kLzAr2eMIgW', 'male', NULL, '2012-12-28', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:06', '2023-11-22 12:23:51', NULL);
INSERT INTO `users` VALUES ('479', 'Paulette', 'Burrow', '8200727077', 'PauletteKBurrow@einrot.com', '$2y$10$YCb4u/RdfY/abQVRzM4Ut.Quh8O4ufB.WT1H5p4i4f8Ci5pAiLSXG', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:06', '2023-11-22 12:23:06', NULL);
INSERT INTO `users` VALUES ('480', 'Diogo', 'Alves', '8200727077', '2022-2312218', '$2y$10$BVX8wXsRSm6NDgdX1/7FQegdMJA.en98cHPq4Aur2lHWM8LKwxcoa', 'male', NULL, '2008-01-09', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:07', '2023-11-22 12:23:51', NULL);
INSERT INTO `users` VALUES ('481', 'Hannah', 'Schmitt', '8200727077', 'HannahASchmitt@dayrep.com', '$2y$10$gXd8Uhw3snEZBOVFI5TpS.fMUAEzvOi1naBNrbIs.Cdr9/zMl7ZRa', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:07', '2023-11-22 12:23:07', NULL);
INSERT INTO `users` VALUES ('482', 'Kauê', 'Cavalcanti', '8200727077', '2022-2312219', '$2y$10$cYRmwjiZbDXasaPP9iaD8ec8G7xk6XODu5Dwl18N7znQHkzHopJvO', 'male', NULL, '2015-10-29', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:07', '2023-11-22 12:23:51', NULL);
INSERT INTO `users` VALUES ('483', 'Alfred', 'Shafer', '8200727077', 'AlfredRShafer@jourrapide.com', '$2y$10$WpyxB8tqIupiEhUjJczUk.xADD1bNZxv35mM5oOznBoHxoytjziui', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:08', '2023-11-22 12:23:08', NULL);
INSERT INTO `users` VALUES ('484', 'Fábio', 'Rodrigues', '8200727077', '2022-2312220', '$2y$10$J2qetefGiO9Iayb/7I9nrukLZzPbLDf0XvSE0azr16cjw1WLQo7K2', 'male', NULL, '2003-01-01', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:08', '2023-11-22 12:23:51', NULL);
INSERT INTO `users` VALUES ('485', 'John', 'Cervantes', '8200727077', 'JohnJCervantes@jourrapide.com', '$2y$10$CfMGj0hZopK.EUPL6OijwuaEJgN9s2WdGu.D5iqHfZDNG4LxOEc9W', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:08', '2023-11-22 12:23:08', NULL);
INSERT INTO `users` VALUES ('486', 'Laura', 'Ribeiro', '8200727077', '2022-2312221', '$2y$10$Ch6xHgVwp.pRH0CI.YDOR.MkkakDiFc4LUY637SUpWIsI4wy4DXB2', 'female', NULL, '2009-12-25', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:09', '2023-11-22 12:23:51', NULL);
INSERT INTO `users` VALUES ('487', 'Russell', 'Petersen', '8200727077', 'RussellLPetersen@rhyta.com', '$2y$10$0RXTbLzmYTHvXs0oFd/HSe6coc6YTz9tfZcSMreyVp3qKSRnYKYdW', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:09', '2023-11-22 12:23:09', NULL);
INSERT INTO `users` VALUES ('488', 'Marisa', 'Barros', '8200727077', '2022-2312222', '$2y$10$ED68lN5QrxsMtAJ4c1Jlke4av3NheL7nRDXOeI.8he6n30GyMl9e.', 'female', NULL, '2006-02-05', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:09', '2023-11-22 12:23:51', NULL);
INSERT INTO `users` VALUES ('489', 'Tim', 'Brooks', '8200727077', 'TimRBrooks@gustr.com', '$2y$10$PBmWJvgS3jq.QWYuitATLOl94ScTf2iPk1SBQKlr/DfPvCaTvlklG', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:10', '2023-11-22 12:23:10', NULL);
INSERT INTO `users` VALUES ('490', 'Lucas', 'Sousa', '8200727077', '2022-2312223', '$2y$10$6hxW2dx8aZ94gmxV7lw54us915GJs4xO5fejK.jV0WG4DOj3UeW1i', 'male', NULL, '2011-02-14', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:10', '2023-11-22 12:23:51', NULL);
INSERT INTO `users` VALUES ('491', 'Patricia', 'Chavez', '8200727077', 'PatriciaSChavez@fleckens.hu', '$2y$10$MBYP96X/EL65BaBhrruySe0kBCPgDmTl.fDij8Ufl9cZSUq135Nj.', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:10', '2023-11-22 12:23:10', NULL);
INSERT INTO `users` VALUES ('492', 'Alex', 'Almeida', '8200727077', '2022-2312224', '$2y$10$uVg92.I8oE6Ib.XOb5W28O0Y0GJm1uTU7skIl/lfUMtqjKZGeso/q', 'male', NULL, '2003-10-27', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:11', '2023-11-22 12:23:51', NULL);
INSERT INTO `users` VALUES ('493', 'Edward', 'Jones', '8200727077', 'EdwardSJones@armyspy.com', '$2y$10$AsOF.eRPyraCUVVT4BsPgOQD90bYfDCWbQGjWkHA2bzcWvmoAO3Ne', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:11', '2023-11-22 12:23:11', NULL);
INSERT INTO `users` VALUES ('494', 'Pedro', 'Sousa', '8200727077', '2022-2312225', '$2y$10$3eYS/q1BkW5zGewBeqXqduDcT5GI5NIpAnGsHZJJHvQSMtGC0y4Jq', 'male', NULL, '2004-06-14', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:11', '2023-11-22 12:23:51', NULL);
INSERT INTO `users` VALUES ('495', 'Tamra', 'Stewart', '8200727077', 'TamraRStewart@superrito.com', '$2y$10$L.OJP8mY2xTVYYFkBRv8CuUxQ1E.nNby2pZqGamr7KZmDL8Hypdcy', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:12', '2023-11-22 12:23:12', NULL);
INSERT INTO `users` VALUES ('496', 'Estevan', 'Pinto', '8200727077', '2022-2312226', '$2y$10$BXi7mdgXQvwzoX.b1csv9.X.UVA75atzq27nqIQ9gz9v37wCPScBW', 'male', NULL, '2011-10-29', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:12', '2023-11-22 12:23:51', NULL);
INSERT INTO `users` VALUES ('497', 'Tiffany', 'Barbieri', '8200727077', 'TiffanyDBarbieri@teleworm.us', '$2y$10$.365W.181US7MZEwqfu9zueoyySvfkLq5zPYZ3G2tJ.lTCLzJ1VVi', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:12', '2023-11-22 12:23:12', NULL);
INSERT INTO `users` VALUES ('498', 'Diego', 'Martins', '8200727077', '2022-2312227', '$2y$10$9Mj6h3r0yWZBWtNjHhUO6O0qeHpBRUVdGDBna1I1dnBqKQUr0F8PG', 'male', NULL, '2013-11-11', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:13', '2023-11-22 12:23:51', NULL);
INSERT INTO `users` VALUES ('499', 'Alfred', 'Bell', '8200727077', 'AlfredBBell@teleworm.us', '$2y$10$aurcL0rUb2yNGy6AyeZjGO7ftayvc5NM1vA199K/73QorixsPcdwm', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:13', '2023-11-22 12:23:13', NULL);
INSERT INTO `users` VALUES ('500', 'Miguel', 'Barbosa', '8200727077', '2022-2312228', '$2y$10$sVfidHHNnWPQP8APim0j5./DsZtVljhx/cEb40mcNIIVi3FqINpwi', 'male', NULL, '2012-01-19', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:13', '2023-11-22 12:23:51', NULL);
INSERT INTO `users` VALUES ('501', 'Linh', 'Hutchins', '8200727077', 'LinhMHutchins@fleckens.hu', '$2y$10$zI7VbdEJRISN2ZofbN1dNOQZrVR61KGmzMSiub1gbPEjWsQ5c9UVm', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:14', '2023-11-22 12:23:14', NULL);
INSERT INTO `users` VALUES ('502', 'José', 'Rodrigues', '8200727077', '2022-2312229', '$2y$10$D5umy.yUZV.qAMAxYDDaPOf/xs6FOjoAYZ.VqpX1h8D.OEz4N0InS', 'male', NULL, '2009-03-17', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:14', '2023-11-22 12:23:51', NULL);
INSERT INTO `users` VALUES ('503', 'Daniel', 'Schutz', '8200727077', 'DanielPSchutz@einrot.com', '$2y$10$V7b0ui6rS26ij2QgR7j8j.xgQ9MAu49uceMOSuvCuLsS.wC5pHYY2', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:14', '2023-11-22 12:23:14', NULL);
INSERT INTO `users` VALUES ('504', 'João', 'Correia', '8200727077', '2022-2312230', '$2y$10$KlZdXrzZeqlTuDm4s6Ij6edzvkkyNDGnddsvMHUTk9OMUATGiPEUG', 'male', NULL, '2014-02-21', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:15', '2023-11-22 12:23:51', NULL);
INSERT INTO `users` VALUES ('505', 'Jerry', 'Forester', '8200727077', 'JerryEForester@einrot.com', '$2y$10$4oPAp/gOpsQZT2odJuK3C.IcRqr6H1CMBnQra3BrsC.p/iiwegIW2', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:15', '2023-11-22 12:23:15', NULL);
INSERT INTO `users` VALUES ('506', 'Erick', 'Pereira', '8200727077', '2022-2312231', '$2y$10$zed1Z5HoOrZJGrwI2RUeveoSHL1YtGtspjq.WybvVlPmTq/Ahp9Iq', 'male', NULL, '2006-03-27', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:15', '2023-11-22 12:23:51', NULL);
INSERT INTO `users` VALUES ('507', 'Chas', 'Jacob', '8200727077', 'ChasDJacob@gustr.com', '$2y$10$58eg2MQki5c0ZQH59bcDguTwGviU5IJzOwWlaj0tpM.3CihRfc02W', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:16', '2023-11-22 12:23:16', NULL);
INSERT INTO `users` VALUES ('508', 'Julian', 'Silva', '8200727077', '2022-2312232', '$2y$10$KTRxFNiplRJcYRZGjnqAw.yiru8g4ec/cLr02.dOsBUCqZibYAd8C', 'male', NULL, '2007-04-25', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:16', '2023-11-22 12:23:51', NULL);
INSERT INTO `users` VALUES ('509', 'Howard', 'McCraw', '8200727077', 'HowardDMcCraw@cuvox.de', '$2y$10$p1nM1FM.yZn8tXgQp7kNJup5n4iCHhzf1UgA6pGvznJNsvmI5lOoi', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:16', '2023-11-22 12:23:16', NULL);
INSERT INTO `users` VALUES ('510', 'Luís', 'Azevedo', '8200727077', '2022-2312233', '$2y$10$DQncirDUl9PCRSLT0SrBp.xy43Vwx/9GOqie5MwaaSoeHrEGRsYm6', 'male', NULL, '2005-06-29', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:17', '2023-11-22 12:23:51', NULL);
INSERT INTO `users` VALUES ('511', 'Valerie', 'Reed', '8200727077', 'ValerieLReed@teleworm.us', '$2y$10$EkD6d7Pz7vzGXBRgOdK9DOs51xJ.96qbF7FgYXDsGES4dZUyCUd9a', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:17', '2023-11-22 12:23:17', NULL);
INSERT INTO `users` VALUES ('512', 'Nicole', 'Santos', '8200727077', '2022-2312234', '$2y$10$oCGTT2HgaY2gia40Dxv2PuXrmuVIWk4KxtapBRAa9LMGnRdh4kgvi', 'female', NULL, '2005-07-28', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:17', '2023-11-22 12:23:51', NULL);
INSERT INTO `users` VALUES ('513', 'Rubi', 'Medina', '8200727077', 'RubiHMedina@rhyta.com', '$2y$10$KH.t.sl.GbUTsC2RF4dYFe/YnHL/TaPIQZC2/7Yh0kiCycheTcsY6', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:18', '2023-11-22 12:23:18', NULL);
INSERT INTO `users` VALUES ('514', 'Clara', 'Pinto', '8200727077', '2022-2312235', '$2y$10$uUQr3xfZ1GRqjmTLBTV1YOjmhgDngZhIdBaKLNQBQ2sq3pbL/KJJS', 'female', NULL, '2006-10-14', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:18', '2023-11-22 12:23:51', NULL);
INSERT INTO `users` VALUES ('515', 'Stephen', 'Meyer', '8200727077', 'StephenJMeyer@armyspy.com', '$2y$10$yzY98fQnJXbUkT2.9IQrnuybPpuZ9p0/BOd3mOE3GXpi/jqVwAlsC', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:18', '2023-11-22 12:23:18', NULL);
INSERT INTO `users` VALUES ('516', 'Julieta', 'Ferreira', '8200727077', '2022-2312236', '$2y$10$8JN/TNPB/Hzcb2xCby6HN.rrNTjvTdYjbCGjtb6oZ6U2lI9xvmJje', 'female', NULL, '2005-03-02', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:18', '2023-11-22 12:23:51', NULL);
INSERT INTO `users` VALUES ('517', 'Justin', 'Dawson', '8200727077', 'JustinNDawson@gustr.com', '$2y$10$niV6/p9QV.iICPrEfOPRTOpLVm6l0pO3EGO/h3Xh/CRsFSqiYD/0q', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:19', '2023-11-22 12:23:19', NULL);
INSERT INTO `users` VALUES ('518', 'Kai', 'Cavalcanti', '8200727077', '2022-2312237', '$2y$10$UY3CMAz2QX8ZMbRrUrKq9ewVbk5zGOjujUDmhdo555yZfDuBcjRLK', 'male', NULL, '2002-11-28', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:19', '2023-11-22 12:23:51', NULL);
INSERT INTO `users` VALUES ('519', 'Grace', 'Weekley', '8200727077', 'GraceMWeekley@rhyta.com', '$2y$10$OrVSJ8OzJR4tWWHlTBireOq28W5TLBXPOPz8m86cMRergfE66HC2y', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:19', '2023-11-22 12:23:19', NULL);
INSERT INTO `users` VALUES ('520', 'Otávio', 'Fernandes', '8200727077', '2022-2312238', '$2y$10$HwGANKFs5oLifnA8mk6E1OrR3RmrkUJQP2SpBGfKX3Q9ca1AA0XDi', 'male', NULL, '2009-09-24', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:20', '2023-11-22 12:23:51', NULL);
INSERT INTO `users` VALUES ('521', 'Lela', 'Orozco', '8200727077', 'LelaTOrozco@jourrapide.com', '$2y$10$bddYzG6vF8CuCEDlNGwxs.wdIy1.LRrTZnE6anPpGhKbFRvdeKGd2', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:20', '2023-11-22 12:23:20', NULL);
INSERT INTO `users` VALUES ('522', 'Brenda', 'Almeida', '8200727077', '2022-2312239', '$2y$10$tBWHyHltaJ07CxKHCgTK5.9oAB4NtkYYzS8gTOMe92TVedbJMgCWC', 'female', NULL, '2012-11-15', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:20', '2023-11-22 12:23:51', NULL);
INSERT INTO `users` VALUES ('523', 'Adam', 'Linkous', '8200727077', 'AdamBLinkous@superrito.com', '$2y$10$Awhs4Jt7Qr9PPfN9DNthDu6dle73.tPnKslAYOMRZIZaQnafT3Tq2', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:21', '2023-11-22 12:23:21', NULL);
INSERT INTO `users` VALUES ('524', 'Matheus', 'Cunha', '8200727077', '2022-2312240', '$2y$10$OQrcIl7aB6fDTLDJe5DyTu6AceSkycnbDK1tmDPWnQaYqL8mPCsY6', 'male', NULL, '2006-06-09', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:21', '2023-11-22 12:23:51', NULL);
INSERT INTO `users` VALUES ('525', 'Susan', 'Romano', '8200727077', 'SusanTRomano@armyspy.com', '$2y$10$7sP.vwo7YdvtZeoeMUgIXeQcehHdGdR4bJw4Nl49QVdEk0.5QSlja', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:21', '2023-11-22 12:23:21', NULL);
INSERT INTO `users` VALUES ('526', 'Lara', 'Cardoso', '8200727077', '2022-2312241', '$2y$10$5YovUfQ6nIIgWwnrcidqHuHj4LWLiv/YyJ2Mg7k7AXll60LiHvKoK', 'female', NULL, '2011-10-08', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:23:22', '2023-11-22 12:23:51', NULL);
INSERT INTO `users` VALUES ('527', 'Elena', 'Fryer', '8200727077', 'ElenaRFryer@dayrep.com', '$2y$10$uaN2jol1YXTwm/QY5HVR/uTBbLtSdOMwm5oJCERPdlqZtSpo1yliW', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:22', '2023-11-22 12:36:22', NULL);
INSERT INTO `users` VALUES ('528', 'Kaue', 'Fernandes', '8200727077', '2022-2312242', '$2y$10$Bta5wDRa0KEv13pmZYCDZOHO8pKkIj75CIZC/EWYvc8gPbFK4P1mW', 'male', NULL, '2007-03-23', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:23', '2023-11-22 12:37:14', NULL);
INSERT INTO `users` VALUES ('529', 'Christopher', 'Schoenberger', '8200727077', 'ChristopherPSchoenberger@dayrep.com', '$2y$10$oq4MIUiLaJKARvL1nare5.WcXL4BlzI1MzdzmX1T7Kw2rfW1K0jd6', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:23', '2023-11-22 12:36:23', NULL);
INSERT INTO `users` VALUES ('530', 'Giovana', 'Castro', '8200727077', '2022-2312243', '$2y$10$SOgqiuX1xsC2q00hBkcq6OcFzUuu2Hl7DA/2pU2sO0jKQ3qi.rrQa', 'female', NULL, '2010-03-09', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:23', '2023-11-22 12:37:14', NULL);
INSERT INTO `users` VALUES ('531', 'Terri', 'Mullins', '8200727077', 'TerriTMullins@cuvox.de', '$2y$10$Jibcx4kmrYiv2Xb2w5cWhOXDXlXxKGn3JDHNi7dzkTGPzf5zmNRpC', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:24', '2023-11-22 12:36:24', NULL);
INSERT INTO `users` VALUES ('532', 'Paulo', 'Oliveira', '8200727077', '2022-2312244', '$2y$10$.EJMzSFd73/9cBa8SCSHauS5y9WvW83nmyHZ/NEDx7ElQbSr5RwQS', 'male', NULL, '2008-02-09', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:24', '2023-11-22 12:37:14', NULL);
INSERT INTO `users` VALUES ('533', 'Amanda', 'Jones', '8200727077', 'AmandaKJones@armyspy.com', '$2y$10$6I0PUqXzEki80aP9PRqZWOFw3f6bk7u4z.q.Vr9Xh2Mhny40QGel6', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:25', '2023-11-22 12:36:25', NULL);
INSERT INTO `users` VALUES ('534', 'Gabriel', 'Correia', '8200727077', '2022-2312245', '$2y$10$p5ktdX1yH6y4C9ys7zHIfOATXT81xFtoivpbx4QecqBr5ak9x/fV2', 'male', NULL, '2010-03-21', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:25', '2023-11-22 12:37:14', NULL);
INSERT INTO `users` VALUES ('535', 'James', 'Ruggeri', '8200727077', 'JamesJRuggeri@cuvox.de', '$2y$10$xzyj8EvuFyd/Fmf6UpeBOuVPUU5VSDncN3bD.fnd7GIxZgINqF2KO', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:25', '2023-11-22 12:36:25', NULL);
INSERT INTO `users` VALUES ('536', 'Anna', 'Pereira', '8200727077', '2022-2312246', '$2y$10$mQ7Xqq9AvQ6eLow2ksLFBev9obHtf/nWfGJ3dQipEkeL.bWEzOtoC', 'female', NULL, '2004-07-18', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:26', '2023-11-22 12:37:14', NULL);
INSERT INTO `users` VALUES ('537', 'Angelia', 'Lowe', '8200727077', 'AngeliaALowe@dayrep.com', '$2y$10$6aUbFsAwtBiB3J2UQgaD7eRrWHXhKX0FpRyQeXn3uV.ZIcTJyTFUi', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:26', '2023-11-22 12:36:26', NULL);
INSERT INTO `users` VALUES ('538', 'Joao', 'Correia', '8200727077', '2022-2312247', '$2y$10$D0eFJXXbRFEVdPQJapnr7.QGOsqPahbQPn/j1QJXoVjf14lesmGH.', 'male', NULL, '2005-12-17', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:26', '2023-11-22 12:37:14', NULL);
INSERT INTO `users` VALUES ('539', 'Joe', 'Eisenberg', '8200727077', 'JoeDEisenberg@teleworm.us', '$2y$10$w6.fcBySH7KEapASfTJdf.4lHkntXvaPbceTjcOybD4BezvjDNehu', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:27', '2023-11-22 12:36:27', NULL);
INSERT INTO `users` VALUES ('540', 'Luis', 'Barros', '8200727077', '2022-2312248', '$2y$10$amaXC7NGKQolblJUS4WxXetor3HllzpEi9wap9EtHOs7L0umSx5Ni', 'male', NULL, '2003-05-02', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:27', '2023-11-22 12:37:14', NULL);
INSERT INTO `users` VALUES ('541', 'Melany', 'Weber', '8200727077', 'MelanySWeber@superrito.com', '$2y$10$bXuNq3RIINJtx4j7GmBywuwvJfDq9PE7rj7QIHgTu7w8PsSe9GUBy', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:27', '2023-11-22 12:36:27', NULL);
INSERT INTO `users` VALUES ('542', 'Luis', 'Pinto', '8200727077', '2022-2312249', '$2y$10$VvM2aW7mNTA5/zwLxNUKrO2j.SDUwmmvoDsc6ZY5yoB5KGk1LQEP.', 'male', NULL, '2011-10-31', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:27', '2023-11-22 12:37:14', NULL);
INSERT INTO `users` VALUES ('543', 'Catalina', 'Hutchcraft', '8200727077', 'CatalinaTHutchcraft@teleworm.us', '$2y$10$dl6frPUL3ccBP.voFNzJtergumtKAnU5sGjmXQZlbfsYZWF4mxm1q', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:28', '2023-11-22 12:36:28', NULL);
INSERT INTO `users` VALUES ('544', 'Marina', 'Martins', '8200727077', '2022-2312250', '$2y$10$m20sboqgobo4LFGXNkiazevPz1XxdLXn5QJqHBzlnSQIxwpi9HgKu', 'female', NULL, '2005-04-04', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:28', '2023-11-22 12:37:14', NULL);
INSERT INTO `users` VALUES ('545', 'Rosalina', 'Berryman', '8200727077', 'RosalinaJBerryman@teleworm.us', '$2y$10$UUykTRdvhPZfXTGvMM4OHe4.5vy3b2g24onzcMcx2wF7lwO5nYIQG', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:28', '2023-11-22 12:36:28', NULL);
INSERT INTO `users` VALUES ('546', 'Gustavo', 'Araujo', '8200727077', '2022-2312251', '$2y$10$4kkybZHaRPl9Dwn2RBQPVur5j47Vd4NRt4XP.8ATHDdn9mABULcjy', 'male', NULL, '2006-03-05', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:29', '2023-11-22 12:37:14', NULL);
INSERT INTO `users` VALUES ('547', 'Edwin', 'Green', '8200727077', 'EdwinMGreen@fleckens.hu', '$2y$10$Wc8MtY7tHT25pmHofIvCkOZpGrnOmitLajHA.gp6ClrNExuv7ctSK', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:29', '2023-11-22 12:36:29', NULL);
INSERT INTO `users` VALUES ('548', 'Sarah', 'Martins', '8200727077', '2022-2312252', '$2y$10$5kbeOCaI4EZso1AD0gaG0usNs1dzjKIWfgDv2ERZs03xfDOqzrDtS', 'female', NULL, '2011-03-13', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:30', '2023-11-22 12:37:14', NULL);
INSERT INTO `users` VALUES ('549', 'Leo', 'Briley', '8200727077', 'LeoSBriley@gustr.com', '$2y$10$tZ3bd/1684PT0y9BwvKzEe9hGd/3lLTLK2yY6QbeaYxxzWGo7CjRm', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:30', '2023-11-22 12:36:30', NULL);
INSERT INTO `users` VALUES ('550', 'Vitor', 'Souza', '8200727077', '2022-2312253', '$2y$10$vmiRln5mvfUAS./sjJFkIOB5cNiYhlgIdAaOlkP0/qLQJpiGlHVlm', 'male', NULL, '2009-06-13', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:30', '2023-11-22 12:37:14', NULL);
INSERT INTO `users` VALUES ('551', 'Rachel', 'Haun', '8200727077', 'RachelSHaun@teleworm.us', '$2y$10$/CogV254hz7pFud6sxxASeKZKWhNUoiO0jDp2gyZkhIhJufWjL6IS', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:30', '2023-11-22 12:36:30', NULL);
INSERT INTO `users` VALUES ('552', 'Thiago', 'Barbosa', '8200727077', '2022-2312254', '$2y$10$IvH5Eg/IX1PtXx3B6s23OeSGxXE1eLMaNn2oEQAESfDljW/tcqbQS', 'male', NULL, '2010-09-17', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:31', '2023-11-22 12:37:14', NULL);
INSERT INTO `users` VALUES ('553', 'Steven', 'Frye', '8200727077', 'StevenDFrye@gustr.com', '$2y$10$cMLZomcX02FOGqExMlteDOz3C/fF.7QtLUma/3LnGzzQ7YCOslHZi', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:31', '2023-11-22 12:36:31', NULL);
INSERT INTO `users` VALUES ('554', 'Kaue', 'Dias', '8200727077', '2022-2312255', '$2y$10$nOBDYiBaXeZvnjrnUQ5sI.0vgSG.xlnl9hSJGR3acHGNLA5aRFTQS', 'male', NULL, '2010-09-18', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:31', '2023-11-22 12:37:14', NULL);
INSERT INTO `users` VALUES ('555', 'Thomas', 'Hendrix', '8200727077', 'ThomasTHendrix@dayrep.com', '$2y$10$8fTwYHG2m1AJt7uUYZkxrO6BkL6ij.aGZSGkCzBiLWjlxCNwsXULG', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:32', '2023-11-22 12:36:32', NULL);
INSERT INTO `users` VALUES ('556', 'Emily', 'Rocha', '8200727077', '2022-2312256', '$2y$10$3ToAQheW9Dk5z90/bdi7ne.Xqs.51m.OJ2E6F/c37NCQGgqXmlj2a', 'female', NULL, '2011-07-25', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:32', '2023-11-22 12:37:14', NULL);
INSERT INTO `users` VALUES ('557', 'Lillian', 'Myers', '8200727077', 'LillianJMyers@gustr.com', '$2y$10$K57i.k1BDUEN37qf2SiNzOBDRZY0xr9L9UONrCLgfmrX/kf9tr4y6', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:32', '2023-11-22 12:36:32', NULL);
INSERT INTO `users` VALUES ('558', 'Tiago', 'Carvalho', '8200727077', '2022-2312257', '$2y$10$fiw9jDUmEGr8IPp249ws7O/alZqkm2japu9ZVKFDft86vC0yl/VhC', 'male', NULL, '2010-10-31', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:33', '2023-11-22 12:37:14', NULL);
INSERT INTO `users` VALUES ('559', 'Chris', 'Cummings', '8200727077', 'ChrisMCummings@rhyta.com', '$2y$10$tF.loSjzfBHFlVuwWfUa9.PbOQNBEHJfl5uXwIePRGlgWsTUlSqJS', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:33', '2023-11-22 12:36:33', NULL);
INSERT INTO `users` VALUES ('560', 'Julio', 'Ribeiro', '8200727077', '2022-2312258', '$2y$10$ibvBpwauOAXFB63AKLOgIulpiPbq5gvUCEHHJDYNrbHxbCV/0wWZG', 'male', NULL, '2007-01-30', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:33', '2023-11-22 12:37:14', NULL);
INSERT INTO `users` VALUES ('561', 'Charles', 'Rosas', '8200727077', 'CharlesCRosas@teleworm.us', '$2y$10$UsCDLk1tc7VBXW2U2q5Une0JUUPXE0g3YFFvv2BqlZg4lNxolVRpq', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:34', '2023-11-22 12:36:34', NULL);
INSERT INTO `users` VALUES ('562', 'Bruno', 'Ribeiro', '8200727077', '2022-2312259', '$2y$10$QNKJevAp3v/OEK53J9F4SOiUGvaApZbpHrdfZIKfR.3LfzT.7NVVS', 'male', NULL, '2004-05-20', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:34', '2023-11-22 12:37:14', NULL);
INSERT INTO `users` VALUES ('563', 'Patricia', 'Tyler', '8200727077', 'PatriciaCTyler@armyspy.com', '$2y$10$.jxF9GgDasAUtq20kqyn3evE6IV.Jk5sJs9PC/p0N74NavQykJKWS', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:34', '2023-11-22 12:36:34', NULL);
INSERT INTO `users` VALUES ('564', 'Thiago', 'Cardoso', '8200727077', '2022-2312260', '$2y$10$FX6sAZOVqHPr/cqYxASko.mOg1MmlIJaYk2X.J.1zyyFg0Lar3JUG', 'male', NULL, '2004-02-05', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:35', '2023-11-22 12:37:14', NULL);
INSERT INTO `users` VALUES ('565', 'Ralph', 'Martinez', '8200727077', 'RalphLMartinez@jourrapide.com', '$2y$10$3sCaOt0sSfCjf4Pcgc7zBu/yLn/mzGES7nh6ecswtaJcXxDaFw4C2', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:35', '2023-11-22 12:36:35', NULL);
INSERT INTO `users` VALUES ('566', 'Julia', 'Cavalcanti', '8200727077', '2022-2312261', '$2y$10$BJ7/cGWnC.5p6gbKiNhBY.rp5rFHJArShFSf/IuWnJX81hOm05rzi', 'female', NULL, '2013-12-22', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:35', '2023-11-22 12:37:14', NULL);
INSERT INTO `users` VALUES ('567', 'Phyllis', 'Pierce', '8200727077', 'PhyllisBPierce@rhyta.com', '$2y$10$e4FEtIDpTkD7OGUCx4yRIOqSlxwXj65Y/BP69y.5h.HoFptMVhd5i', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:36', '2023-11-22 12:36:36', NULL);
INSERT INTO `users` VALUES ('568', 'Rebeca', 'Lima', '8200727077', '2022-2312262', '$2y$10$H2N8B3uqXEUUrpwgJdxDOuSBsRsccPyQDSGCmHUEOUChqpnRXqkuW', 'female', NULL, '2011-07-17', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:36', '2023-11-22 12:37:14', NULL);
INSERT INTO `users` VALUES ('569', 'Audrey', 'Scholl', '8200727077', 'AudreyCScholl@gustr.com', '$2y$10$uWLXiP9.WPpeCYB3PTDbtunARTWjOS0EExdMNxsY5cKi8dyln3EmW', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:36', '2023-11-22 12:36:36', NULL);
INSERT INTO `users` VALUES ('570', 'Pedro', 'Cardoso', '8200727077', '2022-2312263', '$2y$10$oBumVIAps7iAfjOcP1ZN3uWzoZSWTsi5d4pbt10/rphImrB2vXZXG', 'male', NULL, '2006-08-19', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:37', '2023-11-22 12:37:05', NULL);
INSERT INTO `users` VALUES ('571', 'Esther', 'Donovan', '8200727077', 'EstherRDonovan@jourrapide.com', '$2y$10$ltTQxWcWcnXDAhmEKk4BVumupKYxpnhhiwtpYpybOCEs3JP5kQVhq', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:37', '2023-11-22 12:36:37', NULL);
INSERT INTO `users` VALUES ('572', 'Pedro', 'Martins', '8200727077', '2022-2312264', '$2y$10$SLiy5MXdowcIBdIveZpUieO0rai2J37T7wjuHSm0KFCynep3mOOZu', 'male', NULL, '2011-12-26', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:37', '2023-11-22 12:37:05', NULL);
INSERT INTO `users` VALUES ('573', 'Eric', 'Mullins', '8200727077', 'EricGMullins@armyspy.com', '$2y$10$0a32vPNlzjn4DZFVg.c5UOf9Y2YxgvGY0vba2kxskedgPrBVB.yr6', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:38', '2023-11-22 12:36:38', NULL);
INSERT INTO `users` VALUES ('574', 'Nicolas', 'Melo', '8200727077', '2022-2312265', '$2y$10$835QHHGwGCocVcCjoJU6ruK.piUtDucL5bI69DZY5cs1BV8uKg0ye', 'male', NULL, '2008-06-09', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:38', '2023-11-22 12:37:05', NULL);
INSERT INTO `users` VALUES ('575', 'Donald', 'Hardin', '8200727077', 'DonaldRHardin@rhyta.com', '$2y$10$0FcXfu7W89mPF9JfdLEDhenWUu4YDpmKA5zgTdsPz6pJNcxfdvzOW', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:38', '2023-11-22 12:36:38', NULL);
INSERT INTO `users` VALUES ('576', 'Luan', 'Correia', '8200727077', '2022-2312266', '$2y$10$x9w0HlYl6TYtM1yZipu4eOEF4JtEsgWp8CeT7A3MiqPNZvVHEQeMe', 'male', NULL, '2015-11-15', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:39', '2023-11-22 12:37:05', NULL);
INSERT INTO `users` VALUES ('577', 'Eddie', 'Hagins', '8200727077', 'EddiePHagins@fleckens.hu', '$2y$10$7DOXJvFDFJ15lOL/1x2um.sHnkz0veh1W3ulA4dQ2Q4lKqwJBJyOu', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:39', '2023-11-22 12:36:39', NULL);
INSERT INTO `users` VALUES ('578', 'Gabriel', 'Martins', '8200727077', '2022-2312267', '$2y$10$duB0x9jk2bPUMKa7uFpz5uIk7poQPLHaLN3fXYr2gSwpbBTiU9kWC', 'male', NULL, '2007-10-25', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:39', '2023-11-22 12:37:05', NULL);
INSERT INTO `users` VALUES ('579', 'Jeffery', 'Michael', '8200727077', 'JefferyCMichael@superrito.com', '$2y$10$DE6./9.AsF/N5LZ/6IoV9.5vPbjULi42Xe7YAiCFvuiyXYZQDxfdi', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:40', '2023-11-22 12:36:40', NULL);
INSERT INTO `users` VALUES ('580', 'Luiz', 'Almeida', '8200727077', '2022-2312268', '$2y$10$2cNtOOX5yHLO3m2FMASp6ugugv9ur1eRcuEq7cHwNFSa5q3H/vCBG', 'male', NULL, '2011-06-26', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:40', '2023-11-22 12:37:05', NULL);
INSERT INTO `users` VALUES ('581', 'Bryan', 'David', '8200727077', 'BryanGDavid@jourrapide.com', '$2y$10$OIXLn1KiF5rqPuBQctQtsea0Un1ndJDzAIuLO.LJ46o0q6AmuQvlO', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:40', '2023-11-22 12:36:40', NULL);
INSERT INTO `users` VALUES ('582', 'Matheus', 'Carvalho', '8200727077', '2022-2312269', '$2y$10$6jlXCJxyXj6qb.77BHzaXe7FNnMw7bGH1PnggfKYYCNuLgF6LYCOS', 'male', NULL, '2014-09-29', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:41', '2023-11-22 12:37:05', NULL);
INSERT INTO `users` VALUES ('583', 'Latricia', 'Shea', '8200727077', 'LatriciaRShea@dayrep.com', '$2y$10$oX4vUeXE0o1wP/iJohZelOnjnd004TPQACEQg.S0KOAEg./LBsBre', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:41', '2023-11-22 12:36:41', NULL);
INSERT INTO `users` VALUES ('584', 'Samuel', 'Alves', '8200727077', '2022-2312270', '$2y$10$6TLBcacTuxaL3Z4RjUqAkODVej8gA4X3xCc7M7BGCFuV1gWykt.Ey', 'male', NULL, '2015-01-18', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:41', '2023-11-22 12:37:05', NULL);
INSERT INTO `users` VALUES ('585', 'Robert', 'Booker', '8200727077', 'RobertLBooker@fleckens.hu', '$2y$10$3D5Zrj3dRdIcI9sX6cCWLu/1uFKtZwILanJ4vlETBt.7j61lpPxza', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:42', '2023-11-22 12:36:42', NULL);
INSERT INTO `users` VALUES ('586', 'Luis', 'Costa', '8200727077', '2022-2312271', '$2y$10$nrVoDUpate0Ylg8o/xILNuCOyq8cLgD3ZUEct1dBYYo9mW2r9wyq.', 'male', NULL, '2007-07-02', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:42', '2023-11-22 12:37:05', NULL);
INSERT INTO `users` VALUES ('587', 'John', 'Sanchez', '8200727077', 'JohnNSanchez@armyspy.com', '$2y$10$gZzVlZx8BYubi9ngcnbGU.RhT/Do/HTJMpw1K2Km6Y8tN0BJPzF.K', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:42', '2023-11-22 12:36:42', NULL);
INSERT INTO `users` VALUES ('588', 'Tiago', 'Oliveira', '8200727077', '2022-2312272', '$2y$10$Mrq0R1zO8JQGX9IIQM4.Vuhnvz8fDaTFedfMUAUA4iRsuqQgm1pCW', 'male', NULL, '2003-12-13', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:36:42', '2023-11-22 12:37:05', NULL);
INSERT INTO `users` VALUES ('589', 'Scot', 'Penton', '8200727077', 'ScotLPenton@gustr.com', '$2y$10$qYuIV3yOF0.JM1f9vBzaKuo43Zc561q8ug8VpMH1GDgh88RROxX1q', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:20', '2023-11-22 12:39:20', NULL);
INSERT INTO `users` VALUES ('590', 'Kai', 'Cardoso', '8200727077', '2022-2312273', '$2y$10$DvdO9Z2OJlmhZx6W1BifBOyQfYmqs6ONSjAi9wmzKGCrbTZOS72uq', 'male', NULL, '2008-08-20', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:20', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('591', 'Summer', 'Isbell', '8200727077', 'SummerSIsbell@cuvox.de', '$2y$10$VXhuinq8TEOpPNFNZ0IV3.ncW4FHGanXC.lllGkuwR34AeSEvSkS6', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:20', '2023-11-22 12:39:20', NULL);
INSERT INTO `users` VALUES ('592', 'Bianca', 'Goncalves', '8200727077', '2022-2312274', '$2y$10$/24ix8JIpNvyNe6tEsFk0Op3MB4qvHS7.UGIFwqJM7w4aUUBuzZZe', 'female', NULL, '2013-12-21', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:21', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('593', 'Danny', 'Barrington', '8200727077', 'DannyRBarrington@cuvox.de', '$2y$10$pq5Xo4LyHAlqfiYGhD/N4Or9W.LX9AUixffAqWG/Jm3Y0v7N.THl2', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:21', '2023-11-22 12:39:21', NULL);
INSERT INTO `users` VALUES ('594', 'Maria', 'Gomes', '8200727077', '2022-2312275', '$2y$10$hSTYrH7f6kLApUQLG2M5MerZawVuTIvJnn3KeLcZjGIK/lcNpTnJu', 'female', NULL, '2005-09-27', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:22', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('595', 'Matthew', 'Groves', '8200727077', 'MatthewSGroves@jourrapide.com', '$2y$10$8zr9jGWIgeiZrsmdadIgreiUQxblHaHxMaW3FLDIwHTrnETv07e7a', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:22', '2023-11-22 12:39:22', NULL);
INSERT INTO `users` VALUES ('596', 'Kaua', 'Barbosa', '8200727077', '2022-2312276', '$2y$10$cU7mC3I0g.JKVQYNHcmXP.CghsnsbV91yaEgnWbOxRbVNAcQvf1ke', 'male', NULL, '2013-04-03', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:22', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('597', 'Terry', 'Burden', '8200727077', 'TerryRBurden@cuvox.de', '$2y$10$JH4fVAbDiTptLz/jh2Sx/OUnmA8uCxGWeZ0qhn.1ruxcRBHs/S3na', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:22', '2023-11-22 12:39:22', NULL);
INSERT INTO `users` VALUES ('598', 'Matilde', 'Rocha', '8200727077', '2022-2312277', '$2y$10$sCZ9vCuD4BT3W624fFc2rebE6WXUH01eXH.DVTpPRYru0eo2YJbyO', 'female', NULL, '2006-01-30', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:23', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('599', 'John', 'Kates', '8200727077', 'JohnGKates@cuvox.de', '$2y$10$sjRfuQ7vkINXe.dYhd8NEOzZZNE3GHMTmTEqsbgCqV6WnTbT.ElEC', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:23', '2023-11-22 12:39:23', NULL);
INSERT INTO `users` VALUES ('600', 'Laura', 'Cavalcanti', '8200727077', '2022-2312278', '$2y$10$c/QydnwKauDAYJzjF9hYpeKJKrj5DPSXs.4k0BYGcY/FstPV9607q', 'female', NULL, '2006-01-16', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:23', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('601', 'Paula', 'Hughes', '8200727077', 'PaulaDHughes@cuvox.de', '$2y$10$FR4PI7BzG7Ec1J.7mjrL9u3hyP5ylZvDNFdmsYIGTH38t7LVGEwaa', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:24', '2023-11-22 12:39:24', NULL);
INSERT INTO `users` VALUES ('602', 'Paulo', 'Souza', '8200727077', '2022-2312279', '$2y$10$nQ3YgqV.ZERhiTQAwNze..nx8FukV4vG621JAFZeGkpB3JFR82P2S', 'male', NULL, '2011-08-26', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:24', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('603', 'Matthew', 'Perkins', '8200727077', 'MatthewLPerkins@fleckens.hu', '$2y$10$GFF1A/ctU68obggLwxWiv.CQvGWOQPO9AnW/ai0bOnByyxgTXIDlu', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:24', '2023-11-22 12:39:24', NULL);
INSERT INTO `users` VALUES ('604', 'Estevan', 'Fernandes', '8200727077', '2022-2312280', '$2y$10$22Sbk35q1MstYc/NEGg5x.dDZkDvDOlk9gQ1Rt3tewlZV.KF5D8sa', 'male', NULL, '2011-08-16', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:25', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('605', 'Jennifer', 'Williams', '8200727077', 'JenniferJWilliams@dayrep.com', '$2y$10$.XaDkKVRUCIFM/J02KOPUe68CAtBQCfnyPLS7QoLBlzEJC5YpMjjS', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:25', '2023-11-22 12:39:25', NULL);
INSERT INTO `users` VALUES ('606', 'Kaua', 'Barbosa', '8200727077', '2022-2312281', '$2y$10$0lGgHRGngKCBum/HR5jmfO2XWRYFt9YjtBMrlEV1oD4SQjOK8ARs.', 'male', NULL, '2008-03-20', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:25', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('607', 'Robert', 'Brown', '8200727077', 'RobertCBrown@teleworm.us', '$2y$10$iXuUkI9QQo88MArefa0Oy.9pn5tksb98djOMCmHhNjprgto56OhY.', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:26', '2023-11-22 12:39:26', NULL);
INSERT INTO `users` VALUES ('608', 'Mateus', 'Martins', '8200727077', '2022-2312282', '$2y$10$.YtIMxjV2hS8t5ZMy1dqYeaFkZuUQAxMvMnCYKvfdcg4A7jInhwK2', 'male', NULL, '2003-07-21', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:26', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('609', 'Joan', 'Miller', '8200727077', 'JoanJMiller@rhyta.com', '$2y$10$f4CkK8L2Kp3EVyDIiQvqhel4o8DSMaXvlloN8eVPfOouqmXt11Xrq', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:26', '2023-11-22 12:39:26', NULL);
INSERT INTO `users` VALUES ('610', 'Paulo', 'Correia', '8200727077', '2022-2312283', '$2y$10$AyhgN6kreTqwIdBqoY0t/.rH.I5AQluOQXEWfYKDSSuwnlUaA814O', 'male', NULL, '2002-11-29', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:27', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('611', 'Matt', 'Hise', '8200727077', 'MattJHise@jourrapide.com', '$2y$10$p9cKxPYJPfJGfCc/93wg3uEHaiqETX3/tDusafuAKj7bAarpGk4wS', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:27', '2023-11-22 12:39:27', NULL);
INSERT INTO `users` VALUES ('612', 'Julio', 'Souza', '8200727077', '2022-2312284', '$2y$10$M.n61I0RYr2PFlD67A6E6.k34XcPfN1nKV4tpxWMb.ILGqzCgfl0O', 'male', NULL, '2006-03-07', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:27', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('613', 'Donald', 'Flores', '8200727077', 'DonaldJFlores@rhyta.com', '$2y$10$9J4trEALZbj8SPRw9B8EReBFMfqZs5VtMzdKDaXdx5w03yA6mIDAm', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:28', '2023-11-22 12:39:28', NULL);
INSERT INTO `users` VALUES ('614', 'Sophia', 'Carvalho', '8200727077', '2022-2312285', '$2y$10$90Y2bhDdrsKaTTbpUv6CTeZFouHv0FhyMovpm6umN35L2wONVjES.', 'female', NULL, '2006-02-10', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:28', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('615', 'Susan', 'Wolfe', '8200727077', 'SusanWWolfe@cuvox.de', '$2y$10$durIUurGJZweauTJq33JQ.c9.TAmoG07g3atkUQ/IoZKqaKBX8E9e', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:28', '2023-11-22 12:39:28', NULL);
INSERT INTO `users` VALUES ('616', 'Kai', 'Melo', '8200727077', '2022-2312286', '$2y$10$Mi06I4/zq4Yfpr3qV.R8LeX.eSlkFtdPM122Ujrx/tiHXJnuS9oWW', 'male', NULL, '2006-04-04', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:29', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('617', 'Shauna', 'Garcia', '8200727077', 'ShaunaCGarcia@einrot.com', '$2y$10$RWLO3FhkpI.zCiE.UCjqTeN8oLm9KLhKMsJTonuKOLuiikkeYxcx.', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:29', '2023-11-22 12:39:29', NULL);
INSERT INTO `users` VALUES ('618', 'Aline', 'Cardoso', '8200727077', '2022-2312287', '$2y$10$IGEpiwZ/JPPaM6ydg2hc2uZ.Pbic2nY7iNMIlmhtcdLFZQJJJCyry', 'female', NULL, '2013-08-29', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:29', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('619', 'Craig', 'Ackley', '8200727077', 'CraigJAckley@gustr.com', '$2y$10$FDVFzgJjWvzzLP7GB3sf4.fr/3EVrg5wNHBeBA13ESHdwSPV0EXpC', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:30', '2023-11-22 12:39:30', NULL);
INSERT INTO `users` VALUES ('620', 'Joao', 'Sousa', '8200727077', '2022-2312288', '$2y$10$cdhS6EHfyANAZHnX48/.PuRxaHcF/Cd1aBW.9r7JGp8HlwnhsXzRm', 'male', NULL, '2013-10-06', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:30', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('621', 'George', 'Hensley', '8200727077', 'GeorgeLHensley@einrot.com', '$2y$10$z6/Ow9O1OxXXzPTJUzMZRO45ywQJaJ9PALDzCj3aIpGXPNoq0wD7q', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:30', '2023-11-22 12:39:30', NULL);
INSERT INTO `users` VALUES ('622', 'Diogo', 'Rodrigues', '8200727077', '2022-2312289', '$2y$10$ZssxWUrmSymfumtsMSUjgOQjFaFK8tnTSJJbDggyUUWJCcz.GtGoy', 'male', NULL, '2014-04-23', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:31', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('623', 'Chad', 'Moreira', '8200727077', 'ChadRMoreira@einrot.com', '$2y$10$1uYjIUv4lzCC4zjjvd9tvu5Qgh2knmAD62u6Ik0tyIa2FDL8YkL6K', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:31', '2023-11-22 12:39:31', NULL);
INSERT INTO `users` VALUES ('624', 'Thiago', 'Souza', '8200727077', '2022-2312290', '$2y$10$EM9N8kd5oMKKyWzC8ANanezWKTs5acsKvPZeI0Mi6NZrPvVwGrs3a', 'male', NULL, '2011-05-28', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:31', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('625', 'Charles', 'Rashid', '8200727077', 'CharlesDRashid@einrot.com', '$2y$10$Chjh4p/xwnXIAAvEZDhaWO3rEJkFieISy7fMdsv.wabeJz70LBQuy', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:32', '2023-11-22 12:39:32', NULL);
INSERT INTO `users` VALUES ('626', 'Rodrigo', 'Cunha', '8200727077', '2022-2312291', '$2y$10$kwQwX3lh3uWlyJ0qoPcmNOLquctgn3eTi/rgsEcw54q2uk1jhizSi', 'male', NULL, '2014-02-03', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:32', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('627', 'Jesse', 'Buggs', '8200727077', 'JesseDBuggs@fleckens.hu', '$2y$10$82tgUhI7aeMJSIAL3ZzFNeYwV0eDCvV5Pl0e1LpNOVCU7xfPvZXVG', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:32', '2023-11-22 12:39:32', NULL);
INSERT INTO `users` VALUES ('628', 'Rafaela', 'Souza', '8200727077', '2022-2312292', '$2y$10$2q6ho5wTaaekEL6NTHzsZufM39FX32jpT407fv8jUfu2zMLND59JC', 'female', NULL, '2008-04-30', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:33', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('629', 'Sammy', 'Shockey', '8200727077', 'SammyFShockey@dayrep.com', '$2y$10$WET6dk6UGUgH9TamkzxVr.LQ4dc6Tt6Z93j07ElPi7KnRGI2Ed8mG', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:33', '2023-11-22 12:39:33', NULL);
INSERT INTO `users` VALUES ('630', 'Arthur', 'Correia', '8200727077', '2022-2312293', '$2y$10$9sni5k08NT1vtXylZJY0V.pzIWqLzNdPzmynMgwwYSHthDJywa5Zq', 'male', NULL, '2006-09-16', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:33', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('631', 'Richard', 'Crum', '8200727077', 'RichardMCrum@superrito.com', '$2y$10$yILjEDwg3cL9.xUWZHnYhe4a3hJZmuDDXPbpUxNhEz3yBsEonMhsC', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:34', '2023-11-22 12:39:34', NULL);
INSERT INTO `users` VALUES ('632', 'Lara', 'Carvalho', '8200727077', '2022-2312294', '$2y$10$0XBF2qNDzsN5SjxdUIpdhuxJcOC04wU9MGnphxoiVWT9ToZP8wOSG', 'female', NULL, '2012-01-03', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:34', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('633', 'Albert', 'Steinmetz', '8200727077', 'AlbertKSteinmetz@gustr.com', '$2y$10$1d3VMC2t0Dk6oEB27u9S5uXKPr.sYiJXV.2onP4jum6C7kc.3BuY2', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:34', '2023-11-22 12:39:34', NULL);
INSERT INTO `users` VALUES ('634', 'Bianca', 'Santos', '8200727077', '2022-2312295', '$2y$10$Wg5uXYJgQxOmlaQyiU5CXu4nalNx3W.UzK.3zc1sCq9Acf8ANprQe', 'female', NULL, '2008-08-02', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:35', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('635', 'Adam', 'McCoy', '8200727077', 'AdamCMcCoy@jourrapide.com', '$2y$10$f/YksMDHxQlLqunajr17iOiv2Qg0wOqQfj5x078BmXk3lvO8ECFdW', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:35', '2023-11-22 12:39:35', NULL);
INSERT INTO `users` VALUES ('636', 'Victor', 'Costa', '8200727077', '2022-2312296', '$2y$10$cPOuTnZID4awPH237H7FN.8xsiAGwo5I5sFQWDvKYCMh4SvyDyXRa', 'male', NULL, '2012-01-08', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:35', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('637', 'Ronald', 'Fuller', '8200727077', 'RonaldMFuller@einrot.com', '$2y$10$e/DJQrA3C96P8pIuitjnjOfKWTWzGqgCOMzEYci8dVEVPx/GLejYq', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:36', '2023-11-22 12:39:36', NULL);
INSERT INTO `users` VALUES ('638', 'Caio', 'Barbosa', '8200727077', '2022-2312297', '$2y$10$jh8y.1c01wd1agA2rYyUeeuk3G8McRh4kDVwp.QQcVj8JtkYOeH5S', 'male', NULL, '2004-01-01', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:36', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('639', 'Michael', 'Housel', '8200727077', 'MichaelMHousel@teleworm.us', '$2y$10$A1i0xn/kNrHIugQb/lNcOe3wTPCddQ0IlSXmrEkT7nW7I9ARfCbSy', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:36', '2023-11-22 12:39:36', NULL);
INSERT INTO `users` VALUES ('640', 'Miguel', 'Goncalves', '8200727077', '2022-2312298', '$2y$10$sqlApiIoGKiFTPcz./HLzuV7Lm09DsVaaD0O.tXLpMxk6jhHoyKLi', 'male', NULL, '2013-06-30', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:37', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('641', 'Patrick', 'Roberts', '8200727077', 'PatrickSRoberts@superrito.com', '$2y$10$XaM102ymAiXRBZ8eajJMxeGFLuJGqXewncyN3Vf32wDrOHoFScPXq', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:37', '2023-11-22 12:39:37', NULL);
INSERT INTO `users` VALUES ('642', 'Bruno', 'Costa', '8200727077', '2022-2312299', '$2y$10$dC6dA3kx9/1f4l3fZpvPXO3qwOxXdca06W9khKydntIk5qXaEuITu', 'male', NULL, '2011-06-01', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:37', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('643', 'David', 'Collins', '8200727077', 'DavidMCollins@rhyta.com', '$2y$10$44GjsHe206ZSxcBneyewUOwD.GNzg.98xAHHqhddffaKfc.t7/Kxy', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:38', '2023-11-22 12:39:38', NULL);
INSERT INTO `users` VALUES ('644', 'Carlos', 'Sousa', '8200727077', '2022-2312300', '$2y$10$OD1wtik7ppovEIh3p.dVn.FslDgtZ1bm1I.Cm5wzKUPd2GzLggO0W', 'male', NULL, '2014-06-22', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:38', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('645', 'Mike', 'McCormick', '8200727077', 'MikeJMcCormick@teleworm.us', '$2y$10$D1YXzU1lpsMtnNV6qNOWxudd7rWuEo5FkkXKvHq2e/zSy1tkjSpL.', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:38', '2023-11-22 12:39:38', NULL);
INSERT INTO `users` VALUES ('646', 'Estevan', 'Ferreira', '8200727077', '2022-2312301', '$2y$10$mBIE6vzJ8LAQG2vk/g8PRu7GO6vG8j6sMfh36QV5tHD/comwN00H.', 'male', NULL, '2005-01-27', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:39', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('647', 'Odell', 'Watson', '8200727077', 'OdellJWatson@fleckens.hu', '$2y$10$HBHiqlOel74T8nH/Up/fMOqk7P4UrRpb.15fn7uIGJEbEMCFravre', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:39', '2023-11-22 12:39:39', NULL);
INSERT INTO `users` VALUES ('648', 'Joao', 'Cardoso', '8200727077', '2022-2312302', '$2y$10$SLkLb/TclclLHPUwOZdDIeGywkiAYHanl5axrKNbuJNPcK0UBCsLC', 'male', NULL, '2005-05-21', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:39', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('649', 'Dallas', 'Heffner', '8200727077', 'DallasBHeffner@rhyta.com', '$2y$10$z0bbVqlOj9KT.V5oDl59uOtDurc3TyPUEpTi9eEE5QikyzxtFgof6', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:40', '2023-11-22 12:39:40', NULL);
INSERT INTO `users` VALUES ('650', 'Jose', 'Almeida', '8200727077', '2022-2312303', '$2y$10$c8PQYNGrqJsljpfXpFaQo.MMfaT5yBj7REaR7t33l3Px1OaqSa/i6', 'male', NULL, '2015-09-04', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:40', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('651', 'Lillian', 'Smith', '8200727077', 'LillianPSmith@rhyta.com', '$2y$10$tbgyphFUNkQrGBAvGQZLDOa.sH/cnCB55otuodm4j3E.KXrnPDZzq', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:40', '2023-11-22 12:39:40', NULL);
INSERT INTO `users` VALUES ('652', 'Samuel', 'Lima', '8200727077', '2022-2312304', '$2y$10$ocK2uWxlsjX/mvftsqte3uiuxa2O53n20YrmN646MQR1gRAbAeZmC', 'male', NULL, '2011-07-18', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:41', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('653', 'Cynthia', 'Evangelista', '8200727077', 'CynthiaTEvangelista@superrito.com', '$2y$10$43HQEMpu6eKvOHyNDdrqwOnmeDjiYN7nhDPCX37/C/dNfW2VBZmyW', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:41', '2023-11-22 12:39:41', NULL);
INSERT INTO `users` VALUES ('654', 'Douglas', 'Barbosa', '8200727077', '2022-2312305', '$2y$10$7rUKW4.Yrlo3Z0NI1LJylOzG6B5FnIuYjLmG9dYGIqIctWF.GOdcW', 'male', NULL, '2009-08-26', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:41', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('655', 'William', 'Wentworth', '8200727077', 'WilliamPWentworth@gustr.com', '$2y$10$a/kVgl.UjI8ADL3EVUCEEuNjQsTYdMOoUrtzxZR2Q4nP9Wgb3wxAO', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:42', '2023-11-22 12:39:42', NULL);
INSERT INTO `users` VALUES ('656', 'Rafaela', 'Almeida', '8200727077', '2022-2312306', '$2y$10$QYtOags.XQiWaONk6n.ZOewQiXJVsXFd9mlEf5Nr6UoP75kMDF4z.', 'female', NULL, '2012-08-03', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:42', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('657', 'Herman', 'Welsh', '8200727077', 'HermanRWelsh@teleworm.us', '$2y$10$ntF6pGoMSA7Lp3NFFhACne9nwWpK/JyAjGcFKANKrueXylPVTkSEO', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:42', '2023-11-22 12:39:42', NULL);
INSERT INTO `users` VALUES ('658', 'Estevan', 'Melo', '8200727077', '2022-2312307', '$2y$10$15nND/5gTw3RnXgNLISCK.9t3RkpKZm6xziNr6NJUIk2U8jvLE4HK', 'male', NULL, '2014-07-19', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:43', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('659', 'Adolfo', 'Schofield', '8200727077', 'AdolfoJSchofield@cuvox.de', '$2y$10$tztVqzUbHRkyTuMoYITbAOwlM61/3aP8m3UUvNBSQKbVWX7EdJ5ve', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:43', '2023-11-22 12:39:43', NULL);
INSERT INTO `users` VALUES ('660', 'Kai', 'Barros', '8200727077', '2022-2312308', '$2y$10$h89I/JLYm4CI7OgebQYHA.tYSSgjIjbOGi6/rpzKw4w9Utb2czbei', 'male', NULL, '2012-09-15', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:43', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('661', 'Kathryn', 'Lamar', '8200727077', 'KathrynJLamar@jourrapide.com', '$2y$10$tAv.fZj5k4UxUob9mJsDNub3KYhu2slZWMTAtqrSJ/kABvp7MlCxq', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:44', '2023-11-22 12:39:44', NULL);
INSERT INTO `users` VALUES ('662', 'Larissa', 'Gomes', '8200727077', '2022-2312309', '$2y$10$dGkHr8AGnB.a64yC65vS6eWkcsTuTnRtkVYk6n4UOJDMN5nLaobvi', 'female', NULL, '2015-08-14', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:39:44', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('663', 'Micheal', 'Turner', '8200727077', 'MichealBTurner@fleckens.hu', '$2y$10$dsNGMiWdWOYKaVYWpyyTx.pIBm.1N.l8YgSlZ36QZM06DpdrxzfvW', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:41', '2023-11-22 12:41:41', NULL);
INSERT INTO `users` VALUES ('664', 'Aline', 'Ferreira', '8200727077', '2022-2312310', '$2y$10$ZnGYiLODxEtY0rX32Z/AGuOrtVKX3JFgX.MBYNnQO.y1xR9irziNO', 'female', NULL, '2009-02-23', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:41', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('665', 'Randall', 'Martin', '8200727077', 'RandallBMartin@gustr.com', '$2y$10$KDHNV/6AlJKXhGHQCYZ70.MwJ.f3LxNrmht8b.jJxd.wbughv715G', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:42', '2023-11-22 12:41:42', NULL);
INSERT INTO `users` VALUES ('666', 'Antonio', 'Barros', '8200727077', '2022-2312311', '$2y$10$FTa8ClMgR0JUSCjfgUk0IuFxcAOAyH7IEmGYOowxIyr6Zi.OSOt3e', 'male', NULL, '2015-08-19', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:42', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('667', 'Jenelle', 'Peterman', '8200727077', 'JenelleJPeterman@teleworm.us', '$2y$10$U97CXZrRJUoPjufHrAJieuWcUoVUMyUU6f4uYpxN7g1gZbSbREVuG', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:42', '2023-11-22 12:41:42', NULL);
INSERT INTO `users` VALUES ('668', 'Vitor', 'Alves', '8200727077', '2022-2312312', '$2y$10$hNvEdi9G3JQCvAIaHFGw2uH69FAv2iEgl9ul0tMp.qCGzIfHWcVse', 'male', NULL, '2012-10-21', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:43', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('669', 'Brenda', 'Rodriguez', '8200727077', 'BrendaJRodriguez@gustr.com', '$2y$10$JRc/RuL8nH/EI.7JUauJK.ydXagsCMMRtqz/z1vmhEI8Kue2Nwbl6', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:43', '2023-11-22 12:41:43', NULL);
INSERT INTO `users` VALUES ('670', 'Gabriela', 'Santos', '8200727077', '2022-2312313', '$2y$10$aHUVKAKtg0W7iWo5HzbDaegFJm87T9asGB5Q0HjIiOFf15Os0cQDW', 'female', NULL, '2015-03-21', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:43', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('671', 'Michael', 'Oliver', '8200727077', 'MichaelDOliver@einrot.com', '$2y$10$PyTptqVGN0qJLu6k6hm06uI.pNBFPiT1AfgOJWbgRVpqSXj0/SOTy', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:44', '2023-11-22 12:41:44', NULL);
INSERT INTO `users` VALUES ('672', 'Martim', 'Barros', '8200727077', '2022-2312314', '$2y$10$Qh0Niv1.egX4kGA3z.Nxf.5pf0rBTyLId2KSzFeuFLEUsMLYDxk86', 'male', NULL, '2009-02-24', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:44', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('673', 'Crystal', 'Vinson', '8200727077', 'CrystalJVinson@dayrep.com', '$2y$10$t3t32VxEhOCTmhdA9XXUiufS.Fl0NPeCJ/z4bJzO7K7pvzef44.U6', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:44', '2023-11-22 12:41:44', NULL);
INSERT INTO `users` VALUES ('674', 'Vitor', 'Goncalves', '8200727077', '2022-2312315', '$2y$10$Z0D/TmyR9CYHOWowZKbbI.R74HfNY3ChUTXrR.Mt6OmjsPznc6nH6', 'male', NULL, '2006-10-22', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:45', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('675', 'Andrew', 'Lane', '8200727077', 'AndrewJLane@superrito.com', '$2y$10$SHRfnfFPFjJyiesAvHFoAuCiBkWR8Sh2G.UjOrFpOkkrXH2xscHFa', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:45', '2023-11-22 12:41:45', NULL);
INSERT INTO `users` VALUES ('676', 'Emily', 'Costa', '8200727077', '2022-2312316', '$2y$10$1LnvPJgZfR4KSgpHAlSzyuAb0JHMrj8UnG3TKICGkpRBfNMvput7u', 'female', NULL, '2004-12-01', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:45', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('677', 'Will', 'Colley', '8200727077', 'WillCColley@dayrep.com', '$2y$10$EYvcc5VBdZ/Ld75.FNvqHe3IPNz51ojsvwF2aJnbsBV57fpOC8bja', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:46', '2023-11-22 12:41:46', NULL);
INSERT INTO `users` VALUES ('678', 'Joao', 'Cunha', '8200727077', '2022-2312317', '$2y$10$9ta6oDMfEgyIYatDHUzEkOEltrWSPTFQukKlV1uEPHgiLA5zyb6UC', 'male', NULL, '2009-05-09', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:46', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('679', 'Svetlana', 'Martinez', '8200727077', 'SvetlanaJMartinez@einrot.com', '$2y$10$hbhgtRhhO2kZ8o6S8kqYte4xMbOIofKdvD7UzUmaCyTSrlIVVnMYi', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:46', '2023-11-22 12:41:46', NULL);
INSERT INTO `users` VALUES ('680', 'Leonor', 'Pinto', '8200727077', '2022-2312318', '$2y$10$oV6ZSk0rmy2JMECqHem/cuqAL0dpkkAEffpn6otchTL/MZE5yKJpW', 'female', NULL, '2004-02-22', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:47', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('681', 'Jeffrey', 'Brooks', '8200727077', 'JeffreyBBrooks@armyspy.com', '$2y$10$OSlSin2cgXHEViQJ/.dFuOMwMybMIm3wibY3hWr2nl1UQvCC45/di', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:47', '2023-11-22 12:41:47', NULL);
INSERT INTO `users` VALUES ('682', 'Leonor', 'Oliveira', '8200727077', '2022-2312319', '$2y$10$oQKBhZ/TQBuKGoNSqQbjP./feeXHdkkiCNOSZKPLNLea5EMT2jTy6', 'female', NULL, '2014-03-19', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:47', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('683', 'Staci', 'Bailey', '8200727077', 'StaciRBailey@cuvox.de', '$2y$10$X3dxgXO1UHg2RczQEI8GhegiH8aFw.3BZ4XTw5U9Q0vHVV2Mv89UO', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:48', '2023-11-22 12:41:48', NULL);
INSERT INTO `users` VALUES ('684', 'Lucas', 'Ribeiro', '8200727077', '2022-2312320', '$2y$10$HP8aDUmaYowNnxUAOEFbCOfQlWYF95gkJ9b6OKpdGCeGTqArUxsQe', 'male', NULL, '2006-10-28', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:48', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('685', 'Jennifer', 'Jones', '8200727077', 'JenniferTJones@rhyta.com', '$2y$10$RJ2p89g0Ro9J5eZOPg3zaukaR7nuJ3X/adK8UaUs6KdsRo3bdyzE2', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:48', '2023-11-22 12:41:48', NULL);
INSERT INTO `users` VALUES ('686', 'Manuela', 'Cavalcanti', '8200727077', '2022-2312321', '$2y$10$QaGhS8lf20YShfYJVqQmru3wbRweogtt9eTNT2JUh7g//U7TYXmFG', 'female', NULL, '2007-09-25', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:49', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('687', 'Denise', 'Arteaga', '8200727077', 'DeniseLArteaga@einrot.com', '$2y$10$gO9ZVRJzCVTeDEqqIdkGReqoI6eTlMZWmVjG7dkGJZtIkxLZfE7cK', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:49', '2023-11-22 12:41:49', NULL);
INSERT INTO `users` VALUES ('688', 'Emilly', 'Alves', '8200727077', '2022-2312322', '$2y$10$m66SNafJouANe4cOMy/muuANhmH7pFDfuOjQ1NoWWn7Gep2tGjnoW', 'female', NULL, '2008-03-09', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:49', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('689', 'Harold', 'Beasley', '8200727077', 'HaroldMBeasley@teleworm.us', '$2y$10$QsV1EiTQJuOJDEEaU82piepuacN10FawgPLUzB1oExASPEOenrrJC', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:50', '2023-11-22 12:41:50', NULL);
INSERT INTO `users` VALUES ('690', 'Caio', 'Costa', '8200727077', '2022-2312323', '$2y$10$d4Rx6MLurcAghsCQmNOMGuyAfOcYxY8sR/CPtbc6rF3M89t6OKQQa', 'male', NULL, '2011-10-19', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:50', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('691', 'William', 'Adkins', '8200727077', 'WilliamSAdkins@cuvox.de', '$2y$10$q2WN89JXvbUGPTOkHZvq3enumocd4wzn6M8S5uI/R6bMEYzGvaDtW', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:50', '2023-11-22 12:41:50', NULL);
INSERT INTO `users` VALUES ('692', 'Victor', 'Gomes', '8200727077', '2022-2312324', '$2y$10$HWj41NYsASTJ31r0KA8tYetpujVOsFOvrcOwhaeuMs7ZygEEv9d.K', 'male', NULL, '2010-09-14', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:51', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('693', 'James', 'Hall', '8200727077', 'JamesDHall@cuvox.de', '$2y$10$fl5yv2kKzDa3d8oSk2Y1ueKqyZbluAj8pOagLeb/idZixRUxhHqCC', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:51', '2023-11-22 12:41:51', NULL);
INSERT INTO `users` VALUES ('694', 'Nicolas', 'Castro', '8200727077', '2022-2312325', '$2y$10$GdvMGJiOi4vPgoKaR7iIQ.RoRwI8B5xvl2AjzIRugycwAJzCfmy1G', 'male', NULL, '2011-04-22', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:51', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('695', 'Jesse', 'Price', '8200727077', 'JesseMPrice@gustr.com', '$2y$10$1./8kLx/ReHs86QDW6BSTeN5o34IRFKdHTAdknePa5AKs5LEsJInq', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:51', '2023-11-22 12:41:51', NULL);
INSERT INTO `users` VALUES ('696', 'Davi', 'Araujo', '8200727077', '2022-2312326', '$2y$10$uhQnYydhY92r7hKy1MrEduUfTHBrUWPKCf5jt79gdM0jSV484zlaK', 'male', NULL, '2011-01-28', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:52', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('697', 'Terrell', 'Thomas', '8200727077', 'TerrellSThomas@rhyta.com', '$2y$10$z1UdJBF5h7toGJm.ASGTmeIjK52VP9Ch8YR8dn.j1/l1GHlKUcXh.', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:52', '2023-11-22 12:41:52', NULL);
INSERT INTO `users` VALUES ('698', 'Vinicius', 'Pereira', '8200727077', '2022-2312327', '$2y$10$9BG.CO71GWruh9t1n.47ee93qw2qj4vRn2YuNf/CmUs4G.BUBtpCy', 'male', NULL, '2008-01-28', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:52', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('699', 'Brett', 'McKeon', '8200727077', 'BrettCMcKeon@einrot.com', '$2y$10$Wpu2tiM7og.mcDcBG9jhqeXoCnBmjSwTouC4pHDFYhGe.Em1a/29i', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:53', '2023-11-22 12:41:53', NULL);
INSERT INTO `users` VALUES ('700', 'Renan', 'Almeida', '8200727077', '2022-2312328', '$2y$10$Bvyy3DnUygWHNHHIwGzVv.RVpy4ZcCXC1bHZZ.f8c.HJQ3jEuLXRu', 'male', NULL, '2015-02-01', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:53', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('701', 'Thomas', 'Quirk', '8200727077', 'ThomasLQuirk@dayrep.com', '$2y$10$ZuLj6b6YROEYWiDfmfrSsu1wWoqIX5tGkBwhkPUa5/CbOxZav7sbO', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:53', '2023-11-22 12:41:53', NULL);
INSERT INTO `users` VALUES ('702', 'Nicolas', 'Rodrigues', '8200727077', '2022-2312329', '$2y$10$B.Nna8YkfBRbHDZMccJAbe.UGpOA2G.xIFmDpnZGTv2CKzf1z8sUO', 'male', NULL, '2005-12-09', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:54', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('703', 'Harry', 'Carpenter', '8200727077', 'HarryECarpenter@dayrep.com', '$2y$10$M5QNXSxgYS3gC487YeCe.u1mgvzlu1pTqDUa.UxnnjE61Lv2o7ozi', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:54', '2023-11-22 12:41:54', NULL);
INSERT INTO `users` VALUES ('704', 'Luan', 'Alves', '8200727077', '2022-2312330', '$2y$10$EYHfkVCs87Bj5fADsR/.W.tTdagTSEQwvjAUvNkqWRDgIxWHFeI8K', 'male', NULL, '2007-02-07', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:54', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('705', 'Robert', 'Coleman', '8200727077', 'RobertJColeman@fleckens.hu', '$2y$10$7c2Bjy8UsWubEmqpfC0qCO2zxKIZL2n29vsdI4SUPgxIKzVj3mnMi', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:55', '2023-11-22 12:41:55', NULL);
INSERT INTO `users` VALUES ('706', 'Julian', 'Pinto', '8200727077', '2022-2312331', '$2y$10$zCdAVg6F4Ihi9zvp3snFMOpdD4chU9VdtHggNGV543uAjanQqdLAy', 'male', NULL, '2004-09-28', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:55', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('707', 'Phillip', 'Cathey', '8200727077', 'PhillipDCathey@fleckens.hu', '$2y$10$h0odwnNmh378Kp1HQVUES.1KwYH2rh6.a278sTmmX7t26/CHimJ1m', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:55', '2023-11-22 12:41:55', NULL);
INSERT INTO `users` VALUES ('708', 'Rebeca', 'Goncalves', '8200727077', '2022-2312332', '$2y$10$Ea/8aFjA9GTZJW/GiiPttOrBCGaHjacrvJMLmTG7PcdIueC.X4Sre', 'female', NULL, '2010-02-19', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:56', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('709', 'Ann', 'Salmons', '8200727077', 'AnnCSalmons@fleckens.hu', '$2y$10$shGpwGI.0EHsKv7EWdNco.xhmihcX3bzV9MGz1UaRGSXBwyJ0FS..', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:56', '2023-11-22 12:41:56', NULL);
INSERT INTO `users` VALUES ('710', 'Felipe', 'Almeida', '8200727077', '2022-2312333', '$2y$10$h8SH/vthmMZkGqklySeKLutxn7YZSwV/kjGtxY1SOXTrXNPyUZjHS', 'male', NULL, '2015-10-19', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:57', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('711', 'Heather', 'Smith', '8200727077', 'HeatherJSmith@jourrapide.com', '$2y$10$AbE2r43dgJiYW25CcrWINeC6uRmcO0KaE.lCx7Ob.oHkDZhaJRvAK', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:57', '2023-11-22 12:41:57', NULL);
INSERT INTO `users` VALUES ('712', 'Vitoria', 'Cavalcanti', '8200727077', '2022-2312334', '$2y$10$.yH9eyhjFQi8SeE3UueJAunfSkeGBJ6vtgwrmavLofVD8o4YvDSMG', 'female', NULL, '2009-05-19', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:57', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('713', 'Brian', 'Trent', '8200727077', 'BrianBTrent@armyspy.com', '$2y$10$aHdWUpkHXdfjHD1t3oEkgOU/mUObg2IKiILZ7JsNsg7XBA1dnczUO', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:58', '2023-11-22 12:41:58', NULL);
INSERT INTO `users` VALUES ('714', 'Vinicius', 'Pereira', '8200727077', '2022-2312335', '$2y$10$wJ0qAqHOqu2bK8SUL3zsqetuj8VWChsfyIfpWSKadmf37cL3F5jMu', 'male', NULL, '2013-04-17', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:58', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('715', 'Nancy', 'Pagan', '8200727077', 'NancyGPagan@superrito.com', '$2y$10$gtGRn2eEdDBlCbqnOoaY6uHd9hppqET7JMStkJmQq8hZAfDJltbCi', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:58', '2023-11-22 12:41:58', NULL);
INSERT INTO `users` VALUES ('716', 'Leila', 'Ribeiro', '8200727077', '2022-2312336', '$2y$10$gecpL0Nzg0ZNEGLESN5ZzuLkH/mFdM4qp5QgWtVXvEtofjTq2DGyq', 'female', NULL, '2003-05-26', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:59', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('717', 'Heather', 'Young', '8200727077', 'HeatherLYoung@superrito.com', '$2y$10$B18u2UwdrWyjHJgLfuDUveGels8by.DhhrStpJGLryyJPacWplJY2', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:59', '2023-11-22 12:41:59', NULL);
INSERT INTO `users` VALUES ('718', 'Carla', 'Castro', '8200727077', '2022-2312337', '$2y$10$zjwLMtwbNGmkD/SsLTx9cOETtK8ersCFNQ2NAkVYZ9DnDPrJWryXK', 'female', NULL, '2005-11-21', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:41:59', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('719', 'Vincent', 'Ricker', '8200727077', 'VincentJRicker@superrito.com', '$2y$10$V/Pxlc96nJIjbQVdmnd2luleoyY8F53LFZdJ6olEo87pebAVQDmlS', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:42:00', '2023-11-22 12:42:00', NULL);
INSERT INTO `users` VALUES ('720', 'Mateus', 'Melo', '8200727077', '2022-2312338', '$2y$10$g2UDYTH8Cm2JPhrulOYsUOTWtMG8hMyrlsupHlWNGcf4nKjBC90Nm', 'male', NULL, '2012-07-15', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:42:00', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('721', 'Thomas', 'Perry', '8200727077', 'ThomasLPerry@gustr.com', '$2y$10$X335eSIyAR7YpV6Z3OiHVOnY8bxILWeKLgO2rtSWSK/kW5CnoaG8C', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:42:00', '2023-11-22 12:42:00', NULL);
INSERT INTO `users` VALUES ('722', 'Maria', 'Gomes', '8200727077', '2022-2312339', '$2y$10$8E5x.EciixaZXvSMXDFZKe2KRVoMYHC2prAo/aMIfDzzjUAcRtIoq', 'female', NULL, '2011-05-31', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:42:01', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('723', 'Herbert', 'Minor', '8200727077', 'HerbertBMinor@rhyta.com', '$2y$10$JOCoIXrFAcmravQOcF3w4udyU3JwpKcP044mHxLhQ2KP1e.xrBxJ6', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:42:01', '2023-11-22 12:42:01', NULL);
INSERT INTO `users` VALUES ('724', 'Caua', 'Barbosa', '8200727077', '2022-2312340', '$2y$10$XAQefVUxQ3.i2x99pbFFlecFO0wEqxU15.YP/y4krALrFd5Vdf.Xi', 'male', NULL, '2008-11-15', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:42:01', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('725', 'Brian', 'Roberts', '8200727077', 'BrianDRoberts@fleckens.hu', '$2y$10$HVCYDvp5Al2iGHbl3bddKOkgTZhiD.KID92sqeEaXH9mmNke0GVLS', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:42:02', '2023-11-22 12:42:02', NULL);
INSERT INTO `users` VALUES ('726', 'Estevan', 'Castro', '8200727077', '2022-2312341', '$2y$10$MpgNnsEqGnrqVvggvKPMo.EGy/0gJuyIklp1wZlP/BRwYRW3fADFm', 'male', NULL, '2004-12-06', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:42:02', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('727', 'Vickey', 'Warfield', '8200727077', 'VickeyKWarfield@dayrep.com', '$2y$10$uB8fiJ/G5d3dflHHCXA4MuthgydVufygYQkQEmcOwVswARxCNblCO', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:42:02', '2023-11-22 12:42:02', NULL);
INSERT INTO `users` VALUES ('728', 'Enzo', 'Goncalves', '8200727077', '2022-2312342', '$2y$10$KurOCWtRwR56XZf9wTz3Y.BPpV3mkEwvohNXfbvyFMWhpjaGVllbi', 'male', NULL, '2010-07-27', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:42:03', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('729', 'Erma', 'Green', '8200727077', 'ErmaRGreen@einrot.com', '$2y$10$JTXLgo1S4EE5Sp9gndBZGOgMW0jmtY6kIxVwqMetSmav2tIFZ/55K', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:42:03', '2023-11-22 12:42:03', NULL);
INSERT INTO `users` VALUES ('730', 'Livia', 'Rodrigues', '8200727077', '2022-2312343', '$2y$10$/0CcIww40NkMc371WFRJaOOfitxQ0kA56W7E9kXkOIjBADi13fiZG', 'female', NULL, '2007-12-19', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:42:03', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('731', 'John', 'Harris', '8200727077', 'JohnTHarris@jourrapide.com', '$2y$10$0GV7Hnqzx3mJPtnt4IwhXe1CyeswugyIKHN29/shWSFDrUL1y1UqC', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:42:04', '2023-11-22 12:42:04', NULL);
INSERT INTO `users` VALUES ('732', 'Rodrigo', 'Barbosa', '8200727077', '2022-2312344', '$2y$10$DxkhwCfPwnv7NNdsS7shG.fbDgy8JmZrUS5hFvzQxUh1KhcKK52r2', 'male', NULL, '2005-07-17', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:42:04', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('733', 'Virgie', 'Rodriguez', '8200727077', 'VirgieTRodriguez@teleworm.us', '$2y$10$ZWiS1Fi8u/LGo7BcyPcb/O2T2szJoHusz6imyp9ddQASrOi0G7Qe.', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:42:04', '2023-11-22 12:42:04', NULL);
INSERT INTO `users` VALUES ('734', 'Rodrigo', 'Alves', '8200727077', '2022-2312345', '$2y$10$n8XJ8B3Vs5kz6kDdSWOqL.qF.68h9qZNG0vmvm0L9eWiTZpEKjANS', 'male', NULL, '2005-10-06', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:42:05', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('735', 'Kevin', 'Brown', '8200727077', 'KevinJBrown@teleworm.us', '$2y$10$TiGP6lYw5.nLJ.XqAPxGB.dn3Jhso5YiKNAWtu0NfAuGIohRnQKk6', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:42:05', '2023-11-22 12:42:05', NULL);
INSERT INTO `users` VALUES ('736', 'Julian', 'Castro', '8200727077', '2022-2312346', '$2y$10$bhhGZNIeq0d/PkkzNpIiteW77WmyK9h/ufdRlff5Ki9hNxquTCsPG', 'male', NULL, '2007-02-02', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:42:05', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('737', 'Sandra', 'Lomax', '8200727077', 'SandraGLomax@superrito.com', '$2y$10$INFAJWcvwM/PvM/A9ObKgez4jO5GPnFx3n4GaXoD2zPw3pm3wkqsu', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:42:06', '2023-11-22 12:42:06', NULL);
INSERT INTO `users` VALUES ('738', 'Eduardo', 'Pereira', '8200727077', '2022-2312347', '$2y$10$WUiCvOvmly/Bju8vZAsDkOAAIGxAt6wkbHmI/9j/D0I9rEY3pZahC', 'male', NULL, '2011-11-16', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:42:06', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('739', 'Luther', 'McDonald', '8200727077', 'LutherKMcDonald@rhyta.com', '$2y$10$h7GWBospwFNW3jejnkVxFeZoJL9Y0B3uM5GlbUTzpLIy5sDfz7uKy', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:42:06', '2023-11-22 12:42:06', NULL);
INSERT INTO `users` VALUES ('740', 'Vitoria', 'Souza', '8200727077', '2022-2312348', '$2y$10$mW/4lYK8LYf8hVRRrhvUoeEHbVtk1cYSszW1.E8AD/7DEWicEq5q.', 'female', NULL, '2015-05-30', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:42:07', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('741', 'Erika', 'Hubert', '8200727077', 'ErikaLHubert@armyspy.com', '$2y$10$sWdOjnPeuyT/phmqkeTFy.uAFbj77C7XZKaqahokhsqQpZA6eR/PS', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:42:07', '2023-11-22 12:42:07', NULL);
INSERT INTO `users` VALUES ('742', 'Ryan', 'Cardoso', '8200727077', '2022-2312349', '$2y$10$ZeS7KTjDeN8vcdnUWV5OQu5NnhhQEN0PLhgrDfBY/DMywpFaVh8A6', 'male', NULL, '2006-01-20', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:42:07', '2023-11-22 12:51:04', NULL);
INSERT INTO `users` VALUES ('743', 'Jannie', 'Hancock', '8200727077', 'JannieEHancock@teleworm.us', '$2y$10$bgcBAsjSjOBih5alpLYKgO8WKbKpt.iGSuF8n4VktZAF81iGv35Ma', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:34', '2023-11-22 12:51:34', NULL);
INSERT INTO `users` VALUES ('744', 'Emily', 'Silva', '8200727077', '2022-2312350', '$2y$10$ENlQGbmOR2dU6lbyiCUfYO0viSC6vwXOALsK6C5BRomp1fTuht7yi', 'female', NULL, '2011-05-22', NULL, NULL, NULL, '1', '0', 'dY0sPYFZQS6D_oVKB31YBa:APA91bH39uJRMn-qr_wwAgb4aXRtETCPzR6w7ZOx97NHvuKvmw0LhoCgEip2sslRuj6c434MvdcZqTAxRN5grI3Rhx1c890BCT5WEXoFwRsS0x1DezrdWu6mkmD4kFxVBKNbW1qXt2QI', '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:34', '2024-07-17 15:15:49', NULL);
INSERT INTO `users` VALUES ('745', 'Sarah', 'Laporte', '8200727077', 'SarahMLaporte@dayrep.com', '$2y$10$WNkfgb21YZ0KVSEULXLykuFvUAOwBfCqJ2iNN/6Dmok1/KbECOpyi', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:34', '2023-11-22 12:51:34', NULL);
INSERT INTO `users` VALUES ('746', 'Raissa', 'Fernandes', '8200727077', '2022-2312351', '$2y$10$sHVMEonPwNjWyRtdzh6ObuFoILHuRuyvNpkWLh.qj6Mulydm3qmxy', 'female', NULL, '2010-01-01', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:35', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('747', 'John', 'Kennedy', '8200727077', 'JohnLKennedy@rhyta.com', '$2y$10$uN5nqPq65ANgwsJd6RoeYuZeHU019N3g7tA.1sL0iw5dRXyge8K42', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:35', '2023-11-22 12:51:35', NULL);
INSERT INTO `users` VALUES ('748', 'Mariana', 'Oliveira', '8200727077', '2022-2312352', '$2y$10$VEc91To2XWEtEAZJgG/vQ..aiubh7OKSYckrRFTBiQ3iLobbMJ5JS', 'female', NULL, '2009-02-07', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:35', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('749', 'Ramon', 'Wells', '8200727077', 'RamonBWells@dayrep.com', '$2y$10$IEMY2/b9IIFXZMvuRNvysehyN1PPWzKx8r4d1mqp8P3yTJ4pmf7JG', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:36', '2023-11-22 12:51:36', NULL);
INSERT INTO `users` VALUES ('750', 'Vinicius', 'Souza', '8200727077', '2022-2312353', '$2y$10$/sEje9TNOAc1RLrd4NlM8uEUE4HurmBChRN1KWEJlJBa3i3cW80Ry', 'male', NULL, '2008-11-03', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:36', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('751', 'Cecilia', 'Lockwood', '8200727077', 'CeciliaPLockwood@jourrapide.com', '$2y$10$Or6uxVHPVe/EpDbh2jHEWeACgSv7cZwus4ZDTwa8GCkBjebUidmZ6', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:36', '2023-11-22 12:51:36', NULL);
INSERT INTO `users` VALUES ('752', 'Luiz', 'Cunha', '8200727077', '2022-2312354', '$2y$10$n9nbmR4la3B1ovBW86bIN.HU5q2iXebephbprCg4bTpoznFye30g2', 'male', NULL, '2012-09-26', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:36', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('753', 'Aaron', 'Price', '8200727077', 'AaronKPrice@fleckens.hu', '$2y$10$pO6tm.KMRipwo3b3XKbEl.CfDje2JNjkbaIkzVHxkNlA2HB2h8g/O', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:37', '2023-11-22 12:51:37', NULL);
INSERT INTO `users` VALUES ('754', 'Rafael', 'Oliveira', '8200727077', '2022-2312355', '$2y$10$yT6.7ZWklhXYpVMK9pzYqumqrkozTO9wj83jCitxTDUWysX12BZq2', 'male', NULL, '2009-01-07', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:37', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('755', 'Jason', 'Trevino', '8200727077', 'JasonGTrevino@superrito.com', '$2y$10$mIKdgVEQ23UapWNp83wl0uV2GrOxRYnh4UVWvahjm79yZPis.92iK', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:38', '2023-11-22 12:51:38', NULL);
INSERT INTO `users` VALUES ('756', 'Nicolash', 'Pereira', '8200727077', '2022-2312356', '$2y$10$pC9NQ6WzrSQZ4.XT3nkAA.AtwSnUpAO3ml9qoIIUnoZPoB1zqPT4.', 'male', NULL, '2006-07-17', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:38', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('757', 'Dolores', 'Cerna', '8200727077', 'DoloresMCerna@rhyta.com', '$2y$10$yKaVuXb0SC17LBYAUTDHTOFUrHmW/38pNKiHRAzzFIJgLFlnOvzPm', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:38', '2023-11-22 12:51:38', NULL);
INSERT INTO `users` VALUES ('758', 'Leonor', 'Barros', '8200727077', '2022-2312357', '$2y$10$X2narBwm7lS29ds13DuA/u6sHVL7d4gfdyDs/6IV4m2kJMB.HSuYC', 'female', NULL, '2010-05-04', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:39', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('759', 'Troy', 'Socha', '8200727077', 'TroyJSocha@jourrapide.com', '$2y$10$VNBFE5tzBussVjIapigri.WobKuzzBiHvqXUT5DCy35J6eheLSCZe', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:39', '2023-11-22 12:51:39', NULL);
INSERT INTO `users` VALUES ('760', 'Vinicius', 'Cunha', '8200727077', '2022-2312358', '$2y$10$B4unMBe18B/pLDnAKVqXJOW8qn5taHfl.AjBC6UFf.gH0CcVNWG6m', 'male', NULL, '2013-04-16', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:39', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('761', 'Helen', 'Barnes', '8200727077', 'HelenLBarnes@einrot.com', '$2y$10$IwBvN9HU4JTgJhZnlDVl3u6W1iHGNfzooseEJIqEBvVf8/K7yU7CK', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:40', '2023-11-22 12:51:40', NULL);
INSERT INTO `users` VALUES ('762', 'Andre', 'Oliveira', '8200727077', '2022-2312359', '$2y$10$CAuCkL/D/8mNWDg/nn96MuVkObRHJUjOCgJcT/2.j1XWkTgWfZsIm', 'male', NULL, '2015-07-07', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:40', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('763', 'Yvonne', 'Spikes', '8200727077', 'YvonneESpikes@fleckens.hu', '$2y$10$JaRhIrfIK0j0COQh521UKOfMROX944Qqshho1EW33glvfwk6RYS9.', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:40', '2023-11-22 12:51:40', NULL);
INSERT INTO `users` VALUES ('764', 'Marcos', 'Silva', '8200727077', '2022-2312360', '$2y$10$MyrBe8B0Yr1.oZVodHThuujwWPqcquBpyKyo3PJrGI.O1O8ZzsmJu', 'male', NULL, '2003-10-02', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:41', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('765', 'Leo', 'Redington', '8200727077', 'LeoMRedington@gustr.com', '$2y$10$QHNi4ZZR/MllpuQF/oKD5ODP1wJpT./GJd6AREzJ8b0GlWWKcsR4S', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:41', '2023-11-22 12:51:41', NULL);
INSERT INTO `users` VALUES ('766', 'Camila', 'Dias', '8200727077', '2022-2312361', '$2y$10$1IO34i1MAg5ojGQo1/OFz.Akw1ZHjPti8uvTrjDgNHbsy4Ho.TLu6', 'female', NULL, '2004-07-26', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:41', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('767', 'James', 'Hutchins', '8200727077', 'JamesSHutchins@einrot.com', '$2y$10$nqH9XED1JLgSAzVwToc3.utx/ut6./ze3svXJjdCPf2W0VrTYfns6', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:42', '2023-11-22 12:51:42', NULL);
INSERT INTO `users` VALUES ('768', 'Felipe', 'Castro', '8200727077', '2022-2312362', '$2y$10$2J9P0wkWtNqQyCucJ4VnHeBTQP2OB.ZNmBYEoOgvrFmf6p76IxrXu', 'male', NULL, '2003-07-20', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:42', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('769', 'Clifton', 'Perkins', '8200727077', 'CliftonLPerkins@gustr.com', '$2y$10$fuJxAkDibMJOWZeaPsNHN.HbulewQp9HCuKm6j.9zbW049kn4M0PS', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:42', '2023-11-22 12:51:42', NULL);
INSERT INTO `users` VALUES ('770', 'Gabrielly', 'Carvalho', '8200727077', '2022-2312363', '$2y$10$ifKMJ5SSC94sop.A629/pOmv5h8hlmxZ5SooueGUbqwDNO4wLpGuu', 'female', NULL, '2013-09-09', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:43', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('771', 'Danielle', 'Hess', '8200727077', 'DanielleMHess@armyspy.com', '$2y$10$uod1mfwAA91kWADiqJaENeamM5Xz1XUCKLJYGNDfxaJW7D/Euj/tK', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:43', '2023-11-22 12:51:43', NULL);
INSERT INTO `users` VALUES ('772', 'Vitoria', 'Cavalcanti', '8200727077', '2022-2312364', '$2y$10$UCZ5Pbpge7CRCNHYbJu11OqDDVDHX6Y9.hqzofBLpQjCkVVamet1e', 'female', NULL, '2007-12-21', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:43', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('773', 'Deena', 'Evans', '8200727077', 'DeenaMEvans@rhyta.com', '$2y$10$2X9t/cIp96FYS9I2SN7fuu2lQG.9Jw3ACLlILi2dOFS3Ty0zhwkxq', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:44', '2023-11-22 12:51:44', NULL);
INSERT INTO `users` VALUES ('774', 'Estevan', 'Barbosa', '8200727077', '2022-2312365', '$2y$10$.SxYnQsGRokBlqVyqgh5Nexsw3SwVqSjQI5DPdIWEOHcz6Ih0G0Ey', 'male', NULL, '2014-02-23', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:44', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('775', 'Rosetta', 'Sampson', '8200727077', 'RosettaMSampson@superrito.com', '$2y$10$RX7yaKwKfWzM.fwmA8Ag8eFUDpisgXlMyAIzHX/4LfWAS/BOcnSju', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:44', '2023-11-22 12:51:44', NULL);
INSERT INTO `users` VALUES ('776', 'Eduarda', 'Fernandes', '8200727077', '2022-2312366', '$2y$10$lQZociU4EUJ72hMzzs0r7OzrkMq7N26kctJck1TXUlmaftw27FTQy', 'female', NULL, '2009-08-07', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:45', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('777', 'Bianca', 'Wilkerson', '8200727077', 'BiancaSWilkerson@teleworm.us', '$2y$10$ml4UHktkFyQEVeiCveaTse4qLmBgOt8rut4K7YTr/.2RXQ/xaFlIa', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:45', '2023-11-22 12:51:45', NULL);
INSERT INTO `users` VALUES ('778', 'Mateus', 'Barros', '8200727077', '2022-2312367', '$2y$10$u5ABiUN./BBtQ8dXH3DBq.kumelo.yqhylGmcewXyFfAmzZoa9V.G', 'male', NULL, '2006-06-27', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:45', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('779', 'Antonio', 'Lopez', '8200727077', 'AntonioMLopez@dayrep.com', '$2y$10$nxj6TOp9G23Ui7kapj4.r.b7z2Z2TDKyUJwUozWbOwoTA9XBOU4QS', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:45', '2023-11-22 12:51:45', NULL);
INSERT INTO `users` VALUES ('780', 'Murilo', 'Ribeiro', '8200727077', '2022-2312368', '$2y$10$EeNLfWFMV8Sp7io.RklwN.1MCIXw7SJXzkL4m5qTunLJb16yI9KJi', 'male', NULL, '2013-07-19', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:46', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('781', 'Jesse', 'Moten', '8200727077', 'JesseSMoten@jourrapide.com', '$2y$10$ZvvhAuJWBsS5n.VBO/HHrep9RXv7vYClO2MN4S/oT5ewPfw4PymQa', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:46', '2023-11-22 12:51:46', NULL);
INSERT INTO `users` VALUES ('782', 'Miguel', 'Fernandes', '8200727077', '2022-2312369', '$2y$10$yl5tJFVptIFH89k8K320LOYRIAVWb7lWZuW4jBsuGQzxbptHWPQ3K', 'male', NULL, '2014-09-26', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:46', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('783', 'Annie', 'Reddy', '8200727077', 'AnnieSReddy@armyspy.com', '$2y$10$M784hrnaTW0PhAkR/Udo6.pYmsKr.RhLerJ/HtQuoRWVVd24ASBs.', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:47', '2023-11-22 12:51:47', NULL);
INSERT INTO `users` VALUES ('784', 'Leticia', 'Cavalcanti', '8200727077', '2022-2312370', '$2y$10$4oMVglV77P71hl/Y6ruBBuvhFrxQUE2cnUhTsIKyDdlZTnFShZNVe', 'female', NULL, '2004-09-06', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:47', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('785', 'Michael', 'Frye', '8200727077', 'MichaelLFrye@armyspy.com', '$2y$10$hr/glYU6Kl8Quq5xCd7d/utQE413jgbaBVfy3QrtaXgSnBjvaHuyG', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:47', '2023-11-22 12:51:47', NULL);
INSERT INTO `users` VALUES ('786', 'Renan', 'Ribeiro', '8200727077', '2022-2312371', '$2y$10$gY92RliRpGerUxlt57uKz.FgXqxEJThuugP8.THTFx.XBDsKd.nRy', 'male', NULL, '2003-06-03', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:48', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('787', 'Rebecca', 'Spadaro', '8200727077', 'RebeccaMSpadaro@dayrep.com', '$2y$10$wsyPykV5OxOS.o5ePbA32ek.Hu2G4Tr87qzQfI6CEUx0cTCJjqFT2', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:48', '2023-11-22 12:51:48', NULL);
INSERT INTO `users` VALUES ('788', 'Danilo', 'Sousa', '8200727077', '2022-2312372', '$2y$10$rOpZyWt8TA89Dzb9aeU6Qeqy5B8nEQkLKEpCvXtp9bMs5AQh5dtM.', 'male', NULL, '2007-04-04', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:48', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('789', 'Charles', 'Brooks', '8200727077', 'CharlesNBrooks@superrito.com', '$2y$10$A.0HT9OdUw9sXyuQb/ZnTuENd5Ol6Q2rxKs02TEVtQj3re2L9HbZK', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:49', '2023-11-22 12:51:49', NULL);
INSERT INTO `users` VALUES ('790', 'Diogo', 'Azevedo', '8200727077', '2022-2312373', '$2y$10$shzs9pUEhFyKk8AEei.XDOHkaXPGVVTa.fafS/RW8dKTDqYb9ljre', 'male', NULL, '2004-02-23', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:49', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('791', 'Richard', 'Sierra', '8200727077', 'RichardGSierra@fleckens.hu', '$2y$10$gYuazavDOwUMNFFc64Bkauor3p89o0kZNKI06KUFrVBPpRxfltqES', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:49', '2023-11-22 12:51:49', NULL);
INSERT INTO `users` VALUES ('792', 'Larissa', 'Ferreira', '8200727077', '2022-2312374', '$2y$10$fHJucwNU.LWfETBBbznCwuo/tHfkjhbrR9H3QC4EBmdASbO2wAa1u', 'female', NULL, '2011-11-19', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:50', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('793', 'Kenneth', 'Mills', '8200727077', 'KennethNMills@armyspy.com', '$2y$10$HEM1h0nP4PuvPCFIpt8wP.pPWTYmOqHBYYPJfd2K3tWY.9hz8iGi6', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:50', '2023-11-22 12:51:50', NULL);
INSERT INTO `users` VALUES ('794', 'Carlos', 'Martins', '8200727077', '2022-2312375', '$2y$10$5JZP9E7egsvIkUQqK3i2Q.S5njCxWgKqtm4DTY5i1X4xjgWw6k0pG', 'male', NULL, '2003-04-17', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:50', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('795', 'Monica', 'Vieira', '8200727077', 'MonicaSVieira@dayrep.com', '$2y$10$uctPXDSxsRCXSH3pfuXD3O9vob5KBFQQbiiRpA.5PvJYWwc0NAH/e', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:51', '2023-11-22 12:51:51', NULL);
INSERT INTO `users` VALUES ('796', 'Vinicius', 'Cunha', '8200727077', '2022-2312376', '$2y$10$XscvIrKz62/YcZdq2sLmUOYXfBAlYKvW58zqAdWmBj3s0PzX9Q3.W', 'male', NULL, '2012-04-28', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:51', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('797', 'Michelle', 'Goins', '8200727077', 'MichelleRGoins@cuvox.de', '$2y$10$y/DYeHOyF9401FEMUWQZnOR1rWxUng3BsD3o0fTqbrWHdNHBpCgOC', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:51', '2023-11-22 12:51:51', NULL);
INSERT INTO `users` VALUES ('798', 'Kaue', 'Silva', '8200727077', '2022-2312377', '$2y$10$thLLS2sHR6wjLgQ4x6tfdOEPpRnSHsVHNxAkFqUav2G4i592WBKDm', 'male', NULL, '2007-10-04', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:52', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('799', 'Caitlin', 'McKenzie', '8200727077', 'CaitlinDMcKenzie@armyspy.com', '$2y$10$SkTYn.GoRpZ9/Eci2vNU6ez8N1H.xQM9mfxGMXkATypWp7tWZZEB6', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:52', '2023-11-22 12:51:52', NULL);
INSERT INTO `users` VALUES ('800', 'Evelyn', 'Martins', '8200727077', '2022-2312378', '$2y$10$Ddw9LALQ.aLgGTzMQT6iU.LHHsDiT4Y00ReM8tja08ckDKY/vLyk2', 'female', NULL, '2005-01-01', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:52', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('801', 'George', 'Ornelas', '8200727077', 'GeorgeCOrnelas@armyspy.com', '$2y$10$31XCFpDemw/GDh5AaKmabuZ9v2Mmg5j/zmqV4Q1mt6PG0nC011PLu', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:53', '2023-11-22 12:51:53', NULL);
INSERT INTO `users` VALUES ('802', 'Alex', 'Barros', '8200727077', '2022-2312379', '$2y$10$npLwjo/kuL7f.86475lws.dGuismC571p47gaml1pkGW86QCol/MK', 'male', NULL, '2003-11-01', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:51:53', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('803', 'Cecil', 'McCall', '8200727077', 'CecilBMcCall@dayrep.com', '$2y$10$KNTcUv7ABFv6qxrmWPNr2u0vWUv0d7/l38kuNOu6RzQBtWHtn3pwe', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:03', '2023-11-22 12:52:03', NULL);
INSERT INTO `users` VALUES ('805', 'Harvey', 'Link', '8200727077', 'HarveyJLink@rhyta.com', '$2y$10$XNP1hhBG5C55WUEkdHepjeoh/yRYKHEy06QB/5aAc69y7EhcFfpM6', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:04', '2023-11-22 12:52:04', NULL);
INSERT INTO `users` VALUES ('807', 'Antonio', 'Senter', '8200727077', 'AntonioCSenter@cuvox.de', '$2y$10$8cZvNUSeC7AXj92.jBNPM.CRCdZcKm4Paxda6sJJ5vVr5WBTIRXoO', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:04', '2023-11-22 12:52:04', NULL);
INSERT INTO `users` VALUES ('809', 'Jason', 'McIntosh', '8200727077', 'JasonMMcIntosh@superrito.com', '$2y$10$cthrnHul6Ids5qrN4Vh89.t3m4N1.4lp7lnQiqptGLT6W8Q7YwjVG', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:05', '2023-11-22 12:52:05', NULL);
INSERT INTO `users` VALUES ('811', 'Thomas', 'Petit', '8200727077', 'ThomasCPetit@cuvox.de', '$2y$10$YwkbHaI5nrl34Siq8D6QZ.5ShY8HAMZ/RFd5js5Z.JytbkDq5j7wu', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:05', '2023-11-22 12:52:05', NULL);
INSERT INTO `users` VALUES ('813', 'Jimmy', 'Feldmann', '8200727077', 'JimmyCFeldmann@armyspy.com', '$2y$10$uvIqKgqOtuUdTRC22Um/B.bUVaIJkc.HNwFVEsWxnZjBVI/e1k/OO', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:06', '2023-11-22 12:52:06', NULL);
INSERT INTO `users` VALUES ('815', 'Julia', 'Emond', '8200727077', 'JuliaAEmond@cuvox.de', '$2y$10$QG5IQwHVIWxaxPY0Lycb0eLJjn4LbXFHJ6CS07aWBK1XnMnW43ale', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:07', '2023-11-22 12:52:07', NULL);
INSERT INTO `users` VALUES ('817', 'Lisa', 'Holmes', '8200727077', 'LisaTHolmes@rhyta.com', '$2y$10$gxu5f5xCfPJz2hmLtnN5COr9Ejy.y.vmdeDoi.BILRhiDR2Qhp01a', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:07', '2023-11-22 12:52:07', NULL);
INSERT INTO `users` VALUES ('819', 'Debra', 'Matamoros', '8200727077', 'DebraDMatamoros@dayrep.com', '$2y$10$wii0qpM778z7yluCM3hvveVJDnVKp1bjXxgZUOY1seD3.BnYpOe66', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:08', '2023-11-22 12:52:08', NULL);
INSERT INTO `users` VALUES ('821', 'Shannon', 'James', '8200727077', 'ShannonPJames@dayrep.com', '$2y$10$1DjxuYYh9DG1LUi6zRCXU.zd/EfFNlV2IyPH3PNfOb0ULzKPuNDyG', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:09', '2023-11-22 12:52:09', NULL);
INSERT INTO `users` VALUES ('823', 'Tony', 'Herman', '8200727077', 'TonySHerman@cuvox.de', '$2y$10$9haes0Nr/hgnbzK84q67vOOsYVOrxtNugaAPN0RVdEmA8eeJQoia.', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:09', '2023-11-22 12:52:09', NULL);
INSERT INTO `users` VALUES ('825', 'Patrick', 'Takahashi', '8200727077', 'PatrickGTakahashi@jourrapide.com', '$2y$10$rgmVv2nZb1rbz58p.ary7uBBts3pPn2UcBDJAhvQNIFWO3vJAx8Jy', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:10', '2023-11-22 12:52:10', NULL);
INSERT INTO `users` VALUES ('827', 'Robert', 'Cummings', '8200727077', 'RobertMCummings@armyspy.com', '$2y$10$3.QxbmDBv3llnHaRIwju3egaf9Cb7vZrNnrGixtU3waY5HVEVLPMy', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:11', '2023-11-22 12:52:11', NULL);
INSERT INTO `users` VALUES ('829', 'Glenn', 'Osborne', '8200727077', 'GlennBOsborne@gustr.com', '$2y$10$TsHGN/ZtQVrGqoxs/P3an.oYJyzTQWUHBmJGa3XdJEbOaNsk2dQ4O', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:11', '2023-11-22 12:52:11', NULL);
INSERT INTO `users` VALUES ('831', 'Alfred', 'Bernard', '8200727077', 'AlfredABernard@cuvox.de', '$2y$10$m6hAiUv5HNSyQRaJOLPM/emRYcLg/vaNHhDQ7V/RnEwmHBBBIP.p.', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:12', '2023-11-22 12:52:12', NULL);
INSERT INTO `users` VALUES ('833', 'Roslyn', 'Scarborough', '8200727077', 'RoslynBScarborough@gustr.com', '$2y$10$/GUb3KICmHrmwlNuMQ1IZ.Dlt2VPG0R0zZxnp6SK7m6QmueqhMPPS', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:13', '2023-11-22 12:52:13', NULL);
INSERT INTO `users` VALUES ('835', 'Stuart', 'Holland', '8200727077', 'StuartLHolland@gustr.com', '$2y$10$xy0VlpeRqlJQzu9F2miQBOTcU/mjdD9cRKXfO.S6vj9ZT8uZRjXBS', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:13', '2023-11-22 12:52:13', NULL);
INSERT INTO `users` VALUES ('837', 'Sal', 'Peguero', '8200727077', 'SalSPeguero@teleworm.us', '$2y$10$dJ7OAfHUxb1rmLHi.ba5E.zm3MG0broqAnRIKfsVhXo3Fu0x/8uHq', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:14', '2023-11-22 12:52:14', NULL);
INSERT INTO `users` VALUES ('839', 'Jan', 'Ramos', '8200727077', 'JanVRamos@superrito.com', '$2y$10$GZj6dAb3nusMD3mW.dxPmeNsqRv8qNJGdm/g/Vgpec/uSkxQF0aZi', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:15', '2023-11-22 12:52:15', NULL);
INSERT INTO `users` VALUES ('841', 'Robert', 'Gibbs', '8200727077', 'RobertAGibbs@superrito.com', '$2y$10$7Vm1KqOxTra/xjIJLCK9C.FQLO8ksAVxQkBEmAxUSK45ZnRhr9EYi', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:15', '2023-11-22 12:52:15', NULL);
INSERT INTO `users` VALUES ('843', 'Judy', 'Lovell', '8200727077', 'JudyJLovell@einrot.com', '$2y$10$THGU7AszZmNj.u4h8ZJN5uW8OaZm0JOyuVr6mo3nuH0n63MkRVEvm', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:16', '2023-11-22 12:52:16', NULL);
INSERT INTO `users` VALUES ('845', 'Ruby', 'Black', '8200727077', 'RubyJBlack@cuvox.de', '$2y$10$e5l.fI0Y32oUuv6ruKsRm.d4iJNHqw6GkE2JXEsyMi/QaL0DH.THu', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:17', '2023-11-22 12:52:17', NULL);
INSERT INTO `users` VALUES ('847', 'Shirley', 'Lay', '8200727077', 'ShirleyBLay@fleckens.hu', '$2y$10$bsuDz8SCsmVjShFCAk2.n.flxtKNTYBnCGzI.GDrK15cHRo7De/F6', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:17', '2023-11-22 12:52:17', NULL);
INSERT INTO `users` VALUES ('849', 'Thomas', 'Pinson', '8200727077', 'ThomasMPinson@rhyta.com', '$2y$10$HHTdpYkPAzIHVwsYIgbfQ.2rAQfzV9TMOeAVzsU.tGuazJmlAf7.C', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:18', '2023-11-22 12:52:18', NULL);
INSERT INTO `users` VALUES ('851', 'Justine', 'Stephens', '8200727077', 'JustineRStephens@gustr.com', '$2y$10$q8UgsDNkFaFAx9zJg.zMy.uM9lzCibHNqVGCMJ2Ra82mEf63whY/m', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:19', '2023-11-22 12:52:19', NULL);
INSERT INTO `users` VALUES ('853', 'Alice', 'Ohara', '8200727077', 'AliceJOhara@dayrep.com', '$2y$10$GONHs2M.GMpwvlmNDUfZIucByzc4NMODQVSrqyh.2SXpdoSmhGp3S', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:19', '2023-11-22 12:52:19', NULL);
INSERT INTO `users` VALUES ('855', 'Victoria', 'Jernigan', '8200727077', 'VictoriaHJernigan@einrot.com', '$2y$10$DkzYoIzVmr56P8G9mDoLeuzabYrDkKaUyyK8.3T3zoTJkEqLa5Lxm', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:20', '2023-11-22 12:52:20', NULL);
INSERT INTO `users` VALUES ('857', 'Mary', 'Baker', '8200727077', 'MaryCBaker@dayrep.com', '$2y$10$rudZoUoTWZ6c4rLIu7seger6ioPYGrvzLKRGq/PArDOodMMSOu246', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:21', '2023-11-22 12:52:21', NULL);
INSERT INTO `users` VALUES ('859', 'Doris', 'Fabre', '8200727077', 'DorisRFabre@teleworm.us', '$2y$10$FIKpQ0hm4SNv/nyC6G.u4uPfb7WY0EKheqBIq5uelm8ylHbMxTyV6', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:21', '2023-11-22 12:52:21', NULL);
INSERT INTO `users` VALUES ('861', 'Valerie', 'Lugo', '8200727077', 'ValerieJLugo@teleworm.us', '$2y$10$x6t2cJYx7NvThKv7h8K0Zuv37nGym4TLjYKIr0B4dx4BlzX/p9PUW', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:22', '2023-11-22 12:52:22', NULL);
INSERT INTO `users` VALUES ('863', 'Joyce', 'Tyree', '8200727077', 'JoyceATyree@superrito.com', '$2y$10$o.Q9BEPSSdJ4jRQP2/RHsOpXQ7Rvhkylob.8lVOHFGtD2io8QW95O', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:36', '2023-11-22 12:52:36', NULL);
INSERT INTO `users` VALUES ('865', 'Mark', 'Coleman', '8200727077', 'MarkJColeman@rhyta.com', '$2y$10$iEKNjqBwio8gPVsJpc3W6.54ipTYbPL4ttEJHkDRBhC7gN/8bQiU.', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:37', '2023-11-22 12:52:37', NULL);
INSERT INTO `users` VALUES ('867', 'Vera', 'Grisham', '8200727077', 'VeraHGrisham@cuvox.de', '$2y$10$McYxOZRb.D97.NqtLSoaEe8Ux/yXgLgb./EskC/1G6uDdQxnHQHCu', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:38', '2023-11-22 12:52:38', NULL);
INSERT INTO `users` VALUES ('869', 'Mason', 'McClary', '8200727077', 'MasonLMcClary@teleworm.us', '$2y$10$lTTqYm7Xws.runmtp6M0Nejw0uzQwGv0O0IXc8D2JWLMp/toLH21K', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:38', '2023-11-22 12:52:38', NULL);
INSERT INTO `users` VALUES ('871', 'Lisa', 'Winters', '8200727077', 'LisaSWinters@jourrapide.com', '$2y$10$0nJb2K5zrBnev.lQq.Xn..BxJ0ZQcPhSD/.b8KLLHJ88YkPCkGNRm', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:39', '2023-11-22 12:52:39', NULL);
INSERT INTO `users` VALUES ('873', 'Mark', 'Estes', '8200727077', 'MarkKEstes@superrito.com', '$2y$10$fpAQW9H4haRVcSgE9q.AaO3NJcmVAF5atGXxX0R4sbFYASEj5KBxK', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:39', '2023-11-22 12:52:39', NULL);
INSERT INTO `users` VALUES ('875', 'Francis', 'Roybal', '8200727077', 'FrancisRRoybal@armyspy.com', '$2y$10$B.17yOLmlUbnTE3HYbXWPunej71zA6vxe8NwDbLk2/BHndQvScgBu', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:40', '2023-11-22 12:52:40', NULL);
INSERT INTO `users` VALUES ('877', 'Bradley', 'Jackson', '8200727077', 'BradleyJJackson@rhyta.com', '$2y$10$rhZ6AkPoEOkQjjpK7.piEes.iT1dSKDUmaaONRTv/2E81VqDRFRD.', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:41', '2023-11-22 12:52:41', NULL);
INSERT INTO `users` VALUES ('879', 'Reba', 'Horton', '8200727077', 'RebaRHorton@gustr.com', '$2y$10$PRHd2/.8zhkeXWKX9BTofeN9PAvDzywnSYQflo/XmUg7qxgDGAXhu', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:41', '2023-11-22 12:52:41', NULL);
INSERT INTO `users` VALUES ('881', 'Donald', 'Shepherd', '8200727077', 'DonaldBShepherd@armyspy.com', '$2y$10$KfJI8Mz59YKUjU993Pqd1OV8fo/R78NjbYVcYyMycapXJbWEQpaRO', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:42', '2023-11-22 12:52:42', NULL);
INSERT INTO `users` VALUES ('883', 'George', 'Singh', '8200727077', 'GeorgeCSingh@teleworm.us', '$2y$10$xBL6AyJSdxRbwXAQ1947o.qzshr7K8WVR2hPdCVlOiOxDDuKCcFxq', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:43', '2023-11-22 12:52:43', NULL);
INSERT INTO `users` VALUES ('885', 'Everett', 'Velasquez', '8200727077', 'EverettCVelasquez@gustr.com', '$2y$10$iIITFsuPJboMgFepA9ZWVeCJEdWPoF60.1npgDCacdY2Nosv63ef2', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:43', '2023-11-22 12:52:43', NULL);
INSERT INTO `users` VALUES ('887', 'David', 'Thompson', '8200727077', 'DavidDThompson@rhyta.com', '$2y$10$QqnIMH6rp3wb1zstZe0NLempDd/v.IgOQCC5zK36MHq2h35rcQtvi', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:44', '2023-11-22 12:52:44', NULL);
INSERT INTO `users` VALUES ('889', 'Rose', 'Turner', '8200727077', 'RoseDTurner@superrito.com', '$2y$10$mWHvK6iszoJ040ZXKZyqyeHPT36CB1JXmt8jfiXUYw2geb2WxYqPe', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', 'dlTVqCueSdKlG0Rkk-0V5k:APA91bGNJ4ArFHnPQB3WfjiJRm9691TCpL9q5tKsLktL79FVoWPCuHZxmE60b47wpnnLFZy4GjzDc8GafukYS00lHAkbXz53HZlHwhrQIwy7Nvpo5lCCT1I', '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:45', '2024-11-04 01:25:12', NULL);
INSERT INTO `users` VALUES ('891', 'William', 'Wagner', '8200727077', 'WilliamMWagner@superrito.com', '$2y$10$/LJb39Ux.zKnlQ8wfVzoe.xa1Rmqi7ov0s8vKW5P33eM6jtJQfWue', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:45', '2023-11-22 12:52:45', NULL);
INSERT INTO `users` VALUES ('893', 'Ursula', 'Brandon', '8200727077', 'UrsulaCBrandon@teleworm.us', '$2y$10$.xhGfAAZQGR1c5HIjg28VuAPQoG6V.7m1QAxr7Q9qEvWjXL6f8622', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:46', '2023-11-22 12:52:46', NULL);
INSERT INTO `users` VALUES ('895', 'James', 'Kendall', '8200727077', 'JamesBKendall@einrot.com', '$2y$10$HxOamxk9fOx2fYnn/l3Hr.c8R90JuszV.XttLfnNiohoiEceZfHD.', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:47', '2023-11-22 12:52:47', NULL);
INSERT INTO `users` VALUES ('897', 'Bill', 'Penix', '8200727077', 'BillLPenix@einrot.com', '$2y$10$ktV3jH8Kre1zZO2xU7VuReP5M9uOthqkedTbULD8oP3amgJt5hUcm', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:47', '2023-11-22 12:52:47', NULL);
INSERT INTO `users` VALUES ('899', 'Ruth', 'Peterson', '8200727077', 'RuthMPeterson@superrito.com', '$2y$10$1Uc77j9Duzf/tydEPztaqu4rJ9/dgKwSNaBDXm1SZJU/Unywco0H.', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:48', '2023-11-22 12:52:48', NULL);
INSERT INTO `users` VALUES ('901', 'Richard', 'Palmer', '8200727077', 'RichardAPalmer@einrot.com', '$2y$10$0s.1Mr/INLiNq97uBNGI7uOrAU.Qpvz6mUGcsDFEpzk/ibV0KMWs6', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:49', '2023-11-22 12:52:49', NULL);
INSERT INTO `users` VALUES ('903', 'Christopher', 'Kanagy', '8200727077', 'ChristopherMKanagy@jourrapide.com', '$2y$10$azs4ImGZ3soZ5w.lHYcz0e6Kh96CTIbDYc6Y34QE8IkPCSpYNIjpS', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:49', '2023-11-22 12:52:49', NULL);
INSERT INTO `users` VALUES ('905', 'Lauren', 'Thorne', '8200727077', 'LaurenFThorne@dayrep.com', '$2y$10$JfM.ZLrKBkR/HUQW7.NWcuuFgBOl9rHtGSEAdawhoQc5bMglqbJN6', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:50', '2023-11-22 12:52:50', NULL);
INSERT INTO `users` VALUES ('907', 'Brandi', 'Keeton', '8200727077', 'BrandiLKeeton@dayrep.com', '$2y$10$d3ysqyxu7TyGxlqzPPskLeCuZsALU8tG297kztfv.Mlp16rs8xADy', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:51', '2023-11-22 12:52:51', NULL);
INSERT INTO `users` VALUES ('909', 'Gary', 'Carlson', '8200727077', 'GaryLCarlson@dayrep.com', '$2y$10$31uvWsDQkNo/Ik6HbZF8del8P3sgbYF/Anl4TYOQdF27a0ID8KKmS', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:51', '2023-11-22 12:52:51', NULL);
INSERT INTO `users` VALUES ('911', 'Henry', 'Young', '8200727077', 'HenryMYoung@einrot.com', '$2y$10$LzVIdr9EeOtZgJ/DeUkPh.xNaGdjLFnEsUFTa4lXFuYfCaqEhUB7C', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:52', '2023-11-22 12:52:52', NULL);
INSERT INTO `users` VALUES ('913', 'Lynne', 'Wilson', '8200727077', 'LynneDWilson@superrito.com', '$2y$10$pfKI3VP8T61i1Gs7TtmDxeqXZFufoRcgZ3nLuwg/ruaQdltMVO/vq', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:52', '2023-11-22 12:52:52', NULL);
INSERT INTO `users` VALUES ('915', 'Edward', 'Labelle', '8200727077', 'EdwardLLabelle@dayrep.com', '$2y$10$nI9uFX1QbOc5qu0vOeuLMeghH77t/3oTRAzMga5sjRaEkAGNoOfRC', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:53', '2023-11-22 12:52:53', NULL);
INSERT INTO `users` VALUES ('917', 'Vicky', 'Petrosky', '8200727077', 'VickyKPetrosky@superrito.com', '$2y$10$CIQJBuObdu5QOWVN76hUeumq7u.26JyI/m8kyo4270/FZFbvWP2Qy', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:54', '2023-11-22 12:52:54', NULL);
INSERT INTO `users` VALUES ('919', 'Bettie', 'Bracco', '8200727077', 'BettieBBracco@cuvox.de', '$2y$10$MCCXqXP2b49HkqWiU/6wYuXwbdWxAog/j6HVwCmeS2EbGsRv2oN6S', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:54', '2023-11-22 12:52:54', NULL);
INSERT INTO `users` VALUES ('921', 'Marion', 'Wallace', '8200727077', 'MarionJWallace@gustr.com', '$2y$10$dwUJGKfj47yRgL5prTohFOo5yKM77T.KOp5/rH05BuLwAL.r.cnVS', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:55', '2023-11-22 12:52:55', NULL);
INSERT INTO `users` VALUES ('923', 'David', 'Bennett', '8200727077', 'DavidBBennett@einrot.com', '$2y$10$n2LKjG/4yWN4SiXn5a/reub3CMVkwj68fh.7ova4j5Db6spoc0WXW', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:56', '2023-11-22 12:52:56', NULL);
INSERT INTO `users` VALUES ('925', 'James', 'Elias', '8200727077', 'JamesSElias@cuvox.de', '$2y$10$pfGBs7wY08V.N9dANL97m.UxgWRnkGhXMd0IrRpeyzgDgrBonA3tS', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:56', '2023-11-22 12:52:56', NULL);
INSERT INTO `users` VALUES ('927', 'Gary', 'Cumming', '8200727077', 'GarySCumming@rhyta.com', '$2y$10$Pvk7f/HByLHDkQF.cRicbO/s7./3E.lex99qDCB8uN.BzokAi6gXe', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:57', '2023-11-22 12:52:57', NULL);
INSERT INTO `users` VALUES ('929', 'Thomas', 'Calfee', '8200727077', 'ThomasCCalfee@armyspy.com', '$2y$10$H6uxipH6oOb1zCPqrdlOXeHlMK.A//ASbXrALWjHbPfR2N1E1lPUG', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:58', '2023-11-22 12:52:58', NULL);
INSERT INTO `users` VALUES ('931', 'Patti', 'Allen', '8200727077', 'PattiRAllen@einrot.com', '$2y$10$u2E4RVfhmCIhYflgwiuLFea6vVZ54VbKi3D5htzqak9ZIwRlvXFGC', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:58', '2023-11-22 12:52:58', NULL);
INSERT INTO `users` VALUES ('933', 'Gregory', 'Faulkner', '8200727077', 'GregoryBFaulkner@fleckens.hu', '$2y$10$BGvBMpdry6yTbnWF05cugOK.5Tqv2vPtaC/RurE4Qp.8fTv5nGkDW', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:52:59', '2023-11-22 12:52:59', NULL);
INSERT INTO `users` VALUES ('935', 'Clinton', 'Pope', '8200727077', 'ClintonCPope@teleworm.us', '$2y$10$/nFPCq/GT5qDgQuQcKfZCe5.rRuVEPNjza0RHDNAPiK6iAgrdYite', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:00', '2023-11-22 12:53:00', NULL);
INSERT INTO `users` VALUES ('937', 'Aaron', 'Crader', '8200727077', 'AaronMCrader@gustr.com', '$2y$10$/Fr8PXaJlGbxFS.JFRJ6BuFHuFCnJRc8Om0X3MX8UJZwDFqyz/mLa', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:00', '2023-11-22 12:53:00', NULL);
INSERT INTO `users` VALUES ('939', 'Alexander', 'Hennigan', '8200727077', 'AlexanderJHennigan@jourrapide.com', '$2y$10$B4hO8oX0Rm3uYX5hvwjUXur3TAR5b2iBN7Zih4byHQCISWPhecFce', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:01', '2023-11-22 12:53:01', NULL);
INSERT INTO `users` VALUES ('941', 'Ella', 'Panton', '8200727077', 'EllaJPanton@teleworm.us', '$2y$10$pzwif2YyjEwoyqxgXK2M1eochn5Hj87pNkCiaAIGErRY.2Eb23QRO', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:02', '2023-11-22 12:53:02', NULL);
INSERT INTO `users` VALUES ('943', 'Peter', 'Reeder', '8200727077', 'PeterLReeder@einrot.com', '$2y$10$myCEHrMllsGhT9ysrLnO9OCyH5yRHs.fQtbH0Lnhppt3wU7HKh2ki', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:22', '2023-11-22 12:53:22', NULL);
INSERT INTO `users` VALUES ('945', 'Martin', 'Farris', '8200727077', 'MartinCFarris@gustr.com', '$2y$10$xJQjJ9D4D1AUVzj6Hx9hTuY80yNysCmy4JFFHAviMWr/cBzrn5OlK', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:22', '2023-11-22 12:53:22', NULL);
INSERT INTO `users` VALUES ('947', 'Michael', 'Oakley', '8200727077', 'MichaelPOakley@rhyta.com', '$2y$10$Vv5iI6S5ayflrUxePrke3O5W1hmlxeHjXzXgCjkneky9/gV.RFBGu', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:23', '2023-11-22 12:53:23', NULL);
INSERT INTO `users` VALUES ('949', 'Frederick', 'Rood', '8200727077', 'FrederickDRood@fleckens.hu', '$2y$10$NHR7azGEyzd2WVqs5qjQgu/G61wDh/20QERK5riEd9N58DHOrh0mK', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:24', '2023-11-22 12:53:24', NULL);
INSERT INTO `users` VALUES ('951', 'Patricia', 'Ayers', '8200727077', 'PatriciaTAyers@jourrapide.com', '$2y$10$xrKyuiWCItxxF4t7xUmma.kBfUpm.iPgJz7qx5qXuUJspWJZwr0/K', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:24', '2023-11-22 12:53:24', NULL);
INSERT INTO `users` VALUES ('953', 'Sherilyn', 'White', '8200727077', 'SherilynMWhite@cuvox.de', '$2y$10$W7f7aOYh4BOOG38l6xKAnOoJvNWZEpe0fa85DopP0rqOz1.0JntpG', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:25', '2023-11-22 12:53:25', NULL);
INSERT INTO `users` VALUES ('955', 'James', 'Lopez', '8200727077', 'JamesALopez@dayrep.com', '$2y$10$5oKaRK09UXnssU8gKpWFHO6JOLWm1IQcKc7s3YU1Cg9r79zcNThqC', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:26', '2023-11-22 12:53:26', NULL);
INSERT INTO `users` VALUES ('957', 'Al', 'Fall', '8200727077', 'AlJFall@rhyta.com', '$2y$10$y5haYP7c7TGhb4t7LJluZud1R036y0V2mPG5FtzGteSINKfh5pAGW', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:26', '2023-11-22 12:53:26', NULL);
INSERT INTO `users` VALUES ('959', 'Loren', 'Nash', '8200727077', 'LorenTNash@rhyta.com', '$2y$10$SEGAdMexDuCx6Wb3A0gee.Kv8sCcA6rYUierRMtmC1GiDyPCtMvsC', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:27', '2023-11-22 12:53:27', NULL);
INSERT INTO `users` VALUES ('961', 'Arlene', 'Weir', '8200727077', 'ArleneJWeir@gustr.com', '$2y$10$XO8G54TNDHx/wdMLaZJMmu80aaCpcb551nSdq4..I2ARIFr/JOFVa', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:28', '2023-11-22 12:53:28', NULL);
INSERT INTO `users` VALUES ('963', 'Eric', 'Villarreal', '8200727077', 'EricCVillarreal@teleworm.us', '$2y$10$FgM7rnseD1iIlmCQMaW1Bu1i4LwBxSaqSbTxpBs.wx.aTr2v3zhAO', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:28', '2023-11-22 12:53:28', NULL);
INSERT INTO `users` VALUES ('965', 'Robert', 'Sturgill', '8200727077', 'RobertLSturgill@teleworm.us', '$2y$10$AzwNyQwZj3N3L1lxoI0zUOtU/Tk7ul9fYv0DeXImhaVMZf/3wD9oe', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:29', '2023-11-22 12:53:29', NULL);
INSERT INTO `users` VALUES ('967', 'Lauren', 'Newby', '8200727077', 'LaurenANewby@gustr.com', '$2y$10$04d.WXWlwl9pnONlDq9vn.Jvuxrzn3KPMP.FLG6fout.n.E5RGjsq', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:30', '2023-11-22 12:53:30', NULL);
INSERT INTO `users` VALUES ('969', 'Paul', 'Parker', '8200727077', 'PaulMParker@cuvox.de', '$2y$10$asyhGyq3dg5OhHkE/8Ghye/87qqyn7rV10TwjmpBVG6FoOyPJaiDO', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:30', '2023-11-22 12:53:30', NULL);
INSERT INTO `users` VALUES ('971', 'Ida', 'Walls', '8200727077', 'IdaKWalls@teleworm.us', '$2y$10$bKzixn2D7bQMQofwAT1ufu/89ztoGH065NyRsAgJRotdxDtY67Qpu', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:31', '2023-11-22 12:53:31', NULL);
INSERT INTO `users` VALUES ('973', 'Gregory', 'Pate', '8200727077', 'GregoryMPate@einrot.com', '$2y$10$oaM7NU7fByEYEco2WP0.k.LrGPi/fGqVQlPw7Ht2ZzkgqpVqNgavO', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:32', '2023-11-22 12:53:32', NULL);
INSERT INTO `users` VALUES ('975', 'Howard', 'Wolf', '8200727077', 'HowardLWolf@rhyta.com', '$2y$10$FvUdHPp.m6D6xMEcXdqenO.xKzZMRMBAKI01Mr34hcimiT/MTw.C6', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:32', '2023-11-22 12:53:32', NULL);
INSERT INTO `users` VALUES ('977', 'Amy', 'Schwab', '8200727077', 'AmyCSchwab@armyspy.com', '$2y$10$C2.PGnlkGcDPM2sbXOom2uoqeEDrSPHdPX70.txfqFzM8wwlYavHG', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:33', '2023-11-22 12:53:33', NULL);
INSERT INTO `users` VALUES ('979', 'Teresa', 'Durden', '8200727077', 'TeresaTDurden@teleworm.us', '$2y$10$e/4Db/JAFK8MhpT7GenwAOPtPd27TmsNsLuyGwjH8UuNZhI1zTnVS', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:34', '2023-11-22 12:53:34', NULL);
INSERT INTO `users` VALUES ('981', 'Shannon', 'Zayas', '8200727077', 'ShannonJZayas@cuvox.de', '$2y$10$/rLRmMX0rLUuOjv6yNmW8eEK3yQe.7L79cIBj05IHVorRjQaxyrCu', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:34', '2023-11-22 12:53:34', NULL);
INSERT INTO `users` VALUES ('983', 'Lisa', 'Houghton', '8200727077', 'LisaDHoughton@armyspy.com', '$2y$10$ackzNcFfQDebFWy.xxYIPOcljU5KZZTci3vlh7eLnDQclJLELXiRK', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:35', '2023-11-22 12:53:35', NULL);
INSERT INTO `users` VALUES ('985', 'Raymond', 'Braddock', '8200727077', 'RaymondJBraddock@dayrep.com', '$2y$10$WIAdcybp2126bgo88Icdd.U7tgEmcJTmpLm7XjM17ifPMvjhfk5Dm', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:36', '2023-11-22 12:53:36', NULL);
INSERT INTO `users` VALUES ('987', 'Alan', 'Jackson', '8200727077', 'AlanSJackson@fleckens.hu', '$2y$10$zvyC/tKgY.0w4aYJZuvpHeaUFA//O2Dzd9py5smVTcQSQLmPT3Q7C', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:36', '2023-11-22 12:53:36', NULL);
INSERT INTO `users` VALUES ('989', 'Mary', 'Hart', '8200727077', 'MaryJHart@rhyta.com', '$2y$10$eAJP6zuO3InQzaeeNBUZquSbv97bSVpzIkB59..CJQhckdQXuly22', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:37', '2023-11-22 12:53:37', NULL);
INSERT INTO `users` VALUES ('991', 'Brian', 'Houghton', '8200727077', 'BrianEHoughton@gustr.com', '$2y$10$MZkbBCKi/u1ap2bSeqlx4.anx6siyoNDDhjQAejXEzm3C5SJa42Ma', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:38', '2023-11-22 12:53:38', NULL);
INSERT INTO `users` VALUES ('993', 'Miles', 'Montenegro', '8200727077', 'MilesDMontenegro@armyspy.com', '$2y$10$dQDkYoR3I2N6dNZCY4XPg.cPSgvtL.vDyHdFKKjywzvAcqKzWiEQ6', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:38', '2023-11-22 12:53:38', NULL);
INSERT INTO `users` VALUES ('995', 'Fernando', 'Crews', '8200727077', 'FernandoRCrews@dayrep.com', '$2y$10$wTH4kfJVXG0EuZ6KcQxF7ejyiomprl5QEVl4vOoONdLz75ZAMJGuW', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:39', '2023-11-22 12:53:39', NULL);
INSERT INTO `users` VALUES ('997', 'Dennis', 'Chew', '8200727077', 'DennisSChew@rhyta.com', '$2y$10$dy85gns/vdI462IjphYw3OD20gUsh7Voxn6MYFMLgwY2JtVZruLPm', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:40', '2023-11-22 12:53:40', NULL);
INSERT INTO `users` VALUES ('999', 'Jules', 'Stewart', '8200727077', 'JulesNStewart@superrito.com', '$2y$10$cFzQ5Bj4cZjnfjAjzxTVzuj06eJ5Ut2AboT6HHIzI.y5QUR13Nq0m', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:40', '2023-11-22 12:53:40', NULL);
INSERT INTO `users` VALUES ('1001', 'Maria', 'Morrisey', '8200727077', 'MariaTMorrisey@fleckens.hu', '$2y$10$ess1Yz8mRwukpVcDFldim.mSF1I2UEyqykCwXzBKBSk5204kK/dZi', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:41', '2023-11-22 12:53:41', NULL);
INSERT INTO `users` VALUES ('1003', 'Bobbie', 'Tran', '8200727077', 'BobbieITran@armyspy.com', '$2y$10$iStRLmg908osa0sUkkGPKuscjEvjz8jSy2f3O603u2UaOFi2nOigy', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:50', '2023-11-22 12:53:50', NULL);
INSERT INTO `users` VALUES ('1004', 'Vitor', 'Rocha', '8200727077', '2022-2312480', '$2y$10$s/6VJC.hXZ0aMT27K/NwkeqO8tUmCSHofBMwbRJaiN4R25sMOSYTK', 'male', NULL, '2004-06-25', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:51', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('1005', 'James', 'Dodson', '8200727077', 'JamesRDodson@jourrapide.com', '$2y$10$Lv5c7Kj6neSyV0oyQoIVPuIY51DBrLt6ViDc1cYF3QTWUbyyhWH5C', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:51', '2023-11-22 12:53:51', NULL);
INSERT INTO `users` VALUES ('1006', 'Laura', 'Martins', '8200727077', '2022-2312481', '$2y$10$iUDnGEFwv/pfG65e3xP9V.jGAC1QO14OqxR2U6NdXttlHdslcKVZ2', 'female', NULL, '2005-02-01', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:51', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('1007', 'Rocco', 'Walter', '8200727077', 'RoccoGWalter@gustr.com', '$2y$10$FJzGB5oeihSBVLHTBnbpiu1qoQ6kMZYcksVelGDvKYcoljhobE7jm', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:52', '2023-11-22 12:53:52', NULL);
INSERT INTO `users` VALUES ('1008', 'Emilly', 'Correia', '8200727077', '2022-2312482', '$2y$10$iEhR8vQL2/L8.j6ljRO6pe/6aX3GE1F30GZssd0dTX1fYMSEqXwTu', 'female', NULL, '2013-06-11', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:52', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('1009', 'Neil', 'Ware', '8200727077', 'NeilMWare@dayrep.com', '$2y$10$gUfaCqgLpkM3xc/Qz2xI5e7wGP1B4EWX8wCUFaacbmYtWxBqF2RXm', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:52', '2023-11-22 12:53:52', NULL);
INSERT INTO `users` VALUES ('1010', 'Manuela', 'Pereira', '8200727077', '2022-2312483', '$2y$10$4l9gRHFP7IrKlplup.rqiu2grF58/PkqcrnnKjnEh97Ndgh6ZdwLi', 'female', NULL, '2011-03-20', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:53', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('1011', 'Gabriel', 'Doss', '8200727077', 'GabrielNDoss@fleckens.hu', '$2y$10$mbe4npxjPr.nClhcp9JCZ.NqVugC0azgwf2DQsQO.UcuYknV1G1Le', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:53', '2023-11-22 12:53:53', NULL);
INSERT INTO `users` VALUES ('1012', 'Bruno', 'Cardoso', '8200727077', '2022-2312484', '$2y$10$a9FWmEK5RtY/4pfvKKE6iODXUgvpKNYqQ9fjKVMG6c9ugcgSgHXTi', 'male', NULL, '2011-03-12', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:53', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('1013', 'Alfred', 'Hall', '8200727077', 'AlfredDHall@cuvox.de', '$2y$10$1ST80A.MPimqq/7dQBGn3uXws1vVjxaf9TXseM15m3D9vXE5OGgga', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:53', '2023-11-22 12:53:53', NULL);
INSERT INTO `users` VALUES ('1014', 'Lucas', 'Correia', '8200727077', '2022-2312485', '$2y$10$lqswCs/5vLT2Jw.QnsUmZ.jomY.wR64Uwa2oBzvnQJsDrG5GIj6X6', 'male', NULL, '2006-12-17', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:54', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('1015', 'Catherine', 'Plante', '8200727077', 'CatherineWPlante@rhyta.com', '$2y$10$/LaGQs4YXUZurceKm2EIKOY/cnG08ENlTo4wZPBhzkR9fHojQwK4O', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:54', '2023-11-22 12:53:54', NULL);
INSERT INTO `users` VALUES ('1016', 'Livia', 'Barros', '8200727077', '2022-2312486', '$2y$10$rQhoDEZmvNgGu3G8qwscbuZnWFMoNWwahNnzRc1tgSEF6FdqwwdSu', 'female', NULL, '2013-04-25', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:54', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('1017', 'Charles', 'Paulus', '8200727077', 'CharlesBPaulus@fleckens.hu', '$2y$10$P2lfQyON2l15gf0mx4gnDupGeSrebEwEu6xuNAM4jrCzz6iMdjnBK', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:55', '2023-11-22 12:53:55', NULL);
INSERT INTO `users` VALUES ('1018', 'Miguel', 'Martins', '8200727077', '2022-2312487', '$2y$10$MmRrXwmepNpO4Xwo7fW6C.XiN3gLrxQJaySkup2DD22Mk66Fho6mW', 'male', NULL, '2014-05-17', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:55', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('1019', 'Cory', 'Masse', '8200727077', 'CoryLMasse@jourrapide.com', '$2y$10$gnBWHyimJNTtSs3wCO0tK.LpAzZ8bdbLFWniqOLObtRlCs2zO8qja', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:55', '2023-11-22 12:53:55', NULL);
INSERT INTO `users` VALUES ('1020', 'Luan', 'Alves', '8200727077', '2022-2312488', '$2y$10$HPtUPMivB.IyXUUHgZMjKuOIdS68fbQaHxQkxfZ.h5lpUOvRmPiOW', 'male', NULL, '2009-03-08', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:56', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('1021', 'Richard', 'Finley', '8200727077', 'RichardAFinley@cuvox.de', '$2y$10$36b5KYQWSdngiQPVRcNwuuTEVXWxVtsKsB.gHb2QhKaChVeC7JeXi', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:56', '2023-11-22 12:53:56', NULL);
INSERT INTO `users` VALUES ('1022', 'Estevan', 'Correia', '8200727077', '2022-2312489', '$2y$10$vr1jh1QeoDq7urSCdeFQOu/CId0FOlsmqCd4LYkBDR7jlf5vPfauS', 'male', NULL, '2005-01-07', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:56', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('1023', 'Elvia', 'Cook', '8200727077', 'ElviaMCook@teleworm.us', '$2y$10$yXq44iO5uBGkMvhR0F9rm.CCOqVzteint5pS0AvTT8m.YpKsD4fre', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:57', '2023-11-22 12:53:57', NULL);
INSERT INTO `users` VALUES ('1024', 'Daniel', 'Barros', '8200727077', '2022-2312490', '$2y$10$BucAjdn05.6/tpXUEREJnOEeE7Y85bV9UmqmDb4EJ88dFqcdvD7xW', 'male', NULL, '2009-04-24', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:57', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('1025', 'Lynn', 'Griffin', '8200727077', 'LynnWGriffin@gustr.com', '$2y$10$5B101UZyuS3Q/6iAIgdkPO.BNosWDlHiM4H7nT.foKDIfLi7snVuK', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:57', '2023-11-22 12:53:57', NULL);
INSERT INTO `users` VALUES ('1026', 'Carlos', 'Goncalves', '8200727077', '2022-2312491', '$2y$10$FPYQfByWStSYQYnpGkYwietgql8HfiNBEBi6As7wk52d.HRl54wBW', 'male', NULL, '2003-09-12', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:58', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('1027', 'Julius', 'Panos', '8200727077', 'JuliusCPanos@rhyta.com', '$2y$10$98nvFilGsIsaPtQrI7ylheDGots36BahYIzyrxFjpJL3.lWMz4Ejq', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:58', '2023-11-22 12:53:58', NULL);
INSERT INTO `users` VALUES ('1028', 'Joao', 'Martins', '8200727077', '2022-2312492', '$2y$10$RK7nncuAiWIqTX89SUoHtezcv1bhyRh//uzM4xrzzcPXWLfJaqxta', 'male', NULL, '2011-08-04', NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:58', '2023-11-22 12:54:23', NULL);
INSERT INTO `users` VALUES ('1029', 'Carl', 'Young', '8200727077', 'CarlSYoung@einrot.com', '$2y$10$On62ZOd.fIadjPa48ivynehk4tSWuPUgJuZyhjimPYimKZUtRdmL.', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:59', '2024-09-30 13:12:06', NULL);
INSERT INTO `users` VALUES ('1030', 'Paulo', 'Almeida', '8200727077', '2022-2312493', '$2y$10$//ViMzyXn1umZjaEAVBEnebcCmqIFSjk/zntnYEaMbjIVOXQcZ4BC', 'male', '12/user/66475059f12a54.661937891715949657.jpg', '2012-06-27', 'Mankuva', 'Mankuva', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:59', '2024-09-30 13:04:17', NULL);
INSERT INTO `users` VALUES ('1031', 'Doris', 'Ranson', '8200727077', 'DorisGRanson@cuvox.de', '$2y$10$jei6pTHqDU2AITF4UwJ.XeCtt/Rmyi9ipRMgPpq807ZNGDKz6Rtwu', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:53:59', '2024-09-30 13:12:06', NULL);
INSERT INTO `users` VALUES ('1032', 'Aline', 'Cunha', '8200727077', '2022-2312494', '$2y$10$nZ5BG4zMEWLxBYKnFhRQVuDDoApgv7AHIEYim1HMLT.tIo84dMwVe', 'female', '12/user/66475039c180e9.942525481715949625.jpg', '2014-03-12', 'Bhuj', 'Bhuj', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:54:00', '2024-09-30 13:04:17', NULL);
INSERT INTO `users` VALUES ('1033', 'Hazel', 'Centers', '8200727077', 'HazelFCenters@fleckens.hu', '$2y$10$Y67jq77bdlWqpTqT7fqdvei9lH9yCUFS7gDjp64iG0DBa3k5o8gX2', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:54:00', '2024-09-30 13:12:06', NULL);
INSERT INTO `users` VALUES ('1034', 'Beatrice', 'Castro', '8200727077', '2022-2312495', '$2y$10$ioHlBdpKLI56mfw/BIbecelQ4/A8BeHb7BzOEQCvbNDzO9ovhmbA2', 'female', '12/user/66474ff523e352.336633091715949557.jpg', '2004-04-16', 'Bhuj', 'Bhuj', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:54:00', '2024-09-30 13:04:17', NULL);
INSERT INTO `users` VALUES ('1035', 'Alvin', 'Holmes', '8200727077', 'AlvinAHolmes@cuvox.de', '$2y$10$0SEOOsAlZG0mczdmOuGDyOiPTJN9J0QVgiuM7FGSXH674cg7GQzi.', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:54:01', '2024-09-30 13:12:06', NULL);
INSERT INTO `users` VALUES ('1036', 'Kai', 'Souza', '8200727077', '2022-2312496', '$2y$10$9cnAdjfpA18vz1jGhDMg9eXhvdwORfv046Blp.OvT8gwRE5Ya/uGW', 'male', '12/user/66474fe165c3f7.389097351715949537.jpg', '2007-01-18', 'Gujarat', 'Gujarat', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:54:01', '2024-09-30 13:04:17', NULL);
INSERT INTO `users` VALUES ('1037', 'Marie', 'Pope', '8200727077', 'MarieHPope@jourrapide.com', '$2y$10$.CWvmZWWX6p/TBiXXYR3VerUVu8kH.J97LOo8kauWKr4VuQTcxMnO', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:54:01', '2024-09-30 13:12:06', NULL);
INSERT INTO `users` VALUES ('1038', 'Luis', 'Fernandes', '8200727077', '2022-2312497', '$2y$10$2TD0FdxcEdKhOrQ52gyarOO2ft9tpHSOEYG.BUW7sfkCILGlShFVC', 'male', '12/user/66474fc9b632d0.255016631715949513.jpg', '2013-03-08', 'Kutch', 'Kutch', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:54:02', '2024-09-30 13:04:17', NULL);
INSERT INTO `users` VALUES ('1039', 'Martha', 'Sayre', '8200727077', 'MarthaFSayre@einrot.com', '$2y$10$b2Gl0W8Z037sFypK6Ay/8.iIet4KSjyzmN7Ov1g4z73OATsrDyGnC', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:54:02', '2024-09-30 13:12:06', NULL);
INSERT INTO `users` VALUES ('1040', 'Paulo', 'Castro', '8200727077', '2022-2312498', '$2y$10$88UoxdFRT3MSM9/SI2zoxOmu7LBAp6zRupiSPz6D/FnDWbmmwdKxK', 'male', '12/user/66474fb680aea2.014913031715949494.jpg', '2015-06-06', 'Madhapar', 'Madhapar', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:54:02', '2024-09-30 13:04:17', NULL);
INSERT INTO `users` VALUES ('1041', 'Peter', 'Ferrell', '8200727077', 'PeterSFerrell@rhyta.com', '$2y$10$OHuOKLzSS.bjuaLT/4NndOFNDy./rWE43vTZ/DWNFOEEVFSoidjRq', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:54:03', '2024-09-30 13:12:06', NULL);
INSERT INTO `users` VALUES ('1042', 'FAbio', 'Carvalho', '8200727077', '2022-2312499', '$2y$10$PyUSgSRVLAfcJPW1H1l/wOCja82XYjbUKZBtQG0Gm.4AJdE/Kk5lG', 'male', '12/user/66474ecc593fe2.145420391715949260.jpg', '2014-03-06', 'bhuj', 'bhuj', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:54:03', '2024-09-30 13:04:17', NULL);
INSERT INTO `users` VALUES ('1043', 'Michael', 'Murphy', '8200727077', 'MichaelPMurphy@armyspy.com', '$2y$10$TBvw66PhZG44V9H7Q17Z0OeY4tcQxlRWi6m1QIsecwfIduiSYhQ0a', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:54:03', '2024-09-30 13:12:06', NULL);
INSERT INTO `users` VALUES ('1044', 'Kai', 'Martins', '8200727077', '2022-2312500', '$2y$10$FveLZKIk6WTZkpoxBxnMgeWe0bD76utI8l227y3z4uaq8AQ4m9vQe', 'male', '12/user/65eedead579de6.656955531710153389.jpg', '2012-06-25', 'Madhapar', 'Madhapar', NULL, '1', '0', '', '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:54:04', '2025-01-06 13:44:08', NULL);
INSERT INTO `users` VALUES ('1045', 'David', 'Villa', '8200727077', 'DavidTVilla@cuvox.de', '$2y$10$oeb55Uda6nx9Xo41EjBFge3okco1xTJx3kcM3SJKuoe8tuGOMRmDu', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:54:04', '2024-09-30 13:12:06', NULL);
INSERT INTO `users` VALUES ('1046', 'Igor', 'Fernandes', '8200727077', '2022-2312501', '$2y$10$D7ic7qLVue.1UpXjcxeFOOS8mmVS9Ru2zT8BCcVCUqXNPqyg/a3G.', 'male', '12/user/65eede9e6d2c88.377717781710153374.jpg', '2011-07-29', 'bhuj', 'bhuj', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:54:04', '2024-09-30 13:04:17', NULL);
INSERT INTO `users` VALUES ('1047', 'Clarissa', 'Woodard', '8200727077', 'ClarissaRWoodard@dayrep.com', '$2y$10$1jm.Da6o9J1qFkRlZOhU2OM7/hmYZARrpR2FixHb7j31woKjyRGlG', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:54:05', '2024-09-30 13:12:06', NULL);
INSERT INTO `users` VALUES ('1048', 'Vitoria', 'Cavalcanti', '8200727077', '2022-2312502', '$2y$10$R2pClDrs7L2xG0zfiukCduITwgcmsj3jJ5jV6R7YQLBBJkCw73rMm', 'female', '12/user/65eede8db48717.153364291710153357.jpg', '2015-02-03', 'Madhapar', 'Madhapar', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:54:05', '2024-09-30 13:04:17', NULL);
INSERT INTO `users` VALUES ('1049', 'Nicholas', 'Towles', '8200727077', 'NicholasMTowles@armyspy.com', '$2y$10$v6hKuDgzk6LWp/rBmL5OxOHjsUunXLX9z26LMWqxjMJbBDumiK/lu', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', 'fuWcnHTNRGqANQWurXgfXs:APA91bHIrfZJoSf9uNk1V4U3oKpCjsOGSVFXWMHTnxEjRkVFLh9VbZMxvasm55Vok1sctOKs_-HWe5Jo9skSxqlyRBCnIH561_yM0tdFPzDy25bAxlvMHBqPXxDkmuxkS7gxgTpzwE4u', '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:54:05', '2024-09-30 13:12:06', NULL);
INSERT INTO `users` VALUES ('1050', 'Vinicius', 'Silva', '8200727077', '2022-2312503', '$2y$10$i/uvimytw7jdwhRDHn86S..Ot0tdNmLFx5RsbzatAe0OObrOhsCde', 'male', '12/user/65eede81123950.802689581710153345.jpg', '2013-05-13', 'Madhapar', 'Madhapar', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:54:06', '2024-09-30 13:04:17', NULL);
INSERT INTO `users` VALUES ('1051', 'Michael', 'Harmon', '8200727077', 'MichaelKHarmon@fleckens.hu', '$2y$10$Z/mAiMnahFnTVGjevbo.zuGgp6v7DvXtEIfSUsuVI/u8XLphvBgVq', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:54:06', '2024-09-30 13:12:06', NULL);
INSERT INTO `users` VALUES ('1052', 'Igor', 'Azevedo', '8200727077', '2022-2312504', '$2y$10$jA7UPE0aL.buSpkR0Nt5LeAa2vUQiJnWC/aI8FFqEKOC5LXSawEWm', 'male', '12/user/65eede6abdd723.710855001710153322.jpg', '2011-05-14', 'bhuj', 'bhuj', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:54:06', '2024-09-30 13:04:17', NULL);
INSERT INTO `users` VALUES ('1053', 'Patricia', 'Dyke', '8200727077', 'PatriciaSDyke@armyspy.com', '$2y$10$hvAERhQS.6lOBzwzJb5LwelQYILhf8XgbXA4/vQTMcNX9IrEhprNa', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:54:07', '2024-09-30 13:12:06', NULL);
INSERT INTO `users` VALUES ('1054', 'Sarah', 'Azevedo', '8200727077', '2022-2312505', '$2y$10$2WMTjTn2KsjOTSRTaMoMQ.XC9I/tAzYaGOHqomWPitL9anUghz4nu', 'female', '12/user/65eede5924fe51.917295901710153305.jpg', '2010-01-30', 'bhuj', 'bhuj', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:54:07', '2024-09-30 13:04:17', NULL);
INSERT INTO `users` VALUES ('1055', 'David', 'Meyer', '8200727077', 'DavidJMeyer@superrito.com', '$2y$10$TY55AboX/2ber1WcHoaMcewPD6/wY3VU0k9z3kE7gaG6cSjc..SyG', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:54:07', '2024-09-30 13:12:06', NULL);
INSERT INTO `users` VALUES ('1056', 'Larissa', 'Oliveira', '8200727077', '2022-2312506', '$2y$10$4b0YQoE35PArlrc6PtDUGuX1bTz3t/WGutGVeWeYtgz79Iq0wxbGC', 'female', '12/user/65eede4abffe46.005611251710153290.jpg', '2008-10-26', 'bhuj', 'bhuj', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:54:08', '2024-09-30 13:04:17', NULL);
INSERT INTO `users` VALUES ('1057', 'Charles', 'Roe', '8200727077', 'CharlesBRoe@armyspy.com', '$2y$10$oDAMVyvD7sSl8Wm1hzgKW.jm7suxTNe1tFBUXbpDVYquX9pElLRPq', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', 'd4gClOl4QnqUoQlRZ-Dp3z:APA91bE61bIsbvGVBeXObugkUUEh80GoOs50vStBg6dah3VYNshyj3hsANYLdsKgltNBZSv_8focSfrx5VluJscacYG4kQ_PDQNrJ4aOmt8t0U64la3VLQZqH-13kxf6Vrtr8CIyPwlW', '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:54:08', '2024-09-30 13:12:06', NULL);
INSERT INTO `users` VALUES ('1058', 'Arthur', 'Fernandes', '8200727077', '2022-2312507', '$2y$10$tZrauSAnatJQ677XT/jhXOwuK0CCcYrwXo9txc54rQy2zdVfjDWfu', 'male', '12/user/65eede3acd3962.645805061710153274.jpg', '2013-06-26', 'bhuj', 'bhuj', NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:54:08', '2024-09-30 13:04:17', NULL);
INSERT INTO `users` VALUES ('1059', 'Brian', 'West', '8200727077', 'BrianNWest@fleckens.hu', '$2y$10$JM.CH/lZid/JimB.gPOyq.133fkIJNHS425o39Bq/Rz0t9pYeBxPC', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:54:09', '2024-09-30 13:12:06', NULL);
INSERT INTO `users` VALUES ('1060', 'Gabriela', 'Santos', '8200727077', '2022-2312508', '$2y$10$ZQEbvLg84t3Ur.80FasVpebw8VoVU0lv8eibexwESP7mILddrxrHO', 'female', '12/user/65eede292daec4.889861101710153257.jpg', '2005-02-14', 'madhapar', 'madhapar', NULL, '1', '1', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:54:09', '2024-09-30 13:04:17', NULL);
INSERT INTO `users` VALUES ('1061', 'Amber', 'Wayt', '8200727077', 'AmberMWayt@gustr.com', '$2y$10$g0t9ZY9tRZeZaiPlH.drAuHntSp2pF1RJoQRR2.15LJis2b2IjLM6', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', 'fjeTM7k3QQukkTFVOmRE8A:APA91bHwEjg2nHFigA64Nub7g6SJLvibQ0NHSy5NRrA4sEXo7V41C_7t_R5SNH0Ma7CANu_VakcD9f7_Pxn9S4YeGDmJw3coCapzInHFXhA7c4kIjqVJrsg', '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:54:09', '2025-01-09 14:57:16', NULL);
INSERT INTO `users` VALUES ('1062', 'Kauan', 'Sousa', '8200727077', '2022-2312509', '$2y$10$0JsEY69JCDk5O8DAtQgYZuQNgPe5otGvoZ5LpfmbkZ7lejgmQlWpa', 'male', '12/user/66474eaebabfe0.728014071715949230.jpg', '2006-11-22', 'bhuj', 'bhuj', NULL, '1', '1', 'cSbFmYQNQRmF-5jxitMR6h:APA91bHlgYWqhMuvvJfqbd5NRNyC2OCIQePcOZjuxQVGeNQ_hVZ4Vr9Lo8ioExW_VnK9njgckRsx9MMFgs-ptYxhX6Z9HCTo2LzX_5axVhYOKuamYx0r71g', '12', 'en', NULL, NULL, '1', NULL, NULL, '2023-11-22 12:54:10', '2025-01-09 15:33:43', NULL);
INSERT INTO `users` VALUES ('1087', 'Smitss', 'Chauhan', '965555885', 'smitc@gmail.com', '$2y$10$KKrzvEPa3K6L0T2Lyy1g4Odu25UyvIKG8hi/0YQi05k9BNJBQQle.', 'male', '12/user/660bb386dd88c6.074923701712042886.png', '1970-01-01', '-', '-', NULL, '1', '0', 'dDLKr3SbRK2jCX_LEjL-H5:APA91bH5ZciU36jBLhJWc-pJT1FZ1OQJB03sESIDwKe2ovykcTG6cYlGsmDhzgpVuVETlVLtGBE3olncSLuJ1Rtjw12UJ2OVVHuuFC46rH7FZ2XMIpCPQLk', '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-04-02 12:58:06', '2025-01-07 19:02:34', NULL);
INSERT INTO `users` VALUES ('1088', 'MK', 'SINGH', '9937646687', 'INFO.MANISHAGENCIES@GMAIL.COM', '$2y$10$2VSR0Cm.eRyFn8gnXt8Kze9qG75fFONcl0VNbWX6a.W9D/GxyvjZq', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-10-01 11:30:24', '2024-10-01 11:30:24', NULL);
INSERT INTO `users` VALUES ('1089', 'ANIKA', 'SINGH', '9937646687', '2023-240120510', '$2y$10$N9jmrBTjejjhdw.5LmXULO3kGkPpXyWGcKTYFs.p7FcZm1uqiL5a6', 'female', 'super-admin/user/66fb8ff8b7d958.369242591727762424.png', '2020-02-23', 'BORIGUMMA', 'BORIGUMMA', NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-10-01 11:30:25', '2024-10-01 11:30:25', '1970-01-01 01:00:00');
INSERT INTO `users` VALUES ('1090', 'Noel', 'Ndhlovu', '0824851195', 'noelndhlovu10@gmail.com', '$2y$10$.rwzvWXOv.JDo8faPr/EEu7UZRCwuK/edzVNoSKGXwtgpwSoBCT76', 'male', 'super-admin/guardian/66fdc17b85cda6.981739971727906171.jpg', NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-10-03 03:26:11', '2024-10-03 03:26:11', NULL);
INSERT INTO `users` VALUES ('1091', 'Noel', 'Ndhlovu', '0824851195', '2023-240120511', '$2y$10$mhf/eHtPPefrOXCzfrDtuu4FhcUU/uafKqLo80yeBCncuKvEN81M6', 'female', 'super-admin/user/66fdc17be23785.433444881727906171.jpg', '2021-05-17', '1000 Ormonde Drive, Mondeor, 2091', '2000 Ormonde Drive, Mondeor, 2091', NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-10-03 03:26:12', '2024-10-03 03:26:12', '1970-01-01 01:00:00');
INSERT INTO `users` VALUES ('1092', 'ako', 'kos', '022451254', 'akos@gmail.com', '$2y$10$X6IX8FuU9Y4Sc74B8chgqu7WuzJVXwmqBDUdKRMF58qXbh34twfAa', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-10-03 21:23:39', '2024-10-03 21:23:39', NULL);
INSERT INTO `users` VALUES ('1093', 'dan', 'daz', '0245555555', '2023-240120512', '$2y$10$3wsSHyxNzQ.RA7TL8D4wxumkUuk35/joj6PTI6xew8k2p/nc6/oAy', 'male', NULL, '2024-10-03', 'accra', 'tema', NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-10-03 21:23:40', '2024-10-03 21:23:40', '1970-01-01 01:00:00');
INSERT INTO `users` VALUES ('1094', 'Hafiz', 'Mohd', '9149521228', 'hafizz.pvt@gmail.com', '$2y$10$dzlEAccN7VOIZV64lEb6eeWeHTxYiR7kPC00Rb8F6Ds/DaNaqG3LG', 'male', 'super-admin/guardian/670179e63c7135.957993271728149990.JPG', NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-10-05 23:09:50', '2024-10-05 23:09:50', NULL);
INSERT INTO `users` VALUES ('1095', 'Ilham', 'Malik', '9797875911', '2023-240120513', '$2y$10$TSJZi3QD7oY.uy8CcCEhvOjjmVZZgD6USpAndIWtE9eIRQR38lspa', 'male', 'super-admin/user/670179e68fc8d2.359081831728149990.jpg', '1999-07-17', 'Safapora', 'Safapora', NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-10-05 23:09:50', '2024-10-05 23:09:50', '1970-01-01 01:00:00');
INSERT INTO `users` VALUES ('1096', 'Gg', 'Gt', '5555255', 'demo@demomfok.com', '$2y$10$55PuGrJ8x61mCKZAzsi.fOMxO/5dd/xDNN/n8358RQtTZQRSp/oja', 'female', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-10-08 15:58:26', '2024-10-08 15:58:26', NULL);
INSERT INTO `users` VALUES ('1097', 'Demo', 'Demo', '552555555', '2023-240120514', '$2y$10$ZpK0DLG3OBoW5Kam9bCEtu4qAqxRZdSHZjeMJ23bwX15TMDO/mTxe', 'male', NULL, '2024-10-01', 'Gggg', 'Gtg', NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-10-08 15:58:26', '2024-10-08 15:58:26', '1970-01-01 01:00:00');
INSERT INTO `users` VALUES ('1098', 'ttt', 'mmm', '035555555', 'tt@gmail.com', '$2y$10$tKDkS8NFh0O3ziSyTRWKIOXh1DM2VUA1lG1lT0dn81EhSbxZvHAFK', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', '', '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-10-09 22:13:09', '2024-10-27 20:40:54', NULL);
INSERT INTO `users` VALUES ('1099', 'nomi', 'abbas', '030163333333', '2023-240120515', '$2y$10$PJhWxzjgtKg76p2VupJL2O9EwvTo8PzqqEbAb7cVbwyDMgtC4G0pK', 'male', NULL, '1985-02-19', 'mul', 'mul', NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-10-09 22:13:09', '2024-10-09 22:13:09', '1970-01-01 01:00:00');
INSERT INTO `users` VALUES ('1100', 'Parent', 'Demo', '0601000000', 'sd@gmail.com', '$2y$10$BC/52yMthYJJD8D0C98Yo.vhDnTaKLU4GR3BO//tYwHTo1Cy.x652', 'male', 'super-admin/guardian/6706c87d0ec840.907057161728497789.png', NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-10-09 23:46:29', '2024-10-09 23:46:29', NULL);
INSERT INTO `users` VALUES ('1101', 'Test', 'Surname', '0600000000', '2023-240120516', '$2y$10$vxM.zCpqMORGlbuXwyhft.HhaxEefjPuzr4iDJELauy9KlMc/IOcO', 'male', 'super-admin/user/6706c87d7bcae9.743315091728497789.png', '2020-10-15', 'njvdsvdpx mKFB D', 'sk.jzdlskj vl', NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-10-09 23:46:29', '2024-10-09 23:46:29', '1970-01-01 01:00:00');
INSERT INTO `users` VALUES ('1102', 'BENJAMINI', 'ATHANAS', '0684573370', 'bennycive@gmail.com', '$2y$10$oOtfiD0/pIFmHpX1bqR3yOrsXpGspGcvotcGNbXIqYpkJNfvDlvuu', 'male', 'super-admin/guardian/6708daa5e664d0.877091501728633509.png', NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-10-11 13:28:30', '2024-10-11 13:28:30', NULL);
INSERT INTO `users` VALUES ('1103', 'musa', 'joshua', '0627871360', '2023-240120517', '$2y$10$7jMnxp7jtICQluCuvuGjCeAl6BxNJbnsVGz1u.u2ymsz8E26Gc1oe', 'male', 'super-admin/user/6708daa6754d48.015702631728633510.png', '2022-02-17', 'DODODMA
DODOMA', 'DODODMA
DODOMA', NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-10-11 13:28:30', '2024-10-11 13:28:30', '1970-01-01 01:00:00');
INSERT INTO `users` VALUES ('1104', 'Noel', 'Ndhlovu', '0824851195', 'spazamedia@gmail.com', '$2y$10$w96hGFBN0n9sjl3.6.zTl.FMZgPWjeOd8F3cjjud0gp0Si48Aacy6', 'male', 'super-admin/guardian/670d9241c5fe46.315185141728942657.jpg', NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-10-15 03:20:58', '2024-10-15 03:20:58', NULL);
INSERT INTO `users` VALUES ('1105', 'Noel', 'Ndhlovu', '0824851195', '2023-240120518', '$2y$10$LGdbAC.9AsjNQSp5hqmATeddkYxIZC2UiP/1lTsOSrgcw5xq/m8TS', 'male', 'super-admin/user/670d9242344f77.756013991728942658.jpg', '2023-07-12', '87 Ormonde Drive', 'Mondeor', NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-10-15 03:20:58', '2024-10-15 03:20:58', '1970-01-01 01:00:00');
INSERT INTO `users` VALUES ('1106', 'qwas', 'wqs', '1234567890', 'wsq@gmail.com', '$2y$10$mAcc5Wj6r/8RBxig3tuZt.RW/Y4m80whTmsXBqXgHABPCu9qcqhnm', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-10-15 11:20:56', '2024-10-15 11:20:56', NULL);
INSERT INTO `users` VALUES ('1107', 'Super', 'Admin', '08436577050', '2023-240120519', '$2y$10$arIsECQycDAiLFl5N4J4nOT8DcGZSz4JUqG4knfCH7.d4R2kwrD0q', 'male', NULL, '2024-10-15', 'dxas', 'asdqa', NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-10-15 11:20:56', '2024-10-15 11:20:56', '1970-01-01 01:00:00');
INSERT INTO `users` VALUES ('1108', 'lohith', 'kumar', '9666877739', 'LOHITH@gmail.com', '$2y$10$.r6gKm1XeuUX5gv1x5m3YOhRGItN/LeSgyBhLVwDM4ldmfM9puZ0.', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-10-15 11:51:02', '2024-10-15 11:51:02', NULL);
INSERT INTO `users` VALUES ('1109', 'lohith', 'kumar', '9666877739', '2023-240120520', '$2y$10$5JkaJXrogiGhCXVlu629Y.KVdeoDB9TpP9jMk.G0ohpxwfZoMwUKq', 'male', NULL, '2020-02-14', 'sbcbdshbvhsbvh', 'sbcbdshbvhsbvh', NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-10-15 11:51:02', '2024-10-15 11:51:02', '1970-01-01 01:00:00');
INSERT INTO `users` VALUES ('1110', 'SDSSFF', 'FFSFVSXV', '2424214242', 'jananibidar@gmail.com', '$2y$10$W1ECEhJmNGNHAFYE/LIrmexgFUoKuJuwYtaLz7xAmxY56hWah1vuO', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-10-16 12:11:16', '2024-10-16 12:11:16', NULL);
INSERT INTO `users` VALUES ('1111', 'Narasappa', 'Malge', '8050061666', '2023-240120521', '$2y$10$FYjSNR/grvYXpWtdNvjWYOed5l0QuaNzl.KPi5PkngYofC.B9is7y', 'male', 'super-admin/user/670f600cb2e2b7.516029381729060876.jpg', '2024-10-15', 'CCASCF', 'AXACAZC', NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-10-16 12:11:17', '2024-10-16 12:11:17', '1970-01-01 01:00:00');
INSERT INTO `users` VALUES ('1112', 'SOHAN', 'MIAH', '01875807154', 'contact.shohan@gmail.com', '$2y$10$stUrcpm2WL.xh9sV18aMJensYiXStdaKTIlEt.y1dNfJZlS7LanTW', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-10-21 09:48:18', '2024-10-21 09:48:18', NULL);
INSERT INTO `users` VALUES ('1113', 'SOHAN', 'MIAH', '01618519679', '2023-240120522', '$2y$10$gKSe2XPWPbkeB9DUHV6kwuzxvctWAK1o05J5Lh2AWAPn.feVHqM56', 'male', NULL, '2004-11-07', 'GOPALPUR', 'Gala', NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-10-21 09:48:18', '2024-10-21 09:48:18', '1970-01-01 01:00:00');
INSERT INTO `users` VALUES ('1114', 'Babubhai', 'padmani', '9016767902', 'arpanpadamani@gmail.com', '$2y$10$E9/lrHx9VzQpY9y1UynQxO5zJd/VX0Yd2V5b9WRZaFy3CIexhOb0y', 'male', 'super-admin/guardian/672ef9352c6f18.668599891731131701.png', NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-11-09 11:25:01', '2024-11-09 11:25:01', NULL);
INSERT INTO `users` VALUES ('1115', 'Arpan', 'Padmani', '9662511313', '2023-240120523', '$2y$10$sHpUbC16yliwYJH68I3ouexWA3PO18ql3FelZwAMZiMPHcip9S2ga', 'male', 'super-admin/user/672ef935918288.949164241731131701.jpeg', '2020-08-06', 'River heaven , sarthana jakatnaka', 'River heaven , sarthana jakatnaka', NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-11-09 11:25:02', '2024-11-09 11:25:02', '1970-01-01 01:00:00');
INSERT INTO `users` VALUES ('1116', 'Usman', 'Usman', '07038314168', 'Ibrahimu098@gmail.com', '$2y$10$haFmY6j1pB01rvwpeKgcM.67JJtbaT0q53OVg4HuLT5cDRc2Gb6ui', 'male', 'super-admin/guardian/6736e4e6718fb4.016486191731650790.jpg', NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-11-15 11:36:30', '2024-11-15 11:36:30', NULL);
INSERT INTO `users` VALUES ('1117', 'Usman', 'Usman', '07038314168', '2023-240120524', '$2y$10$0lVeswhhNP5EqfpTsadjtOyK6N61mupD./dPDe/bxeMFc1b7xMTJ.', 'male', 'super-admin/user/6736e4e6ce0fc4.609936951731650790.jpg', '1998-11-15', 'No 13 Amfani Street Kuregu Wusasa Zaria', 'No Amfani Street Kuregu Wusasa Zaria', NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-11-15 11:36:31', '2024-11-15 11:36:31', '1970-01-01 01:00:00');
INSERT INTO `users` VALUES ('1118', 'Test', 'Parent', '08133117245', 'testparent@gmail.com', '$2y$10$2f/i99d5E9M2aVhDNLF5lerdrLHs7DdYM7EYI6b52SiVgsDEqo8/W', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-11-17 16:07:43', '2024-11-17 16:07:43', NULL);
INSERT INTO `users` VALUES ('1119', 'Doe', 'Test', NULL, '2023-240120525', '$2y$10$UaIZCVkjFXliHqvkY2H4nOvCYykbZG2K2OTMMWbRlpREf8snfmKni', 'male', NULL, '2022-02-16', 'Sapele Cresent', 'Sapele Cresent', NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-11-17 16:07:43', '2024-11-17 16:07:43', '1970-01-01 01:00:00');
INSERT INTO `users` VALUES ('1120', 'Ysys', 'Ysys', '234', 'gs@gsmcom.com', '$2y$10$/cas/r/eqBIhEXckevYWFeniFacr3S5vAFlF4k5mCSks/NwcZRv4K', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-11-17 18:55:40', '2024-11-17 18:55:40', NULL);
INSERT INTO `users` VALUES ('1121', 'Hwha', 'Wyys', '6464', '2023-240120526', '$2y$10$rmiOlkpg9VwdvO8zvF.7k.G4NTY9b1mxkpXJbOn.ivI34d3hyO5Y.', 'male', NULL, '2024-11-14', 'Gaga', 'Gaga', NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-11-17 18:55:41', '2024-11-17 18:55:41', '1970-01-01 01:00:00');
INSERT INTO `users` VALUES ('1122', 'demo', 'demo', '01950036169', 'demo@gmail.com', '$2y$10$DQ1uTKdWtPCTObQMrUIv6OhhT.l7Jtcf/a4/La2IVMh8os2rPswG6', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-12-01 20:30:48', '2024-12-01 20:30:48', NULL);
INSERT INTO `users` VALUES ('1123', 'demo', 'demo', '019638364784', '2023-240120527', '$2y$10$5WXaEvl6o2p3MGFSZHGs.OsfqWt/5/u4kp9hG3EboJsVuIUzeoP/y', 'male', NULL, '2019-11-07', 'demo', 'demo', NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-12-01 20:30:48', '2024-12-01 20:30:48', '1970-01-01 01:00:00');
INSERT INTO `users` VALUES ('1124', 'BENJAMINI', 'ATHANAS', '9090909090', 'praul09@gmail.com', '$2y$10$f/qZkJrnpq7zUjx31i0dQO4vKMAjX6ojq/19o/u4/hzNaEgXV8uVm', 'female', 'super-admin/guardian/675069de576366.035988991733323230.jpg', NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-12-04 20:10:30', '2024-12-04 20:10:30', NULL);
INSERT INTO `users` VALUES ('1125', 'Praphul', 'Mandewalkar', '9742795502', '2023-240120528', '$2y$10$qWkvDsGQ5hUpAKFZ3BDq/OPrwHRvRsQeGxPXF0EswMf7GZu8mydTq', 'male', 'super-admin/user/675069ded0c988.598063591733323230.png', '2024-09-26', 'qwert', 'qwert', NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-12-04 20:10:31', '2024-12-04 20:10:31', '1970-01-01 01:00:00');
INSERT INTO `users` VALUES ('1126', 'Noel', 'Ndhlovu', '0824851195', 'mikaajohnn@gmail.com', '$2y$10$ysaJpBsQZmSlkG0pXiMrwOR/eJNUiSL4iiVtfwE8gqKMQeg1uMs7m', 'male', 'super-admin/guardian/67588ae2bf7a45.960584041733855970.jpg', NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-12-11 00:09:31', '2024-12-11 00:09:31', NULL);
INSERT INTO `users` VALUES ('1127', 'Oscar', 'Ndhlovu', '0824851195', '2023-240120529', '$2y$10$NpQiGgchGlyOM2vs38UGn./MOFwN7CWOAYbr5vu2q/O6i98gPoCd.', 'male', 'super-admin/user/67588ae3cbb494.869328571733855971.jpg', '2015-12-01', '87 Ormonde Drive', '87 Ormonde Drive
Mondeor', NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-12-11 00:09:32', '2024-12-11 00:09:32', '1970-01-01 01:00:00');
INSERT INTO `users` VALUES ('1128', 'Azizbek', 'Eshmurodov', '928741313', 'azizbeksamsung9@gmail.com', '$2y$10$2CR1rJufTWHrQqVpFyo/wO.HY7IfcUG2Or.TPlNu2UFu4FxifSGrW', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-12-11 12:11:32', '2024-12-11 12:11:32', NULL);
INSERT INTO `users` VALUES ('1129', 'Azizbek', 'Eshmurodov', '928741313', '2023-240120530', '$2y$10$IJXFaCatfwYq5qkCr7CdD.UYy0IkK.54FhdTE6wQclUpbmExtrnSW', 'male', NULL, '2004-04-02', 'Khujand', 'Khujand', NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-12-11 12:11:32', '2024-12-11 12:11:32', '1970-01-01 01:00:00');
INSERT INTO `users` VALUES ('1130', 'Ibrahim', 'Hany', '01014277866', 'hema200621v@gmail.com', '$2y$10$4IFqsWGvUBBPQH.XlI0.z.Qz42MrEYkuShyIy8OALXBZ1lYW4dksa', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-12-11 19:43:02', '2024-12-15 02:54:39', NULL);
INSERT INTO `users` VALUES ('1131', 'Ibrahim', 'Hany', '01014277866', '2023-240120531', '$2y$10$UcpXi6WSN8pclQeupmUw.eHv8/FA.mKTxBJWc7Rjkt7Fx15LQANMe', 'male', NULL, '2008-12-11', 'Behira', 'Behira
Makteb aml', NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-12-11 19:43:02', '2024-12-11 19:43:02', '1970-01-01 01:00:00');
INSERT INTO `users` VALUES ('1132', 'Ibrahim', 'Hany', '01014277866', '2023-240120532', '$2y$10$Brw.GZz4lKmkb/AZv.coB.wC5UDaYjiVfxO/kawuHYNy2wzhdJs2u', 'male', NULL, '2000-02-11', 'Behira', 'Behira
Makteb aml', NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-12-15 02:54:39', '2024-12-15 02:54:39', '1970-01-01 01:00:00');
INSERT INTO `users` VALUES ('1133', 'Sergo', 'Esakia', '995591414138', 'roland.esakia@gmail.com', '$2y$10$4Gtwfn.1.NSEObVwcCME9.jAdQMW70ZZN1kdPQ46.VW7a/IQsA53q', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-12-30 21:15:56', '2024-12-30 21:18:17', NULL);
INSERT INTO `users` VALUES ('1134', 'Roland', 'Esakia', '995591414138', '2023-240120533', '$2y$10$aFPw7YGT0N2gS9j8cb43aOF9dW2Wbvwcb1JSKWnNhMdKP3UcGHT2.', 'male', 'super-admin/user/6772c0347f42c6.129506501735573556.jpg', '2010-12-12', 'Samtredia 3a', 'Samtredia 3a', NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-12-30 21:15:56', '2024-12-30 21:15:56', '1970-01-01 01:00:00');
INSERT INTO `users` VALUES ('1135', 'Roland', 'Esakia', NULL, '2023-240120534', '$2y$10$H/K8bpjitZsKDj89zHAWv.0X5rtiDD3rxS9gCNRvjYYf8p44P2oBC', 'male', 'super-admin/user/6772c0c12276b7.373478061735573697.jpg', '2010-10-10', 'samtredia 3a', 'samtredia 3a', NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2024-12-30 21:18:17', '2024-12-30 21:18:17', '1970-01-01 01:00:00');
INSERT INTO `users` VALUES ('1136', 'Pol', 'Lilo', '0088765455', 'bro@g.com', '$2y$10$mMRv2tPuzASm8Ay0kCGqKu/zQKIMZCkLbOk4mqv0KdML.RqgLdzi6', 'male', NULL, NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2025-01-06 23:10:50', '2025-01-06 23:10:50', NULL);
INSERT INTO `users` VALUES ('1137', 'Harden', 'Sky', '9900999900087', '2023-240120535', '$2y$10$GnrsB5/hdiue2GRciTt3OO1osdB3C4fvji9nK/7TXOJpYWJNMcSrm', 'male', NULL, '2025-01-06', 'Rêve 49', 'Rrr 4477 ww', NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2025-01-06 23:10:51', '2025-01-06 23:10:51', '1970-01-01 01:00:00');
INSERT INTO `users` VALUES ('1138', 'mohamed', 'elaraby', '0562354761', 'mohamedelaraby2029@gmail.com', '$2y$10$4WZ7/jEK74sF6xS649J2/uHH/K7LkD/KYLWeJ3da0Hx0Z83nNXcZ2', 'male', 'super-admin/guardian/677daa9e48ee01.682881791736288926.PNG', NULL, NULL, NULL, NULL, '1', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2025-01-08 03:58:46', '2025-01-08 03:58:46', NULL);
INSERT INTO `users` VALUES ('1139', 'mohamed', 'elaraby', '0562354761', '2023-240120536', '$2y$10$rfMEOuh892AWJ917Yr2P7uh40YV7UlFXgG2nJCpiz9BTc0.Tpk.KO', 'male', 'super-admin/user/677daa9e97a903.691288641736288926.PNG', '2023-11-14', 'elhamra-street', 'riady', NULL, '0', '0', NULL, '12', 'en', NULL, NULL, '1', NULL, NULL, '2025-01-08 03:58:46', '2025-01-08 03:58:46', '1970-01-01 01:00:00');

